// Code generated by @carbon/layout. DO NOT EDIT.
//
// Copyright IBM Corp. 2018, 2019
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--fluid-spacing-01: 0 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--fluid-spacing-02: 2vw !default;

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--fluid-spacing-03: 5vw !default;

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--fluid-spacing-04: 10vw !default;

/// @type List
/// @access public
/// @group @carbon/layout
$carbon--fluid-spacing: (
  $carbon--fluid-spacing-01,
  $carbon--fluid-spacing-02,
  $carbon--fluid-spacing-03,
  $carbon--fluid-spacing-04
);

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--fluid-spacing-01
$fluid-spacing-01: $carbon--fluid-spacing-01 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--fluid-spacing-02
$fluid-spacing-02: $carbon--fluid-spacing-02 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--fluid-spacing-03
$fluid-spacing-03: $carbon--fluid-spacing-03 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--fluid-spacing-04
$fluid-spacing-04: $carbon--fluid-spacing-04 !default;
