//
// Copyright IBM Corp. 2016, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

@import 'colors';
@import 'spacing';
@import 'theme-tokens';
@import 'functions';
@import 'motion';

/// Sets the prefix for all classes
/// @access public
/// @type String
/// @example .bx--batch-actions
$prefix: 'bx' !default;
