//
// Copyright IBM Corp. 2016, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

@import './vendor/@carbon/elements/scss/import-once/import-once';
@import './vendor/@carbon/elements/scss/type/font-face/mono';
@import './vendor/@carbon/elements/scss/type/font-face/sans';

@include exports('css--font-face') {
  @if not variable-exists('css--font-face') or $css--font-face == true {
    @include carbon--font-face-mono();
    @include carbon--font-face-sans();
    @if not variable-exists('css--plex') or $css--plex == false {
      @warn 'Usage of Helvetica font in `carbon-components` has been removed. IBM Plex will be emitted instead';
    }
  }
}
