//
// Copyright IBM Corp. 2018, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

@import 'settings';

/// Sans `@font-face`'s
/// @access public
/// @group @carbon/type
@mixin carbon--font-face-sans {
  /* cyrillic-ext */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Light Italic'), local('IBMPlexSans-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F,
      U+FE2E-FE2F;
  }
  /* cyrillic */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Light Italic'), local('IBMPlexSans-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
  }
  /* greek */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Light Italic'), local('IBMPlexSans-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0370-03FF;
  }
  /* vietnamese */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Light Italic'), local('IBMPlexSans-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Light Italic'), local('IBMPlexSans-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Light Italic'), local('IBMPlexSans-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* cyrillic-ext */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Italic'), local('IBMPlexSans-Italic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F,
      U+FE2E-FE2F;
  }
  /* cyrillic */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Italic'), local('IBMPlexSans-Italic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
  }
  /* greek */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Italic'), local('IBMPlexSans-Italic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0370-03FF;
  }
  /* vietnamese */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Italic'), local('IBMPlexSans-Italic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Italic'), local('IBMPlexSans-Italic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans Italic'), local('IBMPlexSans-Italic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* cyrillic-ext */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans SemiBold Italic'),
      local('IBMPlexSans-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F,
      U+FE2E-FE2F;
  }
  /* cyrillic */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans SemiBold Italic'),
      local('IBMPlexSans-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
  }
  /* greek */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans SemiBold Italic'),
      local('IBMPlexSans-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0370-03FF;
  }
  /* vietnamese */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans SemiBold Italic'),
      local('IBMPlexSans-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans SemiBold Italic'),
      local('IBMPlexSans-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: italic;
    src: local('IBM Plex Sans SemiBold Italic'),
      local('IBMPlexSans-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* cyrillic-ext */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans Light'), local('IBMPlexSans-Light'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F,
      U+FE2E-FE2F;
  }
  /* cyrillic */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans Light'), local('IBMPlexSans-Light'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
  }
  /* greek */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans Light'), local('IBMPlexSans-Light'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0370-03FF;
  }
  /* vietnamese */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans Light'), local('IBMPlexSans-Light'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans Light'), local('IBMPlexSans-Light'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans Light'), local('IBMPlexSans-Light'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* cyrillic-ext */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans'), local('IBMPlexSans'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F,
      U+FE2E-FE2F;
  }
  /* cyrillic */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans'), local('IBMPlexSans'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
  }
  /* greek */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans'), local('IBMPlexSans'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0370-03FF;
  }
  /* vietnamese */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans'), local('IBMPlexSans'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans'), local('IBMPlexSans'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans'), local('IBMPlexSans'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* cyrillic-ext */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans SemiBold'), local('IBMPlexSans-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F,
      U+FE2E-FE2F;
  }
  /* cyrillic */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans SemiBold'), local('IBMPlexSans-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;
  }
  /* greek */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans SemiBold'), local('IBMPlexSans-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0370-03FF;
  }
  /* vietnamese */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans SemiBold'), local('IBMPlexSans-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans SemiBold'), local('IBMPlexSans-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans';
    font-style: normal;
    src: local('IBM Plex Sans SemiBold'), local('IBMPlexSans-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2'))
        format('woff2');
    font-display: $carbon--font-display;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
}