// Code generated by @carbon/layout. DO NOT EDIT.
//
// Copyright IBM Corp. 2018, 2019
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--icon-size-01: 1rem !default;

/// @type Number
/// @access public
/// @group @carbon/layout
$carbon--icon-size-02: 1.25rem !default;

/// @type List
/// @access public
/// @group @carbon/layout
$carbon--icon-size: ($carbon--icon-size-01, $carbon--icon-size-02);

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--icon-size-01
$icon-size-01: $carbon--icon-size-01 !default;

/// @type Number
/// @access public
/// @group @carbon/layout
/// @alias carbon--icon-size-02
$icon-size-02: $carbon--icon-size-02 !default;
