//
// Copyright IBM Corp. 2018, 2018
//
// This source code is licensed under the Apache-2.0 license found in the
// LICENSE file in the root directory of this source tree.
//

@import 'settings';

/// Sans `@font-face`'s
/// @access public
/// @group @carbon/type
@mixin carbon--font-face-sans-condensed {
  /* vietnamese */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed Light Italic'),
      local('IBMPlexSansCond-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-LightItalic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169,
      U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed Light Italic'),
      local('IBMPlexSansCond-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-LightItalic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed Light Italic'),
      local('IBMPlexSansCond-LightItalic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-LightItalic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* vietnamese */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed Italic'),
      local('IBMPlexSansCond-Italic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Italic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169,
      U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed Italic'),
      local('IBMPlexSansCond-Italic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Italic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed Italic'),
      local('IBMPlexSansCond-Italic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Italic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* vietnamese */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed SemiBold Italic'),
      local('IBMPlexSansCond-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169,
      U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed SemiBold Italic'),
      local('IBMPlexSansCond-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans Condensed';
    font-style: italic;
    src: local('IBM Plex Sans Condensed SemiBold Italic'),
      local('IBMPlexSansCond-SemiBoldItalic'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-SemiBoldItalic.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* vietnamese */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed Light'), local('IBMPlexSansCond-Light'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Light.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169,
      U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed Light'), local('IBMPlexSansCond-Light'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Light.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 300;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed Light'), local('IBMPlexSansCond-Light'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Light.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* vietnamese */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed'), local('IBMPlexSansCond'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Regular.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169,
      U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed'), local('IBMPlexSansCond'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Regular.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 400;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed'), local('IBMPlexSansCond'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-Regular.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
  /* vietnamese */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed SemiBold'),
      local('IBMPlexSansCond-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-SemiBold.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169,
      U+01A0-01A1, U+01AF-01B0, U+1EA0-1EF9, U+20AB;
  }
  /* latin-ext */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed SemiBold'),
      local('IBMPlexSansCond-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-SemiBold.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB,
      U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
  }
  /* latin */
  @font-face {
    font-weight: 600;
    font-family: 'IBM Plex Sans Condensed';
    font-style: normal;
    src: local('IBM Plex Sans Condensed SemiBold'),
      local('IBMPlexSansCond-SemiBold'),
      url(static('/fonts/IBM-Plex-Sans-Condensed/fonts/complete/woff2/IBMPlexSansCondensed-SemiBold.woff2'))
        format('woff2');
    font-display: swap;
    unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,
      U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212,
      U+2215, U+FEFF, U+FFFD;
  }
}
