html,
body,
div,
span,
applet,
object,
iframe,
h1,
h2,
h3,
h4,
h5,
h6,
p,
blockquote,
pre,
a,
abbr,
acronym,
address,
big,
cite,
code,
del,
dfn,
em,
img,
ins,
kbd,
q,
s,
samp,
small,
strike,
strong,
sub,
sup,
tt,
var,
b,
u,
i,
center,
dl,
dt,
dd,
ol,
ul,
li,
fieldset,
form,
label,
legend,
table,
caption,
tbody,
tfoot,
thead,
tr,
th,
td,
article,
aside,
canvas,
details,
embed,
figure,
figcaption,
footer,
header,
hgroup,
menu,
nav,
output,
ruby,
section,
summary,
time,
mark,
audio,
video {
  margin: 0;
  padding: 0;
  font: inherit;
  font-size: 100%;
  vertical-align: baseline;
  border: 0; }

button,
select,
input,
textarea {
  font-family: inherit;
  border-radius: 0; }

input[type='text']::-ms-clear {
  display: none; }

/* HTML5 display-role reset for older browsers */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section {
  display: block; }

body {
  line-height: 1; }

sup {
  vertical-align: super; }

sub {
  vertical-align: sub; }

ol,
ul {
  list-style: none; }

blockquote,
q {
  quotes: none; }

blockquote::before,
blockquote::after,
q::before,
q::after {
  content: ''; }

table {
  border-collapse: collapse;
  border-spacing: 0; }

* {
  box-sizing: border-box; }

button {
  margin: 0; }

html {
  font-size: 100%; }

body {
  font-weight: 400;
  font-family: 'IBM Plex Sans', 'Helvetica Neue', Arial, sans-serif;
  text-rendering: optimizeLegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale; }

code {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace; }

strong {
  font-weight: 600; }

@media screen and (-ms-high-contrast: active) {
  svg {
    fill: ButtonText; } }

h1 {
  font-size: 2.625rem;
  font-weight: 300;
  line-height: 1.199;
  letter-spacing: 0; }

h2 {
  font-size: 2rem;
  font-weight: 400;
  line-height: 1.25;
  letter-spacing: 0; }

h3 {
  font-size: 1.75rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0; }

h4 {
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.4;
  letter-spacing: 0; }

h5 {
  font-size: 1rem;
  font-weight: 600;
  line-height: 1.375;
  letter-spacing: 0; }

h6 {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px; }

p {
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.5;
  letter-spacing: 0; }

a {
  color: #0062ff; }

em {
  font-style: italic; }

@keyframes skeleton {
  0% {
    right: auto;
    left: 0;
    width: 0%;
    opacity: 0.3; }
  20% {
    right: auto;
    left: 0;
    width: 100%;
    opacity: 1; }
  28% {
    right: 0;
    left: auto;
    width: 100%; }
  51% {
    right: 0;
    left: auto;
    width: 0%; }
  58% {
    right: 0;
    left: auto;
    width: 0%; }
  82% {
    right: 0;
    left: auto;
    width: 100%; }
  83% {
    right: auto;
    left: 0;
    width: 100%; }
  96% {
    right: auto;
    left: 0;
    width: 0%; }
  100% {
    right: auto;
    left: 0;
    width: 0%;
    opacity: 0.3; } }

.bx--text-truncate--end {
  display: inline-block;
  width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.bx--text-truncate--front {
  display: inline-block;
  width: 100%;
  overflow: hidden;
  direction: rtl;
  white-space: nowrap;
  text-overflow: ellipsis; }

/* cyrillic-ext */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Light Italic"), local("IBMPlexMono-LightItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Light Italic"), local("IBMPlexMono-LightItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* vietnamese */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Light Italic"), local("IBMPlexMono-LightItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Light Italic"), local("IBMPlexMono-LightItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Light Italic"), local("IBMPlexMono-LightItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Italic"), local("IBMPlexMono-Italic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Italic"), local("IBMPlexMono-Italic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* vietnamese */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Italic"), local("IBMPlexMono-Italic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Italic"), local("IBMPlexMono-Italic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono Italic"), local("IBMPlexMono-Italic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono SemiBold Italic"), local("IBMPlexMono-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono SemiBold Italic"), local("IBMPlexMono-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* vietnamese */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono SemiBold Italic"), local("IBMPlexMono-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono SemiBold Italic"), local("IBMPlexMono-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: italic;
  src: local("IBM Plex Mono SemiBold Italic"), local("IBMPlexMono-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono Light"), local("IBMPlexMono-Light"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono Light"), local("IBMPlexMono-Light"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* vietnamese */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono Light"), local("IBMPlexMono-Light"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono Light"), local("IBMPlexMono-Light"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono Light"), local("IBMPlexMono-Light"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono"), local("IBMPlexMono"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono"), local("IBMPlexMono"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* vietnamese */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono"), local("IBMPlexMono"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono"), local("IBMPlexMono"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono"), local("IBMPlexMono"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono SemiBold"), local("IBMPlexMono-SemiBold"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono SemiBold"), local("IBMPlexMono-SemiBold"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* vietnamese */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono SemiBold"), local("IBMPlexMono-SemiBold"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono SemiBold"), local("IBMPlexMono-SemiBold"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Mono';
  font-style: normal;
  src: local("IBM Plex Mono SemiBold"), local("IBMPlexMono-SemiBold"), url("/static/fonts/IBM-Plex-Mono/fonts/complete/woff2/IBMPlexMono-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Light Italic"), local("IBMPlexSans-LightItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Light Italic"), local("IBMPlexSans-LightItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* greek */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Light Italic"), local("IBMPlexSans-LightItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0370-03FF; }

/* vietnamese */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Light Italic"), local("IBMPlexSans-LightItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Light Italic"), local("IBMPlexSans-LightItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Light Italic"), local("IBMPlexSans-LightItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-LightItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Italic"), local("IBMPlexSans-Italic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Italic"), local("IBMPlexSans-Italic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* greek */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Italic"), local("IBMPlexSans-Italic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0370-03FF; }

/* vietnamese */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Italic"), local("IBMPlexSans-Italic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Italic"), local("IBMPlexSans-Italic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Italic"), local("IBMPlexSans-Italic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Italic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans SemiBold Italic"), local("IBMPlexSans-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans SemiBold Italic"), local("IBMPlexSans-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* greek */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans SemiBold Italic"), local("IBMPlexSans-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0370-03FF; }

/* vietnamese */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans SemiBold Italic"), local("IBMPlexSans-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans SemiBold Italic"), local("IBMPlexSans-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans SemiBold Italic"), local("IBMPlexSans-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBoldItalic.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans Light"), local("IBMPlexSans-Light"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans Light"), local("IBMPlexSans-Light"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* greek */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans Light"), local("IBMPlexSans-Light"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0370-03FF; }

/* vietnamese */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans Light"), local("IBMPlexSans-Light"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans Light"), local("IBMPlexSans-Light"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans Light"), local("IBMPlexSans-Light"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans"), local("IBMPlexSans"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans"), local("IBMPlexSans"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* greek */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans"), local("IBMPlexSans"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0370-03FF; }

/* vietnamese */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans"), local("IBMPlexSans"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans"), local("IBMPlexSans"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans"), local("IBMPlexSans"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* cyrillic-ext */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans SemiBold"), local("IBMPlexSans-SemiBold"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F; }

/* cyrillic */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans SemiBold"), local("IBMPlexSans-SemiBold"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }

/* greek */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans SemiBold"), local("IBMPlexSans-SemiBold"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0370-03FF; }

/* vietnamese */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans SemiBold"), local("IBMPlexSans-SemiBold"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0102-0103, U+0110-0111, U+1EA0-1EF9, U+20AB; }

/* latin-ext */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans SemiBold"), local("IBMPlexSans-SemiBold"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans SemiBold"), local("IBMPlexSans-SemiBold"), url("/static/fonts/IBM-Plex-Sans/fonts/complete/woff2/IBMPlexSans-SemiBold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

.bx--assistive-text,
.bx--visually-hidden {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.bx--body {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  color: #161616;
  line-height: 1;
  background-color: #f4f4f4; }

body {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  color: #161616;
  line-height: 1;
  background-color: #f4f4f4; }

.bx--grid {
  margin-right: auto;
  margin-left: auto;
  max-width: 99rem;
  padding-right: 1rem;
  padding-left: 1rem; }
  @media (min-width: 42rem) {
    .bx--grid {
      padding-right: 2rem;
      padding-left: 2rem; } }
  @media (min-width: 99rem) {
    .bx--grid {
      padding-right: 2.5rem;
      padding-left: 2.5rem; } }
@media (min-width: 99rem) {
  .bx--grid--full-width {
    max-width: 100%; } }

.bx--row {
  display: flex;
  flex-wrap: wrap;
  margin-right: -1rem;
  margin-left: -1rem; }

.bx--row-padding [class*='bx--col'],
.bx--col-padding {
  padding-top: 1rem;
  padding-bottom: 1rem; }

.bx--grid--condensed [class*='bx--col'] {
  padding-top: 0.03125rem;
  padding-bottom: 0.03125rem; }

.bx--col {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col, .bx--grid--condensed .bx--col {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col, .bx--grid--narrow .bx--col {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-sm-0 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-sm-0, .bx--grid--condensed .bx--col-sm-0 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-sm-0, .bx--grid--narrow .bx--col-sm-0 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-sm-1 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-sm-1, .bx--grid--condensed .bx--col-sm-1 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-sm-1, .bx--grid--narrow .bx--col-sm-1 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-sm-2 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-sm-2, .bx--grid--condensed .bx--col-sm-2 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-sm-2, .bx--grid--narrow .bx--col-sm-2 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-sm-3 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-sm-3, .bx--grid--condensed .bx--col-sm-3 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-sm-3, .bx--grid--narrow .bx--col-sm-3 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-sm-4 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-sm-4, .bx--grid--condensed .bx--col-sm-4 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-sm-4, .bx--grid--narrow .bx--col-sm-4 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-sm,
.bx--col-sm--auto {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-sm, .bx--grid--condensed .bx--col-sm, .bx--row--condensed .bx--col-sm--auto, .bx--grid--condensed .bx--col-sm--auto {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-sm, .bx--grid--narrow .bx--col-sm, .bx--row--narrow .bx--col-sm--auto, .bx--grid--narrow .bx--col-sm--auto {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col,
.bx--col-sm {
  flex-basis: 0;
  flex-grow: 1;
  max-width: 100%; }

.bx--col--auto,
.bx--col-sm--auto {
  flex: 1 0 0%;
  width: auto;
  max-width: 100%; }

.bx--col-sm-0 {
  display: none; }

.bx--col-sm-1 {
  display: block;
  flex: 0 0 25%;
  max-width: 25%; }

.bx--col-sm-2 {
  display: block;
  flex: 0 0 50%;
  max-width: 50%; }

.bx--col-sm-3 {
  display: block;
  flex: 0 0 75%;
  max-width: 75%; }

.bx--col-sm-4 {
  display: block;
  flex: 0 0 100%;
  max-width: 100%; }

.bx--offset-sm-0 {
  margin-left: 0; }

.bx--offset-sm-1 {
  margin-left: 25%; }

.bx--offset-sm-2 {
  margin-left: 50%; }

.bx--offset-sm-3 {
  margin-left: 75%; }

.bx--col-md-0 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-0, .bx--grid--condensed .bx--col-md-0 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-0, .bx--grid--narrow .bx--col-md-0 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md-1 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-1, .bx--grid--condensed .bx--col-md-1 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-1, .bx--grid--narrow .bx--col-md-1 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md-2 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-2, .bx--grid--condensed .bx--col-md-2 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-2, .bx--grid--narrow .bx--col-md-2 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md-3 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-3, .bx--grid--condensed .bx--col-md-3 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-3, .bx--grid--narrow .bx--col-md-3 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md-4 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-4, .bx--grid--condensed .bx--col-md-4 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-4, .bx--grid--narrow .bx--col-md-4 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md-5 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-5, .bx--grid--condensed .bx--col-md-5 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-5, .bx--grid--narrow .bx--col-md-5 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md-6 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-6, .bx--grid--condensed .bx--col-md-6 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-6, .bx--grid--narrow .bx--col-md-6 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md-7 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-7, .bx--grid--condensed .bx--col-md-7 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-7, .bx--grid--narrow .bx--col-md-7 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md-8 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md-8, .bx--grid--condensed .bx--col-md-8 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md-8, .bx--grid--narrow .bx--col-md-8 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-md,
.bx--col-md--auto {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-md, .bx--grid--condensed .bx--col-md, .bx--row--condensed .bx--col-md--auto, .bx--grid--condensed .bx--col-md--auto {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-md, .bx--grid--narrow .bx--col-md, .bx--row--narrow .bx--col-md--auto, .bx--grid--narrow .bx--col-md--auto {
    padding-right: 1rem;
    padding-left: 0; }

@media (min-width: 42rem) {
  .bx--col,
  .bx--col-md {
    flex-basis: 0;
    flex-grow: 1;
    max-width: 100%; }
  .bx--col--auto,
  .bx--col-md--auto {
    flex: 1 0 0%;
    width: auto;
    max-width: 100%; }
  .bx--col-md-0 {
    display: none; }
  .bx--col-md-1 {
    display: block;
    flex: 0 0 12.5%;
    max-width: 12.5%; }
  .bx--col-md-2 {
    display: block;
    flex: 0 0 25%;
    max-width: 25%; }
  .bx--col-md-3 {
    display: block;
    flex: 0 0 37.5%;
    max-width: 37.5%; }
  .bx--col-md-4 {
    display: block;
    flex: 0 0 50%;
    max-width: 50%; }
  .bx--col-md-5 {
    display: block;
    flex: 0 0 62.5%;
    max-width: 62.5%; }
  .bx--col-md-6 {
    display: block;
    flex: 0 0 75%;
    max-width: 75%; }
  .bx--col-md-7 {
    display: block;
    flex: 0 0 87.5%;
    max-width: 87.5%; }
  .bx--col-md-8 {
    display: block;
    flex: 0 0 100%;
    max-width: 100%; }
  .bx--offset-md-0 {
    margin-left: 0; }
  .bx--offset-md-1 {
    margin-left: 12.5%; }
  .bx--offset-md-2 {
    margin-left: 25%; }
  .bx--offset-md-3 {
    margin-left: 37.5%; }
  .bx--offset-md-4 {
    margin-left: 50%; }
  .bx--offset-md-5 {
    margin-left: 62.5%; }
  .bx--offset-md-6 {
    margin-left: 75%; }
  .bx--offset-md-7 {
    margin-left: 87.5%; } }

.bx--col-lg-0 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-0, .bx--grid--condensed .bx--col-lg-0 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-0, .bx--grid--narrow .bx--col-lg-0 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-1 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-1, .bx--grid--condensed .bx--col-lg-1 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-1, .bx--grid--narrow .bx--col-lg-1 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-2 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-2, .bx--grid--condensed .bx--col-lg-2 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-2, .bx--grid--narrow .bx--col-lg-2 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-3 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-3, .bx--grid--condensed .bx--col-lg-3 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-3, .bx--grid--narrow .bx--col-lg-3 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-4 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-4, .bx--grid--condensed .bx--col-lg-4 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-4, .bx--grid--narrow .bx--col-lg-4 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-5 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-5, .bx--grid--condensed .bx--col-lg-5 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-5, .bx--grid--narrow .bx--col-lg-5 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-6 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-6, .bx--grid--condensed .bx--col-lg-6 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-6, .bx--grid--narrow .bx--col-lg-6 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-7 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-7, .bx--grid--condensed .bx--col-lg-7 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-7, .bx--grid--narrow .bx--col-lg-7 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-8 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-8, .bx--grid--condensed .bx--col-lg-8 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-8, .bx--grid--narrow .bx--col-lg-8 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-9 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-9, .bx--grid--condensed .bx--col-lg-9 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-9, .bx--grid--narrow .bx--col-lg-9 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-10 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-10, .bx--grid--condensed .bx--col-lg-10 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-10, .bx--grid--narrow .bx--col-lg-10 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-11 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-11, .bx--grid--condensed .bx--col-lg-11 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-11, .bx--grid--narrow .bx--col-lg-11 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-12 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-12, .bx--grid--condensed .bx--col-lg-12 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-12, .bx--grid--narrow .bx--col-lg-12 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-13 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-13, .bx--grid--condensed .bx--col-lg-13 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-13, .bx--grid--narrow .bx--col-lg-13 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-14 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-14, .bx--grid--condensed .bx--col-lg-14 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-14, .bx--grid--narrow .bx--col-lg-14 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-15 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-15, .bx--grid--condensed .bx--col-lg-15 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-15, .bx--grid--narrow .bx--col-lg-15 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg-16 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg-16, .bx--grid--condensed .bx--col-lg-16 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg-16, .bx--grid--narrow .bx--col-lg-16 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-lg,
.bx--col-lg--auto {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-lg, .bx--grid--condensed .bx--col-lg, .bx--row--condensed .bx--col-lg--auto, .bx--grid--condensed .bx--col-lg--auto {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-lg, .bx--grid--narrow .bx--col-lg, .bx--row--narrow .bx--col-lg--auto, .bx--grid--narrow .bx--col-lg--auto {
    padding-right: 1rem;
    padding-left: 0; }

@media (min-width: 66rem) {
  .bx--col,
  .bx--col-lg {
    flex-basis: 0;
    flex-grow: 1;
    max-width: 100%; }
  .bx--col--auto,
  .bx--col-lg--auto {
    flex: 1 0 0%;
    width: auto;
    max-width: 100%; }
  .bx--col-lg-0 {
    display: none; }
  .bx--col-lg-1 {
    display: block;
    flex: 0 0 6.25%;
    max-width: 6.25%; }
  .bx--col-lg-2 {
    display: block;
    flex: 0 0 12.5%;
    max-width: 12.5%; }
  .bx--col-lg-3 {
    display: block;
    flex: 0 0 18.75%;
    max-width: 18.75%; }
  .bx--col-lg-4 {
    display: block;
    flex: 0 0 25%;
    max-width: 25%; }
  .bx--col-lg-5 {
    display: block;
    flex: 0 0 31.25%;
    max-width: 31.25%; }
  .bx--col-lg-6 {
    display: block;
    flex: 0 0 37.5%;
    max-width: 37.5%; }
  .bx--col-lg-7 {
    display: block;
    flex: 0 0 43.75%;
    max-width: 43.75%; }
  .bx--col-lg-8 {
    display: block;
    flex: 0 0 50%;
    max-width: 50%; }
  .bx--col-lg-9 {
    display: block;
    flex: 0 0 56.25%;
    max-width: 56.25%; }
  .bx--col-lg-10 {
    display: block;
    flex: 0 0 62.5%;
    max-width: 62.5%; }
  .bx--col-lg-11 {
    display: block;
    flex: 0 0 68.75%;
    max-width: 68.75%; }
  .bx--col-lg-12 {
    display: block;
    flex: 0 0 75%;
    max-width: 75%; }
  .bx--col-lg-13 {
    display: block;
    flex: 0 0 81.25%;
    max-width: 81.25%; }
  .bx--col-lg-14 {
    display: block;
    flex: 0 0 87.5%;
    max-width: 87.5%; }
  .bx--col-lg-15 {
    display: block;
    flex: 0 0 93.75%;
    max-width: 93.75%; }
  .bx--col-lg-16 {
    display: block;
    flex: 0 0 100%;
    max-width: 100%; }
  .bx--offset-lg-0 {
    margin-left: 0; }
  .bx--offset-lg-1 {
    margin-left: 6.25%; }
  .bx--offset-lg-2 {
    margin-left: 12.5%; }
  .bx--offset-lg-3 {
    margin-left: 18.75%; }
  .bx--offset-lg-4 {
    margin-left: 25%; }
  .bx--offset-lg-5 {
    margin-left: 31.25%; }
  .bx--offset-lg-6 {
    margin-left: 37.5%; }
  .bx--offset-lg-7 {
    margin-left: 43.75%; }
  .bx--offset-lg-8 {
    margin-left: 50%; }
  .bx--offset-lg-9 {
    margin-left: 56.25%; }
  .bx--offset-lg-10 {
    margin-left: 62.5%; }
  .bx--offset-lg-11 {
    margin-left: 68.75%; }
  .bx--offset-lg-12 {
    margin-left: 75%; }
  .bx--offset-lg-13 {
    margin-left: 81.25%; }
  .bx--offset-lg-14 {
    margin-left: 87.5%; }
  .bx--offset-lg-15 {
    margin-left: 93.75%; } }

.bx--col-xlg-0 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-0, .bx--grid--condensed .bx--col-xlg-0 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-0, .bx--grid--narrow .bx--col-xlg-0 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-1 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-1, .bx--grid--condensed .bx--col-xlg-1 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-1, .bx--grid--narrow .bx--col-xlg-1 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-2 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-2, .bx--grid--condensed .bx--col-xlg-2 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-2, .bx--grid--narrow .bx--col-xlg-2 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-3 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-3, .bx--grid--condensed .bx--col-xlg-3 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-3, .bx--grid--narrow .bx--col-xlg-3 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-4 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-4, .bx--grid--condensed .bx--col-xlg-4 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-4, .bx--grid--narrow .bx--col-xlg-4 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-5 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-5, .bx--grid--condensed .bx--col-xlg-5 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-5, .bx--grid--narrow .bx--col-xlg-5 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-6 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-6, .bx--grid--condensed .bx--col-xlg-6 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-6, .bx--grid--narrow .bx--col-xlg-6 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-7 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-7, .bx--grid--condensed .bx--col-xlg-7 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-7, .bx--grid--narrow .bx--col-xlg-7 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-8 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-8, .bx--grid--condensed .bx--col-xlg-8 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-8, .bx--grid--narrow .bx--col-xlg-8 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-9 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-9, .bx--grid--condensed .bx--col-xlg-9 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-9, .bx--grid--narrow .bx--col-xlg-9 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-10 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-10, .bx--grid--condensed .bx--col-xlg-10 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-10, .bx--grid--narrow .bx--col-xlg-10 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-11 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-11, .bx--grid--condensed .bx--col-xlg-11 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-11, .bx--grid--narrow .bx--col-xlg-11 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-12 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-12, .bx--grid--condensed .bx--col-xlg-12 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-12, .bx--grid--narrow .bx--col-xlg-12 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-13 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-13, .bx--grid--condensed .bx--col-xlg-13 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-13, .bx--grid--narrow .bx--col-xlg-13 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-14 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-14, .bx--grid--condensed .bx--col-xlg-14 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-14, .bx--grid--narrow .bx--col-xlg-14 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-15 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-15, .bx--grid--condensed .bx--col-xlg-15 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-15, .bx--grid--narrow .bx--col-xlg-15 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg-16 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg-16, .bx--grid--condensed .bx--col-xlg-16 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg-16, .bx--grid--narrow .bx--col-xlg-16 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-xlg,
.bx--col-xlg--auto {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-xlg, .bx--grid--condensed .bx--col-xlg, .bx--row--condensed .bx--col-xlg--auto, .bx--grid--condensed .bx--col-xlg--auto {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-xlg, .bx--grid--narrow .bx--col-xlg, .bx--row--narrow .bx--col-xlg--auto, .bx--grid--narrow .bx--col-xlg--auto {
    padding-right: 1rem;
    padding-left: 0; }

@media (min-width: 82rem) {
  .bx--col,
  .bx--col-xlg {
    flex-basis: 0;
    flex-grow: 1;
    max-width: 100%; }
  .bx--col--auto,
  .bx--col-xlg--auto {
    flex: 1 0 0%;
    width: auto;
    max-width: 100%; }
  .bx--col-xlg-0 {
    display: none; }
  .bx--col-xlg-1 {
    display: block;
    flex: 0 0 6.25%;
    max-width: 6.25%; }
  .bx--col-xlg-2 {
    display: block;
    flex: 0 0 12.5%;
    max-width: 12.5%; }
  .bx--col-xlg-3 {
    display: block;
    flex: 0 0 18.75%;
    max-width: 18.75%; }
  .bx--col-xlg-4 {
    display: block;
    flex: 0 0 25%;
    max-width: 25%; }
  .bx--col-xlg-5 {
    display: block;
    flex: 0 0 31.25%;
    max-width: 31.25%; }
  .bx--col-xlg-6 {
    display: block;
    flex: 0 0 37.5%;
    max-width: 37.5%; }
  .bx--col-xlg-7 {
    display: block;
    flex: 0 0 43.75%;
    max-width: 43.75%; }
  .bx--col-xlg-8 {
    display: block;
    flex: 0 0 50%;
    max-width: 50%; }
  .bx--col-xlg-9 {
    display: block;
    flex: 0 0 56.25%;
    max-width: 56.25%; }
  .bx--col-xlg-10 {
    display: block;
    flex: 0 0 62.5%;
    max-width: 62.5%; }
  .bx--col-xlg-11 {
    display: block;
    flex: 0 0 68.75%;
    max-width: 68.75%; }
  .bx--col-xlg-12 {
    display: block;
    flex: 0 0 75%;
    max-width: 75%; }
  .bx--col-xlg-13 {
    display: block;
    flex: 0 0 81.25%;
    max-width: 81.25%; }
  .bx--col-xlg-14 {
    display: block;
    flex: 0 0 87.5%;
    max-width: 87.5%; }
  .bx--col-xlg-15 {
    display: block;
    flex: 0 0 93.75%;
    max-width: 93.75%; }
  .bx--col-xlg-16 {
    display: block;
    flex: 0 0 100%;
    max-width: 100%; }
  .bx--offset-xlg-0 {
    margin-left: 0; }
  .bx--offset-xlg-1 {
    margin-left: 6.25%; }
  .bx--offset-xlg-2 {
    margin-left: 12.5%; }
  .bx--offset-xlg-3 {
    margin-left: 18.75%; }
  .bx--offset-xlg-4 {
    margin-left: 25%; }
  .bx--offset-xlg-5 {
    margin-left: 31.25%; }
  .bx--offset-xlg-6 {
    margin-left: 37.5%; }
  .bx--offset-xlg-7 {
    margin-left: 43.75%; }
  .bx--offset-xlg-8 {
    margin-left: 50%; }
  .bx--offset-xlg-9 {
    margin-left: 56.25%; }
  .bx--offset-xlg-10 {
    margin-left: 62.5%; }
  .bx--offset-xlg-11 {
    margin-left: 68.75%; }
  .bx--offset-xlg-12 {
    margin-left: 75%; }
  .bx--offset-xlg-13 {
    margin-left: 81.25%; }
  .bx--offset-xlg-14 {
    margin-left: 87.5%; }
  .bx--offset-xlg-15 {
    margin-left: 93.75%; } }

.bx--col-max-0 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-0, .bx--grid--condensed .bx--col-max-0 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-0, .bx--grid--narrow .bx--col-max-0 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-1 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-1, .bx--grid--condensed .bx--col-max-1 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-1, .bx--grid--narrow .bx--col-max-1 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-2 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-2, .bx--grid--condensed .bx--col-max-2 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-2, .bx--grid--narrow .bx--col-max-2 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-3 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-3, .bx--grid--condensed .bx--col-max-3 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-3, .bx--grid--narrow .bx--col-max-3 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-4 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-4, .bx--grid--condensed .bx--col-max-4 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-4, .bx--grid--narrow .bx--col-max-4 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-5 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-5, .bx--grid--condensed .bx--col-max-5 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-5, .bx--grid--narrow .bx--col-max-5 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-6 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-6, .bx--grid--condensed .bx--col-max-6 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-6, .bx--grid--narrow .bx--col-max-6 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-7 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-7, .bx--grid--condensed .bx--col-max-7 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-7, .bx--grid--narrow .bx--col-max-7 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-8 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-8, .bx--grid--condensed .bx--col-max-8 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-8, .bx--grid--narrow .bx--col-max-8 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-9 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-9, .bx--grid--condensed .bx--col-max-9 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-9, .bx--grid--narrow .bx--col-max-9 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-10 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-10, .bx--grid--condensed .bx--col-max-10 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-10, .bx--grid--narrow .bx--col-max-10 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-11 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-11, .bx--grid--condensed .bx--col-max-11 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-11, .bx--grid--narrow .bx--col-max-11 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-12 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-12, .bx--grid--condensed .bx--col-max-12 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-12, .bx--grid--narrow .bx--col-max-12 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-13 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-13, .bx--grid--condensed .bx--col-max-13 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-13, .bx--grid--narrow .bx--col-max-13 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-14 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-14, .bx--grid--condensed .bx--col-max-14 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-14, .bx--grid--narrow .bx--col-max-14 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-15 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-15, .bx--grid--condensed .bx--col-max-15 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-15, .bx--grid--narrow .bx--col-max-15 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max-16 {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max-16, .bx--grid--condensed .bx--col-max-16 {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max-16, .bx--grid--narrow .bx--col-max-16 {
    padding-right: 1rem;
    padding-left: 0; }

.bx--col-max,
.bx--col-max--auto {
  width: 100%;
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--row--condensed .bx--col-max, .bx--grid--condensed .bx--col-max, .bx--row--condensed .bx--col-max--auto, .bx--grid--condensed .bx--col-max--auto {
    padding-right: 0.03125rem;
    padding-left: 0.03125rem; }
  .bx--row--narrow .bx--col-max, .bx--grid--narrow .bx--col-max, .bx--row--narrow .bx--col-max--auto, .bx--grid--narrow .bx--col-max--auto {
    padding-right: 1rem;
    padding-left: 0; }

@media (min-width: 99rem) {
  .bx--col,
  .bx--col-max {
    flex-basis: 0;
    flex-grow: 1;
    max-width: 100%; }
  .bx--col--auto,
  .bx--col-max--auto {
    flex: 1 0 0%;
    width: auto;
    max-width: 100%; }
  .bx--col-max-0 {
    display: none; }
  .bx--col-max-1 {
    display: block;
    flex: 0 0 6.25%;
    max-width: 6.25%; }
  .bx--col-max-2 {
    display: block;
    flex: 0 0 12.5%;
    max-width: 12.5%; }
  .bx--col-max-3 {
    display: block;
    flex: 0 0 18.75%;
    max-width: 18.75%; }
  .bx--col-max-4 {
    display: block;
    flex: 0 0 25%;
    max-width: 25%; }
  .bx--col-max-5 {
    display: block;
    flex: 0 0 31.25%;
    max-width: 31.25%; }
  .bx--col-max-6 {
    display: block;
    flex: 0 0 37.5%;
    max-width: 37.5%; }
  .bx--col-max-7 {
    display: block;
    flex: 0 0 43.75%;
    max-width: 43.75%; }
  .bx--col-max-8 {
    display: block;
    flex: 0 0 50%;
    max-width: 50%; }
  .bx--col-max-9 {
    display: block;
    flex: 0 0 56.25%;
    max-width: 56.25%; }
  .bx--col-max-10 {
    display: block;
    flex: 0 0 62.5%;
    max-width: 62.5%; }
  .bx--col-max-11 {
    display: block;
    flex: 0 0 68.75%;
    max-width: 68.75%; }
  .bx--col-max-12 {
    display: block;
    flex: 0 0 75%;
    max-width: 75%; }
  .bx--col-max-13 {
    display: block;
    flex: 0 0 81.25%;
    max-width: 81.25%; }
  .bx--col-max-14 {
    display: block;
    flex: 0 0 87.5%;
    max-width: 87.5%; }
  .bx--col-max-15 {
    display: block;
    flex: 0 0 93.75%;
    max-width: 93.75%; }
  .bx--col-max-16 {
    display: block;
    flex: 0 0 100%;
    max-width: 100%; }
  .bx--offset-max-0 {
    margin-left: 0; }
  .bx--offset-max-1 {
    margin-left: 6.25%; }
  .bx--offset-max-2 {
    margin-left: 12.5%; }
  .bx--offset-max-3 {
    margin-left: 18.75%; }
  .bx--offset-max-4 {
    margin-left: 25%; }
  .bx--offset-max-5 {
    margin-left: 31.25%; }
  .bx--offset-max-6 {
    margin-left: 37.5%; }
  .bx--offset-max-7 {
    margin-left: 43.75%; }
  .bx--offset-max-8 {
    margin-left: 50%; }
  .bx--offset-max-9 {
    margin-left: 56.25%; }
  .bx--offset-max-10 {
    margin-left: 62.5%; }
  .bx--offset-max-11 {
    margin-left: 68.75%; }
  .bx--offset-max-12 {
    margin-left: 75%; }
  .bx--offset-max-13 {
    margin-left: 81.25%; }
  .bx--offset-max-14 {
    margin-left: 87.5%; }
  .bx--offset-max-15 {
    margin-left: 93.75%; } }

.bx--no-gutter,
.bx--row.bx--no-gutter [class*='bx--col'] {
  padding-right: 0;
  padding-left: 0; }

.bx--no-gutter--start,
.bx--row.bx--no-gutter--start [class*='bx--col'] {
  padding-left: 0; }

.bx--no-gutter--end,
.bx--row.bx--no-gutter--end [class*='bx--col'] {
  padding-right: 0; }

.bx--no-gutter--left,
.bx--row.bx--no-gutter--left [class*='bx--col'] {
  padding-left: 0; }

.bx--no-gutter--right,
.bx--row.bx--no-gutter--right [class*='bx--col'] {
  padding-right: 0; }

.bx--hang--start {
  padding-left: 1rem; }

.bx--hang--end {
  padding-right: 1rem; }

.bx--hang--left {
  padding-left: 1rem; }

.bx--hang--right {
  padding-right: 1rem; }

.bx--aspect-ratio {
  position: relative; }

.bx--aspect-ratio::before {
  float: left;
  width: 1px;
  height: 0;
  margin-left: -1px;
  content: ''; }

.bx--aspect-ratio::after {
  display: table;
  clear: both;
  content: ''; }

.bx--aspect-ratio--16x9::before {
  padding-top: 56.25%; }

.bx--aspect-ratio--9x16::before {
  padding-top: 177.77778%; }

.bx--aspect-ratio--2x1::before {
  padding-top: 50%; }

.bx--aspect-ratio--1x2::before {
  padding-top: 200%; }

.bx--aspect-ratio--4x3::before {
  padding-top: 75%; }

.bx--aspect-ratio--3x4::before {
  padding-top: 133.33333%; }

.bx--aspect-ratio--1x1::before {
  padding-top: 100%; }

.bx--aspect-ratio--object {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%; }

.bx--btn-set {
  display: flex; }

.bx--btn-set--stacked {
  flex-direction: column; }

.bx--btn-set .bx--btn {
  width: 100%;
  max-width: 12.25rem; }
  .bx--btn-set .bx--btn:not(:focus) {
    box-shadow: -0.0625rem 0 0 0 #e0e0e0; }
  .bx--btn-set .bx--btn:first-of-type:not(:focus) {
    box-shadow: inherit; }

.bx--btn-set .bx--btn:focus + .bx--btn {
  box-shadow: inherit; }

.bx--btn-set--stacked .bx--btn:not(:focus) {
  box-shadow: 0 -0.0625rem 0 0 #e0e0e0; }

.bx--btn-set--stacked .bx--btn:first-of-type:not(:focus) {
  box-shadow: inherit; }

.bx--btn-set .bx--btn.bx--btn--disabled {
  box-shadow: -0.0625rem 0 0 0 #8d8d8d; }
  .bx--btn-set .bx--btn.bx--btn--disabled:first-of-type {
    box-shadow: none; }

.bx--btn-set--stacked .bx--btn.bx--btn--disabled {
  box-shadow: 0 -0.0625rem 0 0 #8d8d8d; }
  .bx--btn-set--stacked .bx--btn.bx--btn--disabled:first-of-type {
    box-shadow: none; }

.bx--btn {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  position: relative;
  display: inline-flex;
  flex-shrink: 0;
  align-items: center;
  justify-content: space-between;
  max-width: 20rem;
  min-height: 3rem;
  margin: 0;
  padding: calc(0.875rem - 3px) 63px calc(0.875rem - 3px) 15px;
  text-align: left;
  text-decoration: none;
  vertical-align: top;
  border-radius: 0;
  outline: none;
  cursor: pointer;
  transition: all 70ms cubic-bezier(0, 0, 0.38, 0.9); }
  .bx--btn:disabled, .bx--btn:hover:disabled, .bx--btn:focus:disabled, .bx--btn.bx--btn--disabled, .bx--btn.bx--btn--disabled:hover, .bx--btn.bx--btn--disabled:focus {
    color: #8d8d8d;
    background: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none;
    cursor: not-allowed; }
  .bx--btn .bx--btn__icon {
    position: absolute;
    right: 1rem;
    flex-shrink: 0;
    width: 1rem;
    height: 1rem; }

.bx--btn::-moz-focus-inner {
  padding: 0;
  border: 0; }

.bx--btn--primary {
  color: #ffffff;
  background-color: #0f62fe;
  border-color: transparent;
  border-style: solid;
  border-width: 1px; }
  .bx--btn--primary:hover {
    background-color: #0353e9; }
  .bx--btn--primary:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #f4f4f4; }
  .bx--btn--primary:disabled:hover, .bx--btn--primary:disabled:focus, .bx--btn--primary:hover.bx--btn--disabled, .bx--btn--primary:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .bx--btn--primary:active {
    background-color: #002d9c; }
  .bx--btn--primary .bx--btn__icon,
  .bx--btn--primary .bx--btn__icon path {
    fill: currentColor; }
  .bx--btn--primary:hover {
    color: #ffffff; }

.bx--btn--secondary {
  color: #ffffff;
  background-color: #393939;
  border-color: transparent;
  border-style: solid;
  border-width: 1px; }
  .bx--btn--secondary:hover {
    background-color: #4c4c4c; }
  .bx--btn--secondary:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #f4f4f4; }
  .bx--btn--secondary:disabled:hover, .bx--btn--secondary:disabled:focus, .bx--btn--secondary:hover.bx--btn--disabled, .bx--btn--secondary:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .bx--btn--secondary:active {
    background-color: #6f6f6f; }
  .bx--btn--secondary .bx--btn__icon,
  .bx--btn--secondary .bx--btn__icon path {
    fill: currentColor; }
  .bx--btn--secondary:hover, .bx--btn--secondary:focus {
    color: #ffffff; }

.bx--btn--tertiary {
  color: #0f62fe;
  background-color: transparent;
  border-color: #0f62fe;
  border-style: solid;
  border-width: 1px; }
  .bx--btn--tertiary:hover {
    background-color: #0353e9; }
  .bx--btn--tertiary:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #f4f4f4; }
  .bx--btn--tertiary:disabled:hover, .bx--btn--tertiary:disabled:focus, .bx--btn--tertiary:hover.bx--btn--disabled, .bx--btn--tertiary:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .bx--btn--tertiary:active {
    background-color: #002d9c; }
  .bx--btn--tertiary .bx--btn__icon,
  .bx--btn--tertiary .bx--btn__icon path {
    fill: currentColor; }
  .bx--btn--tertiary:hover {
    color: #ffffff; }
  .bx--btn--tertiary:focus {
    color: #ffffff;
    background-color: #0f62fe; }
  .bx--btn--tertiary:active {
    border-color: transparent; }
  .bx--btn--tertiary:disabled, .bx--btn--tertiary:hover:disabled, .bx--btn--tertiary:focus:disabled, .bx--btn--tertiary.bx--btn--disabled, .bx--btn--tertiary.bx--btn--disabled:hover, .bx--btn--tertiary.bx--btn--disabled:focus {
    color: #c6c6c6;
    background: transparent;
    outline: none; }

.bx--btn--ghost {
  color: #0f62fe;
  background-color: transparent;
  border-color: transparent;
  border-style: solid;
  border-width: 1px;
  padding: calc(0.875rem - 3px) 12px; }
  .bx--btn--ghost:hover {
    background-color: #e5e5e5; }
  .bx--btn--ghost:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #f4f4f4; }
  .bx--btn--ghost:disabled:hover, .bx--btn--ghost:disabled:focus, .bx--btn--ghost:hover.bx--btn--disabled, .bx--btn--ghost:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .bx--btn--ghost:active {
    background-color: #c6c6c6; }
  .bx--btn--ghost .bx--btn__icon,
  .bx--btn--ghost .bx--btn__icon path {
    fill: currentColor; }
  .bx--btn--ghost .bx--btn__icon {
    position: static;
    margin-left: 0.5rem; }
  .bx--btn--ghost:hover, .bx--btn--ghost:active {
    color: #0043ce; }
  .bx--btn--ghost:active {
    background-color: #c6c6c6; }
  .bx--btn--ghost:disabled, .bx--btn--ghost:hover:disabled, .bx--btn--ghost:focus:disabled, .bx--btn--ghost.bx--btn--disabled, .bx--btn--ghost.bx--btn--disabled:hover, .bx--btn--ghost.bx--btn--disabled:focus {
    color: #c6c6c6;
    background: transparent;
    border-color: transparent;
    outline: none; }
  .bx--btn--ghost.bx--btn--sm {
    padding: calc(0.375rem - 3px) 12px; }
  .bx--btn--ghost.bx--btn--field {
    padding: calc(0.675rem - 3px) 12px; }

.bx--btn.bx--btn--icon-only.bx--tooltip__trigger {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus {
    outline: 1px solid #0f62fe; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus {
    outline: 1px solid transparent; }
    .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus svg {
      outline: 1px solid #0f62fe; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
        display: inline-block; } }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--a11y::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--a11y::after {
    transition: none; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
      .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
        width: 13rem; } }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after {
    content: attr(aria-label); }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--a11y::after {
    content: none; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible::after, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover::after, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible + .bx--assistive-text, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover + .bx--assistive-text, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible + .bx--assistive-text, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover + .bx--assistive-text, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover.bx--tooltip--a11y::before, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus .bx--assistive-text,
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus + .bx--assistive-text, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--hidden .bx--assistive-text, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .bx--btn.bx--btn--icon-only.bx--tooltip__trigger svg, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover svg, .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus svg {
    fill: currentColor; }

.bx--btn.bx--btn--icon-only.bx--btn--ghost:focus svg {
  fill: #161616; }

.bx--btn.bx--btn--icon-only.bx--btn--ghost:hover svg {
  fill: #161616; }

.bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus {
  border-color: #0f62fe; }

.bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus
svg {
  outline-color: transparent; }

.bx--btn--icon-only--top {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--btn--icon-only--top:focus {
    outline: 1px solid #0f62fe; }
  .bx--btn--icon-only--top:focus {
    outline: 1px solid transparent; }
    .bx--btn--icon-only--top:focus svg {
      outline: 1px solid #0f62fe; }
  .bx--btn--icon-only--top::before, .bx--btn--icon-only--top::after,
  .bx--btn--icon-only--top .bx--assistive-text,
  .bx--btn--icon-only--top + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--btn--icon-only--top::before, .bx--btn--icon-only--top::after,
      .bx--btn--icon-only--top .bx--assistive-text,
      .bx--btn--icon-only--top + .bx--assistive-text {
        display: inline-block; } }
  .bx--btn--icon-only--top::before, .bx--btn--icon-only--top::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--btn--icon-only--top.bx--tooltip--a11y::before, .bx--btn--icon-only--top.bx--tooltip--a11y::after {
    transition: none; }
  .bx--btn--icon-only--top::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .bx--btn--icon-only--top .bx--assistive-text,
  .bx--btn--icon-only--top + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .bx--btn--icon-only--top::after,
  .bx--btn--icon-only--top .bx--assistive-text,
  .bx--btn--icon-only--top + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--btn--icon-only--top::after,
      .bx--btn--icon-only--top .bx--assistive-text,
      .bx--btn--icon-only--top + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--btn--icon-only--top::after,
      .bx--btn--icon-only--top .bx--assistive-text,
      .bx--btn--icon-only--top + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--btn--icon-only--top::after,
      .bx--btn--icon-only--top .bx--assistive-text,
      .bx--btn--icon-only--top + .bx--assistive-text {
        width: 13rem; } }
  .bx--btn--icon-only--top::after {
    content: attr(aria-label); }
  .bx--btn--icon-only--top.bx--tooltip--a11y::after {
    content: none; }
  .bx--btn--icon-only--top.bx--tooltip--visible::before, .bx--btn--icon-only--top.bx--tooltip--visible::after, .bx--btn--icon-only--top:hover::before, .bx--btn--icon-only--top:hover::after, .bx--btn--icon-only--top:focus::before, .bx--btn--icon-only--top:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .bx--btn--icon-only--top.bx--tooltip--visible .bx--assistive-text,
  .bx--btn--icon-only--top.bx--tooltip--visible + .bx--assistive-text, .bx--btn--icon-only--top:hover .bx--assistive-text,
  .bx--btn--icon-only--top:hover + .bx--assistive-text, .bx--btn--icon-only--top:focus .bx--assistive-text,
  .bx--btn--icon-only--top:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .bx--btn--icon-only--top.bx--tooltip--visible .bx--assistive-text,
  .bx--btn--icon-only--top.bx--tooltip--visible + .bx--assistive-text, .bx--btn--icon-only--top.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--btn--icon-only--top:hover .bx--assistive-text,
  .bx--btn--icon-only--top:hover + .bx--assistive-text, .bx--btn--icon-only--top:hover.bx--tooltip--a11y::before, .bx--btn--icon-only--top:focus .bx--assistive-text,
  .bx--btn--icon-only--top:focus + .bx--assistive-text, .bx--btn--icon-only--top:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--btn--icon-only--top.bx--tooltip--hidden .bx--assistive-text, .bx--btn--icon-only--top.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .bx--btn--icon-only--top.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .bx--btn--icon-only--top::before, .bx--btn--icon-only--top::after,
  .bx--btn--icon-only--top .bx--assistive-text,
  .bx--btn--icon-only--top + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--btn--icon-only--top::before {
    top: -0.5rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--btn--icon-only--top::after,
  .bx--btn--icon-only--top .bx--assistive-text,
  .bx--btn--icon-only--top + .bx--assistive-text {
    top: -0.8125rem;
    left: 50%;
    transform: translate(-50%, -100%); }

.bx--btn--icon-only--bottom::before, .bx--btn--icon-only--bottom::after,
.bx--btn--icon-only--bottom .bx--assistive-text,
.bx--btn--icon-only--bottom + .bx--assistive-text {
  bottom: 0;
  left: 50%; }

.bx--btn--icon-only--bottom::before {
  bottom: -0.5rem;
  border-color: transparent transparent #393939 transparent;
  border-width: 0 0.25rem 0.3125rem 0.25rem;
  transform: translate(-50%, 100%); }

.bx--btn--icon-only--bottom::after,
.bx--btn--icon-only--bottom .bx--assistive-text,
.bx--btn--icon-only--bottom + .bx--assistive-text {
  bottom: -0.8125rem;
  transform: translate(-50%, 100%); }

.bx--btn--icon-only {
  padding-right: 0.9375rem;
  padding-left: 0.9375rem; }
  .bx--btn--icon-only .bx--btn__icon {
    position: static; }
  .bx--btn--icon-only.bx--btn--ghost .bx--btn__icon {
    margin: 0; }

.bx--btn path[data-icon-path='inner-path'] {
  fill: none; }

.bx--btn.bx--btn--icon-only.bx--btn--ghost
.bx--btn__icon,
.bx--btn.bx--btn--icon-only.bx--btn--ghost:hover
.bx--btn__icon {
  fill: #161616; }

.bx--btn--ghost.bx--btn--icon-only
.bx--btn__icon
path,
.bx--btn--ghost.bx--btn--icon-only .bx--btn__icon {
  fill: #161616; }

.bx--btn--ghost.bx--btn--icon-only[disabled]
.bx--btn__icon
path,
.bx--btn--ghost.bx--btn--icon-only[disabled]
.bx--btn__icon,
.bx--btn.bx--btn--icon-only.bx--btn--ghost[disabled]:hover
.bx--btn__icon {
  fill: #c6c6c6; }

.bx--btn--ghost.bx--btn--icon-only[disabled] {
  cursor: not-allowed; }

.bx--btn--field.bx--btn--icon-only {
  padding-right: 0.6875rem;
  padding-left: 0.6875rem; }

.bx--btn--sm.bx--btn--icon-only {
  padding-right: 0.4375rem;
  padding-left: 0.4375rem; }

.bx--btn--danger {
  color: #ffffff;
  background-color: #da1e28;
  border-color: transparent;
  border-style: solid;
  border-width: 1px; }
  .bx--btn--danger:hover {
    background-color: #b81921; }
  .bx--btn--danger:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #f4f4f4; }
  .bx--btn--danger:disabled:hover, .bx--btn--danger:disabled:focus, .bx--btn--danger:hover.bx--btn--disabled, .bx--btn--danger:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .bx--btn--danger:active {
    background-color: #750e13; }
  .bx--btn--danger .bx--btn__icon,
  .bx--btn--danger .bx--btn__icon path {
    fill: currentColor; }
  .bx--btn--danger:hover {
    color: #ffffff; }

.bx--btn--sm {
  min-height: 2rem;
  padding: calc(0.375rem - 3px) 60px calc(0.375rem - 3px) 12px; }

.bx--btn--field {
  min-height: 2.5rem;
  padding: calc(0.675rem - 3px) 60px calc(0.675rem - 3px) 12px; }

.bx--btn.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 9.375rem; }
  .bx--btn.bx--skeleton:hover, .bx--btn.bx--skeleton:focus, .bx--btn.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--btn.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--btn.bx--skeleton::before {
        animation: none; } }
@keyframes hide-feedback {
  0% {
    visibility: inherit;
    opacity: 1; }
  100% {
    visibility: hidden;
    opacity: 0; } }

@keyframes show-feedback {
  0% {
    visibility: hidden;
    opacity: 0; }
  100% {
    visibility: inherit;
    opacity: 1; } }

.bx--btn--copy {
  position: relative;
  overflow: visible; }
  .bx--btn--copy .bx--btn__icon {
    margin-left: 0.3125rem; }

.bx--btn--copy__feedback {
  position: absolute;
  top: 1.2rem;
  left: 50%;
  display: none; }
  .bx--btn--copy__feedback:focus {
    border: 2px solid #da1e28; }
  .bx--btn--copy__feedback::before {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px;
    top: 1.1rem;
    z-index: 2;
    padding: 0.25rem;
    color: #ffffff;
    font-weight: 400;
    white-space: nowrap;
    border-radius: 4px;
    transform: translateX(-50%);
    content: attr(data-feedback);
    pointer-events: none; }
  .bx--btn--copy__feedback::after {
    top: 0.85rem;
    left: -0.3rem;
    z-index: 1;
    width: 0.6rem;
    height: 0.6rem;
    border-right: 1px solid #393939;
    border-bottom: 1px solid #393939;
    transform: rotate(-135deg);
    content: ''; }
  .bx--btn--copy__feedback::before, .bx--btn--copy__feedback::after {
    position: absolute;
    display: block;
    background: #393939; }
  .bx--btn--copy__feedback--displayed {
    display: inline-flex; }

.bx--copy-btn {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2.5rem;
  height: 2.5rem;
  padding: 0;
  background-color: #ffffff;
  border: none;
  cursor: pointer; }
  .bx--copy-btn:hover {
    background-color: #e5e5e5; }
  .bx--copy-btn::before {
    position: absolute;
    z-index: 6000;
    width: 0;
    height: 0;
    border-style: solid;
    content: '';
    display: none; }
  .bx--copy-btn .bx--copy-btn__feedback {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px;
    display: none;
    box-sizing: content-box;
    margin: auto;
    overflow: visible;
    clip: auto; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--copy-btn .bx--copy-btn__feedback {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--copy-btn .bx--copy-btn__feedback {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--copy-btn .bx--copy-btn__feedback {
        width: 13rem; } }
  .bx--copy-btn::before, .bx--copy-btn::after,
  .bx--copy-btn .bx--assistive-text,
  .bx--copy-btn + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--copy-btn::before {
    bottom: -0.5rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--copy-btn::after,
  .bx--copy-btn .bx--assistive-text,
  .bx--copy-btn + .bx--assistive-text {
    bottom: -0.8125rem;
    transform: translate(-50%, 100%); }
  .bx--copy-btn:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    outline-color: #0f62fe; }
  .bx--copy-btn.bx--copy-btn--animating::before, .bx--copy-btn.bx--copy-btn--animating .bx--copy-btn__feedback {
    display: block; }
  .bx--copy-btn.bx--copy-btn--animating.bx--copy-btn--fade-out::before, .bx--copy-btn.bx--copy-btn--animating.bx--copy-btn--fade-out .bx--copy-btn__feedback {
    animation: 110ms cubic-bezier(0.2, 0, 0.38, 0.9) hide-feedback; }
  .bx--copy-btn.bx--copy-btn--animating.bx--copy-btn--fade-in::before, .bx--copy-btn.bx--copy-btn--animating.bx--copy-btn--fade-in .bx--copy-btn__feedback {
    animation: 110ms cubic-bezier(0.2, 0, 0.38, 0.9) show-feedback; }

.bx--copy {
  font-size: 0; }

.bx--fieldset {
  margin-bottom: 2rem; }

.bx--form-item {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
  align-items: flex-start; }

.bx--label {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  display: inline-block;
  margin-bottom: 0.5rem;
  color: #525252;
  font-weight: 400;
  line-height: 1rem;
  vertical-align: baseline; }

.bx--label .bx--tooltip__trigger {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.bx--label.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 4.6875rem;
  height: 0.875rem; }
  .bx--label.bx--skeleton:hover, .bx--label.bx--skeleton:focus, .bx--label.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--label.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--label.bx--skeleton::before {
        animation: none; } }
input[type='number'] {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace; }

input[data-invalid]:not(:focus),
.bx--number[data-invalid] input[type='number']:not(:focus),
.bx--text-input__field-wrapper[data-invalid]
> .bx--text-input--invalid:not(:focus),
.bx--text-area__wrapper[data-invalid]
> .bx--text-area--invalid:not(:focus),
.bx--select-input__wrapper[data-invalid]
.bx--select-input:not(:focus),
.bx--list-box[data-invalid]:not(:focus),
.bx--combo-box[data-invalid] .bx--text-input:not(:focus) {
  outline: 2px solid #da1e28;
  outline-offset: -2px; }

input[data-invalid] ~ .bx--form-requirement,
[data-invalid] ~ .bx--form-requirement,
.bx--number[data-invalid] .bx--number__input-wrapper ~ .bx--form-requirement,
.bx--date-picker-input__wrapper ~ .bx--form-requirement,
.bx--time-picker--invalid ~ .bx--form-requirement,
.bx--text-input__field-wrapper[data-invalid] ~ .bx--form-requirement,
.bx--text-input--warn ~ .bx--form-requirement,
.bx--text-area__wrapper[data-invalid] ~ .bx--form-requirement,
.bx--select-input__wrapper[data-invalid] ~ .bx--form-requirement,
.bx--time-picker[data-invalid] ~ .bx--form-requirement,
.bx--list-box[data-invalid] ~ .bx--form-requirement {
  display: block;
  max-height: 12.5rem;
  overflow: visible;
  font-weight: 400; }

input[data-invalid] ~ .bx--form-requirement,
[data-invalid] ~ .bx--form-requirement,
.bx--number[data-invalid] .bx--number__input-wrapper ~ .bx--form-requirement,
.bx--date-picker-input__wrapper ~ .bx--form-requirement,
.bx--time-picker--invalid ~ .bx--form-requirement,
.bx--text-input__field-wrapper[data-invalid] ~ .bx--form-requirement,
.bx--text-area__wrapper[data-invalid] ~ .bx--form-requirement,
.bx--select-input__wrapper[data-invalid] ~ .bx--form-requirement,
.bx--time-picker[data-invalid] ~ .bx--form-requirement,
.bx--list-box[data-invalid] ~ .bx--form-requirement {
  color: #da1e28; }

.bx--form--fluid .bx--text-input__field-wrapper[data-invalid],
.bx--form--fluid .bx--text-input__field-wrapper[data-warn] {
  display: block; }

.bx--form--fluid .bx--fieldset {
  margin: 0; }

.bx--form--fluid input[data-invalid] {
  outline: none; }

.bx--form--fluid .bx--form-requirement {
  margin: 0;
  padding: 0.5rem 2.5rem 0.5rem 1rem; }

input:not(output):not([data-invalid]):-moz-ui-invalid {
  box-shadow: none; }

.bx--form-requirement {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  display: none;
  max-height: 0;
  margin: 0.25rem 0 0;
  overflow: hidden; }

.bx--select--inline .bx--form__helper-text {
  margin-top: 0; }

.bx--form__helper-text {
  font-size: 0.75rem;
  line-height: 1.34;
  letter-spacing: 0.32px;
  z-index: 0;
  width: 100%;
  margin-top: 0.25rem;
  color: #525252;
  opacity: 1; }

.bx--label--disabled,
.bx--form__helper-text--disabled {
  color: #c6c6c6; }

@keyframes rotate {
  0% {
    transform: rotate(0deg); }
  100% {
    transform: rotate(360deg); } }

@keyframes rotate-end-p1 {
  100% {
    transform: rotate(360deg); } }

@keyframes rotate-end-p2 {
  100% {
    transform: rotate(-360deg); } }

/* Stroke animations */
@keyframes init-stroke {
  0% {
    stroke-dashoffset: 240; }
  100% {
    stroke-dashoffset: 40; } }

@keyframes stroke-end {
  0% {
    stroke-dashoffset: 40; }
  100% {
    stroke-dashoffset: 240; } }

.bx--loading {
  animation-name: rotate;
  animation-duration: 690ms;
  animation-timing-function: linear;
  animation-iteration-count: infinite;
  animation-fill-mode: forwards;
  width: 10.5rem;
  height: 10.5rem; }
  .bx--loading svg circle {
    animation-name: init-stroke;
    animation-duration: 10ms;
    animation-timing-function: cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--loading__svg {
  fill: transparent; }

.bx--loading__svg circle {
  stroke-width: 8;
  stroke-linecap: butt;
  stroke-dasharray: 240; }

.bx--loading__stroke {
  stroke: #0f62fe;
  stroke-dashoffset: 40; }

.bx--loading--small .bx--loading__stroke {
  stroke-dashoffset: 99; }

.bx--loading--stop {
  animation: rotate-end-p1 700ms cubic-bezier(0.2, 0, 1, 0.9) forwards, rotate-end-p2 700ms cubic-bezier(0.2, 0, 1, 0.9) 700ms forwards; }
  .bx--loading--stop svg circle {
    animation-name: stroke-end;
    animation-duration: 700ms;
    animation-timing-function: cubic-bezier(0.2, 0, 1, 0.9);
    animation-delay: 700ms;
    animation-fill-mode: forwards; }

.bx--loading--small {
  width: 2rem;
  height: 2rem; }
  .bx--loading--small circle {
    stroke-width: 12; }

.bx--loading--small .bx--loading__svg {
  stroke: #0f62fe; }

.bx--loading__background {
  stroke: #e0e0e0;
  stroke-dashoffset: 0; }

.bx--loading-overlay {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 6000;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 100%;
  background-color: rgba(22, 22, 22, 0.5);
  transition: background-color 720ms cubic-bezier(0.4, 0.14, 0.3, 1); }

.bx--loading-overlay--stop {
  display: none; }

.bx--file {
  width: 100%; }

.bx--file--invalid {
  margin-right: 0.5rem;
  fill: #da1e28; }

.bx--file--label {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  margin-bottom: 0.5rem;
  color: #161616; }

.bx--file-input {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.bx--file-btn {
  display: inline-flex;
  margin: 0;
  padding-right: 4rem; }

.bx--file-browse-btn {
  display: inline-block;
  width: 100%;
  max-width: 20rem;
  margin-bottom: 0.5rem;
  color: #0f62fe;
  outline: 2px solid transparent;
  outline-offset: -2px;
  cursor: pointer;
  transition: 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--file-browse-btn:focus, .bx--file-browse-btn:hover {
    outline: 2px solid #0f62fe; }
  .bx--file-browse-btn:hover, .bx--file-browse-btn:focus, .bx--file-browse-btn:active, .bx--file-browse-btn:active:visited {
    text-decoration: underline; }
  .bx--file-browse-btn:active {
    color: #161616; }

.bx--file-browse-btn--disabled {
  color: #c6c6c6;
  text-decoration: none;
  cursor: no-drop; }
  .bx--file-browse-btn--disabled:hover, .bx--file-browse-btn--disabled:focus {
    color: #c6c6c6;
    text-decoration: none;
    outline: none; }

.bx--file-browse-btn--disabled .bx--file__drop-container {
  border: 1px dashed #ffffff; }

.bx--label-description {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  margin-bottom: 1rem;
  color: #525252; }

.bx--file-btn ~ .bx--file-container {
  margin-top: 1.5rem; }

.bx--btn ~ .bx--file-container {
  margin-top: 1rem; }

.bx--file .bx--file-container,
.bx--file ~ .bx--file-container {
  margin-top: 0.5rem; }

.bx--file__selected-file {
  display: grid;
  grid-auto-rows: auto;
  grid-gap: 1rem;
  grid-template-columns: 1fr auto;
  align-items: center;
  max-width: 20rem;
  min-height: 3rem;
  margin-bottom: 0.5rem;
  word-break: break-word;
  background-color: #ffffff; }
  .bx--file__selected-file:last-child {
    margin-bottom: 0; }
  .bx--file__selected-file .bx--form-requirement {
    grid-column: 1 / -1;
    max-height: none;
    margin: 0; }
  .bx--file__selected-file .bx--loading {
    width: 2rem;
    height: 2rem;
    margin-right: -0.5rem; }
  .bx--file__selected-file .bx--inline-loading__animation .bx--loading {
    margin-right: 0; }
  .bx--file__selected-file .bx--file-filename {
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px;
    margin-left: 1rem;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis; }

.bx--file__selected-file--field {
  min-height: 2.5rem; }

.bx--file__selected-file--sm {
  min-height: 2rem; }

.bx--file__selected-file--invalid__wrapper {
  outline: 2px solid #da1e28;
  outline-offset: -2px;
  max-width: 20rem;
  margin-bottom: 0.5rem;
  background-color: #ffffff;
  outline-width: 1px; }

.bx--file__selected-file--invalid {
  outline: 2px solid #da1e28;
  outline-offset: -2px;
  padding: 1rem 0; }

.bx--file__selected-file--invalid .bx--form-requirement {
  padding-top: 1rem;
  border-top: 1px solid #e0e0e0; }

.bx--file__selected-file--invalid
.bx--form-requirement__title,
.bx--file__selected-file--invalid
.bx--form-requirement__supplement {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  padding: 0 1rem; }

.bx--file__selected-file--invalid
.bx--form-requirement__supplement {
  color: #161616; }

.bx--file__selected-file--invalid + .bx--form-requirement {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  display: block;
  max-height: 12.5rem;
  padding: 0.5rem 1rem;
  overflow: visible;
  color: #da1e28;
  font-weight: 400; }

.bx--file__selected-file--invalid
+ .bx--form-requirement
.bx--form-requirement__supplement {
  padding-bottom: 0.5rem;
  color: #161616; }

.bx--file__state-container {
  display: flex;
  justify-content: center;
  min-width: 1.5rem;
  padding-right: 1rem; }
  .bx--file__state-container .bx--loading__svg {
    stroke: #161616; }

.bx--file__state-container .bx--file-complete {
  cursor: pointer;
  fill: #0f62fe; }
  .bx--file__state-container .bx--file-complete:focus {
    outline: 1px solid #0f62fe; }
  .bx--file__state-container .bx--file-complete [data-icon-path='inner-path'] {
    opacity: 1;
    fill: #ffffff; }

.bx--file__state-container .bx--file-invalid {
  width: 1rem;
  height: 1rem;
  margin-right: 0.5rem;
  fill: #da1e28; }

.bx--file__state-container .bx--file-close {
  display: flex;
  width: 1rem;
  height: 1rem;
  padding: 0;
  background-color: transparent;
  border: none;
  cursor: pointer;
  fill: #161616; }
  .bx--file__state-container .bx--file-close:focus {
    outline: 1px solid #0f62fe; }

.bx--file__state-container .bx--file-close svg path {
  fill: #161616; }

.bx--file__state-container .bx--inline-loading__animation {
  margin-right: -0.5rem; }

.bx--file__drop-container {
  display: flex;
  align-items: flex-start;
  justify-content: space-between;
  height: 6rem;
  padding: 1rem;
  overflow: hidden;
  border: 1px dashed #8d8d8d; }

.bx--file__drop-container--drag-over {
  background: none;
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--form-item.bx--checkbox-wrapper {
  margin-bottom: 0.25rem; }

.bx--form-item.bx--checkbox-wrapper:first-of-type {
  margin-top: 0.1875rem; }

.bx--label + .bx--form-item.bx--checkbox-wrapper {
  margin-top: -0.125rem; }

.bx--form-item.bx--checkbox-wrapper:last-of-type {
  margin-bottom: 0.1875rem; }

.bx--checkbox {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.bx--checkbox-label {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  position: relative;
  display: flex;
  min-height: 1.5rem;
  padding-left: 1.625rem;
  line-height: 1.5rem;
  cursor: pointer;
  user-select: none; }

.bx--checkbox-label-text {
  padding-left: 0.375rem; }

.bx--checkbox-label::before,
.bx--checkbox-label::after {
  box-sizing: border-box; }

.bx--checkbox-label::before {
  position: absolute;
  top: 0.125rem;
  left: 0;
  width: 1rem;
  height: 1rem;
  margin: 0.125rem;
  background-color: transparent;
  border: 1px solid #161616;
  border-radius: 1px;
  content: ''; }

.bx--checkbox-label::after {
  position: absolute;
  top: 0.5rem;
  left: 0.375rem;
  width: 0.5625rem;
  height: 0.3125rem;
  margin-top: -0.1875rem;
  background: none;
  border-bottom: 2px solid #ffffff;
  border-left: 2px solid #ffffff;
  transform: scale(0) rotate(-45deg);
  transform-origin: bottom right;
  content: ''; }

.bx--checkbox:checked + .bx--checkbox-label::before,
.bx--checkbox:indeterminate + .bx--checkbox-label::before,
.bx--checkbox-label[data-contained-checkbox-state='true']::before,
.bx--checkbox-label[data-contained-checkbox-state='mixed']::before {
  background-color: #161616;
  border-color: #161616;
  border-width: 1px; }

.bx--checkbox:checked + .bx--checkbox-label::after,
.bx--checkbox-label[data-contained-checkbox-state='true']::after {
  transform: scale(1) rotate(-45deg); }

.bx--checkbox:indeterminate + .bx--checkbox-label::after,
.bx--checkbox-label[data-contained-checkbox-state='mixed']::after {
  top: 0.6875rem;
  width: 0.5rem;
  border-bottom: 2px solid #ffffff;
  border-left: 0 solid #ffffff;
  transform: scale(1) rotate(0deg); }

.bx--checkbox:focus + .bx--checkbox-label::before,
.bx--checkbox-label__focus::before,
.bx--checkbox:checked:focus + .bx--checkbox-label::before,
.bx--checkbox-label[data-contained-checkbox-state='true'].bx--checkbox-label__focus::before,
.bx--checkbox:indeterminate:focus + .bx--checkbox-label::before,
.bx--checkbox-label[data-contained-checkbox-state='mixed'].bx--checkbox-label__focus::before {
  box-shadow: 0 0 0 2px #ffffff, 0 0 0 4px #0f62fe; }

.bx--checkbox:disabled + .bx--checkbox-label,
.bx--checkbox-label[data-contained-checkbox-disabled='true'] {
  color: #c6c6c6;
  cursor: not-allowed; }

.bx--checkbox:disabled + .bx--checkbox-label::before,
.bx--checkbox-label[data-contained-checkbox-disabled='true']::before {
  border-color: #c6c6c6; }

.bx--checkbox:checked:disabled + .bx--checkbox-label::before,
.bx--checkbox:indeterminate:disabled
+ .bx--checkbox-label::before,
.bx--checkbox-label[data-contained-checkbox-state='true'][data-contained-checkbox-disabled='true']::before,
.bx--checkbox-label[data-contained-checkbox-state='mixed'][data-contained-checkbox-disabled='true']::before {
  background-color: #c6c6c6; }

.bx--checkbox-label-text.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 6.25rem;
  height: 1rem;
  margin: auto 0 auto 0.375rem; }
  .bx--checkbox-label-text.bx--skeleton:hover, .bx--checkbox-label-text.bx--skeleton:focus, .bx--checkbox-label-text.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--checkbox-label-text.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--checkbox-label-text.bx--skeleton::before {
        animation: none; } }
.bx--list-box__wrapper--inline {
  display: inline-grid;
  grid-gap: 0.25rem;
  grid-template: auto auto / auto auto;
  align-items: center; }
  .bx--list-box__wrapper--inline .bx--label {
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
  .bx--list-box__wrapper--inline .bx--label,
  .bx--list-box__wrapper--inline .bx--form__helper-text,
  .bx--list-box__wrapper--inline .bx--form-requirement {
    margin: 0; }
  .bx--list-box__wrapper--inline .bx--form__helper-text {
    max-width: none; }
  .bx--list-box__wrapper--inline .bx--form-requirement {
    grid-column: 2; }

.bx--list-box {
  position: relative;
  width: 100%;
  height: 2.5rem;
  max-height: 2.5rem;
  color: #161616;
  background-color: #ffffff;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  cursor: pointer;
  transition: all 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--list-box:hover {
    background-color: #e5e5e5; }

.bx--list-box--xl {
  height: 3rem;
  max-height: 3rem; }

.bx--list-box--sm {
  height: 2rem;
  max-height: 2rem; }

.bx--list-box--expanded {
  border-bottom-color: #e0e0e0; }

.bx--list-box--expanded:hover {
  background-color: #ffffff; }

.bx--list-box--expanded:hover.bx--list-box--light:hover {
  background-color: #f4f4f4; }

.bx--list-box .bx--text-input {
  height: 100%; }

.bx--list-box__invalid-icon {
  position: absolute;
  top: 50%;
  right: 2.5rem;
  transform: translateY(-50%);
  fill: #da1e28; }

.bx--list-box[data-invalid] .bx--list-box__field {
  padding-right: 4rem;
  border-bottom: 0; }

.bx--list-box[data-invalid].bx--list-box--inline
.bx--list-box__field {
  padding-right: 3.5rem; }

.bx--list-box--light {
  background-color: #f4f4f4; }

.bx--list-box--light .bx--list-box__menu {
  background: #f4f4f4; }

.bx--list-box--light .bx--list-box__menu-item__option {
  border-top-color: #e0e0e0; }

.bx--list-box--light.bx--list-box--expanded {
  border-bottom-color: transparent; }

.bx--list-box--disabled:hover {
  background-color: #ffffff; }

.bx--list-box--light.bx--list-box--disabled {
  background-color: #f4f4f4; }

.bx--list-box--disabled,
.bx--list-box--disabled .bx--list-box__field,
.bx--list-box--disabled .bx--list-box__field:focus {
  border-bottom-color: transparent;
  outline: none; }

.bx--list-box--disabled .bx--list-box__label,
.bx--list-box--disabled.bx--list-box--inline
.bx--list-box__label {
  color: #c6c6c6; }

.bx--list-box--disabled .bx--list-box__menu-icon > svg {
  fill: #c6c6c6; }

.bx--list-box--disabled,
.bx--list-box--disabled .bx--list-box__field,
.bx--list-box--disabled .bx--list-box__menu-icon {
  cursor: not-allowed; }

.bx--list-box--disabled .bx--list-box__menu-item,
.bx--list-box--disabled .bx--list-box__menu-item:hover,
.bx--list-box--disabled
.bx--list-box__menu-item--highlighted {
  color: #c6c6c6;
  text-decoration: none; }

.bx--list-box--disabled .bx--list-box__selection:hover {
  cursor: not-allowed; }

.bx--list-box--disabled.bx--list-box[data-invalid]
.bx--list-box__field {
  padding-right: 3rem; }

.bx--list-box--disabled.bx--list-box[data-invalid].bx--list-box--inline
.bx--list-box__field {
  padding-right: 2rem; }

.bx--list-box.bx--list-box--inline {
  background-color: transparent;
  border-width: 0; }
  .bx--list-box.bx--list-box--inline:hover {
    background-color: #e5e5e5; }

.bx--list-box.bx--list-box--inline.bx--list-box--expanded {
  border-bottom-width: 0; }

.bx--list-box.bx--list-box--inline.bx--list-box--expanded
.bx--list-box__field[aria-expanded='true'] {
  border-width: 0; }

.bx--list-box.bx--list-box--inline.bx--list-box--disabled:hover {
  background-color: transparent; }

.bx--list-box.bx--list-box--inline.bx--list-box--expanded:hover {
  background-color: #f4f4f4; }

.bx--list-box.bx--list-box--inline
.bx--list-box__field {
  padding: 0 2rem 0 0.5rem; }

.bx--list-box.bx--list-box--inline
.bx--list-box__menu-icon {
  right: 0.5rem; }

.bx--list-box.bx--list-box--inline
.bx--list-box__invalid-icon {
  right: 2rem; }

.bx--list-box--inline .bx--list-box__label {
  color: #161616; }

.bx--list-box--inline .bx--list-box__field {
  height: 100%; }

.bx--dropdown--inline .bx--list-box__field {
  max-width: 30rem; }

.bx--dropdown--inline .bx--list-box__menu {
  min-width: 18rem;
  max-width: 30rem; }

.bx--list-box__field {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  position: relative;
  display: inline-flex;
  align-items: center;
  height: calc(100% + 1px);
  padding: 0 3rem 0 1rem;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  vertical-align: top;
  outline: none;
  cursor: pointer; }
  .bx--list-box__field::-moz-focus-inner {
    border: 0; }

.bx--list-box__field:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--list-box__field[disabled] {
  color: #c6c6c6;
  outline: none; }

.bx--list-box__field .bx--text-input {
  padding-right: 4.5rem; }

.bx--list-box[data-invalid]
.bx--list-box__field
.bx--text-input {
  padding-right: 6.125rem; }

.bx--list-box[data-invalid]
.bx--list-box__field
.bx--text-input
+ .bx--list-box__invalid-icon {
  right: 4.125rem; }

.bx--list-box__field .bx--text-input--empty {
  padding-right: 3rem; }

.bx--list-box[data-invalid]
.bx--list-box__field
.bx--text-input--empty {
  padding-right: 4.5rem; }

.bx--list-box[data-invalid]
.bx--list-box__field
.bx--text-input--empty
+ .bx--list-box__invalid-icon {
  right: 2.5rem; }

.bx--list-box__label {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  overflow: hidden;
  color: #161616;
  white-space: nowrap;
  text-overflow: ellipsis;
  user-select: none; }

.bx--list-box__menu-icon {
  position: absolute;
  top: 0;
  right: 1rem;
  display: flex;
  align-items: center;
  height: 100%;
  cursor: pointer;
  transition: transform 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--list-box__menu-icon > svg {
  height: 100%;
  fill: #161616; }

.bx--list-box__menu-icon--open {
  transform: rotate(180deg); }

.bx--list-box__selection {
  position: absolute;
  top: 50%;
  /* to preserve .5rem space between icons according to spec top/transform used to center the combobox clear selection icon in IE11 */
  right: 2.0625rem;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 1.875rem;
  height: 1.875rem;
  transform: translateY(-50%);
  cursor: pointer;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  user-select: none; }
  .bx--list-box__selection:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.bx--list-box__selection > svg {
  fill: #525252; }

.bx--list-box--disabled .bx--list-box__selection:focus {
  outline: none; }

.bx--list-box__selection--multi {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  position: static;
  top: auto;
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: auto;
  height: 1.5rem;
  margin-right: 0.625rem;
  padding: 0.5rem;
  padding-right: 0.125rem;
  color: #ffffff;
  line-height: 0;
  background-color: #393939;
  border-radius: 0.75rem;
  transform: none; }

.bx--list-box__selection--multi > svg {
  width: 1.25rem;
  height: 1.25rem;
  margin-left: 0.25rem;
  padding: 0.125rem;
  fill: #ffffff; }
  .bx--list-box__selection--multi > svg:hover {
    background-color: #4c4c4c;
    border-radius: 50%; }

.bx--list-box--disabled
.bx--list-box__selection--multi
> svg {
  fill: #c6c6c6; }
  .bx--list-box--disabled
.bx--list-box__selection--multi
> svg:hover {
    background-color: initial; }

.bx--list-box__selection--multi:focus,
.bx--list-box__selection--multi:hover {
  outline: none; }

.bx--list-box__menu {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
  position: absolute;
  right: 0;
  left: 0;
  z-index: 6000;
  width: 100%;
  overflow-y: auto;
  background-color: #ffffff;
  transition: max-height 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--list-box__menu:focus {
    outline: 1px solid #0f62fe; }

.bx--list-box
.bx--list-box__field[aria-expanded='false']
+ .bx--list-box__menu {
  max-height: 0; }

.bx--list-box--expanded .bx--list-box__menu {
  max-height: 13.75rem; }

.bx--list-box--expanded.bx--list-box--xl
.bx--list-box__menu {
  max-height: 16.5rem; }

.bx--list-box--expanded.bx--list-box--sm
.bx--list-box__menu {
  max-height: 11rem; }

.bx--list-box__menu-item {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  position: relative;
  height: 2.5rem;
  color: #525252;
  cursor: pointer;
  transition: background 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  user-select: none; }
  .bx--list-box__menu-item:hover {
    background-color: #e5e5e5; }
  .bx--list-box__menu-item:active {
    background-color: #e0e0e0; }

.bx--list-box--sm .bx--list-box__menu-item {
  height: 2rem; }

.bx--list-box--xl .bx--list-box__menu-item {
  height: 3rem; }

.bx--list-box--disabled .bx--list-box__menu-item:hover {
  background-color: transparent; }

.bx--list-box--light .bx--list-box__menu-item:active {
  background-color: #e0e0e0; }

.bx--list-box--disabled
.bx--list-box__menu-item__option:hover {
  border-top-color: #e0e0e0; }

.bx--list-box__menu-item:first-of-type
.bx--list-box__menu-item__option {
  border-top-color: transparent; }

.bx--list-box__menu-item:hover
.bx--list-box__menu-item__option {
  color: #161616; }

.bx--list-box__menu-item:hover
+ .bx--list-box__menu-item
.bx--list-box__menu-item__option {
  border-top-color: transparent; }

.bx--list-box--disabled
.bx--list-box__menu-item:hover
+ .bx--list-box__menu-item
.bx--list-box__menu-item__option {
  border-top-color: #e0e0e0; }

.bx--list-box__menu-item__option {
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: block;
  height: 2.5rem;
  margin: 0 1rem;
  padding: 0.6875rem 0;
  padding-right: 1.5rem;
  overflow: hidden;
  color: #525252;
  font-weight: normal;
  line-height: 1rem;
  white-space: nowrap;
  text-decoration: none;
  text-overflow: ellipsis;
  border-top: 1px solid transparent;
  border-top-color: #e0e0e0;
  border-bottom: 1px solid transparent;
  transition: border-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--list-box__menu-item__option:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    margin: 0;
    padding: 0.6875rem 1rem;
    border-color: transparent; }
  .bx--list-box__menu-item__option:hover {
    color: #161616;
    border-color: transparent; }

.bx--list-box--sm .bx--list-box__menu-item__option {
  height: 2rem;
  padding-top: 0.4375rem;
  padding-bottom: 0.4375rem; }

.bx--list-box--xl .bx--list-box__menu-item__option {
  height: 3rem;
  padding-top: 0.9375rem;
  padding-bottom: 0.9375rem; }

.bx--list-box--disabled
.bx--list-box__menu-item:hover
.bx--list-box__menu-item__option,
.bx--list-box--disabled .bx--list-box__menu-item__option {
  color: #c6c6c6; }

.bx--list-box.bx--list-box--inline
.bx--list-box__menu-item__option {
  margin: 0 0.5rem; }
  .bx--list-box.bx--list-box--inline
.bx--list-box__menu-item__option:focus {
    margin: 0;
    padding-right: 0.5rem;
    padding-left: 0.5rem; }

.bx--list-box__menu-item--highlighted {
  color: #161616;
  background-color: #e5e5e5;
  border-color: transparent; }

.bx--list-box__menu-item--highlighted
.bx--list-box__menu-item__option,
.bx--list-box__menu-item--highlighted
+ .bx--list-box__menu-item
.bx--list-box__menu-item__option {
  border-top-color: transparent; }

.bx--list-box__menu-item--highlighted
.bx--list-box__menu-item__option {
  color: #161616; }

.bx--list-box__menu-item--active {
  color: #161616;
  background-color: #e0e0e0;
  border-bottom-color: #e0e0e0; }

.bx--list-box--light .bx--list-box__menu-item--active {
  background-color: #e0e0e0;
  border-bottom-color: #e0e0e0; }

.bx--list-box__menu-item--active:hover {
  background-color: #e5e5e5;
  border-bottom-color: #e5e5e5; }

.bx--list-box__menu-item--active
.bx--list-box__menu-item__option {
  color: #161616; }

.bx--list-box__menu-item--active
+ .bx--list-box__menu-item
> .bx--list-box__menu-item__option {
  border-top-color: transparent; }

.bx--list-box__menu-item__selected-icon {
  position: absolute;
  top: 50%;
  right: 1rem;
  display: none;
  transform: translateY(-50%);
  fill: #161616; }

.bx--list-box--inline
.bx--list-box__menu-item__selected-icon {
  right: 0.5rem; }

.bx--list-box__menu-item--active
.bx--list-box__menu-item__selected-icon {
  display: block; }

.bx--list-box__menu-item .bx--checkbox-label {
  width: 100%; }

.bx--list-box__menu-item .bx--checkbox-label-text {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.bx--list-box--up .bx--list-box__menu {
  bottom: 2.5rem; }

.bx--list-box--up.bx--dropdown--sm
.bx--list-box__menu,
.bx--list-box--up.bx--list-box--sm
.bx--list-box__menu {
  bottom: 2rem; }

.bx--list-box--up.bx--dropdown--xl
.bx--list-box__menu,
.bx--list-box--up.bx--list-box--xl
.bx--list-box__menu {
  bottom: 3rem; }

.bx--list-box input[role='combobox'],
.bx--list-box input[type='text'] {
  min-width: 0;
  background-color: inherit; }

.bx--combo-box .bx--text-input::-ms-clear {
  display: none; }

.bx--combo-box.bx--list-box--expanded
.bx--text-input {
  border-bottom-color: #e0e0e0; }

.bx--combo-box .bx--list-box__field,
.bx--combo-box.bx--list-box[data-invalid]
.bx--list-box__field,
.bx--combo-box.bx--list-box--disabled.bx--list-box[data-invalid]
.bx--list-box__field {
  padding: 0; }

.bx--radio-button-group {
  display: flex;
  align-items: center;
  margin-top: 0.375rem; }

.bx--label + .bx--form-item .bx--radio-button-group {
  margin-top: 0; }

.bx--radio-button-group--vertical {
  flex-direction: column;
  align-items: flex-start; }
  .bx--radio-button-group--vertical.bx--radio-button-group--label-left {
    align-items: flex-end; }
  .bx--radio-button-group--vertical .bx--radio-button__label {
    margin-right: 0;
    line-height: 1.25rem; }
  .bx--radio-button-group--vertical .bx--radio-button__label:not(:last-of-type) {
    margin-bottom: 0.5rem; }

.bx--radio-button {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0);
  visibility: inherit; }

.bx--radio-button__label {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  align-items: center;
  margin-right: 1rem;
  cursor: pointer; }

.bx--radio-button__appearance {
  flex-shrink: 0;
  width: 1.125rem;
  height: 1.125rem;
  margin-right: 0.5rem;
  background-color: transparent;
  border: 1px solid #161616;
  border-radius: 50%; }

.bx--radio-button:checked
+ .bx--radio-button__label
.bx--radio-button__appearance {
  display: flex;
  align-items: center;
  justify-content: center;
  border-color: #161616; }
  .bx--radio-button:checked
+ .bx--radio-button__label
.bx--radio-button__appearance::before {
    position: relative;
    display: inline-block;
    width: 100%;
    height: 100%;
    background-color: #161616;
    border-radius: 50%;
    transform: scale(0.5);
    content: ''; }
    @media screen and (-ms-high-contrast: active) {
      .bx--radio-button:checked
+ .bx--radio-button__label
.bx--radio-button__appearance::before {
        background-color: windowText; } }
.bx--radio-button:disabled + .bx--radio-button__label {
  color: #c6c6c6;
  cursor: not-allowed; }

.bx--radio-button:disabled
+ .bx--radio-button__label
.bx--radio-button__appearance,
.bx--radio-button:disabled:checked
+ .bx--radio-button__label
.bx--radio-button__appearance {
  border-color: #c6c6c6; }
  .bx--radio-button:disabled
+ .bx--radio-button__label
.bx--radio-button__appearance::before,
  .bx--radio-button:disabled:checked
+ .bx--radio-button__label
.bx--radio-button__appearance::before {
    background-color: #c6c6c6; }

.bx--radio-button:focus
+ .bx--radio-button__label
.bx--radio-button__appearance {
  outline: 1px solid transparent;
  box-shadow: 0 0 0 2px #0f62fe; }

.bx--radio-button__label.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 6.25rem;
  height: 1.125rem; }
  .bx--radio-button__label.bx--skeleton:hover, .bx--radio-button__label.bx--skeleton:focus, .bx--radio-button__label.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--radio-button__label.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--radio-button__label.bx--skeleton::before {
        animation: none; } }
.bx--radio-button__label.bx--skeleton
.bx--radio-button__appearance {
  display: none; }

.bx--radio-button-wrapper .bx--radio-button__label {
  display: flex;
  align-items: center;
  justify-content: center;
  margin: 0; }

.bx--radio-button-wrapper:not(:last-of-type) {
  margin-right: 1rem; }

.bx--radio-button-group--vertical
.bx--radio-button-wrapper:not(:last-of-type) {
  margin-right: 0;
  margin-bottom: 0.5rem; }

.bx--radio-button-group--label-right .bx--radio-button__label,
.bx--radio-button-wrapper.bx--radio-button-wrapper--label-right
.bx--radio-button__label {
  flex-direction: row; }

.bx--radio-button-group--label-left .bx--radio-button__label,
.bx--radio-button-wrapper.bx--radio-button-wrapper--label-left
.bx--radio-button__label {
  flex-direction: row-reverse; }

.bx--radio-button-group--label-left
.bx--radio-button__appearance,
.bx--radio-button-wrapper.bx--radio-button-wrapper--label-left
.bx--radio-button__appearance {
  margin-right: 0;
  margin-left: 0.5rem; }

.bx--toggle {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }
  .bx--toggle:focus {
    outline: none; }

.bx--toggle__label {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  position: relative;
  display: flex;
  align-items: center;
  margin: 0.5rem 0;
  cursor: pointer; }

.bx--toggle__appearance {
  position: relative;
  width: 3rem;
  height: 1.5rem; }
  .bx--toggle__appearance::before {
    position: absolute;
    top: 0;
    display: block;
    box-sizing: border-box;
    width: 3rem;
    height: 1.5rem;
    background-color: #8d8d8d;
    border-radius: 0.9375rem;
    box-shadow: 0 0 0 1px transparent, 0 0 0 3px transparent;
    cursor: pointer;
    transition: box-shadow 70ms cubic-bezier(0.2, 0, 1, 0.9), background-color 70ms cubic-bezier(0.2, 0, 1, 0.9);
    content: '';
    will-change: box-shadow; }
  .bx--toggle__appearance::after {
    position: absolute;
    top: 0.1875rem;
    left: 0.1875rem;
    display: block;
    box-sizing: border-box;
    width: 1.125rem;
    height: 1.125rem;
    background-color: #ffffff;
    border-radius: 50%;
    cursor: pointer;
    transition: transform 70ms cubic-bezier(0.2, 0, 1, 0.9);
    content: ''; }

.bx--toggle__check {
  position: absolute;
  top: 0.375rem;
  left: 0.375rem;
  z-index: 1;
  width: 0.375rem;
  height: 0.3125rem;
  transform: scale(0.2);
  transition: 70ms cubic-bezier(0.2, 0, 1, 0.9);
  fill: #ffffff; }

.bx--toggle__text--left,
.bx--toggle__text--right {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  position: relative;
  margin-left: 0.5rem; }

.bx--toggle__text--left {
  position: absolute;
  left: 3rem; }

.bx--toggle:checked
+ .bx--toggle__label
.bx--toggle__text--left,
.bx--toggle:not(:checked)
+ .bx--toggle__label
.bx--toggle__text--right {
  visibility: hidden; }

.bx--toggle:checked
+ .bx--toggle__label
.bx--toggle__text--right,
.bx--toggle:not(:checked)
+ .bx--toggle__label
.bx--toggle__text--left {
  display: inline; }

.bx--toggle:checked
+ .bx--toggle__label
.bx--toggle__appearance::before {
  background-color: #24a148; }

.bx--toggle:checked
+ .bx--toggle__label
.bx--toggle__appearance::after {
  background-color: #ffffff;
  transform: translateX(1.5rem); }

.bx--toggle
+ .bx--toggle__label
.bx--toggle__appearance::before {
  box-shadow: 0 0 0 1px transparent, 0 0 0 3px transparent; }

.bx--toggle:focus + .bx--toggle__label,
.bx--toggle:active
+ .bx--toggle__label
.bx--toggle__appearance::before {
  box-shadow: 0 0 0 1px #f4f4f4, 0 0 0 3px #0f62fe; }

.bx--toggle:disabled + .bx--toggle__label {
  cursor: not-allowed; }

.bx--toggle:disabled
+ .bx--toggle__label
.bx--toggle__appearance::before {
  background-color: #ffffff; }

.bx--toggle:disabled
+ .bx--toggle__label
.bx--toggle__appearance::after {
  background-color: #c6c6c6; }

.bx--toggle:disabled
+ .bx--toggle__label
.bx--toggle__appearance::before, .bx--toggle:disabled
+ .bx--toggle__label
.bx--toggle__appearance::after {
  cursor: not-allowed;
  transition: 70ms cubic-bezier(0.2, 0, 1, 0.9); }

.bx--toggle:disabled
+ .bx--toggle__label
.bx--toggle__text--left,
.bx--toggle:disabled
+ .bx--toggle__label
.bx--toggle__text--right {
  color: #c6c6c6; }

.bx--toggle:disabled:active
+ .bx--toggle__label
.bx--toggle__appearance:before {
  box-shadow: none; }

.bx--toggle:disabled
+ .bx--toggle__label
.bx--toggle__check {
  fill: #c6c6c6; }

.bx--toggle--small
+ .bx--toggle__label
.bx--toggle__appearance {
  width: 2rem;
  height: 1rem; }
  .bx--toggle--small
+ .bx--toggle__label
.bx--toggle__appearance::before {
    top: 0;
    box-sizing: border-box;
    width: 2rem;
    height: 1rem;
    border-radius: 0.9375rem; }
  .bx--toggle--small
+ .bx--toggle__label
.bx--toggle__appearance::after {
    top: 0.1875rem;
    left: 0.1875rem;
    width: 0.625rem;
    height: 0.625rem; }

.bx--toggle--small:checked
+ .bx--toggle__label
.bx--toggle__check {
  transform: scale(1) translateX(1rem);
  fill: #24a148; }

.bx--toggle--small
+ .bx--toggle__label
.bx--toggle__text--left {
  left: 2rem; }

.bx--toggle--small:checked
+ .bx--toggle__label
.bx--toggle__appearance::after {
  margin-left: 0;
  transform: translateX(1.0625rem); }

.bx--toggle-input {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }
  .bx--toggle-input:focus {
    outline: none; }

.bx--toggle-input__label {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  color: #525252;
  cursor: pointer; }

.bx--toggle__switch {
  position: relative;
  display: flex;
  align-items: center;
  width: 3rem;
  height: 1.5rem;
  cursor: pointer; }
  .bx--toggle__switch::before {
    position: absolute;
    top: 0;
    display: block;
    box-sizing: border-box;
    width: 3rem;
    height: 1.5rem;
    background-color: #8d8d8d;
    border-radius: 0.9375rem;
    box-shadow: 0 0 0 1px transparent, 0 0 0 3px transparent;
    transition: box-shadow 70ms cubic-bezier(0.2, 0, 1, 0.9), background-color 70ms cubic-bezier(0.2, 0, 1, 0.9);
    content: '';
    will-change: box-shadow; }
  .bx--toggle__switch::after {
    position: absolute;
    top: 0.1875rem;
    left: 0.1875rem;
    display: block;
    box-sizing: border-box;
    width: 1.125rem;
    height: 1.125rem;
    background-color: #ffffff;
    border-radius: 50%;
    transition: transform 70ms cubic-bezier(0.2, 0, 1, 0.9);
    content: ''; }
  .bx--toggle-input__label .bx--toggle__switch {
    margin-top: 1rem; }

.bx--toggle__text--off,
.bx--toggle__text--on {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  position: absolute;
  top: 50%;
  margin-left: 3.5rem;
  white-space: nowrap;
  transform: translateY(-50%);
  user-select: none; }

.bx--toggle-input:checked
+ .bx--toggle-input__label
> .bx--toggle__switch
> .bx--toggle__text--off,
.bx--toggle-input:not(:checked)
+ .bx--toggle-input__label
> .bx--toggle__switch
> .bx--toggle__text--on {
  visibility: hidden; }

.bx--toggle-input:checked
+ .bx--toggle-input__label
> .bx--toggle__switch::before {
  background-color: #24a148; }

.bx--toggle-input:checked
+ .bx--toggle-input__label
> .bx--toggle__switch::after {
  background-color: #ffffff;
  transform: translateX(1.5rem); }

.bx--toggle-input:focus
+ .bx--toggle-input__label
> .bx--toggle__switch::before,
.bx--toggle-input:active
+ .bx--toggle-input__label
> .bx--toggle__switch::before {
  box-shadow: 0 0 0 1px #f4f4f4, 0 0 0 3px #0f62fe; }

.bx--toggle-input:disabled + .bx--toggle-input__label {
  color: #c6c6c6;
  cursor: not-allowed; }

.bx--toggle-input:disabled
+ .bx--toggle-input__label
> .bx--toggle__switch {
  cursor: not-allowed; }
  .bx--toggle-input:disabled
+ .bx--toggle-input__label
> .bx--toggle__switch::before {
    background-color: #ffffff; }
  .bx--toggle-input:disabled
+ .bx--toggle-input__label
> .bx--toggle__switch::after {
    background-color: #c6c6c6; }
  .bx--toggle-input:disabled
+ .bx--toggle-input__label
> .bx--toggle__switch::before, .bx--toggle-input:disabled
+ .bx--toggle-input__label
> .bx--toggle__switch::after {
    cursor: not-allowed;
    transition: 70ms cubic-bezier(0.2, 0, 1, 0.9); }

.bx--toggle-input:disabled:active
+ .bx--toggle-input__label
> .bx--toggle__switch::before {
  box-shadow: none; }

.bx--toggle-input--small + .bx--toggle-input__label > .bx--toggle__switch {
  width: 2rem;
  height: 1rem; }
  .bx--toggle-input--small + .bx--toggle-input__label > .bx--toggle__switch::before {
    width: 2rem;
    height: 1rem;
    border-radius: 0.9375rem; }
  .bx--toggle-input--small + .bx--toggle-input__label > .bx--toggle__switch::after {
    width: 0.625rem;
    height: 0.625rem; }

.bx--toggle-input--small + .bx--toggle-input__label .bx--toggle__text--off,
.bx--toggle-input--small + .bx--toggle-input__label .bx--toggle__text--on {
  margin-left: 2.5rem; }

.bx--toggle-input--small:checked + .bx--toggle-input__label > .bx--toggle__switch::after {
  transform: translateX(1.0625rem); }

.bx--toggle-input--small:checked + .bx--toggle-input__label .bx--toggle__check {
  transform: scale(1) translateX(1rem);
  fill: #24a148; }

.bx--toggle-input--small:disabled:checked
+ .bx--toggle-input__label
.bx--toggle__check {
  fill: #c6c6c6; }

.bx--toggle__label.bx--skeleton {
  flex-direction: column;
  align-items: flex-start; }
  .bx--toggle__label.bx--skeleton .bx--toggle__label-text {
    margin-bottom: 0.5rem; }

.bx--search {
  position: relative;
  display: flex;
  align-items: center;
  width: 100%; }

.bx--search .bx--label {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.bx--search-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  order: 1;
  width: 100%;
  padding: 0 2.5rem;
  color: #161616;
  text-overflow: ellipsis;
  background-color: #ffffff;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  appearance: none; }
  .bx--search-input:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--search-input::placeholder {
    color: #6f6f6f;
    font-weight: 400; }
  .bx--search-input::-ms-clear {
    display: none; }

.bx--search-input[disabled] {
  color: #c6c6c6;
  background-color: #ffffff;
  border-bottom: 1px solid transparent;
  cursor: not-allowed; }
  .bx--search-input[disabled]::placeholder {
    color: #c6c6c6;
    font-weight: 400; }

.bx--search-input[disabled] ~ .bx--search-magnifier {
  fill: #c6c6c6; }

.bx--search--light .bx--search-input {
  background: #f4f4f4; }

.bx--search--sm .bx--search-input {
  height: 2rem;
  padding: 0 2rem; }

.bx--search--sm .bx--search-magnifier {
  left: 0.5rem; }

.bx--search--lg .bx--search-input {
  height: 2.5rem;
  padding: 0 2.5rem; }

.bx--search--lg .bx--search-magnifier {
  left: 0.75rem; }

.bx--search--xl .bx--search-input {
  height: 3rem;
  padding: 0 3rem; }

.bx--search-magnifier {
  position: absolute;
  top: 50%;
  left: 1rem;
  z-index: 2;
  width: 1rem;
  height: 1rem;
  transform: translateY(-50%);
  pointer-events: none;
  fill: #525252; }

.bx--search-close {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: absolute;
  top: 0;
  right: 0; }
  .bx--search-close::-moz-focus-inner {
    border: 0; }
  .bx--search-close::before {
    position: absolute;
    top: 0.0625rem;
    left: 0;
    display: block;
    width: 2px;
    height: calc(100% - 2px);
    background-color: #ffffff;
    transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
    content: ''; }
  .bx--search-close:hover {
    border-bottom: 1px solid #8d8d8d; }
    .bx--search-close:hover::before {
      background-color: #e5e5e5; }

.bx--search-button {
  flex-shrink: 0;
  margin-left: 0.125rem;
  background-color: #ffffff; }
  .bx--search-button svg {
    vertical-align: middle;
    fill: currentColor; }

.bx--search-close svg {
  fill: inherit; }

.bx--search-close,
.bx--search-button {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2.5rem;
  height: 2.5rem;
  border-color: transparent;
  border-style: solid;
  border-width: 1px 0;
  visibility: inherit;
  cursor: pointer;
  opacity: 1;
  transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9), border 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }
  .bx--search-close:hover,
  .bx--search-button:hover {
    background-color: #e5e5e5; }
  .bx--search-close:focus,
  .bx--search-button:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--search-close:active,
  .bx--search-button:active {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    background-color: #e0e0e0; }

.bx--search-close:focus::before,
.bx--search-close:active::before {
  background-color: #0f62fe; }

.bx--search-input:focus ~ .bx--search-close:hover {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--search--sm .bx--search-close,
.bx--search--sm ~ .bx--search-button {
  width: 2rem;
  height: 2rem; }

.bx--search--lg .bx--search-close,
.bx--search--lg ~ .bx--search-button {
  width: 2.5rem;
  height: 2.5rem; }

.bx--search--xl .bx--search-close,
.bx--search--xl ~ .bx--search-button {
  width: 3rem;
  height: 3rem; }

.bx--search-close--hidden {
  visibility: hidden;
  opacity: 0; }

.bx--search--xl.bx--skeleton .bx--search-input,
.bx--search--lg.bx--skeleton .bx--search-input,
.bx--search--sm.bx--skeleton .bx--search-input {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%; }
  .bx--search--xl.bx--skeleton .bx--search-input:hover, .bx--search--xl.bx--skeleton .bx--search-input:focus, .bx--search--xl.bx--skeleton .bx--search-input:active,
  .bx--search--lg.bx--skeleton .bx--search-input:hover,
  .bx--search--lg.bx--skeleton .bx--search-input:focus,
  .bx--search--lg.bx--skeleton .bx--search-input:active,
  .bx--search--sm.bx--skeleton .bx--search-input:hover,
  .bx--search--sm.bx--skeleton .bx--search-input:focus,
  .bx--search--sm.bx--skeleton .bx--search-input:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--search--xl.bx--skeleton .bx--search-input::before,
  .bx--search--lg.bx--skeleton .bx--search-input::before,
  .bx--search--sm.bx--skeleton .bx--search-input::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--search--xl.bx--skeleton .bx--search-input::before,
      .bx--search--lg.bx--skeleton .bx--search-input::before,
      .bx--search--sm.bx--skeleton .bx--search-input::before {
        animation: none; } }
  .bx--search--xl.bx--skeleton .bx--search-input::placeholder,
  .bx--search--lg.bx--skeleton .bx--search-input::placeholder,
  .bx--search--sm.bx--skeleton .bx--search-input::placeholder {
    color: transparent; }

.bx--select {
  position: relative;
  display: flex;
  flex-direction: column;
  align-items: flex-start; }

.bx--select-input__wrapper {
  position: relative;
  display: flex;
  align-items: center; }

.bx--select-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: block;
  width: 14rem;
  min-width: 8rem;
  max-width: 28rem;
  height: 2.5rem;
  padding: 0 3rem 0 1rem;
  color: #161616;
  background-color: #ffffff;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  border-radius: 0;
  cursor: pointer;
  transition: outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  appearance: none;
  -moz-appearance: none;
  -webkit-appearance: none; }
  .bx--select-input:hover {
    background-color: #e5e5e5; }
  .bx--select-input::-ms-expand {
    display: none; }

@-moz-document url-prefix() {
  .bx--select-input:-moz-focusring, .bx--select-input::-moz-focus-inner {
    color: transparent;
    text-shadow: 0 0 0 #000000;
    background-image: none; } }
  .bx--select-input:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    color: #161616; }
  .bx--select-input:disabled, .bx--select-input:hover:disabled {
    color: #c6c6c6;
    background-color: #ffffff;
    border-bottom-color: #ffffff;
    cursor: not-allowed; }

.bx--select-input--sm {
  height: 2rem;
  max-height: 2rem; }

.bx--select-input--xl {
  height: 3rem;
  max-height: 3rem; }

.bx--select--disabled .bx--label,
.bx--select--disabled .bx--form__helper-text {
  color: #c6c6c6; }

.bx--select-input__wrapper[data-invalid] .bx--select-input {
  padding-right: 5rem; }

.bx--select-input:disabled ~ .bx--select__arrow {
  fill: #c6c6c6; }

.bx--select--light .bx--select-input {
  background-color: #f4f4f4; }
  .bx--select--light .bx--select-input:hover {
    background-color: #e5e5e5; }
  .bx--select--light .bx--select-input:disabled, .bx--select--light .bx--select-input:hover:disabled {
    color: #c6c6c6;
    background-color: #ffffff;
    cursor: not-allowed; }

.bx--select__arrow {
  position: absolute;
  top: 0;
  right: 1rem;
  height: 100%;
  pointer-events: none;
  fill: #161616; }

.bx--select-input__wrapper[data-invalid]
.bx--select-input
~ .bx--select__invalid-icon {
  position: absolute;
  right: 3rem;
  fill: #da1e28; }

.bx--select-optgroup,
.bx--select-option {
  color: #161616; }

.bx--select-option[disabled] {
  cursor: not-allowed;
  opacity: 0.5; }

@-moz-document url-prefix() {
  .bx--select-option {
    color: #161616;
    background-color: #ffffff; }
  .bx--select-optgroup {
    color: #161616; } }

.bx--select--inline {
  display: flex;
  flex-direction: row;
  align-items: center; }

.bx--select--inline.bx--select--invalid .bx--label,
.bx--select--inline.bx--select--invalid
.bx--form__helper-text {
  align-self: flex-start;
  margin-top: 0.8125rem; }

.bx--select--inline .bx--form__helper-text {
  margin-bottom: 0;
  margin-left: 0.5rem; }

.bx--select--inline .bx--label {
  margin: 0 0.5rem 0 0;
  white-space: nowrap; }

.bx--select--inline .bx--select-input {
  padding-right: 2rem;
  padding-left: 0.5rem;
  color: #161616;
  background-color: transparent;
  border-bottom: none; }

.bx--select--inline .bx--select-input[disabled],
.bx--select--inline .bx--select-input[disabled]:hover {
  background-color: #ffffff; }

.bx--select--inline .bx--select__arrow {
  right: 0.5rem; }

.bx--select--inline.bx--select--invalid
.bx--select-input {
  padding-right: 3.5rem; }

.bx--select--inline.bx--select--invalid
.bx--select-input
~ .bx--select__invalid-icon {
  right: 2rem; }

.bx--select--inline .bx--select-input:disabled {
  color: #c6c6c6;
  cursor: not-allowed; }
  .bx--select--inline .bx--select-input:disabled ~ * {
    cursor: not-allowed; }

.bx--select.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%;
  height: 2.5rem; }
  .bx--select.bx--skeleton:hover, .bx--select.bx--skeleton:focus, .bx--select.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--select.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--select.bx--skeleton::before {
        animation: none; } }
.bx--select.bx--skeleton .bx--select-input {
  display: none; }

.bx--text-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  width: 100%;
  height: 2.5rem;
  padding: 0 1rem;
  color: #161616;
  background-color: #ffffff;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--text-input:focus, .bx--text-input:active {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--text-input-wrapper svg[hidden] {
    display: none; }

.bx--text-input--xl {
  height: 3rem; }

.bx--text-input--sm {
  height: 2rem; }

.bx--password-input {
  padding-right: 2.5rem; }

.bx--text-input::placeholder {
  color: #a8a8a8;
  opacity: 1; }

.bx--text-input--light {
  background-color: #f4f4f4; }

.bx--text-input__field-wrapper {
  position: relative;
  display: flex;
  align-items: center;
  width: 100%; }
  .bx--text-input__field-wrapper .bx--text-input__invalid-icon {
    position: absolute;
    top: 50%;
    right: 1rem;
    transform: translateY(-50%);
    fill: #da1e28; }
  .bx--text-input__field-wrapper .bx--text-input__invalid-icon--warning {
    fill: #f1c21b; }
    .bx--text-input__field-wrapper .bx--text-input__invalid-icon--warning path[data-icon-path='inner-path'] {
      opacity: 1;
      fill: #000000; }
  .bx--text-input__field-wrapper .bx--text-input--password__visibility {
    position: relative;
    display: inline-flex;
    align-items: center;
    overflow: visible;
    cursor: pointer; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus {
      outline: 1px solid #0f62fe; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus {
      outline: 1px solid transparent; }
      .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus svg {
        outline: 1px solid #0f62fe; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      position: absolute;
      z-index: 6000;
      display: flex;
      align-items: center;
      opacity: 0;
      pointer-events: none; }
      @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
        .bx--text-input__field-wrapper .bx--text-input--password__visibility::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
        .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
        .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
          display: inline-block; } }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility::after {
      transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--a11y::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--a11y::after {
      transition: none; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility::before {
      width: 0;
      height: 0;
      border-style: solid;
      content: ''; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      box-sizing: content-box;
      color: inherit;
      white-space: normal;
      opacity: 1; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
      width: max-content;
      min-width: 1.5rem;
      max-width: 13rem;
      height: auto;
      padding: 0.1875rem 1rem;
      color: #ffffff;
      font-weight: 400;
      text-align: left;
      background-color: #393939;
      border-radius: 0.125rem;
      transform: translateX(-50%);
      font-size: 0.875rem;
      font-weight: 400;
      line-height: 1.29;
      letter-spacing: 0.16px; }
      @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
        .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
        .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
        .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
          width: 13rem; } }
      @supports (-ms-accelerator: true) {
        .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
        .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
        .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
          width: 13rem; } }
      @supports (-ms-ime-align: auto) {
        .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
        .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
        .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
          width: 13rem; } }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility::after {
      content: attr(aria-label); }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--a11y::after {
      content: none; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible::after, .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover::after, .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus::after {
      opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible + .bx--assistive-text, .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover + .bx--assistive-text, .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus + .bx--assistive-text {
      margin: auto;
      overflow: visible;
      clip: auto; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible + .bx--assistive-text, .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover + .bx--assistive-text, .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover.bx--tooltip--a11y::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus + .bx--assistive-text, .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus.bx--tooltip--a11y::before {
      animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--hidden .bx--assistive-text, .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--hidden + .bx--assistive-text {
      margin: -1px;
      overflow: hidden;
      clip: rect(0, 0, 0, 0); }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--hidden.bx--tooltip--a11y::before {
      opacity: 0;
      animation: none; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility::before, .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      bottom: 0;
      left: 50%; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility::before {
      bottom: -0.5rem;
      border-color: transparent transparent #393939 transparent;
      border-width: 0 0.25rem 0.3125rem 0.25rem;
      transform: translate(-50%, 100%); }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      bottom: -0.8125rem;
      transform: translate(-50%, 100%); }
  .bx--text-input__field-wrapper .bx--text-input--password__visibility,
  .bx--text-input__field-wrapper .bx--text-input--password__visibility__toggle.bx--tooltip__trigger {
    position: absolute;
    right: 1rem;
    width: 1rem;
    height: 1rem;
    padding: 0;
    background: none;
    border: 0;
    cursor: pointer; }
    .bx--text-input__field-wrapper .bx--text-input--password__visibility svg,
    .bx--text-input__field-wrapper .bx--text-input--password__visibility__toggle.bx--tooltip__trigger svg {
      fill: #525252; }
  .bx--text-input__field-wrapper .bx--text-input--invalid {
    padding-right: 2.5rem; }
  .bx--text-input__field-wrapper .bx--text-input--invalid.bx--password-input {
    padding-right: 4rem; }
  .bx--text-input__field-wrapper .bx--text-input--invalid
+ .bx--text-input--password__visibility,
  .bx--text-input__field-wrapper .bx--text-input--invalid
+ .bx--text-input--password__visibility__toggle {
    right: 1rem; }

.bx--password-input-wrapper .bx--text-input__invalid-icon {
  right: 2.5rem; }

.bx--text-input:disabled
+ .bx--text-input--password__visibility
svg,
.bx--text-input:disabled
+ .bx--text-input--password__visibility__toggle
svg {
  cursor: not-allowed;
  opacity: 0.5; }

.bx--text-input:disabled {
  outline: 2px solid transparent;
  outline-offset: -2px;
  color: #c6c6c6;
  background-color: #ffffff;
  border-bottom: 1px solid transparent;
  -webkit-text-fill-color: currentColor;
  cursor: not-allowed; }

.bx--text-input--light:disabled {
  background-color: #f4f4f4; }

.bx--text-input:disabled::placeholder {
  color: #c6c6c6;
  opacity: 1; }

.bx--text-input--invalid {
  outline: 2px solid #da1e28;
  outline-offset: -2px;
  box-shadow: none; }
  .bx--text-input--invalid .bx--text-input--password__visibility,
  .bx--text-input--invalid .bx--text-input--password__visibility__toggle {
    right: 2.5rem; }

.bx--form--fluid .bx--text-input-wrapper {
  position: relative;
  background: #ffffff;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--form--fluid .bx--label {
  position: absolute;
  top: 0.8125rem;
  left: 1rem;
  z-index: 1;
  margin: 0; }

.bx--form--fluid .bx--form__helper-text {
  display: none; }

.bx--form--fluid .bx--text-input {
  min-height: 4rem;
  padding: 2rem 1rem 0.8125rem; }

.bx--text-input__divider,
.bx--form--fluid .bx--text-input__divider {
  display: none; }

.bx--form--fluid .bx--text-input--invalid,
.bx--form--fluid .bx--text-input--warn {
  border-bottom: none; }

.bx--form--fluid
.bx--text-input--invalid
+ .bx--text-input__divider,
.bx--form--fluid
.bx--text-input--warn
+ .bx--text-input__divider {
  display: block;
  margin: 0 1rem;
  border-color: #e0e0e0;
  border-style: solid;
  border-bottom: none; }

.bx--form--fluid .bx--text-input__invalid-icon {
  top: 5rem; }

.bx--form--fluid .bx--text-input-wrapper--light {
  background: #f4f4f4; }

.bx--form--fluid
.bx--text-input__field-wrapper[data-invalid]
> .bx--text-input--invalid {
  outline: 2px solid transparent;
  outline-offset: -2px; }

.bx--form--fluid
.bx--text-input__field-wrapper[data-invalid]:not(:focus) {
  outline: 2px solid #da1e28;
  outline-offset: -2px; }

.bx--form--fluid
.bx--text-input__field-wrapper[data-invalid]
> .bx--text-input--invalid:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--text-input-wrapper--inline {
  flex-flow: row wrap; }

.bx--label--inline {
  flex: 1;
  margin: 0.8125rem 0 0 0;
  word-break: break-word;
  overflow-wrap: break-word; }

.bx--label--inline--sm {
  margin-top: 0.5625rem; }

.bx--label--inline--xl {
  margin-top: 1.0625rem; }

.bx--text-input__label-helper-wrapper {
  flex: 2;
  flex-direction: column;
  max-width: 8rem;
  margin-right: 1.5rem;
  overflow-wrap: break-word; }

.bx--form__helper-text--inline {
  margin-top: 0.125rem; }

.bx--text-input__field-outer-wrapper {
  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
  align-items: flex-start;
  width: 100%; }

.bx--text-input__field-outer-wrapper--inline {
  flex: 8;
  flex-direction: column; }

.bx--text-area {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  width: 100%;
  min-width: 10rem;
  height: 100%;
  min-height: 2.5rem;
  padding: 0.6875rem 1rem;
  color: #161616;
  background-color: #ffffff;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  resize: vertical; }

.bx--text-area:focus,
.bx--text-area:active {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--text-area::placeholder {
  color: #a8a8a8;
  opacity: 1;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px; }

.bx--text-area--light {
  background-color: #f4f4f4; }

.bx--text-area--invalid {
  padding-right: 2.5rem; }

.bx--text-area__wrapper {
  position: relative;
  display: flex;
  width: 100%; }

.bx--text-area__invalid-icon {
  position: absolute;
  top: 0.75rem;
  right: 1rem;
  fill: #da1e28; }

.bx--text-area:disabled {
  color: #c6c6c6;
  background-color: #ffffff;
  border-bottom: 1px solid transparent;
  outline: none;
  cursor: not-allowed; }

.bx--text-area:disabled::placeholder {
  color: #c6c6c6; }

.bx--text-area.bx--text-area--light:disabled {
  background-color: #f4f4f4; }

bx--text-area.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  height: 6.25rem; }
  bx--text-area.bx--skeleton:hover, bx--text-area.bx--skeleton:focus, bx--text-area.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  bx--text-area.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      bx--text-area.bx--skeleton::before {
        animation: none; } }
  bx--text-area.bx--skeleton::placeholder {
    color: transparent; }

.bx--number {
  position: relative;
  display: flex;
  flex-direction: column; }

.bx--number input[type='number'] {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: inline-flex;
  box-sizing: border-box;
  width: 100%;
  min-width: 9.375rem;
  height: 2.5rem;
  padding-right: 2rem;
  padding-left: 1rem;
  color: #161616;
  font-weight: 300;
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  background-color: #ffffff;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  border-radius: 0;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  -moz-appearance: textfield; }
  .bx--number input[type='number']:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--number input[type='number']:disabled ~ .bx--number__controls {
    cursor: not-allowed;
    pointer-events: none; }
  .bx--number input[type='number']:disabled ~ .bx--number__controls svg {
    fill: #c6c6c6; }
  .bx--number input[type='number']::-ms-clear {
    display: none; }
  .bx--number input[type='number']::-webkit-inner-spin-button {
    appearance: none; }

.bx--number input[type='number']:disabled,
.bx--number--readonly input[type='number'] {
  color: #c6c6c6;
  background-color: #ffffff;
  border-bottom-color: transparent;
  cursor: not-allowed; }

.bx--number__input-wrapper {
  position: relative;
  display: flex;
  align-items: center; }

.bx--number__controls {
  position: absolute;
  top: 50%;
  right: 0;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  transform: translateY(-50%); }

.bx--number__control-btn {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 2rem;
  height: 1.25rem;
  color: #161616; }
  .bx--number__control-btn::-moz-focus-inner {
    border: 0; }
  .bx--number__control-btn svg {
    position: relative;
    fill: currentColor; }
  .bx--number__control-btn.up-icon svg {
    top: 0.3125rem; }
  .bx--number__control-btn.down-icon svg {
    top: -0.3125rem; }
  .bx--number__control-btn:focus {
    outline: 1px solid #0f62fe;
    color: #161616;
    outline-width: 2px;
    outline-offset: -2px; }
  .bx--number__control-btn:hover {
    color: #161616;
    cursor: pointer; }
  .bx--number__control-btn:disabled {
    color: #c6c6c6;
    cursor: not-allowed; }

.bx--number--readonly .bx--number__control-btn {
  display: none; }

.bx--number__invalid {
  position: absolute;
  right: 2rem;
  fill: #da1e28; }

.bx--number--light input[type='number'] {
  background-color: #f4f4f4; }

.bx--number--light input[type='number']:disabled,
.bx--number--light
.bx--number--readonly
input[type='number'] {
  background-color: #f4f4f4; }

.bx--number--mobile {
  width: auto;
  min-width: 9rem; }
  .bx--number--mobile .bx--number__control-btn, .bx--number--mobile.bx--number--light .bx--number__control-btn {
    position: static;
    width: 2.5rem;
    height: 2.5rem;
    background-color: #ffffff; }
    .bx--number--mobile .bx--number__control-btn:hover, .bx--number--mobile .bx--number__control-btn:focus, .bx--number--mobile.bx--number--light .bx--number__control-btn:hover, .bx--number--mobile.bx--number--light .bx--number__control-btn:focus {
      background-color: #e5e5e5; }
    .bx--number--mobile .bx--number__control-btn:focus, .bx--number--mobile.bx--number--light .bx--number__control-btn:focus {
      outline-width: 2px;
      outline-offset: -2px; }
    .bx--number--mobile .bx--number__control-btn svg, .bx--number--mobile.bx--number--light .bx--number__control-btn svg {
      position: static; }
  .bx--number--mobile input[type='number'] {
    width: auto;
    min-width: 4rem;
    margin: 0;
    padding: 0;
    text-align: center;
    background-color: #ffffff;
    border-right: 1px solid #e0e0e0;
    border-left: 1px solid #e0e0e0; }
  .bx--number--mobile.bx--number--light input[type='number'] {
    background-color: #f4f4f4; }
  .bx--number--mobile.bx--number--light .bx--number__control-btn {
    background-color: #f4f4f4; }

.bx--number--xl input[type='number'] {
  height: 3rem; }

.bx--number--xl .bx--number__control-btn {
  height: 1.5rem; }

.bx--number--xl.bx--number--mobile
.bx--number__control-btn {
  width: 3rem;
  height: 3rem; }

.bx--number--xl .bx--number__control-btn.up-icon svg {
  top: 0.4125rem; }

.bx--number--xl .bx--number__control-btn.down-icon svg {
  top: -0.4125rem; }

.bx--number--sm input[type='number'] {
  height: 2rem; }

.bx--number--sm .bx--number__control-btn {
  height: 1rem; }

.bx--number--sm.bx--number--mobile
.bx--number__control-btn {
  width: 2rem;
  height: 2rem; }

.bx--number--sm .bx--number__control-btn.up-icon svg {
  top: 0.2125rem; }

.bx--number--sm .bx--number__control-btn.down-icon svg {
  top: -0.2125rem; }

.bx--number--nolabel .bx--label + .bx--form__helper-text {
  margin-top: 0; }

.bx--number.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%;
  height: 2.5rem; }
  .bx--number.bx--skeleton:hover, .bx--number.bx--skeleton:focus, .bx--number.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--number.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--number.bx--skeleton::before {
        animation: none; } }
  .bx--number.bx--skeleton input[type='number'] {
    display: none; }

.bx--link {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  color: #0f62fe;
  text-decoration: none;
  outline: none;
  transition: color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--link:hover {
    color: #0043ce;
    text-decoration: underline; }
  .bx--link:active, .bx--link:active:visited, .bx--link:active:visited:hover {
    color: #161616;
    text-decoration: underline; }
  .bx--link:focus {
    outline: 1px solid #0f62fe; }
  .bx--link:visited {
    color: #0f62fe; }
  .bx--link:visited:hover {
    color: #0043ce; }

.bx--link--disabled,
.bx--link--disabled:hover {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: inline;
  color: #c6c6c6;
  font-weight: 400;
  text-decoration: none;
  cursor: not-allowed; }

.bx--link.bx--link--visited:visited {
  color: #8a3ffc; }

.bx--link.bx--link--visited:visited:hover {
  color: #0043ce; }

.bx--link.bx--link--inline {
  text-decoration: underline; }
  .bx--link.bx--link--inline:hover {
    color: #0043ce; }
  .bx--link.bx--link--inline:focus, .bx--link.bx--link--inline:visited {
    text-decoration: none; }

.bx--link--disabled.bx--link--inline {
  text-decoration: underline; }

.bx--list--nested,
.bx--list--unordered,
.bx--list--ordered {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  list-style: none; }

.bx--list__item {
  color: #161616; }

.bx--list--nested {
  margin-left: 1.5rem; }

.bx--list--ordered:not(.bx--list--nested) {
  counter-reset: item; }

.bx--list--ordered:not(.bx--list--nested)
> .bx--list__item {
  position: relative; }

.bx--list--ordered:not(.bx--list--nested)
> .bx--list__item::before {
  position: absolute;
  left: -1.5rem;
  content: counter(item) ".";
  counter-increment: item; }

.bx--list--ordered.bx--list--nested {
  list-style-type: lower-latin; }

.bx--list--unordered > .bx--list__item {
  position: relative; }
  .bx--list--unordered > .bx--list__item::before {
    position: absolute;
    left: -1rem;
    content: '\002013'; }

.bx--list--unordered.bx--list--nested
> .bx--list__item::before {
  left: -0.75rem;
  content: '\0025AA'; }

.bx--table-toolbar {
  position: relative;
  display: flex;
  width: 100%;
  height: 3rem;
  overflow: hidden;
  background: #ffffff; }

.bx--toolbar-content {
  display: flex;
  justify-content: flex-end;
  width: 100%;
  height: 3rem;
  transform: translate3d(0, 0, 0);
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9), clip-path 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--batch-actions ~ .bx--toolbar-content {
  clip-path: polygon(0 0, 100% 0, 100% 100%, 0 100%); }

.bx--toolbar-content .bx--search .bx--search-input {
  background-color: transparent; }

.bx--batch-actions ~ .bx--toolbar-search-container {
  display: flex;
  align-items: center;
  opacity: 1;
  transition: opacity 110ms; }

.bx--toolbar-search-container-expandable {
  position: relative;
  width: 3rem;
  height: 3rem;
  box-shadow: none;
  transition: flex 240ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--toolbar-search-container-expandable .bx--search {
  position: initial;
  width: 3rem;
  height: 100%; }

.bx--toolbar-search-container-expandable
.bx--search
.bx--search-magnifier {
  left: 0;
  width: 3rem;
  height: 3rem;
  padding: 1rem;
  cursor: pointer;
  transition: background 110ms cubic-bezier(0, 0, 0.38, 0.9);
  pointer-events: all; }

.bx--toolbar-search-container-expandable
.bx--search
.bx--search-magnifier:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--toolbar-search-container-expandable
.bx--search
.bx--search-magnifier:hover {
  background: #e5e5e5; }

.bx--toolbar-search-container-expandable
.bx--search
.bx--label {
  visibility: hidden; }

.bx--toolbar-search-container-expandable
.bx--search
.bx--search-input {
  height: 100%;
  padding: 0;
  background-color: transparent;
  border: none;
  visibility: hidden; }

.bx--toolbar-search-container-expandable
.bx--search
.bx--search-close {
  width: 3rem;
  height: 3rem; }
  .bx--toolbar-search-container-expandable
.bx--search
.bx--search-close::before {
    top: 2px;
    height: calc(100% - 4px);
    background-color: #e5e5e5; }

.bx--toolbar-search-container-expandable
.bx--search
.bx--search-close:focus::before {
  background-color: #0f62fe; }

.bx--toolbar-search-container-active {
  flex: auto;
  transition: flex 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--toolbar-search-container-active .bx--search {
  width: 100%; }

.bx--toolbar-search-container-active
.bx--search
.bx--label,
.bx--toolbar-search-container-active
.bx--search
.bx--search-input {
  padding: 0 3rem;
  visibility: inherit; }

.bx--toolbar-search-container-active
.bx--search
.bx--search-input:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px;
  box-shadow: inset 0 0 0 2px #0f62fe; }

.bx--toolbar-search-container-active
.bx--search
.bx--search-input:focus
+ .bx--search-close {
  border: none;
  outline: none;
  box-shadow: none; }

.bx--toolbar-search-container-active
.bx--search
.bx--search-input:not(:placeholder-shown) {
  background: #e5e5e5;
  border: none; }

.bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:focus,
.bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:active,
.bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:hover {
  background: transparent;
  border: none;
  outline: none; }

.bx--toolbar-search-container-persistent .bx--search-close,
.bx--toolbar-search-container-persistent
.bx--search-close:hover,
.bx--toolbar-search-container-active
.bx--search
.bx--search-close,
.bx--toolbar-search-container-active
.bx--search
.bx--search-close:hover {
  background-color: transparent;
  border: none; }

.bx--toolbar-search-container-persistent
.bx--search-close::before {
  display: none; }

.bx--overflow-menu.bx--toolbar-action {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: flex;
  width: 3rem;
  height: 3rem;
  padding: 1rem;
  cursor: pointer;
  transition: background 110ms cubic-bezier(0, 0, 0.38, 0.9); }
  .bx--overflow-menu.bx--toolbar-action::-moz-focus-inner {
    border: 0; }

.bx--toolbar-action {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: flex;
  width: 3rem;
  height: 3rem;
  cursor: pointer;
  transition: background 110ms cubic-bezier(0, 0, 0.38, 0.9); }
  .bx--toolbar-action::-moz-focus-inner {
    border: 0; }

.bx--toolbar-action:hover:not([disabled]) {
  background: #e5e5e5; }

.bx--toolbar-action:hover[aria-expanded='true'] {
  background: #ffffff; }

.bx--toolbar-action[disabled] {
  cursor: not-allowed; }

.bx--toolbar-action[disabled] .bx--toolbar-action__icon {
  cursor: not-allowed;
  fill: #c6c6c6; }

.bx--toolbar-action:focus:not([disabled]),
.bx--toolbar-action:active:not([disabled]) {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }
  .bx--toolbar-action:focus:not([disabled]).bx--toolbar-search-container-expandable,
  .bx--toolbar-action:active:not([disabled]).bx--toolbar-search-container-expandable {
    outline: none; }

.bx--toolbar-action ~ .bx--btn {
  max-width: none;
  margin: 0;
  white-space: nowrap; }

.bx--overflow-menu--data-table {
  height: 3rem; }

.bx--toolbar-action__icon {
  width: auto;
  max-width: 1rem;
  height: 1rem;
  fill: #161616; }

.bx--toolbar-search-container-persistent {
  position: relative;
  width: 100%;
  height: 3rem;
  opacity: 1; }

.bx--toolbar-search-container-persistent
+ .bx--toolbar-content {
  position: relative;
  width: auto; }

.bx--toolbar-search-container-persistent .bx--search {
  position: initial; }

.bx--toolbar-search-container-persistent
.bx--search
.bx--search-magnifier {
  left: 1rem; }

.bx--toolbar-search-container-persistent
.bx--search
.bx--search-input {
  height: 3rem;
  padding: 0 3rem;
  border: none; }

.bx--toolbar-search-container-persistent
.bx--search
.bx--search-input:focus:not([disabled]) {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--toolbar-search-container-persistent
.bx--search
.bx--search-input:hover:not([disabled]) {
  background: #e5e5e5; }

.bx--toolbar-search-container-persistent
.bx--search
.bx--search-input:active:not([disabled]),
.bx--toolbar-search-container-persistent
.bx--search
.bx--search-input:not(:placeholder-shown) {
  background: #e5e5e5; }

.bx--toolbar-search-container-persistent
.bx--search
.bx--search-close {
  width: 3rem;
  height: 3rem; }

.bx--batch-actions--active ~ .bx--toolbar-search-container,
.bx--batch-actions--active ~ .bx--toolbar-content {
  transform: translate3d(0, 48px, 0);
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9), clip-path 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  clip-path: polygon(0 0, 100% 0, 100% 0, 0 0); }

.bx--batch-actions {
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  align-items: center;
  width: 100%;
  height: 100%;
  padding-right: 1.5rem;
  padding-left: 1.5rem;
  overflow-x: auto;
  background-color: #0f62fe;
  transform: translate3d(0, 48px, 0);
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9), clip-path 110ms cubic-bezier(0.2, 0, 0.38, 0.9), opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  clip-path: polygon(0 0, 100% 0, 100% 0, 0 0);
  pointer-events: none;
  will-change: transform; }

.bx--batch-actions:focus {
  outline: 1px solid #0f62fe; }

.bx--batch-actions--active {
  transform: translate3d(0, 0, 0);
  clip-path: polygon(0 0, 100% 0, 100% 100%, 0 100%);
  pointer-events: all; }

.bx--action-list {
  position: absolute;
  right: 0;
  display: flex; }

.bx--action-list .bx--btn {
  min-width: 0;
  padding: calc(0.875rem - 3px) 12px;
  color: #ffffff; }

.bx--action-list .bx--btn:disabled {
  color: #8d8d8d; }

.bx--action-list .bx--btn .bx--btn__icon {
  position: static;
  margin-left: 0.5rem;
  fill: #ffffff; }

.bx--action-list .bx--btn .bx--btn__icon .st0 {
  fill: none; }

.bx--batch-download {
  padding: 0.0625rem; }

.bx--action-list .bx--btn--primary:focus::before,
.bx--action-list .bx--btn--primary::before,
.bx--action-list .bx--btn--primary:focus::after,
.bx--action-list .bx--btn--primary::after {
  display: none; }

.bx--action-list .bx--btn--primary:focus {
  outline: 2px solid #ffffff;
  outline-offset: -0.125rem; }

.bx--action-list
.bx--btn--primary:nth-child(3):hover
+ .bx--btn--primary.bx--batch-summary__cancel::before,
.bx--action-list
.bx--btn--primary:nth-child(3):focus
+ .bx--btn--primary.bx--batch-summary__cancel::before {
  opacity: 0; }

.bx--btn--primary.bx--batch-summary__cancel::before {
  position: absolute;
  top: 0.9375rem;
  left: 0;
  display: block;
  width: 0.0625rem;
  height: 1rem;
  background-color: #ffffff;
  border: none;
  opacity: 1;
  transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  content: ''; }

.bx--btn--primary.bx--batch-summary__cancel:hover::before {
  opacity: 0;
  transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--batch-summary__cancel {
  position: relative;
  padding-right: 1rem; }

.bx--batch-summary {
  position: absolute;
  left: 0;
  display: flex;
  align-items: center;
  margin-left: 1rem;
  color: #ffffff; }

.bx--batch-summary__para {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px; }

.bx--table-toolbar--small {
  height: 2rem; }
  .bx--table-toolbar--small .bx--toolbar-search-container-expandable,
  .bx--table-toolbar--small .bx--toolbar-search-container-persistent {
    height: 2rem; }
  .bx--table-toolbar--small .bx--toolbar-search-container-expandable
.bx--search
.bx--search-input,
  .bx--table-toolbar--small .bx--toolbar-search-container-persistent
.bx--search
.bx--search-input {
    height: 2rem; }
  .bx--table-toolbar--small .bx--toolbar-search-container-expandable
.bx--search
.bx--search-close,
  .bx--table-toolbar--small .bx--toolbar-search-container-persistent
.bx--search
.bx--search-close {
    width: 2rem;
    height: 2rem; }
  .bx--table-toolbar--small .bx--toolbar-search-container-expandable
.bx--search
.bx--search-magnifier,
  .bx--table-toolbar--small .bx--toolbar-search-container-persistent
.bx--search
.bx--search-magnifier {
    width: 2rem;
    height: 2rem;
    padding: 0.5rem; }
  .bx--table-toolbar--small .bx--toolbar-search-container-expandable {
    width: 2rem; }
  .bx--table-toolbar--small .bx--toolbar-search-container-expandable
.bx--search
.bx--search-input {
    padding: 0 3rem; }
  .bx--table-toolbar--small .bx--toolbar-search-container-active {
    flex: auto;
    transition: flex 175ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-input {
    visibility: inherit; }
  .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-input:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    background: #e5e5e5; }
  .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-input:active,
  .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-input:not(:placeholder-shown) {
    background: #e5e5e5; }
  .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:focus,
  .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:active,
  .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:hover {
    outline: 2px solid transparent;
    outline-offset: -2px;
    background: transparent; }

.bx--table-toolbar--small
.bx--batch-actions
.bx--action-list {
  height: 2rem; }

.bx--table-toolbar--small .bx--toolbar-action {
  width: 2rem;
  height: 2rem;
  padding: 0.5rem 0; }

.bx--table-toolbar--small .bx--btn--primary {
  height: 2rem;
  min-height: auto;
  padding-top: calc(0.375rem - 3px);
  padding-bottom: calc(0.375rem - 3px); }

.bx--table-toolbar--small
.bx--btn--primary.bx--batch-summary__cancel::before {
  top: 0.5rem; }

.bx--table-toolbar--small
.bx--toolbar-action
~ .bx--btn {
  height: 2rem;
  overflow: hidden; }

.bx--data-table-container {
  padding-top: 0.125rem; }

.bx--data-table-content {
  overflow-x: auto; }

.bx--data-table-header {
  padding: 1rem 0 1.5rem 1rem;
  background: #ffffff; }

.bx--data-table-header__title {
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.4;
  letter-spacing: 0;
  color: #161616; }

.bx--data-table-header__description {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  color: #525252; }

.bx--data-table {
  width: 100%;
  border-collapse: collapse;
  border-spacing: 0; }

.bx--data-table thead {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  background-color: #e0e0e0; }

.bx--data-table tbody {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  width: 100%;
  background-color: #ffffff; }

.bx--data-table tr {
  width: 100%;
  height: 3rem;
  border: none; }

.bx--data-table tbody tr,
.bx--data-table tbody tr td,
.bx--data-table tbody tr th {
  transition: background-color 70ms cubic-bezier(0, 0, 0.38, 0.9); }

.bx--data-table tbody tr:hover {
  background: #e5e5e5; }

.bx--data-table tbody tr:hover td,
.bx--data-table tbody tr:hover th {
  color: #161616;
  background: #e5e5e5;
  border-top: 1px solid #e5e5e5;
  border-bottom: 1px solid #e5e5e5; }

.bx--data-table th,
.bx--data-table td {
  text-align: left;
  vertical-align: middle; }

.bx--data-table td {
  padding-right: 1rem;
  padding-left: 1rem; }

.bx--data-table th {
  color: #161616;
  background-color: #e0e0e0; }

.bx--data-table th:last-of-type {
  position: static;
  width: auto; }

.bx--data-table .bx--table-header-label {
  padding-right: 1rem;
  padding-left: 1rem;
  text-align: left; }

.bx--data-table td,
.bx--data-table tbody th {
  padding-right: 1rem;
  padding-left: 1rem;
  color: #525252;
  background: #ffffff;
  border-top: 1px solid #ffffff;
  border-bottom: 1px solid #e0e0e0; }
  .bx--data-table td + td:first-of-type,
  .bx--data-table tbody th + td:first-of-type {
    padding-left: 0.75rem; }

@supports (-moz-appearance: none) {
  .bx--data-table td {
    background-clip: padding-box; } }

.bx--data-table
td.bx--table-column-menu
.bx--overflow-menu[aria-expanded='false']:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--data-table
td.bx--table-column-menu
.bx--overflow-menu[aria-expanded='true']:focus {
  outline: none; }

@media screen and (hover: hover), (-ms-high-contrast: active), (-ms-high-contrast: none) {
  .bx--data-table
td.bx--table-column-menu
.bx--overflow-menu
.bx--overflow-menu__icon {
    opacity: 0; } }

.bx--data-table
td.bx--table-column-menu
.bx--overflow-menu.bx--overflow-menu--open
.bx--overflow-menu__icon {
  opacity: 1; }

.bx--data-table.bx--data-table--visible-overflow-menu
td.bx--table-column-menu
.bx--overflow-menu
.bx--overflow-menu__icon,
.bx--data-table
td.bx--table-column-menu
.bx--overflow-menu:hover
.bx--overflow-menu__icon,
.bx--data-table
td.bx--table-column-menu
.bx--overflow-menu:focus
.bx--overflow-menu__icon,
.bx--data-table
tr:hover
td.bx--table-column-menu
.bx--overflow-menu
.bx--overflow-menu__icon {
  opacity: 1; }

.bx--overflow-menu-options__btn
.bx--overflow-menu-options__option-content
svg {
  position: relative;
  top: 0.1875rem;
  margin-right: 0.5rem; }

.bx--data-table .bx--overflow-menu:hover,
.bx--data-table .bx--overflow-menu__trigger:hover {
  background-color: #cacaca; }

.bx--data-table--selected .bx--overflow-menu:hover,
.bx--data-table--selected .bx--overflow-menu__trigger:hover {
  background-color: #e5e5e5; }

.bx--data-table--compact td.bx--table-column-menu,
.bx--data-table--short td.bx--table-column-menu {
  height: 1.5rem;
  padding-top: 0;
  padding-bottom: 0; }

.bx--data-table--short td.bx--table-column-menu {
  height: 2rem; }

.bx--data-table--tall .bx--table-column-menu {
  padding-top: 0.5rem; }

.bx--data-table--zebra
tbody
tr:not(.bx--parent-row):nth-child(even)
td {
  border-bottom: 1px solid #ffffff; }

.bx--data-table--zebra
tbody
tr:not(.bx--parent-row):nth-child(odd)
td {
  background-color: #f4f4f4;
  border-top: 1px solid #f4f4f4;
  border-bottom: 1px solid #f4f4f4; }

.bx--data-table--zebra
tbody
tr:not(.bx--parent-row):hover
td {
  background-color: #e5e5e5;
  border-top: 1px solid #e5e5e5;
  border-bottom: 1px solid #e5e5e5; }

.bx--table-column-checkbox .bx--checkbox-label {
  padding-left: 1rem; }

.bx--data-table th.bx--table-column-checkbox {
  position: static;
  width: 2.75rem;
  padding-right: 1rem;
  padding-left: 1rem;
  background: #e0e0e0;
  transition: background-color 70ms cubic-bezier(0, 0, 0.38, 0.9); }

.bx--data-table thead th.bx--table-column-checkbox,
.bx--data-table tbody td.bx--table-column-checkbox,
.bx--data-table thead th.bx--table-expand,
.bx--data-table tbody td.bx--table-expand {
  min-width: 0;
  padding-right: 0;
  padding-left: 1rem; }

.bx--data-table thead th.bx--table-column-checkbox,
.bx--data-table tbody td.bx--table-column-checkbox {
  width: 2.25rem; }

.bx--data-table thead th.bx--table-expand,
.bx--data-table tbody td.bx--table-expand {
  width: 2rem; }

.bx--data-table--tall .bx--table-column-checkbox {
  padding-top: 0.8125rem; }

.bx--data-table--tall .bx--table-column-radio {
  padding-top: 1rem; }

.bx--date-table tbody th.bx--table-column-checkbox:hover {
  background: #cacaca; }

.bx--table-column-radio {
  width: 48px; }

.bx--table-column-radio .bx--radio-button__appearance {
  margin-right: -0.125rem; }

.bx--data-table--zebra
tbody
tr:nth-child(odd).bx--data-table--selected
td,
tr.bx--data-table--selected td {
  color: #161616;
  background-color: #e0e0e0;
  border-top: 1px solid #e0e0e0;
  border-bottom: 1px solid #c6c6c6; }

.bx--data-table--zebra
tbody
tr:first-of-type:nth-child(odd).bx--data-table--selected
td,
tr.bx--data-table--selected:first-of-type td {
  border-top: 1px solid #c6c6c6; }

.bx--data-table--zebra
tbody
tr:last-of-type:nth-child(odd).bx--data-table--selected
td,
.bx--data-table--zebra
tbody
tr:last-of-type:nth-child(even).bx--data-table--selected
td,
tr.bx--data-table--selected:last-of-type td {
  border-top: 1px solid #e0e0e0;
  border-bottom: 1px solid #e0e0e0; }

.bx--data-table--zebra
tbody
tr:nth-child(even).bx--data-table--selected
td {
  border-bottom: 1px solid #c6c6c6; }

.bx--data-table--zebra
tbody
tr:nth-child(even).bx--data-table--selected:hover
td {
  border-bottom: 1px solid #cacaca; }

.bx--data-table--zebra
tbody
tr:nth-child(odd).bx--data-table--selected:hover
td,
.bx--data-table tbody .bx--data-table--selected:hover td {
  color: #161616;
  background: #cacaca;
  border-top: 1px solid #cacaca;
  border-bottom: 1px solid #cacaca; }

.bx--data-table--selected
.bx--overflow-menu
.bx--overflow-menu__icon {
  opacity: 1; }

.bx--data-table--compact thead tr,
.bx--data-table--compact tbody tr,
.bx--data-table--compact tbody tr th {
  height: 1.5rem; }

.bx--data-table--compact .bx--table-header-label {
  padding-top: 0.125rem;
  padding-bottom: 0.125rem; }

.bx--data-table--compact td,
.bx--data-table--compact tbody tr th {
  padding-top: 0.125rem;
  padding-bottom: 0.125rem; }

.bx--data-table--compact .bx--overflow-menu {
  width: 2rem;
  height: 100%; }

.bx--data-table.bx--data-table--compact
.bx--table-column-checkbox {
  padding-top: 0;
  padding-bottom: 0; }

.bx--data-table.bx--data-table--compact
.bx--table-column-checkbox
.bx--checkbox-label {
  height: 1.4375rem;
  min-height: 1.4375rem; }

.bx--data-table--short thead tr,
.bx--data-table--short tbody tr,
.bx--data-table--short tbody tr th {
  height: 2rem; }

.bx--data-table--short .bx--table-header-label {
  padding-top: 0.4375rem;
  padding-bottom: 0.4375rem; }

.bx--data-table--short td,
.bx--data-table--short tbody tr th {
  padding-top: 0.4375rem;
  padding-bottom: 0.375rem; }

.bx--data-table.bx--data-table--short
.bx--table-column-checkbox {
  padding-top: 0.1875rem;
  padding-bottom: 0.1875rem; }

.bx--data-table--short .bx--overflow-menu {
  height: 100%; }

.bx--data-table--tall thead tr,
.bx--data-table--tall tbody tr,
.bx--data-table--tall tbody tr th {
  height: 4rem; }

.bx--data-table--tall .bx--table-header-label {
  padding-top: 1rem;
  padding-bottom: 1rem; }

.bx--data-table--tall td,
.bx--data-table--tall tbody tr th {
  padding-top: 1rem; }

.bx--data-table--tall th,
.bx--data-table--tall td {
  vertical-align: top; }

.bx--data-table--cell-secondary-text {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.bx--data-table--static {
  width: auto; }

.bx--data-table_inner-container {
  background-color: #e0e0e0;
  transform: translateZ(0); }

.bx--data-table--sticky-header {
  display: block;
  overflow-y: scroll;
  /* When using sticky header, with a selection element in the first column, we need to set the last item to a fixed width to match the table body. We only want this to happen when the last table header does not have any text */ }
  .bx--data-table--sticky-header thead,
  .bx--data-table--sticky-header tbody,
  .bx--data-table--sticky-header tr,
  .bx--data-table--sticky-header th,
  .bx--data-table--sticky-header td {
    display: flex; }
  .bx--data-table--sticky-header thead {
    position: sticky;
    top: 0;
    z-index: 1;
    width: 100%;
    overflow: scroll;
    will-change: transform;
    -ms-overflow-style: none; }
  .bx--data-table--sticky-header thead tr th {
    border-bottom: 1px solid #c6c6c6; }
  .bx--data-table--sticky-header tbody {
    flex-direction: column;
    overflow-x: scroll;
    -ms-overflow-style: none;
    will-change: transform; }
  .bx--data-table--sticky-header tr.bx--parent-row.bx--expandable-row {
    height: auto;
    min-height: 3rem; }
  .bx--data-table--sticky-header tr.bx--expandable-row:not(.bx--parent-row) {
    height: auto; }
  .bx--data-table--sticky-header .bx--table-expand {
    max-width: 3rem; }
  .bx--data-table--sticky-header thead .bx--table-expand {
    align-items: center; }
  .bx--data-table--sticky-header .bx--parent-row {
    min-height: 3rem; }
  .bx--data-table--sticky-header:not(.bx--data-table--compact):not(.bx--data-table--tall):not(.bx--data-table--short) td:not(.bx--table-column-menu):not(.bx--table-column-checkbox) {
    padding-top: 0.875rem; }
  .bx--data-table--sticky-header tr.bx--parent-row.bx--expandable-row:hover
+ tr[data-child-row]
td {
    border-top: 1px solid #e5e5e5; }
  .bx--data-table--sticky-header tr.bx--expandable-row:last-of-type {
    overflow: hidden; }
  .bx--data-table--sticky-header tr.bx--data-table--selected:first-of-type td {
    border-top: none; }
  .bx--data-table--sticky-header thead th.bx--table-column-checkbox,
  .bx--data-table--sticky-header tbody tr td.bx--table-column-checkbox {
    align-items: center;
    width: 2.25rem;
    min-width: 2.25rem; }
  .bx--data-table--sticky-header.bx--data-table--tall thead th.bx--table-column-checkbox, .bx--data-table--sticky-header.bx--data-table--tall td.bx--table-column-checkbox {
    align-items: flex-start; }
  .bx--data-table--sticky-header th.bx--table-column-checkbox ~ th:last-of-type:empty {
    max-width: 4rem; }
  .bx--data-table--sticky-header th:empty:not(.bx--table-expand) {
    max-width: 2.25rem; }
  .bx--data-table--sticky-header td.bx--table-column-menu {
    align-items: center;
    height: auto;
    padding-top: 0; }
  .bx--data-table--sticky-header thead::-webkit-scrollbar,
  .bx--data-table--sticky-header tbody::-webkit-scrollbar {
    display: none; }

@-moz-document url-prefix() {
  .bx--data-table--sticky-header thead,
  .bx--data-table--sticky-header tbody {
    scrollbar-width: none; } }
  .bx--data-table--sticky-header tbody tr:last-of-type {
    border-bottom: 0; }
  .bx--data-table--sticky-header th:not(.bx--table-column-checkbox):not(.bx--table-column-menu):not(.bx--table-expand-v2):not(.bx--table-column-icon),
  .bx--data-table--sticky-header td:not(.bx--table-column-checkbox):not(.bx--table-column-menu):not(.bx--table-expand-v2):not(.bx--table-column-icon) {
    width: 100%;
    min-width: 0; }
  .bx--data-table--sticky-header.bx--data-table--compact tr:not(.bx--expandable-row), .bx--data-table--sticky-header.bx--data-table--short tr:not(.bx--expandable-row), .bx--data-table--sticky-header.bx--data-table--tall tr:not(.bx--expandable-row) {
    height: auto; }
  .bx--data-table--sticky-header.bx--data-table--compact tr:not(.bx--expandable-row) {
    min-height: 1.5rem; }
  .bx--data-table--sticky-header.bx--data-table--short tr:not(.bx--expandable-row) {
    min-height: 2rem; }
  .bx--data-table--sticky-header.bx--data-table--tall tr:not(.bx--expandable-row) {
    min-height: 4rem; }
  .bx--data-table--sticky-header.bx--data-table--compact tr td.bx--table-expand {
    padding-top: 0.25rem; }
  .bx--data-table--sticky-header.bx--data-table--short tr td.bx--table-expand {
    padding-top: 0.5rem; }
  .bx--data-table--sticky-header .bx--table-header-label {
    display: block;
    overflow-x: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    max-width: calc(100% - 10px);
    padding-top: 0.9375rem;
    padding-bottom: 1rem;
    overflow-y: hidden; }
  .bx--data-table--sticky-header.bx--data-table--compact th .bx--table-header-label {
    padding-top: 0.1875rem;
    padding-bottom: 0; }
  .bx--data-table--sticky-header.bx--data-table--short th .bx--table-header-label {
    padding-top: 0.5rem;
    padding-bottom: 0; }
  .bx--data-table--sticky-header.bx--data-table--tall th .bx--table-header-label {
    padding-top: 1rem; }
  .bx--data-table--sticky-header.bx--data-table--tall th.bx--table-expand {
    display: flex;
    align-items: flex-start; }
  .bx--data-table--sticky-header.bx--data-table--compact tr.bx--parent-row
.bx--table-column-checkbox, .bx--data-table--sticky-header.bx--data-table--short tr.bx--parent-row
.bx--table-column-checkbox {
    align-items: flex-start; }

.bx--data-table--max-width {
  max-width: 100%; }

.bx--data-table--sticky-header {
  max-height: 18.75rem; }

.bx--data-table .bx--form-item.bx--checkbox-wrapper:last-of-type {
  margin: 0; }

.bx--data-table--short
.bx--form-item.bx--checkbox-wrapper:last-of-type,
.bx--data-table--compact
.bx--form-item.bx--checkbox-wrapper:last-of-type {
  margin: -0.1875rem 0; }

.bx--data-table tr.bx--parent-row:first-of-type td {
  border-top: 1px solid #e0e0e0; }

.bx--expandable-row--hidden td {
  width: auto;
  padding: 1rem;
  border-top: 0; }

tr.bx--parent-row:not(.bx--expandable-row)
+ tr[data-child-row] {
  height: 0;
  transition: height 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

tr.bx--parent-row:not(.bx--expandable-row)
+ tr[data-child-row]
td {
  padding-top: 0;
  padding-bottom: 0;
  background-color: #e5e5e5;
  border: 0;
  transition: padding 150ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

tr.bx--parent-row:not(.bx--expandable-row)
+ tr[data-child-row]
td
.bx--child-row-inner-container {
  max-height: 0;
  overflow: hidden; }

tr.bx--parent-row.bx--expandable-row + tr[data-child-row] {
  transition: height 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

tr.bx--parent-row.bx--expandable-row + tr[data-child-row] td {
  border-bottom: 1px solid #e0e0e0;
  transition: padding-bottom 110ms cubic-bezier(0.2, 0, 0.38, 0.9), transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

tr.bx--parent-row.bx--expandable-row
+ tr[data-child-row]
td
.bx--child-row-inner-container {
  max-height: 100%; }

.bx--parent-row.bx--expandable-row > td,
.bx--parent-row.bx--expandable-row + tr[data-child-row] > td {
  border-bottom: 1px solid #e0e0e0;
  box-shadow: 0 1px #e0e0e0; }

.bx--parent-row:not(.bx--expandable-row)
+ tr[data-child-row]
> td {
  box-shadow: none; }

.bx--parent-row.bx--expandable-row > td:first-of-type {
  box-shadow: none; }

tr.bx--parent-row:not(.bx--expandable-row) td,
tr.bx--parent-row.bx--expandable-row td,
tr.bx--parent-row.bx--expandable-row {
  transition: height 240ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

tr.bx--parent-row:not(.bx--expandable-row):first-of-type:hover
td {
  border-top: 1px solid #e0e0e0;
  border-bottom: 1px solid #e0e0e0; }

tr.bx--parent-row.bx--expandable-row:hover td {
  color: #161616;
  background-color: #e5e5e5;
  border-top: 1px solid #e0e0e0;
  border-bottom: 1px solid #e0e0e0; }

tr.bx--parent-row.bx--expandable-row:hover td:first-of-type {
  border-bottom: 1px solid #e5e5e5; }

tr.bx--parent-row.bx--expandable-row:hover
+ tr[data-child-row]
td {
  color: #161616;
  background-color: #e5e5e5;
  border-bottom: 1px solid #e0e0e0; }

tr.bx--expandable-row--hover + tr[data-child-row] td {
  border-bottom: 1px solid #e0e0e0; }

tr.bx--expandable-row--hover {
  background-color: #e5e5e5; }

tr.bx--expandable-row--hover td {
  color: #161616;
  background-color: #e5e5e5;
  border-top: 1px solid #e0e0e0;
  border-bottom: 1px solid #e0e0e0; }

tr.bx--parent-row.bx--expandable-row.bx--expandable-row--hover
td:first-of-type {
  border-bottom: 1px solid transparent; }

.bx--data-table td.bx--table-expand {
  width: 2.5rem;
  min-width: 2.5rem;
  border-bottom: 1px solid #e0e0e0; }

.bx--data-table td.bx--table-expand,
th.bx--table-expand {
  padding: 0 1rem; }

.bx--data-table--tall td.bx--table-expand,
.bx--data-table--tall th.bx--table-expand {
  padding-top: 1rem;
  padding-bottom: 1rem; }

.bx--data-table
td.bx--table-expand[data-previous-value='collapsed'] {
  border-bottom: 1px solid transparent; }

.bx--table-expand[data-previous-value='collapsed']
.bx--table-expand__svg {
  transform: rotate(270deg);
  transition: transform 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--table-expand__button {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  height: 1rem;
  vertical-align: inherit; }
  .bx--table-expand__button::-moz-focus-inner {
    border: 0; }

.bx--table-expand__button:focus {
  outline: 1px solid transparent; }

.bx--table-expand__button:focus .bx--table-expand__svg {
  box-shadow: inset 0 0 0 1px #0f62fe; }

.bx--table-expand__svg {
  transform: rotate(90deg);
  transition: transform 150ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }

tr.bx--parent-row.bx--expandable-row
td.bx--table-expand
+ td::after {
  position: absolute;
  bottom: -0.0625rem;
  left: 0;
  width: 0.5rem;
  height: 0.0625rem;
  background: #e0e0e0;
  content: ''; }

tr.bx--parent-row.bx--expandable-row:hover
td.bx--table-expand
+ td::after,
tr.bx--parent-row.bx--expandable-row.bx--expandable-row--hover
td.bx--table-expand
+ td::after {
  background: #e5e5e5; }

tr.bx--parent-row.bx--data-table--selected
td.bx--table-expand
+ td::after {
  display: none; }

.bx--data-table--zebra tbody tr[data-parent-row]:nth-child(4n + 3) td,
.bx--data-table--zebra tbody tr[data-child-row]:nth-child(4n + 4) td {
  border-bottom: 1px solid #ffffff; }

.bx--data-table--zebra tbody tr[data-parent-row]:nth-child(4n + 1) td,
.bx--data-table--zebra tbody tr[data-child-row]:nth-child(4n + 2) td {
  background-color: #f4f4f4;
  border-top: 1px solid #f4f4f4;
  border-bottom: 1px solid #f4f4f4; }

.bx--data-table--zebra tr.bx--parent-row td,
.bx--data-table--zebra
tr.bx--parent-row.bx--expandable-row
+ tr[data-child-row]
td {
  transition: transform 150ms cubic-bezier(0.2, 0, 0.38, 0.9), border-bottom 150ms cubic-bezier(0.2, 0, 0.38, 0.9), border-top 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--data-table--zebra tbody tr[data-parent-row]:hover td,
.bx--data-table--zebra
tbody
tr[data-parent-row]:hover
+ tr[data-child-row]
td,
.bx--data-table--zebra tbody tr[data-child-row]:hover td {
  background-color: #e5e5e5;
  border-top: 1px solid #e5e5e5;
  border-bottom: 1px solid #e5e5e5; }

.bx--data-table--zebra
tr.bx--parent-row.bx--expandable-row.bx--expandable-row--hover
td {
  background: #e5e5e5;
  border-top: 1px solid #e5e5e5;
  border-bottom: 1px solid #e5e5e5; }

tr.bx--parent-row.bx--data-table--selected:first-of-type td {
  background: #e0e0e0;
  border-top: 1px solid #c6c6c6;
  border-bottom: 1px solid #e0e0e0;
  box-shadow: 0 1px #c6c6c6; }

tr.bx--parent-row.bx--data-table--selected td {
  color: #161616;
  background: #e0e0e0;
  border-bottom: 1px solid transparent;
  box-shadow: 0 1px #c6c6c6; }

tr.bx--parent-row.bx--data-table--selected:last-of-type td {
  background: #e0e0e0;
  border-bottom: 1px solid transparent;
  box-shadow: 0 1px #e0e0e0; }

tr.bx--parent-row.bx--data-table--selected:not(.bx--expandable-row):hover
td {
  background: #cacaca;
  border-top: 1px solid #cacaca;
  border-bottom: 1px solid #e0e0e0;
  box-shadow: 0 1px #cacaca; }

tr.bx--parent-row.bx--data-table--selected.bx--expandable-row
td,
tr.bx--parent-row.bx--data-table--selected.bx--expandable-row
td:first-of-type {
  border-bottom: 1px solid transparent;
  box-shadow: 0 1px #e0e0e0; }

tr.bx--parent-row.bx--data-table--selected.bx--expandable-row:hover
td,
tr.bx--parent-row.bx--data-table--selected.bx--expandable-row:hover
td:first-of-type,
tr.bx--parent-row.bx--data-table--selected.bx--expandable-row--hover
td,
tr.bx--parent-row.bx--data-table--selected.bx--expandable-row--hover
td:first-of-type {
  background: #cacaca;
  border-top: 1px solid #cacaca;
  border-bottom: 1px solid transparent;
  box-shadow: 0 1px #cacaca; }

tr.bx--parent-row.bx--data-table--selected.bx--expandable-row
+ tr[data-child-row]
td {
  color: #161616;
  background-color: #e5e5e5;
  border-top: 1px solid #c6c6c6;
  border-bottom: 1px solid #e0e0e0;
  box-shadow: 0 1px #c6c6c6; }

tr.bx--parent-row.bx--data-table--selected.bx--expandable-row
+ tr[data-child-row]:last-of-type
td {
  padding-bottom: 1.5rem;
  box-shadow: inset 0 -1px #c6c6c6; }

tr.bx--parent-row.bx--data-table--selected.bx--expandable-row:hover
+ tr[data-child-row]
td,
tr.bx--parent-row.bx--data-table--selected.bx--expandable-row--hover
+ tr[data-child-row]
td {
  background: #e0e0e0; }

.bx--data-table--sort th {
  height: 3rem;
  border-top: none;
  border-bottom: none; }

.bx--table-sort {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  min-height: 100%;
  color: #161616;
  font: inherit;
  line-height: 1;
  background-color: #e0e0e0;
  transition: background-color 70ms cubic-bezier(0, 0, 0.38, 0.9), outline 70ms cubic-bezier(0, 0, 0.38, 0.9); }
  .bx--table-sort::-moz-focus-inner {
    border: 0; }

.bx--table-sort:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--table-sort:hover {
  background: #cacaca; }

.bx--table-sort:focus svg,
.bx--table-sort:hover svg {
  opacity: 1; }

.bx--data-table--sort th .bx--table-sort__flex {
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  height: 100%;
  min-height: 3rem; }

.bx--data-table--sort:not(.bx--data-table--compact):not(.bx--data-table--short):not(.bx--data-table--tall)
th
.bx--table-sort__flex {
  /* IE11 workaround for align-items: center and min-height
        https://github.com/philipwalton/flexbugs/issues/231 */ }
  @media screen and (-ms-high-contrast: active), screen and (-ms-high-contrast: none) {
    .bx--data-table--sort:not(.bx--data-table--compact):not(.bx--data-table--short):not(.bx--data-table--tall)
th
.bx--table-sort__flex {
      height: 2.99rem; } }
.bx--data-table--compact.bx--data-table--sort
th
.bx--table-sort__flex {
  min-height: 1.5rem; }

.bx--data-table--short.bx--data-table--sort
th
.bx--table-sort__flex {
  min-height: 2rem; }

.bx--data-table--tall.bx--data-table--sort
th
.bx--table-sort__flex {
  align-items: flex-start;
  min-height: 4rem; }

.bx--table-sort .bx--table-sort__icon-inactive {
  display: block; }

.bx--table-sort .bx--table-sort__icon {
  display: none; }

.bx--table-sort__icon-unsorted {
  width: 1.25rem;
  min-width: 1rem;
  margin-right: 0.5rem;
  margin-left: 0.5rem;
  opacity: 0;
  fill: #161616; }

.bx--table-sort.bx--table-sort--active {
  background: #cacaca; }

.bx--table-sort.bx--table-sort--active
.bx--table-sort__icon-unsorted {
  display: none; }

.bx--table-sort.bx--table-sort--active
.bx--table-sort__icon {
  display: block;
  opacity: 1; }

.bx--table-sort--ascending .bx--table-sort__icon {
  transform: rotate(180deg); }

.bx--table-sort__icon {
  width: 1.25rem;
  min-width: 1rem;
  margin-right: 0.5rem;
  margin-left: 0.5rem;
  transform: rotate(0);
  opacity: 1;
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }

.bx--data-table--compact.bx--data-table--sort th {
  height: 1.5rem; }

.bx--data-table--short.bx--data-table--sort th {
  height: 2rem; }

.bx--data-table--tall.bx--data-table--sort th {
  height: 4rem; }

.bx--data-table--tall.bx--data-table--sort
th
.bx--table-sort {
  display: inline-block;
  height: 4rem; }

.bx--data-table--tall .bx--table-sort__icon-unsorted,
.bx--data-table--tall .bx--table-sort__icon {
  margin-top: 0.8125rem; }

.bx--inline-edit-label {
  display: flex;
  align-items: center;
  justify-content: space-between; }
  .bx--inline-edit-label:hover .bx--inline-edit-label__icon {
    opacity: 1; }

.bx--inline-edit-label--inactive {
  display: none; }

.bx--inline-edit-label__action {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none; }
  .bx--inline-edit-label__action::-moz-focus-inner {
    border: 0; }
  .bx--inline-edit-label__action:hover {
    cursor: pointer; }
  .bx--inline-edit-label__action:focus {
    outline: 1px solid #0f62fe;
    padding: 0.125rem; }
    .bx--inline-edit-label__action:focus .bx--inline-edit-label__icon {
      width: auto;
      opacity: 1; }

.bx--inline-edit-label__icon {
  opacity: 0;
  fill: #161616; }

.bx--inline-edit-input {
  display: none; }

.bx--inline-edit-input--active {
  display: block;
  margin-left: -0.75rem; }
  .bx--inline-edit-input--active input {
    padding-left: 0.75rem; }

.bx--data-table--short input {
  height: 2rem; }

.bx--data-table--short select {
  padding: 0.45rem 2.75rem 0.45rem 1rem; }

.bx--data-table--short .bx--select__arrow {
  top: 0.875rem; }

.bx--data-table.bx--skeleton th {
  padding-left: 1rem;
  vertical-align: middle; }

.bx--data-table.bx--skeleton th span,
.bx--data-table.bx--skeleton td span {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  display: block;
  width: 4rem;
  height: 1rem; }
  .bx--data-table.bx--skeleton th span:hover, .bx--data-table.bx--skeleton th span:focus, .bx--data-table.bx--skeleton th span:active,
  .bx--data-table.bx--skeleton td span:hover,
  .bx--data-table.bx--skeleton td span:focus,
  .bx--data-table.bx--skeleton td span:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--data-table.bx--skeleton th span::before,
  .bx--data-table.bx--skeleton td span::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--data-table.bx--skeleton th span::before,
      .bx--data-table.bx--skeleton td span::before {
        animation: none; } }
.bx--data-table.bx--skeleton tr:hover td {
  background: transparent;
  border-color: #e0e0e0; }
  .bx--data-table.bx--skeleton tr:hover td:first-of-type, .bx--data-table.bx--skeleton tr:hover td:last-of-type {
    border-color: #e0e0e0; }

.bx--data-table.bx--skeleton .bx--table-sort-v2 {
  pointer-events: none; }

.bx--data-table.bx--skeleton th span {
  background: #c6c6c6; }

.bx--data-table.bx--skeleton th span::before {
  background: #e5e5e5; }

.bx--data-table-container.bx--skeleton
.bx--data-table-header__title {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 7.5rem;
  height: 1.5rem; }
  .bx--data-table-container.bx--skeleton
.bx--data-table-header__title:hover, .bx--data-table-container.bx--skeleton
.bx--data-table-header__title:focus, .bx--data-table-container.bx--skeleton
.bx--data-table-header__title:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--data-table-container.bx--skeleton
.bx--data-table-header__title::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--data-table-container.bx--skeleton
.bx--data-table-header__title::before {
        animation: none; } }
.bx--data-table-container.bx--skeleton
.bx--data-table-header__description {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 10rem;
  height: 1rem;
  margin-top: 0.5rem; }
  .bx--data-table-container.bx--skeleton
.bx--data-table-header__description:hover, .bx--data-table-container.bx--skeleton
.bx--data-table-header__description:focus, .bx--data-table-container.bx--skeleton
.bx--data-table-header__description:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--data-table-container.bx--skeleton
.bx--data-table-header__description::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--data-table-container.bx--skeleton
.bx--data-table-header__description::before {
        animation: none; } }
.bx--structured-list--selection .bx--structured-list-td,
.bx--structured-list--selection .bx--structured-list-th {
  padding-right: 1rem;
  padding-left: 1rem; }
  .bx--structured-list--selection .bx--structured-list-td:first-child,
  .bx--structured-list--selection .bx--structured-list-th:first-child {
    padding-right: 1rem;
    padding-left: 1rem; }

.bx--structured-list-input {
  display: none; }

.bx--structured-list {
  display: table;
  width: 100%;
  margin-bottom: 5rem;
  overflow-x: auto;
  overflow-y: hidden;
  background-color: transparent;
  border-collapse: collapse;
  border-spacing: 0; }
  .bx--structured-list.bx--structured-list--condensed .bx--structured-list-td, .bx--structured-list.bx--structured-list--condensed .bx--structured-list-th {
    padding: 0.5rem;
    padding-left: 0; }

.bx--structured-list-row {
  display: table-row;
  border-bottom: 1px solid #e0e0e0;
  transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--structured-list--selection
.bx--structured-list-row:hover:not(.bx--structured-list-row--header-row):not(.bx--structured-list-row--selected) {
  background-color: #e5e5e5;
  border-bottom: 1px solid #e5e5e5;
  cursor: pointer; }

.bx--structured-list-row.bx--structured-list-row--selected {
  background-color: #e0e0e0; }

.bx--structured-list-row.bx--structured-list-row--header-row {
  border-bottom: 1px solid #e0e0e0;
  cursor: inherit; }

.bx--structured-list-row:focus:not(.bx--structured-list-row--header-row) {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--structured-list--selection
.bx--structured-list-row:hover:not(.bx--structured-list-row--header-row)
> .bx--structured-list-td,
.bx--structured-list-row.bx--structured-list-row--selected
> .bx--structured-list-td {
  color: #161616; }

.bx--structured-list--selection
.bx--structured-list-row:hover:not(.bx--structured-list-row--header-row)
> .bx--structured-list-td {
  border-top: 1px solid #ffffff; }

.bx--structured-list-thead {
  display: table-header-group;
  vertical-align: middle; }

.bx--structured-list-th {
  padding: 1rem 1rem 0.5rem 1rem;
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: table-cell;
  height: 2.5rem;
  color: #161616;
  font-weight: 600;
  text-align: left;
  text-transform: none;
  vertical-align: bottom; }

.bx--structured-list-tbody {
  display: table-row-group;
  vertical-align: middle; }

.bx--structured-list-td {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px;
  padding: 1rem 1rem 1.5rem 1rem;
  position: relative;
  display: table-cell;
  max-width: 36rem;
  color: #525252;
  transition: color 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--structured-list-content--nowrap {
  white-space: nowrap; }

.bx--structured-list-svg {
  display: inline-block;
  vertical-align: middle;
  transition: all 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: transparent; }

.bx--structured-list-row:hover .bx--structured-list-svg {
  fill: #a8a8a8; }

.bx--structured-list-input:checked
+ .bx--structured-list-row
.bx--structured-list-svg,
.bx--structured-list-input:checked
+ .bx--structured-list-td
.bx--structured-list-svg {
  fill: #161616; }

.bx--structured-list.bx--skeleton .bx--structured-list-th:first-child {
  width: 8%; }

.bx--structured-list.bx--skeleton .bx--structured-list-th:nth-child(3n + 2) {
  width: 30%; }

.bx--structured-list.bx--skeleton .bx--structured-list-th:nth-child(3n + 3) {
  width: 15%; }

.bx--structured-list.bx--skeleton span {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  display: block;
  width: 75%;
  height: 1rem; }
  .bx--structured-list.bx--skeleton span:hover, .bx--structured-list.bx--skeleton span:focus, .bx--structured-list.bx--skeleton span:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--structured-list.bx--skeleton span::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--structured-list.bx--skeleton span::before {
        animation: none; } }
.bx--structured-list.bx--structured-list--selection.bx--skeleton
.bx--structured-list-th:first-child {
  width: 5%; }
  .bx--structured-list.bx--structured-list--selection.bx--skeleton
.bx--structured-list-th:first-child span {
    display: none; }

@keyframes hide-feedback {
  0% {
    visibility: inherit;
    opacity: 1; }
  100% {
    visibility: hidden;
    opacity: 0; } }

@keyframes show-feedback {
  0% {
    visibility: hidden;
    opacity: 0; }
  100% {
    visibility: inherit;
    opacity: 1; } }

.bx--snippet code {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.bx--snippet--inline {
  position: relative;
  display: inline;
  padding: 0;
  color: #161616;
  background-color: #ffffff;
  border: 2px solid transparent;
  border-radius: 4px;
  cursor: pointer; }
  .bx--snippet--inline:hover {
    background-color: #e0e0e0; }
  .bx--snippet--inline:active {
    background-color: #c6c6c6; }
  .bx--snippet--inline:focus {
    border: 2px solid #0f62fe;
    outline: none; }
  .bx--snippet--inline::before {
    position: absolute;
    z-index: 6000;
    width: 0;
    height: 0;
    border-style: solid;
    content: '';
    display: none; }
  .bx--snippet--inline .bx--copy-btn__feedback {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px;
    display: none;
    box-sizing: content-box;
    margin: auto;
    overflow: visible;
    clip: auto; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--snippet--inline .bx--copy-btn__feedback {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--snippet--inline .bx--copy-btn__feedback {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--snippet--inline .bx--copy-btn__feedback {
        width: 13rem; } }
  .bx--snippet--inline::before, .bx--snippet--inline::after,
  .bx--snippet--inline .bx--assistive-text,
  .bx--snippet--inline + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--snippet--inline::before {
    bottom: -0.5rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--snippet--inline::after,
  .bx--snippet--inline .bx--assistive-text,
  .bx--snippet--inline + .bx--assistive-text {
    bottom: -0.8125rem;
    transform: translate(-50%, 100%); }

.bx--snippet--inline.bx--copy-btn--animating::before,
.bx--snippet--inline.bx--copy-btn--animating
.bx--copy-btn__feedback {
  display: block; }

.bx--snippet--inline.bx--copy-btn--animating.bx--copy-btn--fade-out::before,
.bx--snippet--inline.bx--copy-btn--animating.bx--copy-btn--fade-out
.bx--copy-btn__feedback {
  animation: 110ms cubic-bezier(0.2, 0, 0.38, 0.9) hide-feedback; }

.bx--snippet--inline.bx--copy-btn--animating.bx--copy-btn--fade-in::before,
.bx--snippet--inline.bx--copy-btn--animating.bx--copy-btn--fade-in
.bx--copy-btn__feedback {
  animation: 110ms cubic-bezier(0.2, 0, 0.38, 0.9) show-feedback; }

.bx--snippet--inline code {
  padding: 0 0.5rem; }

.bx--snippet--inline.bx--snippet--no-copy {
  display: inline-block; }
  .bx--snippet--inline.bx--snippet--no-copy:hover {
    background-color: #ffffff;
    cursor: auto; }

.bx--snippet--single {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  position: relative;
  width: 100%;
  max-width: 37.5rem;
  background: #ffffff;
  min-width: 20rem;
  max-width: 47.5rem;
  height: 2.5rem;
  padding-right: 2.5rem; }

.bx--snippet--single.bx--snippet--no-copy {
  padding: 0; }
  .bx--snippet--single.bx--snippet--no-copy::after {
    right: 1rem; }

.bx--snippet--single .bx--snippet-container {
  position: relative;
  display: flex;
  align-items: center;
  height: 100%;
  padding-left: 1rem;
  overflow-x: auto;
  border-right: solid 1rem transparent; }
  .bx--snippet--single .bx--snippet-container:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.bx--snippet--single pre {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  padding-right: 0.5rem;
  white-space: nowrap; }

.bx--snippet--single::after {
  position: absolute;
  top: 0;
  right: 3.5rem;
  width: 1rem;
  height: 100%;
  background-image: linear-gradient(to right, rgba(255, 255, 255, 0), #ffffff);
  content: ''; }

.bx--snippet--multi {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  position: relative;
  width: 100%;
  max-width: 37.5rem;
  background: #ffffff;
  min-width: 20rem;
  max-width: 100%;
  padding: 1rem; }

.bx--snippet--multi .bx--snippet-container {
  position: relative;
  min-height: 3.5rem;
  max-height: 14.875rem;
  overflow: hidden;
  transition: max-height 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--snippet--multi.bx--snippet--expand
.bx--snippet-container {
  max-height: 100%;
  padding-bottom: 1rem;
  transition: max-height 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--snippet--multi .bx--snippet-container pre {
  padding-right: 2.5rem;
  padding-bottom: 1.5rem;
  overflow-x: scroll; }

.bx--snippet--multi.bx--snippet--no-copy
.bx--snippet-container
pre {
  padding-right: 0; }

.bx--snippet--multi.bx--snippet--expand
.bx--snippet-container
pre {
  overflow-x: auto; }

.bx--snippet--multi .bx--snippet-container pre::after {
  position: absolute;
  top: 0;
  right: 0;
  width: 1rem;
  height: 100%;
  background-image: linear-gradient(to right, rgba(255, 255, 255, 0), #ffffff);
  content: ''; }

.bx--snippet--multi .bx--snippet-container pre code {
  overflow: hidden; }

.bx--snippet__icon {
  width: 1rem;
  height: 1rem;
  transition: all 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }

.bx--snippet-button {
  position: absolute;
  top: 0;
  right: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2.5rem;
  height: 2.5rem;
  padding: 0;
  overflow: visible;
  background-color: #ffffff;
  border: none;
  outline: none;
  cursor: pointer; }
  .bx--snippet-button:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    outline-color: #0f62fe; }

.bx--snippet--multi .bx--snippet-button {
  top: 0.5rem;
  right: 0.5rem;
  width: 2rem;
  height: 2rem; }

.bx--snippet-button:hover {
  background: #e5e5e5; }

.bx--snippet-button:active {
  background-color: #c6c6c6; }

.bx--btn--copy__feedback {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  font-family: 'IBM Plex Sans', 'Helvetica Neue', Arial, sans-serif;
  top: 0.75rem;
  right: 1.25rem;
  left: inherit;
  z-index: 6000;
  font-weight: 400; }

.bx--btn--copy__feedback::before,
.bx--btn--copy__feedback::after {
  background: #393939; }

.bx--btn--copy__feedback::after {
  border: none; }

.bx--snippet .bx--copy-btn {
  position: absolute;
  top: 0;
  right: 0;
  font-family: 'IBM Plex Sans', 'Helvetica Neue', Arial, sans-serif; }

button.bx--btn.bx--snippet-btn--expand {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  font-family: 'IBM Plex Sans', 'Helvetica Neue', Arial, sans-serif;
  position: absolute;
  right: 0.5rem;
  bottom: 0.5rem;
  display: inline-flex;
  align-items: center;
  padding: 0.5rem;
  padding-left: 1rem;
  color: #161616;
  background-color: #ffffff;
  border: 0; }

button.bx--btn.bx--snippet-btn--expand
.bx--snippet-btn--text {
  position: relative;
  top: -0.0625rem; }

.bx--snippet-btn--expand--hide.bx--snippet-btn--expand {
  display: none; }

.bx--snippet-btn--expand .bx--icon-chevron--down {
  margin-bottom: 0.0625rem;
  margin-left: 0.5rem;
  transform: rotate(0deg);
  transition: 150ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }

button.bx--btn.bx--snippet-btn--expand:hover {
  color: #161616;
  background: #e5e5e5; }

.bx--snippet-btn--expand:active {
  background-color: #c6c6c6; }

.bx--snippet-btn--expand:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px;
  border-color: transparent; }

.bx--snippet--expand
.bx--snippet-btn--expand
.bx--icon-chevron--down {
  transform: rotate(180deg);
  transition: transform 240ms; }

.bx--snippet.bx--snippet--light,
.bx--snippet.bx--snippet--light .bx--snippet-button,
.bx--snippet.bx--snippet--light
.bx--snippet-btn--expand,
.bx--snippet.bx--snippet--light .bx--copy-btn {
  background-color: #f4f4f4; }

.bx--snippet.bx--snippet--light.bx--snippet--inline:hover,
.bx--snippet.bx--snippet--light
.bx--snippet-button:hover,
.bx--snippet.bx--snippet--light
.bx--snippet-btn--expand:hover,
.bx--snippet.bx--snippet--light .bx--copy-btn:hover {
  background-color: var(--cds-ui-01-light, #ebebeb); }

.bx--snippet.bx--snippet--light.bx--snippet--single::after,
.bx--snippet.bx--snippet--light.bx--snippet--multi
.bx--snippet-container
pre::after {
  background-image: linear-gradient(to right, rgba(244, 244, 244, 0), #f4f4f4); }

.bx--snippet--code.bx--skeleton {
  height: 6.125rem; }

.bx--snippet--terminal.bx--skeleton {
  height: 3.5rem; }

.bx--snippet.bx--skeleton .bx--snippet-container {
  height: 100%; }

.bx--snippet.bx--skeleton code {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  display: block;
  width: 100%;
  height: 1rem; }
  .bx--snippet.bx--skeleton code:hover, .bx--snippet.bx--skeleton code:focus, .bx--snippet.bx--skeleton code:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--snippet.bx--skeleton code::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--snippet.bx--skeleton code::before {
        animation: none; } }
.bx--snippet-button .bx--btn--copy__feedback {
  top: 3.175rem;
  right: auto;
  left: 50%; }
  .bx--snippet-button .bx--btn--copy__feedback::before {
    top: 0; }
  .bx--snippet-button .bx--btn--copy__feedback::after {
    top: -0.25rem; }

.bx--snippet--multi
.bx--snippet-button
.bx--btn--copy__feedback {
  top: 2.675rem; }

.bx--snippet--inline .bx--btn--copy__feedback {
  top: calc(100% - 0.25rem);
  right: auto;
  left: 50%; }

bx--snippet--multi.bx--skeleton {
  height: 6.125rem; }

.bx--snippet--single.bx--skeleton {
  height: 3.5rem; }

.bx--snippet.bx--skeleton span {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  display: block;
  width: 100%;
  height: 1rem;
  margin-top: 0.5rem; }
  .bx--snippet.bx--skeleton span:hover, .bx--snippet.bx--skeleton span:focus, .bx--snippet.bx--skeleton span:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--snippet.bx--skeleton span::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--snippet.bx--skeleton span::before {
        animation: none; } }
  .bx--snippet.bx--skeleton span:first-child {
    margin: 0; }
  .bx--snippet.bx--skeleton span:nth-child(2) {
    width: 85%; }
  .bx--snippet.bx--skeleton span:nth-child(3) {
    width: 95%; }

.bx--snippet--single.bx--skeleton
.bx--snippet-container {
  padding-bottom: 0; }

.bx--overflow-menu,
.bx--overflow-menu__trigger {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2rem;
  height: 2rem;
  cursor: pointer;
  transition: outline 110ms cubic-bezier(0, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0, 0, 0.38, 0.9); }
  .bx--overflow-menu::-moz-focus-inner,
  .bx--overflow-menu__trigger::-moz-focus-inner {
    border: 0; }
  .bx--overflow-menu:focus,
  .bx--overflow-menu__trigger:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--overflow-menu:hover,
  .bx--overflow-menu__trigger:hover {
    background-color: #e5e5e5; }

.bx--overflow-menu__trigger.bx--tooltip--a11y.bx--tooltip__trigger:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }
  .bx--overflow-menu__trigger.bx--tooltip--a11y.bx--tooltip__trigger:focus svg {
    outline: none; }

.bx--overflow-menu.bx--overflow-menu--open,
.bx--overflow-menu.bx--overflow-menu--open
.bx--overflow-menu__trigger {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
  background-color: #ffffff;
  transition: none; }

.bx--overflow-menu--light.bx--overflow-menu--open,
.bx--overflow-menu--light.bx--overflow-menu--open
.bx--overflow-menu__trigger {
  background-color: #f4f4f4; }

.bx--overflow-menu__icon {
  width: 1rem;
  height: 1rem;
  fill: #161616; }

.bx--overflow-menu-options {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
  position: absolute;
  top: 32px;
  left: 0;
  z-index: 6000;
  display: none;
  flex-direction: column;
  align-items: flex-start;
  width: 10rem;
  list-style: none;
  background-color: #ffffff; }
  .bx--overflow-menu-options::after {
    position: absolute;
    display: block;
    background-color: #ffffff;
    transition: background-color 110ms cubic-bezier(0, 0, 0.38, 0.9);
    content: ''; }

.bx--overflow-menu.bx--overflow-menu--open:hover {
  background-color: #ffffff; }

.bx--overflow-menu-options--light {
  background-color: #f4f4f4; }
  .bx--overflow-menu-options--light::after {
    background-color: #f4f4f4; }

.bx--overflow-menu.bx--overflow-menu--light.bx--overflow-menu--open:hover {
  background-color: #f4f4f4; }

.bx--overflow-menu-options[data-floating-menu-direction='bottom']::after {
  top: -0.1875rem;
  left: 0;
  width: 2rem;
  height: 0.1875rem; }

.bx--overflow-menu-options[data-floating-menu-direction='top']::after {
  bottom: -0.5rem;
  left: 0;
  width: 2rem;
  height: 0.5rem; }

.bx--overflow-menu-options[data-floating-menu-direction='left']::after {
  top: 0;
  right: -0.375rem;
  width: 0.375rem;
  height: 2rem; }

.bx--overflow-menu-options[data-floating-menu-direction='right']::after {
  top: 0;
  left: -0.375rem;
  width: 0.375rem;
  height: 2rem; }

.bx--overflow-menu--flip.bx--overflow-menu-options[data-floating-menu-direction='top']::after,
.bx--overflow-menu--flip.bx--overflow-menu-options[data-floating-menu-direction='bottom']::after {
  right: 0;
  left: auto; }

.bx--overflow-menu--flip.bx--overflow-menu-options[data-floating-menu-direction='left']::after,
.bx--overflow-menu--flip.bx--overflow-menu-options[data-floating-menu-direction='right']::after {
  top: auto;
  bottom: 0; }

.bx--overflow-menu-options--open {
  display: flex; }

.bx--overflow-menu-options__content {
  width: 100%; }

.bx--overflow-menu-options__option {
  display: flex;
  align-items: center;
  width: 100%;
  height: 2.5rem;
  padding: 0;
  background-color: transparent;
  transition: background-color 110ms cubic-bezier(0, 0, 0.38, 0.9); }

.bx--overflow-menu--divider {
  border-top: 1px solid #e0e0e0; }

.bx--overflow-menu--light .bx--overflow-menu--divider {
  border-top: 1px solid #e0e0e0; }

a.bx--overflow-menu-options__btn::before {
  display: inline-block;
  height: 100%;
  vertical-align: middle;
  content: ''; }

.bx--overflow-menu-options__btn {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: inline-flex;
  align-items: center;
  width: 100%;
  max-width: 11.25rem;
  height: 100%;
  padding: 0 1rem;
  color: #525252;
  font-weight: 400;
  text-align: left;
  background-color: transparent;
  border: none;
  cursor: pointer;
  transition: outline 110ms cubic-bezier(0, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0, 0, 0.38, 0.9), color 110ms cubic-bezier(0, 0, 0.38, 0.9); }
  .bx--overflow-menu-options__btn:hover {
    color: #161616; }
  .bx--overflow-menu-options__btn:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--overflow-menu-options__btn::-moz-focus-inner {
    border: none; }

.bx--overflow-menu-options__btn svg {
  fill: #525252; }

.bx--overflow-menu-options__btn:hover svg {
  fill: #161616; }

.bx--overflow-menu-options__option-content {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.bx--overflow-menu-options__option:hover {
  background-color: #e5e5e5; }

.bx--overflow-menu-options__option--danger {
  border-top: 1px solid #e0e0e0; }

.bx--overflow-menu--light
.bx--overflow-menu-options__option--danger {
  border-top: 1px solid #e0e0e0; }

.bx--overflow-menu-options__option--danger
.bx--overflow-menu-options__btn:hover,
.bx--overflow-menu-options__option--danger
.bx--overflow-menu-options__btn:focus {
  color: #ffffff;
  background-color: #da1e28; }
  .bx--overflow-menu-options__option--danger
.bx--overflow-menu-options__btn:hover svg,
  .bx--overflow-menu-options__option--danger
.bx--overflow-menu-options__btn:focus svg {
    fill: #ffffff; }

.bx--overflow-menu-options__option--disabled:hover {
  background-color: #ffffff;
  cursor: not-allowed; }

.bx--overflow-menu-options__option--disabled
.bx--overflow-menu-options__btn {
  color: #c6c6c6;
  pointer-events: none; }
  .bx--overflow-menu-options__option--disabled
.bx--overflow-menu-options__btn:hover, .bx--overflow-menu-options__option--disabled
.bx--overflow-menu-options__btn:active, .bx--overflow-menu-options__option--disabled
.bx--overflow-menu-options__btn:focus {
    outline: 2px solid transparent;
    outline-offset: -2px;
    background-color: #ffffff; }

.bx--overflow-menu-options__option--disabled
.bx--overflow-menu-options__btn
svg {
  fill: #c6c6c6; }

.bx--overflow-menu--flip {
  left: -140px; }
  .bx--overflow-menu--flip::before {
    left: 145px; }

.bx--content-switcher {
  display: flex;
  justify-content: space-evenly;
  width: 100%;
  height: 2.5rem; }

.bx--content-switcher--disabled {
  cursor: not-allowed; }

.bx--content-switcher-btn {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: relative;
  display: inline-flex;
  align-items: center;
  width: 100%;
  margin: 0;
  padding: 0.5rem 1rem;
  overflow: hidden;
  color: #525252;
  white-space: nowrap;
  text-align: left;
  text-decoration: none;
  background-color: #ffffff;
  border: none;
  transition: all 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--content-switcher-btn:focus {
    z-index: 3;
    box-shadow: inset 0 0 0 2px #0f62fe; }
  .bx--content-switcher-btn:hover {
    cursor: pointer; }
  .bx--content-switcher-btn:hover, .bx--content-switcher-btn:active {
    z-index: 3;
    color: #161616;
    background-color: #e5e5e5; }
  .bx--content-switcher-btn:disabled {
    color: #c6c6c6;
    background-color: #ffffff;
    pointer-events: none; }
    .bx--content-switcher-btn:disabled:hover {
      cursor: not-allowed; }

.bx--content-switcher--light .bx--content-switcher-btn {
  background-color: #f4f4f4; }
  .bx--content-switcher--light .bx--content-switcher-btn:hover {
    background-color: #e5e5e5; }

.bx--content-switcher-btn:first-child {
  border-top-left-radius: 0.25rem;
  border-bottom-left-radius: 0.25rem; }

.bx--content-switcher-btn:last-child {
  border-top-right-radius: 0.25rem;
  border-bottom-right-radius: 0.25rem; }

.bx--content-switcher-btn::before {
  position: absolute;
  left: 0;
  z-index: 2;
  display: block;
  width: 0.0625rem;
  height: 1rem;
  background-color: #e0e0e0;
  content: ''; }

.bx--content-switcher-btn:first-of-type::before {
  display: none; }

.bx--content-switcher--light
.bx--content-switcher-btn::before {
  background-color: #e0e0e0; }

.bx--content-switcher--light
.bx--content-switcher-btn:focus::before,
.bx--content-switcher--light
.bx--content-switcher-btn:focus
+ .bx--content-switcher-btn::before,
.bx--content-switcher--light
.bx--content-switcher-btn:hover::before,
.bx--content-switcher--light
.bx--content-switcher-btn:hover
+ .bx--content-switcher-btn::before,
.bx--content-switcher--light
.bx--content-switcher--selected::before,
.bx--content-switcher--light
.bx--content-switcher--selected
+ .bx--content-switcher-btn::before,
.bx--content-switcher-btn:focus::before,
.bx--content-switcher-btn:focus
+ .bx--content-switcher-btn::before,
.bx--content-switcher-btn:hover::before,
.bx--content-switcher-btn:hover
+ .bx--content-switcher-btn::before,
.bx--content-switcher--selected::before,
.bx--content-switcher--selected
+ .bx--content-switcher-btn::before {
  background-color: transparent; }

.bx--content-switcher__icon {
  transition: fill 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #525252; }

.bx--content-switcher__icon + span {
  margin-left: 0.5rem; }

.bx--content-switcher__label {
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.bx--content-switcher-btn:hover .bx--content-switcher__icon,
.bx--content-switcher-btn:focus .bx--content-switcher__icon {
  fill: #161616; }

.bx--content-switcher--light
.bx--content-switcher-btn.bx--content-switcher--selected,
.bx--content-switcher-btn.bx--content-switcher--selected {
  z-index: 3;
  color: #ffffff;
  background-color: #161616; }
  .bx--content-switcher--light
.bx--content-switcher-btn.bx--content-switcher--selected:disabled,
  .bx--content-switcher-btn.bx--content-switcher--selected:disabled {
    color: #c6c6c6;
    background-color: #8d8d8d; }

.bx--content-switcher-btn.bx--content-switcher--selected
.bx--content-switcher__icon {
  fill: #ffffff; }

/* stylelint-disable */
.flatpickr-calendar {
  background: transparent;
  overflow: hidden;
  max-height: 0;
  opacity: 0;
  visibility: hidden;
  text-align: center;
  padding: 0;
  animation: none;
  direction: ltr;
  border: 0;
  font-size: 14px;
  line-height: 24px;
  border-radius: 5px;
  position: absolute;
  width: 315px;
  box-sizing: border-box;
  touch-action: manipulation;
  background: #fff;
  box-shadow: 1px 0 0 #e6e6e6, -1px 0 0 #e6e6e6, 0 1px 0 #e6e6e6, 0 -1px 0 #e6e6e6, 0 3px 13px rgba(0, 0, 0, 0.08); }

.flatpickr-calendar.open,
.flatpickr-calendar.inline {
  opacity: 1;
  visibility: inherit;
  overflow: visible;
  max-height: 640px; }

.flatpickr-calendar.open {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
  z-index: 99999;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  width: 18rem;
  height: 21rem;
  padding: 0.25rem 0.25rem 0.5rem 0.25rem;
  border: none;
  margin-top: -2px;
  overflow: hidden;
  background-color: #ffffff; }
  .flatpickr-calendar.open:focus {
    outline: 1px solid #0f62fe; }

.flatpickr-calendar.animate.open {
  animation: fpFadeInDown 110ms cubic-bezier(0, 0, 0.38, 0.9); }

.flatpickr-calendar.inline {
  display: block;
  position: relative;
  top: 2px; }

.flatpickr-calendar.static {
  position: absolute;
  top: calc(100% + 2px); }

.flatpickr-calendar.static.open {
  z-index: 999;
  display: block; }

.flatpickr-calendar.hasWeeks {
  width: auto; }

.flatpickr-calendar .hasWeeks .dayContainer,
.flatpickr-calendar .hasTime .dayContainer {
  border-bottom: 0;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0; }

.flatpickr-calendar .hasWeeks .dayContainer {
  border-left: 0; }

.flatpickr-calendar.showTimeInput.hasTime .flatpickr-time {
  height: 40px;
  border-top: 1px solid #e6e6e6; }

.flatpickr-calendar.noCalendar.hasTime .flatpickr-time {
  height: auto; }

.flatpickr-calendar:focus {
  outline: 0; }

.flatpickr-months {
  display: flex;
  justify-content: space-between;
  width: 100%; }

.flatpickr-month {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  height: 2.5rem;
  display: flex;
  align-items: center;
  margin-bottom: 0.25rem;
  background-color: transparent;
  color: #161616;
  line-height: 1;
  text-align: center; }

.flatpickr-prev-month,
.flatpickr-next-month {
  text-decoration: none;
  cursor: pointer;
  line-height: 16px;
  height: 28px;
  padding: 10px calc(3.57% - 1.5px);
  z-index: 3; }

.flatpickr-prev-month,
.flatpickr-next-month {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 2.5rem;
  width: 2.5rem;
  padding: 0;
  fill: #161616;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .flatpickr-prev-month:hover,
  .flatpickr-next-month:hover {
    background-color: #e5e5e5; }

.flatpickr-prev-month:hover svg,
.flatpickr-next-month:hover svg {
  fill: #161616; }

.flatpickr-next-month.disabled svg,
.flatpickr-prev-month.disabled svg {
  fill: #161616;
  cursor: not-allowed; }

.flatpickr-next-month.disabled:hover svg,
.flatpickr-prev-month.disabled:hover svg {
  fill: #161616; }

.flatpickr-current-month {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 1.75rem;
  text-align: center; }

.flatpickr-current-month .cur-month {
  margin-left: 0.25rem;
  margin-right: 0.25rem; }
  .flatpickr-current-month .cur-month:hover {
    background-color: #e5e5e5; }

.numInputWrapper {
  position: relative;
  width: 3.75rem; }
  .numInputWrapper:hover {
    background-color: #e5e5e5; }

.numInputWrapper:hover .arrowUp,
.numInputWrapper:hover .arrowDown {
  opacity: 1; }

.numInputWrapper:hover .numInput[disabled] ~ .arrowUp,
.numInputWrapper:hover .numInput[disabled] ~ .arrowDown {
  opacity: 0; }

.numInputWrapper .numInput {
  display: inline-block;
  width: 100%;
  padding: 0.25rem;
  margin: 0;
  border: none;
  color: #161616;
  font-size: inherit;
  font-family: inherit;
  font-weight: 600;
  background-color: #ffffff;
  cursor: default;
  -moz-appearance: textfield;
  /* Firefox */ }
  .numInputWrapper .numInput:focus {
    outline: 1px solid #0f62fe; }
  .numInputWrapper .numInput[disabled], .numInputWrapper .numInput[disabled]:hover {
    color: #c6c6c6;
    background-color: #ffffff;
    pointer-events: none; }
  .numInputWrapper .numInput::-webkit-outer-spin-button, .numInputWrapper .numInput::-webkit-inner-spin-button {
    -webkit-appearance: none;
    margin: 0;
    /* <-- Apparently some margin are still there even though it's hidden */ }

.numInput[disabled] ~ .arrowUp::after {
  border-bottom-color: #c6c6c6; }

.numInput[disabled] ~ .arrowDown::after {
  border-top-color: #c6c6c6; }

.numInputWrapper .arrowUp,
.numInputWrapper .arrowDown {
  position: absolute;
  left: 2.6rem;
  width: 0.75rem;
  height: 50%;
  border: none;
  padding: 0 0.25rem 0 0.125rem;
  line-height: 50%;
  opacity: 0;
  cursor: pointer; }
  .numInputWrapper .arrowUp::after,
  .numInputWrapper .arrowDown::after {
    position: absolute;
    top: 33%;
    display: block;
    content: '';
    border-left: 0.25rem solid transparent;
    border-right: 0.25rem solid transparent; }
  .numInputWrapper .arrowUp:hover::after,
  .numInputWrapper .arrowDown:hover::after {
    border-bottom-color: #0f62fe;
    border-top-color: #0f62fe; }

.numInputWrapper .arrowUp {
  top: 0.25rem;
  border-bottom: 0; }
  .numInputWrapper .arrowUp::after {
    border-bottom: 0.25rem solid #161616; }

.numInputWrapper .arrowDown {
  top: 0.6875rem; }
  .numInputWrapper .arrowDown::after {
    border-top: 0.25rem solid #161616; }

.flatpickr-weekdays {
  display: flex;
  align-items: center;
  height: 2.5rem; }

.flatpickr-weekdaycontainer {
  display: flex;
  width: 100%; }

.flatpickr-weekday {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  cursor: default;
  color: #161616;
  flex: 1; }

.flatpickr-days:focus {
  outline: 0; }

.dayContainer {
  display: flex;
  flex-wrap: wrap;
  justify-content: space-around;
  height: 15.375rem;
  padding: 0;
  outline: 0; }

.flatpickr-calendar.animate .dayContainer.slideLeft {
  animation: fpFadeOut 400ms cubic-bezier(0.23, 1, 0.32, 1), fpSlideLeft 400ms cubic-bezier(0.23, 1, 0.32, 1); }

.flatpickr-calendar.animate .dayContainer.slideLeft,
.flatpickr-calendar.animate .dayContainer.slideLeftNew {
  transform: translate3d(-100%, 0px, 0px); }

.flatpickr-calendar.animate .dayContainer.slideLeftNew {
  animation: fpFadeIn 400ms cubic-bezier(0.23, 1, 0.32, 1), fpSlideLeft 400ms cubic-bezier(0.23, 1, 0.32, 1); }

.flatpickr-calendar.animate .dayContainer.slideRight {
  animation: fpFadeOut 400ms cubic-bezier(0.23, 1, 0.32, 1), fpSlideRight 400ms cubic-bezier(0.23, 1, 0.32, 1);
  transform: translate3d(100%, 0px, 0px); }

.flatpickr-calendar.animate .dayContainer.slideRightNew {
  animation: fpFadeIn 400ms cubic-bezier(0.23, 1, 0.32, 1), fpSlideRightNew 400ms cubic-bezier(0.23, 1, 0.32, 1); }

.flatpickr-day {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  height: 2.5rem;
  width: 2.5rem;
  display: flex;
  align-items: center;
  justify-content: center;
  color: #161616;
  cursor: pointer;
  transition: all 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .flatpickr-day:hover {
    background: #e5e5e5; }
  .flatpickr-day:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    outline-color: #0f62fe; }

.nextMonthDay,
.prevMonthDay {
  color: #6f6f6f; }

.flatpickr-day.today {
  position: relative;
  color: #0f62fe;
  font-weight: 600; }
  .flatpickr-day.today::after {
    content: '';
    position: absolute;
    display: block;
    bottom: 0.4375rem;
    left: 50%;
    transform: translateX(-50%);
    height: 0.25rem;
    width: 0.25rem;
    background-color: #0f62fe; }

.flatpickr-day.today.no-border {
  border: none; }

.flatpickr-day.today.selected {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }
  .flatpickr-day.today.selected::after {
    display: none; }

.flatpickr-day.inRange {
  background-color: #d0e2ff;
  color: #161616; }

.flatpickr-day.selected {
  color: #ffffff;
  background-color: #0f62fe; }
  .flatpickr-day.selected:focus {
    outline: 0.0625rem solid #f4f4f4;
    outline-offset: -0.1875rem; }

.flatpickr-day.startRange.selected {
  box-shadow: none;
  z-index: 2; }

.flatpickr-day.startRange.inRange:not(.selected),
.flatpickr-day.endRange.inRange {
  outline: 2px solid #0f62fe;
  outline-offset: -2px;
  background: #ffffff;
  z-index: 3; }

.flatpickr-day.endRange:hover {
  outline: 2px solid #0f62fe;
  outline-offset: -2px;
  background: #ffffff;
  color: #161616; }

.flatpickr-day.endRange.inRange.selected {
  color: #ffffff;
  background: #0f62fe; }

.flatpickr-day.flatpickr-disabled {
  cursor: not-allowed;
  color: #c6c6c6; }
  .flatpickr-day.flatpickr-disabled:hover {
    background-color: transparent; }

.flatpickr-input[readonly] {
  cursor: pointer; }

@keyframes fpFadeInDown {
  from {
    opacity: 0;
    transform: translate3d(0, -20px, 0); }
  to {
    opacity: 1;
    transform: translate3d(0, 0, 0); } }

@keyframes fpSlideLeft {
  from {
    transform: translate3d(0px, 0px, 0px); }
  to {
    transform: translate3d(-100%, 0px, 0px); } }

@keyframes fpSlideLeftNew {
  from {
    transform: translate3d(100%, 0px, 0px); }
  to {
    transform: translate3d(0px, 0px, 0px); } }

@keyframes fpSlideRight {
  from {
    transform: translate3d(0, 0, 0px); }
  to {
    transform: translate3d(100%, 0px, 0px); } }

@keyframes fpSlideRightNew {
  from {
    transform: translate3d(-100%, 0, 0px); }
  to {
    transform: translate3d(0, 0, 0px); } }

@keyframes fpFadeOut {
  from {
    opacity: 1; }
  to {
    opacity: 0; } }

@keyframes fpFadeIn {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }

.bx--date-picker {
  display: flex; }

.bx--date-picker--light .bx--date-picker__input {
  background: #f4f4f4; }

.bx--date-picker ~ .bx--label {
  order: 1; }

.bx--date-picker-container {
  position: relative;
  display: flex;
  flex-direction: column;
  justify-content: space-between; }

.bx--date-picker-input__wrapper {
  position: relative;
  display: flex;
  align-items: center; }

.bx--date-picker.bx--date-picker--simple .bx--date-picker__input {
  width: 7.5rem; }

.bx--date-picker.bx--date-picker--simple.bx--date-picker--short .bx--date-picker__input {
  width: 5.7rem; }

.bx--date-picker.bx--date-picker--single
.bx--date-picker__input {
  width: 18rem; }

.bx--date-picker__input {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.32px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: relative;
  display: block;
  min-width: 9rem;
  height: 2.5rem;
  padding: 0 1rem;
  color: #161616;
  background-color: #ffffff;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  transition: 70ms cubic-bezier(0.2, 0, 0.38, 0.9) all; }
  .bx--date-picker__input:focus, .bx--date-picker__input.bx--focused {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--date-picker__input:disabled {
    color: #c6c6c6;
    background-color: #ffffff;
    border-bottom: 1px solid transparent;
    cursor: not-allowed; }
  .bx--date-picker__input:disabled::placeholder {
    color: #c6c6c6; }
  .bx--date-picker__input:disabled:hover {
    border-bottom: 1px solid transparent; }
  .bx--date-picker__input::placeholder {
    color: #6f6f6f;
    opacity: 1; }

.bx--date-picker__input--xl {
  height: 3rem; }

.bx--date-picker__input--sm {
  height: 2rem; }

.bx--date-picker__icon {
  position: absolute;
  top: 50%;
  right: 1rem;
  z-index: 1;
  transform: translateY(-50%);
  cursor: pointer;
  fill: #161616; }

.bx--date-picker__icon ~ .bx--date-picker__input {
  padding-right: 3rem; }

.bx--date-picker__input:disabled ~ .bx--date-picker__icon {
  cursor: not-allowed;
  fill: #c6c6c6; }

.bx--date-picker--range
> .bx--date-picker-container:first-child {
  margin-right: 0.125rem; }

.bx--date-picker--range .bx--date-picker-container,
.bx--date-picker--range .bx--date-picker__input {
  width: 8.96875rem; }

.bx--date-picker.bx--skeleton input,
.bx--date-picker__input.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%; }
  .bx--date-picker.bx--skeleton input:hover, .bx--date-picker.bx--skeleton input:focus, .bx--date-picker.bx--skeleton input:active,
  .bx--date-picker__input.bx--skeleton:hover,
  .bx--date-picker__input.bx--skeleton:focus,
  .bx--date-picker__input.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--date-picker.bx--skeleton input::before,
  .bx--date-picker__input.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--date-picker.bx--skeleton input::before,
      .bx--date-picker__input.bx--skeleton::before {
        animation: none; } }
  .bx--date-picker.bx--skeleton input::placeholder,
  .bx--date-picker__input.bx--skeleton::placeholder {
    color: transparent; }

.bx--date-picker.bx--skeleton .bx--label {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 4.6875rem;
  height: 0.875rem; }
  .bx--date-picker.bx--skeleton .bx--label:hover, .bx--date-picker.bx--skeleton .bx--label:focus, .bx--date-picker.bx--skeleton .bx--label:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--date-picker.bx--skeleton .bx--label::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--date-picker.bx--skeleton .bx--label::before {
        animation: none; } }
.bx--dropdown__wrapper--inline {
  display: inline-grid;
  grid-gap: 0.25rem;
  grid-template: auto auto / auto min-content;
  align-items: center; }
  .bx--dropdown__wrapper--inline .bx--label {
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
  .bx--dropdown__wrapper--inline .bx--label,
  .bx--dropdown__wrapper--inline .bx--form__helper-text,
  .bx--dropdown__wrapper--inline .bx--form-requirement {
    margin: 0; }
  .bx--dropdown__wrapper--inline .bx--form-requirement {
    grid-column: 2; }

.bx--dropdown {
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: relative;
  display: block;
  width: 100%;
  height: 2.5rem;
  color: #161616;
  list-style: none;
  background-color: #ffffff;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  outline: 2px solid transparent;
  cursor: pointer;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--dropdown:hover {
    background-color: #e5e5e5; }

.bx--dropdown .bx--list-box__field {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  padding: 0 3rem 0 1rem;
  text-align: left; }
  .bx--dropdown .bx--list-box__field::-moz-focus-inner {
    border: 0; }

.bx--dropdown--xl {
  height: 3rem;
  max-height: 3rem; }

.bx--dropdown--xl .bx--dropdown__arrow {
  top: 1rem; }

.bx--dropdown--sm {
  height: 2rem;
  max-height: 2rem; }

.bx--dropdown--sm .bx--dropdown__arrow {
  top: 0.5rem; }

.bx--dropdown--open {
  border-bottom-color: #e0e0e0; }

.bx--dropdown--invalid {
  outline: 2px solid #da1e28;
  outline-offset: -2px; }
  .bx--dropdown--invalid .bx--dropdown-text {
    padding-right: 3.5rem; }
  .bx--dropdown--invalid + .bx--form-requirement {
    display: inline-block;
    max-height: 12.5rem;
    color: #da1e28; }

.bx--dropdown__invalid-icon {
  position: absolute;
  top: 50%;
  right: 2.5rem;
  transform: translateY(-50%);
  fill: #da1e28; }

.bx--dropdown--open:hover {
  background-color: #ffffff; }

.bx--dropdown--open:focus {
  outline: 1px solid transparent; }

.bx--dropdown--open .bx--dropdown-list {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
  max-height: 13.75rem;
  transition: max-height 110ms cubic-bezier(0, 0, 0.38, 0.9); }

.bx--dropdown--light {
  background-color: #f4f4f4; }

.bx--dropdown--up .bx--dropdown-list {
  bottom: 2rem; }

.bx--dropdown__arrow {
  position: absolute;
  top: 0.8125rem;
  right: 1rem;
  transform-origin: 50% 45%;
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  pointer-events: none;
  fill: #161616; }

button.bx--dropdown-text {
  width: 100%;
  color: #161616;
  text-align: left;
  background: none;
  border: none; }
  button.bx--dropdown-text:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.bx--dropdown-text {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: block;
  height: calc(100% + 1px);
  padding-right: 2.625rem;
  padding-left: 1rem;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.bx--dropdown-list {
  outline: 2px solid transparent;
  outline-offset: -2px;
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  position: absolute;
  z-index: 6000;
  display: flex;
  flex-direction: column;
  width: 100%;
  max-height: 0;
  overflow-x: hidden;
  overflow-y: auto;
  list-style: none;
  background-color: #ffffff;
  transition: max-height 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--dropdown--light .bx--dropdown-list {
  background-color: #f4f4f4; }

.bx--dropdown:not(.bx--dropdown--open)
.bx--dropdown-item {
  visibility: hidden; }

.bx--dropdown-item {
  position: relative;
  visibility: inherit;
  opacity: 0;
  transition: visibility 70ms cubic-bezier(0.2, 0, 0.38, 0.9), opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--dropdown-item:hover {
    background-color: #e5e5e5; }
    .bx--dropdown-item:hover + .bx--dropdown-item .bx--dropdown-link {
      border-color: transparent; }
  .bx--dropdown-item:active {
    background-color: #e0e0e0; }
  .bx--dropdown-item:first-of-type .bx--dropdown-link {
    border-top-color: transparent; }

.bx--dropdown-item:last-of-type .bx--dropdown-link {
  border-bottom: none; }

.bx--dropdown-link {
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: block;
  height: 2.5rem;
  margin: 0 1rem;
  padding: 0.6875rem 0;
  overflow: hidden;
  color: #525252;
  font-weight: normal;
  line-height: 1rem;
  white-space: nowrap;
  text-decoration: none;
  text-overflow: ellipsis;
  border: 1px solid transparent;
  border-top-color: #e0e0e0; }
  .bx--dropdown-link:hover {
    color: #161616;
    border-color: transparent; }

.bx--dropdown--light .bx--dropdown-link {
  border-top-color: #e0e0e0; }

.bx--dropdown--sm .bx--dropdown-link {
  height: 2rem;
  padding-top: 0.4375rem;
  padding-bottom: 0.4375rem; }

.bx--dropdown--xl .bx--dropdown-link {
  height: 3rem;
  padding-top: 0.9375rem;
  padding-bottom: 0.9375rem; }

.bx--dropdown--focused,
.bx--dropdown-link:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px;
  margin: 0;
  padding: 0.6875rem 1rem; }

.bx--dropdown-list[aria-activedescendant]
.bx--dropdown-link:focus {
  margin: 0 1rem;
  padding: 0.6875rem 0;
  outline: none; }

.bx--dropdown-list[aria-activedescendant]
.bx--dropdown--focused:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px;
  margin: 0;
  padding: 0.6875rem 1rem; }

.bx--dropdown-list[aria-activedescendant]
.bx--dropdown-item:active {
  background-color: inherit; }

.bx--dropdown-item:hover .bx--dropdown-link {
  border-bottom-color: #e5e5e5; }

.bx--dropdown--selected {
  display: none; }

.bx--dropdown--open .bx--dropdown__arrow {
  transform: rotate(-180deg); }

.bx--dropdown--open.bx--dropdown--xl
.bx--dropdown-list {
  max-height: 16.5rem; }

.bx--dropdown--open.bx--dropdown--sm
.bx--dropdown-list {
  max-height: 11rem; }

.bx--dropdown--open .bx--dropdown-item {
  opacity: 1; }

.bx--dropdown--disabled {
  border-bottom-color: transparent;
  cursor: not-allowed; }
  .bx--dropdown--disabled:hover {
    background-color: #ffffff; }
  .bx--dropdown--disabled:focus {
    outline: none; }
  .bx--dropdown--disabled .bx--dropdown-text,
  .bx--dropdown--disabled .bx--list-box__label {
    color: #c6c6c6; }
  .bx--dropdown--disabled .bx--dropdown__arrow,
  .bx--dropdown--disabled .bx--list-box__menu-icon svg {
    fill: #c6c6c6; }
  .bx--dropdown--disabled.bx--dropdown--light:hover {
    background-color: #f4f4f4; }

.bx--dropdown--auto-width {
  width: auto;
  max-width: 25rem; }

.bx--dropdown--inline {
  display: inline-block;
  justify-self: start;
  width: auto;
  background-color: transparent;
  border-bottom-color: transparent;
  transition: background 70ms cubic-bezier(0, 0, 0.38, 0.9); }
  .bx--dropdown--inline:hover {
    background-color: #e5e5e5; }
  .bx--dropdown--inline.bx--dropdown--disabled {
    background-color: transparent; }
  .bx--dropdown--inline .bx--dropdown__arrow {
    top: 0.5rem;
    right: 0.5rem; }

.bx--dropdown--inline.bx--dropdown--open {
  background-color: transparent; }

.bx--dropdown--inline .bx--dropdown-text {
  display: inline-block;
  height: 2rem;
  padding: 0.4375rem 2rem 0.4375rem 0.75rem;
  overflow: visible;
  color: #161616; }

.bx--dropdown--inline.bx--dropdown--disabled
.bx--dropdown-text {
  color: #c6c6c6; }

.bx--dropdown--inline.bx--dropdown--disabled:focus
.bx--dropdown-text {
  outline: 0; }

.bx--dropdown--inline.bx--dropdown--invalid
.bx--dropdown__invalid-icon {
  right: 2rem; }

.bx--dropdown--inline.bx--dropdown--invalid
.bx--dropdown-text {
  padding-right: 3.5rem; }

.bx--dropdown--inline.bx--dropdown--open:focus
.bx--dropdown-list {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2); }

.bx--dropdown--inline .bx--dropdown-link {
  font-weight: normal; }

.bx--dropdown--show-selected .bx--dropdown--selected {
  display: block;
  color: #161616;
  background-color: #e5e5e5; }
  .bx--dropdown--show-selected .bx--dropdown--selected:hover {
    background-color: #e0e0e0; }
  .bx--dropdown--show-selected .bx--dropdown--selected .bx--dropdown-link {
    border-top-color: transparent; }
  .bx--dropdown--show-selected .bx--dropdown--selected + .bx--dropdown-item .bx--dropdown-link {
    border-top-color: transparent; }
  .bx--dropdown--show-selected .bx--dropdown--selected .bx--list-box__menu-item__selected-icon {
    display: block; }

.bx--dropdown-v2.bx--skeleton,
.bx--dropdown.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none; }
  .bx--dropdown-v2.bx--skeleton:hover, .bx--dropdown-v2.bx--skeleton:focus, .bx--dropdown-v2.bx--skeleton:active,
  .bx--dropdown.bx--skeleton:hover,
  .bx--dropdown.bx--skeleton:focus,
  .bx--dropdown.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--dropdown-v2.bx--skeleton::before,
  .bx--dropdown.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--dropdown-v2.bx--skeleton::before,
      .bx--dropdown.bx--skeleton::before {
        animation: none; } }
@keyframes rotate {
  0% {
    transform: rotate(0deg); }
  100% {
    transform: rotate(360deg); } }

@keyframes rotate-end-p1 {
  100% {
    transform: rotate(360deg); } }

@keyframes rotate-end-p2 {
  100% {
    transform: rotate(-360deg); } }

/* Stroke animations */
@keyframes init-stroke {
  0% {
    stroke-dashoffset: 240; }
  100% {
    stroke-dashoffset: 40; } }

@keyframes stroke-end {
  0% {
    stroke-dashoffset: 40; }
  100% {
    stroke-dashoffset: 240; } }

.bx--modal {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 9000;
  display: block;
  align-items: center;
  justify-content: center;
  width: 100vw;
  height: 100vh;
  background-color: transparent;
  visibility: hidden;
  opacity: 0;
  transition: background-color 720ms cubic-bezier(0.4, 0.14, 1, 1), opacity 240ms cubic-bezier(0.4, 0.14, 1, 1), visibility 0ms linear 240ms display 0ms linear;
  content: ''; }
  .bx--modal.is-visible {
    background-color: rgba(22, 22, 22, 0.5);
    visibility: inherit;
    display: flex;
    opacity: 1;
    transition: background-color 720ms cubic-bezier(0, 0, 0.3, 1), opacity 240ms cubic-bezier(0, 0, 0.3, 1), visibility 0ms linear, display 0ms linear; }
  .bx--modal .bx--text-input,
  .bx--modal .bx--text-area,
  .bx--modal .bx--search-input,
  .bx--modal .bx--select-input,
  .bx--modal .bx--dropdown,
  .bx--modal .bx--dropdown-list,
  .bx--modal .bx--number input[type='number'],
  .bx--modal .bx--date-picker__input {
    background-color: #f4f4f4; }

.bx--modal.is-visible .bx--modal-container {
  transform: translate3d(0, 0, 0);
  transition: transform 240ms cubic-bezier(0, 0, 0.3, 1); }

.bx--modal-container {
  position: fixed;
  top: 0;
  display: grid;
  grid-template-rows: auto 1fr auto;
  grid-template-columns: auto;
  width: 100%;
  height: 100%;
  max-height: 100%;
  overflow: hidden;
  background-color: #ffffff;
  outline: 3px solid transparent;
  outline-offset: -3px;
  transform: translate3d(0, -24px, 0);
  transform-origin: top center;
  transition: transform 240ms cubic-bezier(0.4, 0.14, 1, 1); }
  @media (min-width: 42rem) {
    .bx--modal-container {
      position: static;
      width: 84%;
      height: auto;
      max-height: 90%; }
      .bx--modal-container .bx--modal-header,
      .bx--modal-container .bx--modal-content,
      .bx--modal-container .bx--modal-content__regular-content {
        padding-right: 20%; }
      .bx--modal-container .bx--modal-content--with-form {
        padding-right: 1rem; } }
  @media (min-width: 66rem) {
    .bx--modal-container {
      width: 60%;
      max-height: 84%; } }
  @media (min-width: 82rem) {
    .bx--modal-container {
      width: 48%; } }
.bx--modal-header,
.bx--modal-content {
  padding-left: 1rem; }

.bx--modal-header,
.bx--modal-content,
.bx--modal-content__regular-content {
  padding-right: 1rem; }

.bx--modal-content--with-form {
  padding-right: 1rem; }

.bx--modal-container--xs .bx--modal-header {
  padding-right: 3rem; }

.bx--modal-container--xs .bx--modal-content,
.bx--modal-container--xs .bx--modal-content__regular-content,
.bx--modal-container--xs .bx--modal-content--with-form {
  padding-right: 1rem; }

@media (min-width: 42rem) {
  .bx--modal-container--xs {
    width: 48%; } }

@media (min-width: 66rem) {
  .bx--modal-container--xs {
    width: 32%;
    max-height: 48%; } }

@media (min-width: 82rem) {
  .bx--modal-container--xs {
    width: 24%; } }

.bx--modal-container--sm .bx--modal-header {
  padding-right: 3rem; }

.bx--modal-container--sm .bx--modal-content,
.bx--modal-container--sm .bx--modal-content__regular-content,
.bx--modal-container--sm .bx--modal-content--with-form {
  padding-right: 1rem; }

@media (min-width: 42rem) {
  .bx--modal-container--sm {
    width: 60%; } }

@media (min-width: 66rem) {
  .bx--modal-container--sm {
    width: 42%;
    max-height: 72%; } }

@media (min-width: 82rem) {
  .bx--modal-container--sm {
    width: 36%; }
    .bx--modal-container--sm .bx--modal-header,
    .bx--modal-container--sm .bx--modal-content,
    .bx--modal-container--sm .bx--modal-content__regular-content {
      padding-right: 20%; }
    .bx--modal-container--sm .bx--modal-content--with-form {
      padding-right: 1rem; } }

.bx--modal-container--lg .bx--modal-header {
  padding-right: 3rem; }

.bx--modal-container--lg .bx--modal-content,
.bx--modal-container--lg .bx--modal-content__regular-content,
.bx--modal-container--lg .bx--modal-content--with-form {
  padding-right: 1rem; }

@media (min-width: 42rem) {
  .bx--modal-container--lg {
    width: 96%; }
    .bx--modal-container--lg .bx--modal-header,
    .bx--modal-container--lg .bx--modal-content,
    .bx--modal-container--lg .bx--modal-content__regular-content {
      padding-right: 20%; }
    .bx--modal-container--lg .bx--modal-content--with-form {
      padding-right: 1rem; } }

@media (min-width: 66rem) {
  .bx--modal-container--lg {
    width: 84%;
    max-height: 96%; } }

@media (min-width: 82rem) {
  .bx--modal-container--lg {
    width: 72%; } }

.bx--modal-header {
  grid-row: 1/1;
  grid-column: 1/-1;
  margin-bottom: 0.5rem;
  padding-top: 1rem;
  padding-right: 3rem; }

.bx--modal-header__label {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  margin-bottom: 0.25rem;
  color: #525252; }

.bx--modal-header__heading {
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.4;
  letter-spacing: 0;
  color: #161616; }

.bx--modal-content {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px;
  grid-row: 2/-2;
  grid-column: 1/-1;
  margin-bottom: 3rem;
  padding-top: 0.5rem;
  overflow-y: auto;
  color: #161616;
  font-weight: 400; }
  .bx--modal-content:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--modal-content > * {
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.43;
    letter-spacing: 0.16px; }

.bx--modal-scroll-content > *:last-child {
  padding-bottom: 2rem; }

.bx--modal-content--overflow-indicator {
  position: absolute;
  bottom: 3rem;
  left: 0;
  grid-row: 2/-2;
  grid-column: 1/-1;
  width: 100%;
  height: 2rem;
  background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0), #ffffff);
  content: '';
  pointer-events: none; }

.bx--modal-content:focus
~ .bx--modal-content--overflow-indicator {
  width: calc(100% - 4px);
  margin: 0 2px 2px; }

@media screen and (-ms-high-contrast: active) {
  .bx--modal-scroll-content > *:last-child {
    padding-bottom: 0; }
  .bx--modal-content--overflow-indicator {
    display: none; } }

.bx--modal-footer {
  display: flex;
  grid-row: -1/-1;
  grid-column: 1/-1;
  justify-content: flex-end;
  height: 4rem;
  margin-top: auto; }
  .bx--modal-footer .bx--btn {
    flex: 0 1 50%;
    max-width: none;
    height: 4rem;
    margin: 0;
    padding-top: 1rem;
    padding-bottom: 2rem; }

.bx--modal-close {
  position: absolute;
  top: 0;
  right: 0;
  width: 3rem;
  height: 3rem;
  padding: 0.75rem;
  overflow: hidden;
  background-color: transparent;
  border: 2px solid transparent;
  cursor: pointer;
  transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--modal-close:hover {
    background-color: #e5e5e5; }
  .bx--modal-close:focus {
    border-color: #0f62fe;
    outline: none; }

.bx--modal-close::-moz-focus-inner {
  border: 0; }

.bx--modal-close__icon {
  width: 1.25rem;
  height: 1.25rem;
  fill: #161616; }

.bx--body--with-modal-open {
  overflow: hidden; }

.bx--body--with-modal-open .bx--tooltip {
  z-index: 9000; }

.bx--multi-select .bx--list-box__menu {
  min-width: auto; }

.bx--multi-select
.bx--list-box__menu-item__option
.bx--checkbox-wrapper {
  display: flex;
  align-items: center;
  width: 100%;
  height: 100%; }

.bx--multi-select
.bx--list-box__menu-item__option
.bx--checkbox-label {
  display: inline-block;
  width: 100%;
  padding-left: 1.75rem;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.bx--multi-select
.bx--list-box__menu-item__option
> .bx--form-item {
  flex-direction: row;
  margin: 0; }

.bx--multi-select
.bx--list-box__menu-item
.bx--checkbox:checked
~ .bx--checkbox-label-text {
  color: #161616; }

.bx--multi-select--filterable .bx--list-box__selection--multi {
  position: absolute;
  right: auto;
  left: 0.5rem; }

.bx--multi-select--selected .bx--text-input {
  padding-left: 3.5rem; }

.bx--inline-notification {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  width: 100%;
  min-width: 18rem;
  max-width: 18rem;
  height: auto;
  min-height: 3rem;
  margin-top: 1rem;
  margin-bottom: 1rem;
  color: #ffffff; }
  @media (min-width: 42rem) {
    .bx--inline-notification {
      flex-wrap: nowrap;
      max-width: 38rem; } }
  @media (min-width: 66rem) {
    .bx--inline-notification {
      max-width: 46rem; } }
  @media (min-width: 99rem) {
    .bx--inline-notification {
      max-width: 52rem; } }
.bx--inline-notification:not(.bx--inline-notification--low-contrast)
a {
  color: #78a9ff; }

.bx--inline-notification a {
  text-decoration: none; }

.bx--inline-notification a:hover {
  text-decoration: underline; }

.bx--inline-notification a:focus {
  outline: 1px solid #78a9ff; }

.bx--inline-notification.bx--inline-notification--low-contrast
a:focus {
  outline: 1px solid #0f62fe; }

.bx--inline-notification--low-contrast {
  color: #161616; }
  .bx--inline-notification--low-contrast::before {
    position: absolute;
    top: 0;
    left: 0;
    box-sizing: border-box;
    width: 100%;
    height: 100%;
    border-style: solid;
    border-width: 1px 1px 1px 0;
    filter: opacity(0.4);
    content: '';
    pointer-events: none; }

.bx--inline-notification--error {
  background: #393939;
  border-left: 3px solid #fa4d56; }
  .bx--inline-notification--error .bx--inline-notification__icon,
  .bx--inline-notification--error .bx--toast-notification__icon {
    fill: #fa4d56; }

.bx--inline-notification--low-contrast.bx--inline-notification--error {
  background: #fff1f1;
  border-left: 3px solid #da1e28; }
  .bx--inline-notification--low-contrast.bx--inline-notification--error .bx--inline-notification__icon,
  .bx--inline-notification--low-contrast.bx--inline-notification--error .bx--toast-notification__icon {
    fill: #da1e28; }
  .bx--inline-notification--low-contrast.bx--inline-notification--error::before {
    border-color: #da1e28; }

.bx--inline-notification--success {
  background: #393939;
  border-left: 3px solid #42be65; }
  .bx--inline-notification--success .bx--inline-notification__icon,
  .bx--inline-notification--success .bx--toast-notification__icon {
    fill: #42be65; }

.bx--inline-notification--low-contrast.bx--inline-notification--success {
  background: #defbe6;
  border-left: 3px solid #24a148; }
  .bx--inline-notification--low-contrast.bx--inline-notification--success .bx--inline-notification__icon,
  .bx--inline-notification--low-contrast.bx--inline-notification--success .bx--toast-notification__icon {
    fill: #24a148; }
  .bx--inline-notification--low-contrast.bx--inline-notification--success::before {
    border-color: #24a148; }

.bx--inline-notification--info,
.bx--inline-notification--info-square {
  background: #393939;
  border-left: 3px solid #4589ff; }
  .bx--inline-notification--info .bx--inline-notification__icon,
  .bx--inline-notification--info .bx--toast-notification__icon,
  .bx--inline-notification--info-square .bx--inline-notification__icon,
  .bx--inline-notification--info-square .bx--toast-notification__icon {
    fill: #4589ff; }

.bx--inline-notification--low-contrast.bx--inline-notification--info,
.bx--inline-notification--low-contrast.bx--inline-notification--info-square {
  background: #edf5ff;
  border-left: 3px solid #0043ce; }
  .bx--inline-notification--low-contrast.bx--inline-notification--info .bx--inline-notification__icon,
  .bx--inline-notification--low-contrast.bx--inline-notification--info .bx--toast-notification__icon,
  .bx--inline-notification--low-contrast.bx--inline-notification--info-square .bx--inline-notification__icon,
  .bx--inline-notification--low-contrast.bx--inline-notification--info-square .bx--toast-notification__icon {
    fill: #0043ce; }
  .bx--inline-notification--low-contrast.bx--inline-notification--info::before,
  .bx--inline-notification--low-contrast.bx--inline-notification--info-square::before {
    border-color: #0043ce; }

.bx--inline-notification--warning,
.bx--inline-notification--warning-alt {
  background: #393939;
  border-left: 3px solid #f1c21b; }
  .bx--inline-notification--warning .bx--inline-notification__icon,
  .bx--inline-notification--warning .bx--toast-notification__icon,
  .bx--inline-notification--warning-alt .bx--inline-notification__icon,
  .bx--inline-notification--warning-alt .bx--toast-notification__icon {
    fill: #f1c21b; }

.bx--inline-notification--low-contrast.bx--inline-notification--warning,
.bx--inline-notification--low-contrast.bx--inline-notification--warning-alt {
  background: #fdf6dd;
  border-left: 3px solid #f1c21b; }
  .bx--inline-notification--low-contrast.bx--inline-notification--warning .bx--inline-notification__icon,
  .bx--inline-notification--low-contrast.bx--inline-notification--warning .bx--toast-notification__icon,
  .bx--inline-notification--low-contrast.bx--inline-notification--warning-alt .bx--inline-notification__icon,
  .bx--inline-notification--low-contrast.bx--inline-notification--warning-alt .bx--toast-notification__icon {
    fill: #f1c21b; }
  .bx--inline-notification--low-contrast.bx--inline-notification--warning::before,
  .bx--inline-notification--low-contrast.bx--inline-notification--warning-alt::before {
    border-color: #f1c21b; }

.bx--inline-notification--warning
.bx--inline-notification__icon
path[opacity='0'] {
  opacity: 1;
  fill: #000000; }

.bx--inline-notification__details {
  display: flex;
  flex-grow: 1;
  margin: 0 3rem 0 1rem; }
  @media (min-width: 42rem) {
    .bx--inline-notification__details {
      margin: 0 1rem; } }
.bx--inline-notification__icon {
  flex-shrink: 0;
  margin-top: 0.875rem;
  margin-right: 1rem; }

.bx--inline-notification__text-wrapper {
  display: flex;
  flex-wrap: wrap;
  padding: 0.9375rem 0; }

.bx--inline-notification__title {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  margin: 0 0.25rem 0 0; }

.bx--inline-notification__subtitle {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  word-break: break-word; }

.bx--inline-notification__action-button.bx--btn--ghost {
  height: 2rem;
  margin-bottom: 0.5rem;
  margin-left: 2.5rem;
  color: #78a9ff; }
  @media (min-width: 42rem) {
    .bx--inline-notification__action-button.bx--btn--ghost {
      margin: 0.5rem 0; } }
.bx--inline-notification--low-contrast
.bx--inline-notification__action-button.bx--btn--ghost {
  color: #0f62fe; }

.bx--inline-notification__action-button.bx--btn--ghost:active,
.bx--inline-notification__action-button.bx--btn--ghost:hover {
  background-color: #4c4c4c; }

.bx--inline-notification--low-contrast
.bx--inline-notification__action-button.bx--btn--ghost:active,
.bx--inline-notification--low-contrast
.bx--inline-notification__action-button.bx--btn--ghost:hover {
  background-color: #ffffff; }

.bx--inline-notification__action-button.bx--btn--ghost:focus {
  border-color: transparent;
  outline: 2px solid #ffffff;
  outline-offset: -2px;
  box-shadow: none; }

.bx--inline-notification--low-contrast
.bx--inline-notification__action-button.bx--btn--ghost:focus {
  outline-color: #0f62fe; }

.bx--inline-notification--hide-close-button
.bx--inline-notification__action-button.bx--btn--ghost {
  margin-right: 0.5rem; }

.bx--inline-notification__close-button {
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: absolute;
  top: 0;
  right: 0;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  width: 3rem;
  min-width: 3rem;
  max-width: 3rem;
  height: 3rem;
  padding: 0;
  background: transparent;
  border: none;
  cursor: pointer;
  transition: outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--inline-notification__close-button:focus {
    outline: 2px solid #ffffff;
    outline-offset: -2px; }
  .bx--inline-notification__close-button .bx--inline-notification__close-icon {
    fill: #ffffff; }
  @media (min-width: 42rem) {
    .bx--inline-notification__close-button {
      position: static; } }
.bx--inline-notification--low-contrast
.bx--inline-notification__close-button:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--inline-notification--low-contrast
.bx--inline-notification__close-button
.bx--inline-notification__close-icon {
  fill: #161616; }

.bx--inline-notification--low-contrast
.bx--inline-notification__action-button {
  color: #0f62fe; }
  .bx--inline-notification--low-contrast
.bx--inline-notification__action-button:active {
    color: #0f62fe; }
  .bx--inline-notification--low-contrast
.bx--inline-notification__action-button:active, .bx--inline-notification--low-contrast
.bx--inline-notification__action-button:hover {
    background-color: #ffffff; }

.bx--toast-notification {
  display: flex;
  width: 18rem;
  height: auto;
  margin-top: 0.5rem;
  margin-right: 1rem;
  margin-bottom: 0.5rem;
  padding-left: 0.875rem;
  color: #ffffff;
  box-shadow: 0 2px 6px 0 rgba(0, 0, 0, 0.2); }
  .bx--toast-notification:first-child {
    margin-top: 1rem; }
  @media (min-width: 99rem) {
    .bx--toast-notification {
      width: 22rem; } }
.bx--toast-notification:not(.bx--toast-notification--low-contrast)
a {
  color: #78a9ff; }

.bx--toast-notification a {
  text-decoration: none; }

.bx--toast-notification a:hover {
  text-decoration: underline; }

.bx--toast-notification a:focus {
  outline: 1px solid #78a9ff; }

.bx--toast-notification.bx--toast-notification--low-contrast
a:focus {
  outline: 1px solid #0f62fe; }

.bx--toast-notification--low-contrast {
  color: #161616; }

.bx--toast-notification--error {
  background: #393939;
  border-left: 3px solid #fa4d56; }
  .bx--toast-notification--error .bx--inline-notification__icon,
  .bx--toast-notification--error .bx--toast-notification__icon {
    fill: #fa4d56; }

.bx--toast-notification--low-contrast.bx--toast-notification--error {
  background: #fff1f1;
  border-left: 3px solid #da1e28; }
  .bx--toast-notification--low-contrast.bx--toast-notification--error .bx--inline-notification__icon,
  .bx--toast-notification--low-contrast.bx--toast-notification--error .bx--toast-notification__icon {
    fill: #da1e28; }

.bx--toast-notification--success {
  background: #393939;
  border-left: 3px solid #42be65; }
  .bx--toast-notification--success .bx--inline-notification__icon,
  .bx--toast-notification--success .bx--toast-notification__icon {
    fill: #42be65; }

.bx--toast-notification--low-contrast.bx--toast-notification--success {
  background: #defbe6;
  border-left: 3px solid #24a148; }
  .bx--toast-notification--low-contrast.bx--toast-notification--success .bx--inline-notification__icon,
  .bx--toast-notification--low-contrast.bx--toast-notification--success .bx--toast-notification__icon {
    fill: #24a148; }

.bx--toast-notification--info,
.bx--toast-notification--info-square {
  background: #393939;
  border-left: 3px solid #4589ff; }
  .bx--toast-notification--info .bx--inline-notification__icon,
  .bx--toast-notification--info .bx--toast-notification__icon,
  .bx--toast-notification--info-square .bx--inline-notification__icon,
  .bx--toast-notification--info-square .bx--toast-notification__icon {
    fill: #4589ff; }

.bx--toast-notification--low-contrast.bx--toast-notification--info,
.bx--toast-notification--low-contrast.bx--toast-notification--info-square {
  background: #edf5ff;
  border-left: 3px solid #0043ce; }
  .bx--toast-notification--low-contrast.bx--toast-notification--info .bx--inline-notification__icon,
  .bx--toast-notification--low-contrast.bx--toast-notification--info .bx--toast-notification__icon,
  .bx--toast-notification--low-contrast.bx--toast-notification--info-square .bx--inline-notification__icon,
  .bx--toast-notification--low-contrast.bx--toast-notification--info-square .bx--toast-notification__icon {
    fill: #0043ce; }

.bx--toast-notification--warning,
.bx--toast-notification--warning-alt {
  background: #393939;
  border-left: 3px solid #f1c21b; }
  .bx--toast-notification--warning .bx--inline-notification__icon,
  .bx--toast-notification--warning .bx--toast-notification__icon,
  .bx--toast-notification--warning-alt .bx--inline-notification__icon,
  .bx--toast-notification--warning-alt .bx--toast-notification__icon {
    fill: #f1c21b; }

.bx--toast-notification--low-contrast.bx--toast-notification--warning,
.bx--toast-notification--low-contrast.bx--toast-notification--warning-alt {
  background: #fdf6dd;
  border-left: 3px solid #f1c21b; }
  .bx--toast-notification--low-contrast.bx--toast-notification--warning .bx--inline-notification__icon,
  .bx--toast-notification--low-contrast.bx--toast-notification--warning .bx--toast-notification__icon,
  .bx--toast-notification--low-contrast.bx--toast-notification--warning-alt .bx--inline-notification__icon,
  .bx--toast-notification--low-contrast.bx--toast-notification--warning-alt .bx--toast-notification__icon {
    fill: #f1c21b; }

.bx--toast-notification--warning
.bx--toast-notification__icon
path[opacity='0'] {
  opacity: 1;
  fill: #000000; }

.bx--toast-notification__icon {
  flex-shrink: 0;
  margin-top: 0.875rem;
  margin-right: 0.875rem; }

.bx--toast-notification__details {
  margin-right: 1rem; }

.bx--toast-notification__close-button {
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  width: 3rem;
  min-width: 3rem;
  height: 3rem;
  min-height: 3rem;
  margin-left: auto;
  padding: 0;
  background-color: transparent;
  border: none;
  cursor: pointer;
  transition: outline 110ms, background-color 110ms; }
  .bx--toast-notification__close-button:focus {
    outline: 2px solid #ffffff;
    outline-offset: -2px; }
  .bx--toast-notification__close-button .bx--toast-notification__close-icon {
    fill: #ffffff; }

.bx--toast-notification--low-contrast
.bx--toast-notification__close-button:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--toast-notification--low-contrast
.bx--toast-notification__close-button
.bx--toast-notification__close-icon {
  fill: #161616; }

.bx--toast-notification__title {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  margin-top: 1rem;
  font-weight: 600;
  word-break: break-word; }

.bx--toast-notification__subtitle {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  margin-top: 0;
  margin-bottom: 1.5rem;
  color: #ffffff;
  word-break: break-word; }

.bx--toast-notification--low-contrast
.bx--toast-notification__subtitle {
  color: #161616; }

.bx--toast-notification__caption {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  margin-bottom: 1rem;
  color: #ffffff; }

.bx--toast-notification--low-contrast
.bx--toast-notification__caption {
  color: #161616; }

.bx--tooltip__label {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  display: inline-flex;
  align-items: center;
  color: #525252; }
  .bx--tooltip__label:focus {
    outline: 1px solid #0f62fe; }

.bx--tooltip__trigger svg {
  fill: #525252; }

.bx--tooltip__trigger:not(.bx--btn--icon-only) {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  display: inline-flex;
  align-items: center;
  font-size: 1rem;
  cursor: pointer; }
  .bx--tooltip__trigger:not(.bx--btn--icon-only)::-moz-focus-inner {
    border: 0; }
  .bx--tooltip__trigger:not(.bx--btn--icon-only):focus {
    outline: 1px solid #0f62fe;
    fill: #0353e9; }

.bx--tooltip__label .bx--tooltip__trigger {
  margin-left: 0.5rem; }

.bx--tooltip__label--bold {
  font-weight: 600; }

.bx--tooltip {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
  position: absolute;
  z-index: 6000;
  display: none;
  min-width: 13rem;
  max-width: 18rem;
  margin-top: 0.25rem;
  padding: 1rem;
  color: #ffffff;
  word-wrap: break-word;
  background: #393939;
  border-radius: 0.125rem; }
  .bx--tooltip:focus {
    outline: 0;
    box-shadow: inset 0 0 0 1px #393939, inset 0 0 0 2px #f4f4f4; }
  .bx--tooltip p {
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
  .bx--tooltip button {
    padding-right: 2rem; }
  .bx--tooltip .bx--btn:focus {
    border-color: #ffffff;
    outline-color: #393939; }
  .bx--tooltip .bx--link {
    color: #78a9ff;
    font-size: 0.875rem; }
    .bx--tooltip .bx--link:focus {
      outline: 1px solid #ffffff;
      outline-offset: 2px; }
    .bx--tooltip .bx--link:active {
      color: #ffffff; }
    .bx--tooltip .bx--link:visited {
      color: #78a9ff; }
  .bx--tooltip .bx--tooltip__content[tabindex='-1']:focus {
    outline: none; }
  .bx--tooltip .bx--tooltip__caret {
    position: absolute;
    top: calc(-0.42969rem + 1px);
    right: 0;
    left: 0;
    width: 0;
    height: 0;
    margin: 0 auto;
    border-right: 0.42969rem solid transparent;
    border-bottom: 0.42969rem solid #393939;
    border-left: 0.42969rem solid transparent;
    content: ''; }
  .bx--tooltip .bx--tooltip__footer {
    display: flex;
    align-items: center;
    justify-content: space-between;
    margin-top: 1rem; }
  .bx--tooltip[data-floating-menu-direction='left'] .bx--tooltip__caret {
    top: 50%;
    right: calc(-0.42969rem + 1px);
    left: auto;
    transform: rotate(90deg) translate(50%, -50%); }
  .bx--tooltip[data-floating-menu-direction='top'] .bx--tooltip__caret {
    top: auto;
    bottom: calc(-0.42969rem + 1px);
    transform: rotate(180deg); }
  .bx--tooltip[data-floating-menu-direction='right'] .bx--tooltip__caret {
    top: 50%;
    right: auto;
    left: calc(-0.42969rem + 1px);
    transform: rotate(270deg) translate(50%, -50%); }

.bx--tooltip__heading {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  margin-bottom: 0.5rem; }

.bx--tooltip--shown {
  display: block; }

/* begin legacy definition tooltip TODO: deprecate */
.bx--tooltip--definition {
  position: relative; }
  .bx--tooltip--definition .bx--tooltip__trigger {
    font-size: 0.75rem;
    font-weight: 400;
    line-height: 1.34;
    letter-spacing: 0.32px;
    position: relative;
    display: inline-flex;
    color: #161616;
    border-bottom: 1px dotted #0f62fe; }
    .bx--tooltip--definition .bx--tooltip__trigger:hover {
      cursor: pointer; }
      .bx--tooltip--definition .bx--tooltip__trigger:hover + .bx--tooltip--definition__top,
      .bx--tooltip--definition .bx--tooltip__trigger:hover + .bx--tooltip--definition__bottom {
        display: block; }
    .bx--tooltip--definition .bx--tooltip__trigger:focus {
      outline: 1px solid #0f62fe; }
      .bx--tooltip--definition .bx--tooltip__trigger:focus + .bx--tooltip--definition__top,
      .bx--tooltip--definition .bx--tooltip__trigger:focus + .bx--tooltip--definition__bottom {
        display: block; }

.bx--tooltip--definition__bottom,
.bx--tooltip--definition__top {
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
  position: absolute;
  z-index: 1;
  display: none;
  width: 13rem;
  margin-top: 0.75rem;
  padding: 0.5rem 1rem;
  background: #393939;
  border-radius: 0.125rem;
  cursor: pointer;
  pointer-events: none; }
  .bx--tooltip--definition__bottom p,
  .bx--tooltip--definition__top p {
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px;
    color: #ffffff; }
  .bx--tooltip--definition__bottom .bx--tooltip__caret,
  .bx--tooltip--definition__top .bx--tooltip__caret {
    position: absolute;
    right: 0;
    left: 0;
    width: 0.6rem;
    height: 0.6rem;
    margin-left: 1rem;
    background: #393939; }

.bx--tooltip--definition__bottom .bx--tooltip__caret {
  top: -0.2rem;
  transform: rotate(-135deg); }

.bx--tooltip--definition__top {
  margin-top: -2rem;
  transform: translateY(-100%); }
  .bx--tooltip--definition__top .bx--tooltip__caret {
    bottom: -0.2rem;
    transform: rotate(45deg); }

.bx--tooltip--definition__align-end {
  right: 0; }

.bx--tooltip--definition__align-center {
  margin-left: 50%;
  transform: translateX(-50%); }

.bx--tooltip--definition__top.bx--tooltip--definition__align-center {
  margin-left: 50%;
  transform: translate(-50%, -100%); }

.bx--tooltip--definition__align-center .bx--tooltip__caret {
  left: auto;
  margin-right: calc(50% - 6px);
  margin-left: auto; }

.bx--tooltip--definition__align-end .bx--tooltip__caret {
  left: auto;
  margin-right: 1rem;
  margin-left: auto; }

/* end legacy definition tooltip */
.bx--tooltip--definition.bx--tooltip--a11y {
  display: inline-flex; }

.bx--tooltip--definition button.bx--tooltip--a11y {
  margin: 0; }

.bx--tooltip__trigger.bx--tooltip__trigger--definition {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  border-bottom: 0.0625rem dotted #525252;
  transition: border-color 110ms; }

.bx--tooltip__trigger.bx--tooltip__trigger--definition:hover,
.bx--tooltip__trigger.bx--tooltip__trigger--definition:focus {
  border-bottom-color: #0f62fe; }

.bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:focus {
    outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
        display: inline-block; } }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--a11y::after {
    transition: none; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.5rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
        width: 13rem; } }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after {
    content: attr(aria-label); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--a11y::after {
    content: none; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--visible::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--visible::after, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:hover::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:hover::after, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:focus::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:hover.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:focus + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--hidden .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::before {
    top: -0.25rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top + .bx--assistive-text {
    top: -0.5625rem;
    left: 0;
    transform: translate(0, -100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-start::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-start + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-start::before {
    top: -0.25rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-start + .bx--assistive-text {
    top: -0.5625rem;
    left: 0;
    transform: translate(0, -100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-center::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-center + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-center::before {
    top: -0.25rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-center + .bx--assistive-text {
    top: -0.5625rem;
    left: 50%;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-end::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-end + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-end::before {
    top: -0.25rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--top.bx--tooltip--align-end + .bx--assistive-text {
    top: -0.5625rem;
    right: 0;
    left: auto;
    transform: translate(0, -100%); }

.bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:focus {
    outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
        display: inline-block; } }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--a11y::after {
    transition: none; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.5rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
        width: 13rem; } }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after {
    content: attr(aria-label); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--a11y::after {
    content: none; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--visible::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--visible::after, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:hover::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:hover::after, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:focus::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:hover.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:focus + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--hidden .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::before {
    bottom: -0.25rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom + .bx--assistive-text {
    bottom: -0.5625rem;
    left: 0;
    transform: translate(0, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--a11y + .bx--assistive-text {
    bottom: -0.5rem;
    transform: translate(0, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start::before {
    bottom: -0.25rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start + .bx--assistive-text {
    bottom: -0.5625rem;
    left: 0;
    transform: translate(0, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-start.bx--tooltip--a11y + .bx--assistive-text {
    bottom: -0.5rem;
    transform: translate(0, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center::before {
    bottom: -0.25rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center + .bx--assistive-text {
    bottom: -0.5625rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-center.bx--tooltip--a11y + .bx--assistive-text {
    bottom: -0.5rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end::before, .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end::before {
    bottom: -0.25rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end + .bx--assistive-text {
    bottom: -0.5625rem;
    right: 0;
    left: auto;
    transform: translate(0, 100%); }
  .bx--tooltip__trigger.bx--tooltip__trigger--definition.bx--tooltip--bottom.bx--tooltip--align-end.bx--tooltip--a11y + .bx--assistive-text {
    bottom: -0.5rem;
    transform: translate(0, 100%); }

/* begin tooltip icon (TODO: deprecate) */
.bx--tooltip--icon {
  display: inline-flex;
  align-items: center; }

.bx--tooltip--icon__top,
.bx--tooltip--icon__bottom {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--tooltip--icon__top::before, .bx--tooltip--icon__top::after,
  .bx--tooltip--icon__bottom::before,
  .bx--tooltip--icon__bottom::after {
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px;
    position: absolute;
    display: flex;
    align-items: center;
    opacity: 0;
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
    pointer-events: none; }
  .bx--tooltip--icon__top::before,
  .bx--tooltip--icon__bottom::before {
    right: 0;
    left: 0;
    width: 0;
    height: 0;
    margin: 0 auto;
    margin-top: 1px;
    margin-left: 50%;
    border-color: transparent transparent #393939 transparent;
    border-style: solid;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    content: ''; }
  .bx--tooltip--icon__top::after,
  .bx--tooltip--icon__bottom::after {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    min-width: 1.5rem;
    max-width: 13rem;
    height: 1.5rem;
    margin-left: 50%;
    padding: 0 1rem;
    color: #ffffff;
    font-weight: 400;
    white-space: nowrap;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    content: attr(aria-label);
    pointer-events: none; }
  .bx--tooltip--icon__top:hover::before, .bx--tooltip--icon__top:hover::after, .bx--tooltip--icon__top:focus::before, .bx--tooltip--icon__top:focus::after,
  .bx--tooltip--icon__bottom:hover::before,
  .bx--tooltip--icon__bottom:hover::after,
  .bx--tooltip--icon__bottom:focus::before,
  .bx--tooltip--icon__bottom:focus::after {
    opacity: 1; }
  .bx--tooltip--icon__top:hover svg, .bx--tooltip--icon__top:focus svg,
  .bx--tooltip--icon__bottom:hover svg,
  .bx--tooltip--icon__bottom:focus svg {
    fill: #525252; }
  .bx--tooltip--icon__top:focus,
  .bx--tooltip--icon__bottom:focus {
    outline: 1px solid transparent; }
    .bx--tooltip--icon__top:focus svg,
    .bx--tooltip--icon__bottom:focus svg {
      outline: 1px solid #0f62fe; }

.bx--tooltip--icon__top::before {
  transform: translate(-50%, calc(-100% - 9px)) rotate(180deg);
  top: 1px; }

.bx--tooltip--icon__top::after {
  transform: translate(-50%, calc(-100% - 12px));
  top: 0; }

.bx--tooltip--icon__bottom::before {
  transform: translate(-50%, 10px) rotate(0);
  bottom: 0; }

.bx--tooltip--icon__bottom::after {
  transform: translate(-50%, calc(100% + 10px));
  bottom: 0; }

.bx--tooltip--icon__top.bx--tooltip--icon__align-start::before {
  transform: translate(0, calc(-100% - 9px)) rotate(180deg);
  top: 1px;
  margin-left: 4px; }

.bx--tooltip--icon__top.bx--tooltip--icon__align-start::after {
  transform: translate(0, calc(-100% - 12px));
  top: 0;
  margin-left: 0; }

.bx--tooltip--icon__top.bx--tooltip--icon__align-end::before {
  transform: translate(0, calc(-100% - 9px)) rotate(180deg);
  top: 1px;
  right: 0;
  left: auto;
  margin-right: 4px; }

.bx--tooltip--icon__top.bx--tooltip--icon__align-end::after {
  transform: translate(0, calc(-100% - 12px));
  top: 0;
  margin-left: 0;
  right: 0; }

.bx--tooltip--icon__bottom.bx--tooltip--icon__align-start::before {
  transform: translate(0, 10px) rotate(0);
  bottom: 0;
  margin-left: 4px; }

.bx--tooltip--icon__bottom.bx--tooltip--icon__align-start::after {
  transform: translate(0, calc(100% + 10px));
  bottom: 0;
  margin-left: 0; }

.bx--tooltip--icon__bottom.bx--tooltip--icon__align-end::before {
  transform: translate(0, 10px) rotate(0);
  bottom: 0;
  right: 0;
  left: auto;
  margin-right: 4px; }

.bx--tooltip--icon__bottom.bx--tooltip--icon__align-end::after {
  transform: translate(0, calc(100% + 10px));
  bottom: 0;
  margin-left: 0;
  right: 0; }

.bx--tooltip--icon .bx--tooltip__trigger svg {
  margin-left: 0; }

/* end legacy tooltip icon */
.bx--tooltip__trigger:hover svg, .bx--tooltip__trigger:focus svg {
  fill: #525252; }

.bx--tooltip__trigger.bx--tooltip--top {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--tooltip__trigger.bx--tooltip--top:focus {
    outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip--top:focus {
    outline: 1px solid transparent; }
    .bx--tooltip__trigger.bx--tooltip--top:focus svg {
      outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip--top::before, .bx--tooltip__trigger.bx--tooltip--top::after,
  .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip--top::before, .bx--tooltip__trigger.bx--tooltip--top::after,
      .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
        display: inline-block; } }
  .bx--tooltip__trigger.bx--tooltip--top::before, .bx--tooltip__trigger.bx--tooltip--top::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--a11y::after {
    transition: none; }
  .bx--tooltip__trigger.bx--tooltip--top::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .bx--tooltip__trigger.bx--tooltip--top::after,
  .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip--top::after,
      .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--tooltip__trigger.bx--tooltip--top::after,
      .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--tooltip__trigger.bx--tooltip--top::after,
      .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
        width: 13rem; } }
  .bx--tooltip__trigger.bx--tooltip--top::after {
    content: attr(aria-label); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--a11y::after {
    content: none; }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--visible::before, .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--visible::after, .bx--tooltip__trigger.bx--tooltip--top:hover::before, .bx--tooltip__trigger.bx--tooltip--top:hover::after, .bx--tooltip__trigger.bx--tooltip--top:focus::before, .bx--tooltip__trigger.bx--tooltip--top:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--top:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--top:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--top:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--top:hover.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--top:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top:focus + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--top:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--hidden .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .bx--tooltip__trigger.bx--tooltip--top::before, .bx--tooltip__trigger.bx--tooltip--top::after,
  .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip--top::before {
    top: -0.5rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip--top::after,
  .bx--tooltip__trigger.bx--tooltip--top .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top + .bx--assistive-text {
    top: -0.8125rem;
    left: 50%;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-start::before, .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-start + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-start::before {
    top: -0.5rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-start + .bx--assistive-text {
    top: -0.8125rem;
    left: 0;
    transform: translate(0, -100%); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-center::before, .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-center + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-center::before {
    top: -0.5rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-center + .bx--assistive-text {
    top: -0.8125rem;
    left: 50%;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-end::before, .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-end + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-end::before {
    top: -0.5rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--top.bx--tooltip--align-end + .bx--assistive-text {
    top: -0.8125rem;
    right: 0;
    left: auto;
    transform: translate(0, -100%); }

.bx--tooltip__trigger.bx--tooltip--right {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--tooltip__trigger.bx--tooltip--right:focus {
    outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip--right:focus {
    outline: 1px solid transparent; }
    .bx--tooltip__trigger.bx--tooltip--right:focus svg {
      outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip--right::before, .bx--tooltip__trigger.bx--tooltip--right::after,
  .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip--right::before, .bx--tooltip__trigger.bx--tooltip--right::after,
      .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
        display: inline-block; } }
  .bx--tooltip__trigger.bx--tooltip--right::before, .bx--tooltip__trigger.bx--tooltip--right::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--a11y::after {
    transition: none; }
  .bx--tooltip__trigger.bx--tooltip--right::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .bx--tooltip__trigger.bx--tooltip--right::after,
  .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip--right::after,
      .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--tooltip__trigger.bx--tooltip--right::after,
      .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--tooltip__trigger.bx--tooltip--right::after,
      .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
        width: 13rem; } }
  .bx--tooltip__trigger.bx--tooltip--right::after {
    content: attr(aria-label); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--a11y::after {
    content: none; }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--visible::before, .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--visible::after, .bx--tooltip__trigger.bx--tooltip--right:hover::before, .bx--tooltip__trigger.bx--tooltip--right:hover::after, .bx--tooltip__trigger.bx--tooltip--right:focus::before, .bx--tooltip__trigger.bx--tooltip--right:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--right:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--right:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--right:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--right:hover.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--right:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right:focus + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--right:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--hidden .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .bx--tooltip__trigger.bx--tooltip--right::before, .bx--tooltip__trigger.bx--tooltip--right::after,
  .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
    top: 50%;
    right: 0; }
  .bx--tooltip__trigger.bx--tooltip--right::before {
    right: -0.5rem;
    border-color: transparent #393939 transparent transparent;
    border-width: 0.25rem 0.3125rem 0.25rem 0;
    transform: translate(100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--right::after,
  .bx--tooltip__trigger.bx--tooltip--right .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right + .bx--assistive-text {
    right: -0.8125rem;
    transform: translate(100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-start::before, .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-start + .bx--assistive-text {
    top: 50%;
    right: 0; }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-start::before {
    right: -0.5rem;
    border-color: transparent #393939 transparent transparent;
    border-width: 0.25rem 0.3125rem 0.25rem 0;
    transform: translate(100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-start + .bx--assistive-text {
    right: -0.8125rem;
    transform: translate(100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-center::before, .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-center + .bx--assistive-text {
    top: 50%;
    right: 0; }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-center::before {
    right: -0.5rem;
    border-color: transparent #393939 transparent transparent;
    border-width: 0.25rem 0.3125rem 0.25rem 0;
    transform: translate(100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-center + .bx--assistive-text {
    right: -0.8125rem;
    transform: translate(100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-end::before, .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-end + .bx--assistive-text {
    top: 50%;
    right: 0; }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-end::before {
    right: -0.5rem;
    border-color: transparent #393939 transparent transparent;
    border-width: 0.25rem 0.3125rem 0.25rem 0;
    transform: translate(100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--right.bx--tooltip--align-end + .bx--assistive-text {
    right: -0.8125rem;
    transform: translate(100%, -50%); }

.bx--tooltip__trigger.bx--tooltip--bottom {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--tooltip__trigger.bx--tooltip--bottom:focus {
    outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip--bottom:focus {
    outline: 1px solid transparent; }
    .bx--tooltip__trigger.bx--tooltip--bottom:focus svg {
      outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip--bottom::before, .bx--tooltip__trigger.bx--tooltip--bottom::after,
  .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip--bottom::before, .bx--tooltip__trigger.bx--tooltip--bottom::after,
      .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
        display: inline-block; } }
  .bx--tooltip__trigger.bx--tooltip--bottom::before, .bx--tooltip__trigger.bx--tooltip--bottom::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--a11y::after {
    transition: none; }
  .bx--tooltip__trigger.bx--tooltip--bottom::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .bx--tooltip__trigger.bx--tooltip--bottom::after,
  .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip--bottom::after,
      .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--tooltip__trigger.bx--tooltip--bottom::after,
      .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--tooltip__trigger.bx--tooltip--bottom::after,
      .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
        width: 13rem; } }
  .bx--tooltip__trigger.bx--tooltip--bottom::after {
    content: attr(aria-label); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--a11y::after {
    content: none; }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--visible::before, .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--visible::after, .bx--tooltip__trigger.bx--tooltip--bottom:hover::before, .bx--tooltip__trigger.bx--tooltip--bottom:hover::after, .bx--tooltip__trigger.bx--tooltip--bottom:focus::before, .bx--tooltip__trigger.bx--tooltip--bottom:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--bottom:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--bottom:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--bottom:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--bottom:hover.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--bottom:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom:focus + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--bottom:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--hidden .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .bx--tooltip__trigger.bx--tooltip--bottom::before, .bx--tooltip__trigger.bx--tooltip--bottom::after,
  .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip--bottom::before {
    bottom: -0.5rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip--bottom::after,
  .bx--tooltip__trigger.bx--tooltip--bottom .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom + .bx--assistive-text {
    bottom: -0.8125rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-start::before, .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-start + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-start::before {
    bottom: -0.5rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-start + .bx--assistive-text {
    bottom: -0.8125rem;
    left: 0;
    transform: translate(0, 100%); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-center::before, .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-center + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-center::before {
    bottom: -0.5rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-center + .bx--assistive-text {
    bottom: -0.8125rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-end::before, .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-end + .bx--assistive-text {
    bottom: 0;
    left: 50%; }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-end::before {
    bottom: -0.5rem;
    border-color: transparent transparent #393939 transparent;
    border-width: 0 0.25rem 0.3125rem 0.25rem;
    transform: translate(-50%, 100%); }
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--bottom.bx--tooltip--align-end + .bx--assistive-text {
    bottom: -0.8125rem;
    right: 0;
    left: auto;
    transform: translate(0, 100%); }

.bx--tooltip__trigger.bx--tooltip--left {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .bx--tooltip__trigger.bx--tooltip--left:focus {
    outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip--left:focus {
    outline: 1px solid transparent; }
    .bx--tooltip__trigger.bx--tooltip--left:focus svg {
      outline: 1px solid #0f62fe; }
  .bx--tooltip__trigger.bx--tooltip--left::before, .bx--tooltip__trigger.bx--tooltip--left::after,
  .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip--left::before, .bx--tooltip__trigger.bx--tooltip--left::after,
      .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
        display: inline-block; } }
  .bx--tooltip__trigger.bx--tooltip--left::before, .bx--tooltip__trigger.bx--tooltip--left::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--a11y::after {
    transition: none; }
  .bx--tooltip__trigger.bx--tooltip--left::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .bx--tooltip__trigger.bx--tooltip--left::after,
  .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .bx--tooltip__trigger.bx--tooltip--left::after,
      .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .bx--tooltip__trigger.bx--tooltip--left::after,
      .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .bx--tooltip__trigger.bx--tooltip--left::after,
      .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
      .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
        width: 13rem; } }
  .bx--tooltip__trigger.bx--tooltip--left::after {
    content: attr(aria-label); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--a11y::after {
    content: none; }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--visible::before, .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--visible::after, .bx--tooltip__trigger.bx--tooltip--left:hover::before, .bx--tooltip__trigger.bx--tooltip--left:hover::after, .bx--tooltip__trigger.bx--tooltip--left:focus::before, .bx--tooltip__trigger.bx--tooltip--left:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--left:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--left:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--visible .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--visible + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--visible.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--left:hover .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left:hover + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--left:hover.bx--tooltip--a11y::before, .bx--tooltip__trigger.bx--tooltip--left:focus .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left:focus + .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--left:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--hidden .bx--assistive-text, .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .bx--tooltip__trigger.bx--tooltip--left::before, .bx--tooltip__trigger.bx--tooltip--left::after,
  .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
    top: 50%;
    left: 0; }
  .bx--tooltip__trigger.bx--tooltip--left::before {
    left: -0.5rem;
    border-color: transparent transparent transparent #393939;
    border-width: 0.25rem 0 0.25rem 0.3125rem;
    transform: translate(-100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--left::after,
  .bx--tooltip__trigger.bx--tooltip--left .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left + .bx--assistive-text {
    left: -0.8125rem;
    transform: translate(-100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-start::before, .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-start + .bx--assistive-text {
    top: 50%;
    left: 0; }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-start::before {
    left: -0.5rem;
    border-color: transparent transparent transparent #393939;
    border-width: 0.25rem 0 0.25rem 0.3125rem;
    transform: translate(-100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-start::after,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-start .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-start + .bx--assistive-text {
    left: -0.8125rem;
    transform: translate(-100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-center::before, .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-center + .bx--assistive-text {
    top: 50%;
    left: 0; }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-center::before {
    left: -0.5rem;
    border-color: transparent transparent transparent #393939;
    border-width: 0.25rem 0 0.25rem 0.3125rem;
    transform: translate(-100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-center::after,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-center .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-center + .bx--assistive-text {
    left: -0.8125rem;
    transform: translate(-100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-end::before, .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-end + .bx--assistive-text {
    top: 50%;
    left: 0; }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-end::before {
    left: -0.5rem;
    border-color: transparent transparent transparent #393939;
    border-width: 0.25rem 0 0.25rem 0.3125rem;
    transform: translate(-100%, -50%); }
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-end::after,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-end .bx--assistive-text,
  .bx--tooltip__trigger.bx--tooltip--left.bx--tooltip--align-end + .bx--assistive-text {
    left: -0.8125rem;
    transform: translate(-100%, -50%); }

.bx--tabs {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  width: 100%;
  height: auto;
  min-height: 2.5rem;
  color: #161616; }

.bx--tabs--container {
  min-height: 3rem; }

.bx--tabs__nav {
  display: flex;
  flex-direction: row;
  width: auto;
  max-width: 100%;
  margin: 0;
  padding: 0;
  overflow: auto hidden;
  list-style: none;
  transition: max-height 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  scrollbar-width: none; }
  .bx--tabs__nav::-webkit-scrollbar {
    display: none; }

.bx--tabs__overflow-indicator--left,
.bx--tabs__overflow-indicator--right {
  z-index: 1;
  flex: 1 0 auto;
  width: 0.5rem; }

.bx--tabs__overflow-indicator--left {
  margin-right: -0.5rem;
  background-image: linear-gradient(to left, transparent, #f4f4f4); }

.bx--tabs__overflow-indicator--right {
  margin-left: -0.5rem;
  background-image: linear-gradient(to right, transparent, #f4f4f4); }

.bx--tabs--light .bx--tabs__overflow-indicator--left {
  background-image: linear-gradient(to left, transparent, #ffffff); }

.bx--tabs--light .bx--tabs__overflow-indicator--right {
  background-image: linear-gradient(to right, transparent, #ffffff); }

.bx--tabs--container .bx--tabs__overflow-indicator--left {
  background-image: linear-gradient(to left, transparent, #e0e0e0); }

.bx--tabs--container .bx--tabs__overflow-indicator--right {
  background-image: linear-gradient(to right, transparent, #e0e0e0); }

@media not all and (min-resolution: 0.001dpcm) {
  @supports (-webkit-appearance: none) and (stroke-color: transparent) {
    .bx--tabs__overflow-indicator--left {
      margin-right: -1rem;
      background-image: linear-gradient(to left, rgba(244, 244, 244, 0), #f4f4f4); }
    .bx--tabs__overflow-indicator--right {
      margin-left: -1rem;
      background-image: linear-gradient(to right, rgba(244, 244, 244, 0), #f4f4f4); }
    .bx--tabs--container .bx--tabs__overflow-indicator--left {
      background-image: linear-gradient(to left, rgba(224, 224, 224, 0), #e0e0e0); }
    .bx--tabs--container
.bx--tabs__overflow-indicator--right {
      background-image: linear-gradient(to right, rgba(224, 224, 224, 0), #e0e0e0); } } }

.bx--tab--overflow-nav-button {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: flex;
  flex-shrink: 0;
  align-items: center;
  justify-content: center;
  width: 2.5rem; }
  .bx--tab--overflow-nav-button::-moz-focus-inner {
    border: 0; }
  .bx--tab--overflow-nav-button:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.bx--tab--overflow-nav-button--hidden {
  display: none; }

.bx--tabs--container .bx--tab--overflow-nav-button {
  width: 3rem;
  margin: 0;
  background-color: #e0e0e0; }

.bx--tab--overflow-nav-button svg {
  fill: #161616; }

.bx--tabs__nav-item {
  display: flex;
  padding: 0;
  cursor: pointer;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--tabs__nav-item + .bx--tabs__nav-item {
  margin-left: 0.0625rem; }

.bx--tabs--container .bx--tabs__nav-item {
  background-color: #e0e0e0; }

.bx--tabs--container
.bx--tabs__nav-item
+ .bx--tabs__nav-item {
  margin-left: 0;
  box-shadow: -0.0625rem 0 0 0 #8d8d8d; }

.bx--tabs--container
.bx--tabs__nav-item
+ .bx--tabs__nav-item.bx--tabs__nav-item--selected,
.bx--tabs--container
.bx--tabs__nav-item.bx--tabs__nav-item--selected
+ .bx--tabs__nav-item {
  box-shadow: none; }

.bx--tabs__nav-item .bx--tabs__nav-link {
  transition: color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), border-bottom-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--tabs--container .bx--tabs__nav-item:hover {
  background-color: #cacaca; }

.bx--tabs__nav-item--disabled,
.bx--tabs__nav-item--disabled:hover {
  background-color: transparent;
  outline: none;
  cursor: not-allowed; }

.bx--tabs--container
.bx--tabs__nav-item.bx--tabs__nav-item--disabled,
.bx--tabs--container
.bx--tabs__nav-item.bx--tabs__nav-item--disabled:hover {
  background-color: #c6c6c6; }

.bx--tabs__nav-item--selected {
  transition: color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--tabs__nav-item--selected .bx--tabs__nav-link,
.bx--tabs__nav-item--selected .bx--tabs__nav-link:focus,
.bx--tabs__nav-item--selected .bx--tabs__nav-link:active {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  color: #161616;
  border-bottom: 2px solid #0f62fe; }

.bx--tabs--container .bx--tabs__nav-item--selected,
.bx--tabs--container .bx--tabs__nav-item--selected:hover {
  background-color: #ffffff; }
  .bx--tabs--container .bx--tabs__nav-item--selected .bx--tabs__nav-link:focus,
  .bx--tabs--container .bx--tabs__nav-item--selected .bx--tabs__nav-link:active,
  .bx--tabs--container .bx--tabs__nav-item--selected:hover .bx--tabs__nav-link:focus,
  .bx--tabs--container .bx--tabs__nav-item--selected:hover .bx--tabs__nav-link:active {
    box-shadow: none; }

.bx--tabs--container
.bx--tabs__nav-item--selected
.bx--tabs__nav-link {
  line-height: calc(3rem - (0.5rem * 2));
  box-shadow: inset 0 2px 0 0 #0f62fe; }

.bx--tabs--light.bx--tabs--container
.bx--tabs__nav-item--selected,
.bx--tabs--light.bx--tabs--container
.bx--tabs__nav-item--selected:hover {
  background-color: #f4f4f4; }

.bx--tabs__nav-link {
  outline: 2px solid transparent;
  outline-offset: -2px;
  width: 10rem;
  padding: 0.75rem 1rem 0.5rem;
  overflow: hidden;
  color: #525252;
  white-space: nowrap;
  text-decoration: none;
  text-overflow: ellipsis;
  border-bottom: 2px solid #e0e0e0;
  transition: border 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tabs__nav-link:focus, .bx--tabs__nav-link:active {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.bx--tabs--container .bx--tabs__nav-link {
  height: 3rem;
  padding: 0.5rem 1rem;
  line-height: calc(3rem - (0.5rem * 2));
  border-bottom: 0; }

.bx--tabs__nav-item:hover .bx--tabs__nav-link {
  color: #161616;
  border-bottom: 2px solid #8d8d8d; }

.bx--tabs--container
.bx--tabs__nav-item
.bx--tabs__nav-link {
  border-bottom: none; }

.bx--tabs__nav-item--disabled .bx--tabs__nav-link {
  color: #c6c6c6;
  border-bottom: 2px solid #ffffff; }

.bx--tabs__nav-item--disabled:hover .bx--tabs__nav-link {
  color: #c6c6c6;
  border-bottom: 2px solid #ffffff;
  cursor: not-allowed;
  pointer-events: none; }

.bx--tabs__nav-item--disabled .bx--tabs__nav-link:focus,
.bx--tabs__nav-item--disabled .bx--tabs__nav-link:active {
  border-bottom: 2px solid #ffffff;
  outline: none; }

.bx--tabs--light
.bx--tabs__nav-item--disabled
.bx--tabs__nav-link {
  border-bottom-color: #e0e0e0; }

.bx--tabs--light
.bx--tabs__nav-item--disabled:hover
.bx--tabs__nav-link {
  border-bottom-color: #e0e0e0; }

.bx--tabs--light
.bx--tabs__nav-item--disabled
.bx--tabs__nav-link:focus,
.bx--tabs--light
.bx--tabs__nav-item--disabled
.bx--tabs__nav-link:active {
  border-bottom-color: #e0e0e0; }

.bx--tabs--container
.bx--tabs__nav-item--disabled
.bx--tabs__nav-link {
  color: #8d8d8d;
  border-bottom: none; }

.bx--tab-content {
  padding: 1rem; }

.bx--tabs.bx--skeleton {
  cursor: default;
  pointer-events: none; }

.bx--tabs.bx--skeleton .bx--tabs__nav-link {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 4.6875rem; }
  .bx--tabs.bx--skeleton .bx--tabs__nav-link:hover, .bx--tabs.bx--skeleton .bx--tabs__nav-link:focus, .bx--tabs.bx--skeleton .bx--tabs__nav-link:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--tabs.bx--skeleton .bx--tabs__nav-link::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--tabs.bx--skeleton .bx--tabs__nav-link::before {
        animation: none; } }
.bx--tabs.bx--skeleton .bx--tabs-trigger {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 4.6875rem;
  margin-right: 0.0625rem; }
  .bx--tabs.bx--skeleton .bx--tabs-trigger:hover, .bx--tabs.bx--skeleton .bx--tabs-trigger:focus, .bx--tabs.bx--skeleton .bx--tabs-trigger:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--tabs.bx--skeleton .bx--tabs-trigger::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--tabs.bx--skeleton .bx--tabs-trigger::before {
        animation: none; } }
.bx--tabs.bx--skeleton .bx--tabs-trigger svg {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.bx--tag {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  color: #525252;
  background-color: #e0e0e0;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  min-width: 2rem;
  max-width: 100%;
  min-height: 1.5rem;
  margin: 0.25rem;
  padding: 0.25rem 0.5rem;
  word-break: break-word;
  border-radius: 0.9375rem;
  cursor: default; }
  .bx--tag::-moz-focus-inner {
    border: 0; }
  .bx--tag .bx--tag__close-icon:hover {
    background-color: #c6c6c6; }
  .bx--tag:not(:first-child) {
    margin-left: 0; }

.bx--tag--red {
  color: #a2191f;
  background-color: #ffd7d9; }
  .bx--tag--red .bx--tag__close-icon:hover {
    background-color: #ffb3b8; }

.bx--tag--magenta {
  color: #9f1853;
  background-color: #ffd6e8; }
  .bx--tag--magenta .bx--tag__close-icon:hover {
    background-color: #ffafd2; }

.bx--tag--purple {
  color: #6929c4;
  background-color: #e8daff; }
  .bx--tag--purple .bx--tag__close-icon:hover {
    background-color: #d4bbff; }

.bx--tag--blue {
  color: #0043ce;
  background-color: #d0e2ff; }
  .bx--tag--blue .bx--tag__close-icon:hover {
    background-color: #a6c8ff; }

.bx--tag--cyan {
  color: #00539a;
  background-color: #bae6ff; }
  .bx--tag--cyan .bx--tag__close-icon:hover {
    background-color: #82cfff; }

.bx--tag--teal {
  color: #005d5d;
  background-color: #9ef0f0; }
  .bx--tag--teal .bx--tag__close-icon:hover {
    background-color: #3ddbd9; }

.bx--tag--green {
  color: #0e6027;
  background-color: #a7f0ba; }
  .bx--tag--green .bx--tag__close-icon:hover {
    background-color: #6fdc8c; }

.bx--tag--gray {
  color: #525252;
  background-color: #e0e0e0; }
  .bx--tag--gray .bx--tag__close-icon:hover {
    background-color: #c6c6c6; }

.bx--tag--cool-gray {
  color: #4d5358;
  background-color: #dde1e6; }
  .bx--tag--cool-gray .bx--tag__close-icon:hover {
    background-color: #c1c7cd; }

.bx--tag--warm-gray {
  color: #565151;
  background-color: #e5e0df; }
  .bx--tag--warm-gray .bx--tag__close-icon:hover {
    background-color: #cac5c4; }

.bx--tag--high-contrast {
  color: #ffffff;
  background-color: #393939; }
  .bx--tag--high-contrast .bx--tag__close-icon:hover {
    background-color: #4c4c4c; }

.bx--tag--disabled,
.bx--tag--filter.bx--tag--disabled {
  color: #c6c6c6;
  background-color: #ffffff; }
  .bx--tag--disabled .bx--tag__close-icon:hover,
  .bx--tag--filter.bx--tag--disabled .bx--tag__close-icon:hover {
    background-color: #ffffff; }
  .bx--tag--disabled:hover,
  .bx--tag--filter.bx--tag--disabled:hover {
    cursor: not-allowed; }

.bx--tag__label {
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.bx--tag--filter {
  padding-right: 0.125rem;
  cursor: pointer; }
  .bx--tag--filter:focus, .bx--tag--filter:hover {
    outline: none; }

.bx--tag__close-icon {
  flex-shrink: 0;
  width: 1.25rem;
  height: 1.25rem;
  margin: 0 0 0 0.25rem;
  padding: 0.125rem;
  color: currentColor;
  background-color: transparent;
  border: 0;
  border-radius: 50%;
  cursor: pointer; }
  .bx--tag__close-icon svg {
    fill: currentColor; }

.bx--tag--disabled .bx--tag__close-icon {
  cursor: not-allowed; }

.bx--tag__close-icon:focus {
  border-radius: 50%;
  outline: none;
  box-shadow: inset 0 0 0 2px #0f62fe; }

.bx--tag--filter.bx--tag--disabled
.bx--tag__close-icon:hover {
  background-color: transparent; }

.bx--tag--filter.bx--tag--disabled svg {
  fill: #c6c6c6; }

.bx--tag.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  color: #161616;
  background-color: #e0e0e0;
  width: 3.75rem;
  overflow: hidden; }
  .bx--tag.bx--skeleton:hover, .bx--tag.bx--skeleton:focus, .bx--tag.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--tag.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--tag.bx--skeleton::before {
        animation: none; } }
  .bx--tag.bx--skeleton .bx--tag__close-icon:hover {
    background-color: #e0e0e0; }

.bx--data-table-container + .bx--pagination {
  border-top: 0; }

.bx--pagination {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  min-height: 3rem;
  overflow-x: auto;
  background-color: #ffffff;
  border-top: 1px solid #e0e0e0; }
  @media (min-width: 42rem) {
    .bx--pagination {
      overflow: initial; } }
  @media (max-width: 41.98rem) {
    .bx--pagination .bx--pagination__left > *,
    .bx--pagination .bx--pagination__right > * {
      display: none; }
    .bx--pagination .bx--pagination__items-count,
    .bx--pagination .bx--pagination__control-buttons {
      display: initial; } }
.bx--pagination .bx--select {
  align-items: center;
  height: 100%; }

.bx--pagination .bx--select-input--inline__wrapper {
  display: flex;
  height: 100%; }

.bx--pagination .bx--select-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  width: auto;
  min-width: auto;
  height: 3rem;
  padding: 0 2.25rem 0 1rem; }

.bx--pagination .bx--select-input:hover {
  background: #e5e5e5; }

.bx--pagination .bx--select__arrow {
  top: 50%;
  transform: translate(-0.5rem, -50%); }

.bx--pagination
.bx--select__item-count
.bx--select-input {
  border-right: 0.0625rem solid #e0e0e0; }

.bx--pagination
.bx--select__page-number
.bx--select-input {
  border-left: 1px solid #e0e0e0; }

.bx--pagination__left,
.bx--pagination__right {
  display: flex;
  align-items: center;
  height: 3rem; }

.bx--pagination__left > .bx--form-item,
.bx--pagination__right > .bx--form-item {
  height: 100%; }

.bx--pagination__left .bx--pagination__text,
.bx--pagination__right .bx--pagination__text {
  white-space: nowrap; }

.bx--pagination__left .bx--pagination__text {
  margin-right: 0.0625rem; }

.bx--pagination__right .bx--pagination__text {
  margin-right: 1rem;
  margin-left: 0.0625rem; }

.bx--pagination__left {
  padding: 0 1rem; }

@media (min-width: 42rem) {
  .bx--pagination__text {
    display: inline-block; } }

span.bx--pagination__text {
  margin-left: 1rem;
  color: #525252; }

.bx--pagination__button,
.bx--btn--ghost.bx--pagination__button {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 3rem;
  height: 100%;
  margin: 0;
  background: none;
  border: none;
  border-left: 1px solid #e0e0e0;
  cursor: pointer;
  transition: outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }

.bx--pagination__button:focus,
.bx--btn--ghost:focus.bx--pagination__button {
  outline: 2px solid #0f62fe;
  outline-offset: -2px;
  border-left: 0; }

.bx--pagination__button:hover,
.bx--btn--ghost:hover.bx--pagination__button {
  background: #e5e5e5; }

.bx--pagination__button--no-index,
.bx--btn--ghost.bx--pagination__button--no-index {
  cursor: not-allowed;
  fill: #c6c6c6; }

.bx--pagination__button:disabled:hover,
.bx--pagination__button--no-index:hover,
.bx--btn--ghost:disabled:hover.bx--pagination__button,
.bx--btn--ghost:hover.bx--pagination__button--no-index {
  background: #ffffff;
  border-color: #e0e0e0;
  cursor: not-allowed;
  fill: #c6c6c6; }

.bx--pagination.bx--skeleton .bx--skeleton__text {
  margin-right: 1rem;
  margin-bottom: 0; }

@keyframes collapse-accordion {
  0% {
    height: 100%;
    visibility: inherit;
    opacity: 1; }
  100% {
    height: 0;
    visibility: hidden;
    opacity: 0; } }

@keyframes expand-accordion {
  0% {
    height: 0;
    visibility: hidden;
    opacity: 0; }
  100% {
    height: 100%;
    visibility: inherit;
    opacity: 1; } }

.bx--accordion {
  width: 100%;
  list-style: none; }

.bx--accordion__item {
  overflow: visible;
  border-top: 1px solid #e0e0e0;
  transition: all 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--accordion__item:last-child {
    border-bottom: 1px solid #e0e0e0; }

.bx--accordion__heading {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  position: relative;
  display: flex;
  flex-direction: row-reverse;
  align-items: flex-start;
  justify-content: flex-start;
  width: 100%;
  min-height: 2.5rem;
  margin: 0;
  padding: 0.625rem 0;
  color: #161616;
  cursor: pointer;
  transition: background-color cubic-bezier(0.2, 0, 0.38, 0.9) 110ms; }
  .bx--accordion__heading::-moz-focus-inner {
    border: 0; }
  .bx--accordion__heading:hover::before, .bx--accordion__heading:focus::before {
    position: absolute;
    top: -1px;
    left: 0;
    width: 100%;
    height: calc(100% + 2px);
    content: ''; }
  .bx--accordion__heading:hover::before {
    background-color: #e5e5e5; }
  .bx--accordion__heading:focus {
    outline: none; }
  .bx--accordion__heading:focus::before {
    box-sizing: border-box;
    border: 2px solid #0f62fe; }

.bx--accordion__arrow {
  outline: 2px solid transparent;
  outline-offset: -2px;
  flex: 0 0 1rem;
  width: 1rem;
  height: 1rem;
  margin: 2px 1rem 0 0;
  transform: rotate(90deg);
  transition: all 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }

.bx--accordion__title {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px;
  z-index: 1;
  width: 100%;
  margin: 0 0 0 1rem;
  text-align: left; }

.bx--accordion__content {
  display: none;
  padding-right: 1rem;
  padding-left: 1rem;
  transition: padding cubic-bezier(0.2, 0, 0.38, 0.9) 110ms; }
  @media (min-width: 480px) {
    .bx--accordion__content {
      padding-right: 3rem; } }
  @media (min-width: 640px) {
    .bx--accordion__content {
      padding-right: 25%; } }
  .bx--accordion__content > p {
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.43;
    letter-spacing: 0.16px; }

.bx--accordion--start .bx--accordion__heading {
  flex-direction: row; }

.bx--accordion--start .bx--accordion__arrow {
  margin: 2px 0 0 0.5rem; }

.bx--accordion--start .bx--accordion__content {
  margin-left: 1.5rem; }

.bx--accordion__item--collapsing .bx--accordion__content,
.bx--accordion__item--expanding .bx--accordion__content {
  display: block; }

.bx--accordion__item--collapsing .bx--accordion__content {
  animation: 110ms cubic-bezier(0.2, 0, 0.38, 0.9) collapse-accordion; }

.bx--accordion__item--expanding .bx--accordion__content {
  animation: 110ms cubic-bezier(0.2, 0, 0.38, 0.9) expand-accordion; }

.bx--accordion__item--active {
  overflow: visible; }
  .bx--accordion__item--active .bx--accordion__content {
    display: block;
    padding-top: 0.5rem;
    padding-bottom: 1.5rem;
    transition: padding-top cubic-bezier(0, 0, 0.38, 0.9) 110ms, padding-bottom cubic-bezier(0, 0, 0.38, 0.9) 110ms; }
  .bx--accordion__item--active .bx--accordion__arrow {
    /* rtl:ignore */
    transform: rotate(-90deg);
    fill: #161616; }

.bx--accordion.bx--skeleton .bx--accordion__heading,
.bx--accordion.bx--skeleton .bx--accordion__button {
  cursor: default; }

.bx--accordion.bx--skeleton .bx--accordion__arrow {
  cursor: default;
  pointer-events: none;
  fill: #161616; }
  .bx--accordion.bx--skeleton .bx--accordion__arrow:hover, .bx--accordion.bx--skeleton .bx--accordion__arrow:focus, .bx--accordion.bx--skeleton .bx--accordion__arrow:active {
    border: none;
    outline: none;
    cursor: default; }

.bx--accordion.bx--skeleton
.bx--accordion__heading:hover::before {
  background-color: transparent; }

.bx--accordion--end.bx--skeleton
.bx--accordion__arrow {
  margin-left: 1rem; }

.bx--skeleton
.bx--accordion__heading:focus
.bx--accordion__arrow {
  border: none;
  outline: none;
  cursor: default; }

.bx--accordion__title.bx--skeleton__text {
  margin-bottom: 0; }

.bx--progress {
  display: flex;
  list-style: none; }

.bx--progress-step {
  position: relative;
  display: inline-flex;
  flex-direction: row;
  width: 8rem;
  min-width: 7rem;
  overflow: visible; }
  .bx--progress-step .bx--tooltip__label {
    display: block; }

.bx--progress--space-equal .bx--progress-step {
  flex-grow: 1;
  min-width: 8rem; }

.bx--progress-line {
  position: absolute;
  left: 0;
  width: 8rem;
  height: 1px;
  border: 1px inset transparent; }

.bx--progress--space-equal .bx--progress-line {
  width: 100%;
  min-width: 8rem; }

.bx--progress-step svg {
  position: relative;
  z-index: 1;
  flex-shrink: 0;
  width: 1rem;
  height: 1rem;
  margin: 0.625rem 0.5rem 0 0;
  border-radius: 50%;
  fill: #0f62fe; }

.bx--progress-label {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  max-width: 5.5rem;
  margin: 0.5rem 0 0 0;
  overflow: hidden;
  color: #161616;
  line-height: 1.45;
  white-space: nowrap;
  text-overflow: ellipsis;
  transition: box-shadow 110ms cubic-bezier(0.2, 0, 0.38, 0.9), color 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--progress-label::before {
    display: block;
    content: ''; }

.bx--progress-label:hover {
  color: #0f62fe;
  box-shadow: 0 0.0625rem #0f62fe;
  cursor: pointer; }

.bx--progress-label:focus {
  color: #0f62fe;
  outline: none;
  box-shadow: 0 0.1875rem 0 0 #0f62fe; }

.bx--progress--space-equal .bx--progress-label {
  max-width: 100%;
  margin-right: 0.75rem; }

.bx--progress-label:active {
  color: #0f62fe;
  box-shadow: 0 0.1875rem 0 0 #0f62fe; }

.bx--progress-label-overflow:hover ~ .bx--tooltip,
.bx--progress-label-overflow:focus ~ .bx--tooltip {
  visibility: inherit; }

.bx--progress-step .bx--tooltip .bx--tooltip__caret {
  margin-left: 0.625rem; }

.bx--tooltip__text {
  margin: 0;
  padding: 0;
  font-weight: normal; }

.bx--progress-step .bx--tooltip {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px;
  display: block;
  width: 7.8125rem;
  min-width: 7.1875rem;
  min-height: 1.5rem;
  margin-top: 2.5rem;
  margin-left: 1.375rem;
  padding: 0.5rem 1rem;
  color: #ffffff;
  visibility: hidden; }

.bx--progress-step .bx--tooltip_multi {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px;
  width: 9.375rem;
  height: auto;
  color: #ffffff; }

.bx--progress-optional {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  position: absolute;
  left: 0;
  margin-top: 1.75rem;
  margin-left: 1.5rem;
  color: #525252;
  text-align: start; }

.bx--progress-step--current .bx--progress-line {
  background-color: #0f62fe; }

.bx--progress-step--incomplete svg {
  fill: #161616; }

.bx--progress-step--incomplete .bx--progress-line {
  background-color: #e0e0e0; }

.bx--progress-step--complete .bx--progress-line {
  background-color: #0f62fe; }

.bx--progress-step-button {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: flex;
  text-align: left; }
  .bx--progress-step-button::-moz-focus-inner {
    border: 0; }

.bx--progress-step-button--unclickable {
  outline: none;
  cursor: default; }

.bx--progress-step-button--unclickable
.bx--progress-label:hover {
  color: #161616;
  box-shadow: none;
  cursor: default; }

.bx--progress-step-button--unclickable
.bx--tooltip__label:hover {
  color: #0f62fe;
  box-shadow: 0 0.0625rem #0f62fe;
  cursor: pointer; }

.bx--progress-step--disabled {
  cursor: not-allowed;
  pointer-events: none; }
  .bx--progress-step--disabled svg {
    cursor: not-allowed;
    fill: #c6c6c6; }
  .bx--progress-step--disabled .bx--progress-label,
  .bx--progress-step--disabled .bx--progress-label:hover {
    color: #c6c6c6;
    box-shadow: none;
    cursor: not-allowed; }
  .bx--progress-step--disabled .bx--progress-label:focus,
  .bx--progress-step--disabled .bx--progress-label:active {
    outline: none;
    box-shadow: none; }
  .bx--progress-step--disabled .bx--progress-line {
    cursor: not-allowed; }
  .bx--progress-step--disabled .bx--progress-label-overflow:hover
~ .bx--tooltip--definition
.bx--tooltip--definition__bottom {
    display: none; }

.bx--progress__warning > * {
  fill: #da1e28; }

.bx--progress.bx--skeleton .bx--progress-label {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 2.5rem;
  height: 0.75rem; }
  .bx--progress.bx--skeleton .bx--progress-label:hover, .bx--progress.bx--skeleton .bx--progress-label:focus, .bx--progress.bx--skeleton .bx--progress-label:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--progress.bx--skeleton .bx--progress-label::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--progress.bx--skeleton .bx--progress-label::before {
        animation: none; } }
.bx--progress--vertical {
  display: flex;
  flex-direction: column; }

.bx--progress--vertical .bx--progress-step,
.bx--progress--vertical .bx--progress-step-button {
  flex-wrap: wrap;
  align-content: flex-start;
  width: initial;
  min-width: initial;
  min-height: 3.625rem; }

.bx--progress--vertical .bx--progress-step svg,
.bx--progress--vertical .bx--progress-step-button svg {
  display: inline-block;
  margin: 0.0625rem 0.5rem 0; }

.bx--progress--vertical .bx--progress-label {
  display: inline-block;
  width: initial;
  max-width: 10rem;
  margin: 0;
  white-space: initial;
  vertical-align: top; }

.bx--progress--vertical .bx--progress-step .bx--tooltip {
  margin-top: 0.5rem; }

.bx--progress--vertical .bx--progress-optional {
  position: static;
  width: 100%;
  margin-top: auto;
  margin-left: 2rem; }

.bx--progress--vertical .bx--progress-line {
  position: absolute;
  top: 0;
  left: 0;
  width: 1px;
  height: 100%; }

.bx--breadcrumb {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: inline; }
  @media (min-width: 42rem) {
    .bx--breadcrumb {
      display: flex;
      flex-wrap: wrap; } }
.bx--breadcrumb-item {
  position: relative;
  display: flex;
  align-items: center;
  margin-right: 0.5rem; }

.bx--breadcrumb-item .bx--link:visited {
  color: #0f62fe; }

.bx--breadcrumb-item::after {
  margin-left: 0.5rem;
  color: #161616;
  content: '/'; }

.bx--breadcrumb--no-trailing-slash
.bx--breadcrumb-item:last-child::after {
  content: ''; }

.bx--breadcrumb-item:last-child,
.bx--breadcrumb-item:last-child::after {
  margin-right: 0; }

.bx--breadcrumb .bx--link {
  white-space: nowrap; }

.bx--breadcrumb-item [aria-current='page'],
.bx--breadcrumb-item.bx--breadcrumb-item--current
.bx--link {
  color: #161616;
  cursor: auto; }
  .bx--breadcrumb-item [aria-current='page']:hover,
  .bx--breadcrumb-item.bx--breadcrumb-item--current
.bx--link:hover {
    text-decoration: none; }

.bx--breadcrumb.bx--skeleton .bx--link {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 6.25rem;
  height: 1rem; }
  .bx--breadcrumb.bx--skeleton .bx--link:hover, .bx--breadcrumb.bx--skeleton .bx--link:focus, .bx--breadcrumb.bx--skeleton .bx--link:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--breadcrumb.bx--skeleton .bx--link::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--breadcrumb.bx--skeleton .bx--link::before {
        animation: none; } }
.bx--toolbar {
  display: flex;
  flex-flow: row nowrap;
  align-items: center;
  margin: 1rem 0; }
  .bx--toolbar > div {
    margin: 0 0.25rem; }
  .bx--toolbar .bx--search-input {
    height: 2rem;
    background-color: transparent;
    outline: none; }
  .bx--toolbar .bx--search-close {
    display: none; }
  .bx--toolbar .bx--overflow-menu__icon {
    transition: fill 50ms cubic-bezier(0.2, 0, 0.38, 0.9);
    fill: #525252; }
  .bx--toolbar .bx--search-magnifier {
    top: 0.5rem;
    left: 0.375rem;
    transform: scale(1.15);
    cursor: pointer;
    transition: all 175ms cubic-bezier(0.2, 0, 0.38, 0.9);
    fill: #525252; }
  .bx--toolbar fieldset {
    padding: 0;
    border: 0; }
  .bx--toolbar .bx--toolbar-search--active {
    width: 15.625rem; }
    .bx--toolbar .bx--toolbar-search--active .bx--search-magnifier {
      top: 0.5625rem;
      transform: scale(1); }
    .bx--toolbar .bx--toolbar-search--active .bx--search-input {
      background-color: #f4f4f4; }
    .bx--toolbar .bx--toolbar-search--active .bx--search-close {
      display: block; }
  .bx--toolbar .bx--checkbox-label {
    margin-bottom: 0; }
  .bx--toolbar .bx--overflow-menu--open > .bx--overflow-menu__icon {
    fill: #0f62fe; }

.bx--toolbar-search {
  width: 1.8rem;
  transition: all 175ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--toolbar-search__btn {
  position: absolute;
  top: 0;
  left: 0;
  width: 2rem;
  height: 2rem;
  background: transparent;
  border: 0; }
  .bx--toolbar-search__btn:focus {
    outline: 1px solid #0f62fe; }

.bx--toolbar-filter-icon {
  padding-right: 0;
  padding-left: 0; }

.bx--toolbar-menu__title {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  padding: 0.5rem 1.25rem;
  font-weight: 600; }

.bx--toolbar-menu__option {
  padding: 0.5rem 1.25rem; }

.bx--toolbar-menu__divider {
  width: 100%;
  border: 0;
  border-top: 1px solid #e0e0e0; }

.bx--radio-button-group {
  border: none; }

.bx--toolbar-search:not(.bx--toolbar-search--active)
.bx--search-input {
  border-bottom: none; }

.bx--time-picker {
  display: flex;
  align-items: flex-end; }

.bx--time-picker__select {
  justify-content: center; }
  .bx--time-picker__select:not(:last-of-type) {
    margin: 0 0.125rem; }

.bx--time-picker__input {
  display: flex;
  flex-direction: column; }

.bx--time-picker .bx--select-input {
  width: auto;
  min-width: auto;
  margin: 0;
  padding-right: 3rem;
  line-height: 1; }

.bx--time-picker__input-field {
  outline: 2px solid transparent;
  outline-offset: -2px;
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.32px;
  display: flex;
  align-items: center;
  width: 4.875rem;
  height: 2.5rem;
  transition: outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--time-picker__input-field::placeholder {
    color: #6f6f6f; }

.bx--time-picker--light .bx--select-input {
  background-color: #f4f4f4; }
  .bx--time-picker--light .bx--select-input:hover {
    background-color: #e5e5e5; }
  .bx--time-picker--light .bx--select-input:disabled, .bx--time-picker--light .bx--select-input:hover:disabled {
    color: #c6c6c6;
    background-color: transparent;
    border-bottom: 1px solid transparent;
    cursor: not-allowed; }

.bx--slider-container {
  display: flex;
  align-items: center;
  user-select: none; }

.bx--slider {
  position: relative;
  width: 100%;
  min-width: 12.5rem;
  max-width: 40rem;
  margin: 0 1rem; }

.bx--slider__range-label {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.32px;
  color: #161616;
  white-space: nowrap; }
  .bx--slider__range-label:last-of-type {
    margin-right: 1rem; }

.bx--slider__track {
  position: absolute;
  width: 100%;
  height: 0.125rem;
  background: #e0e0e0;
  transform: translate(0%, -50%);
  cursor: pointer; }

.bx--slider__track:before {
  position: absolute;
  top: -0.3125rem;
  left: 50%;
  display: inline-block;
  width: 0.125rem;
  height: 0.25rem;
  background: #e0e0e0;
  transform: translate(-50%, 0);
  content: ''; }

.bx--slider__filled-track {
  position: absolute;
  width: 100%;
  height: 0.125rem;
  background: #161616;
  transform: translate(0%, -50%);
  transform-origin: left;
  transition: background 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  pointer-events: none; }

.bx--slider__thumb {
  position: absolute;
  top: 0;
  z-index: 3;
  width: 0.875rem;
  height: 0.875rem;
  background: #161616;
  border-radius: 50%;
  outline: none;
  box-shadow: inset 0 0 0 1px transparent, inset 0 0 0 2px transparent;
  transform: translate(-50%, -50%);
  cursor: pointer;
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9), background 110ms cubic-bezier(0.2, 0, 0.38, 0.9), box-shadow 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--slider__thumb:hover {
    transform: translate(-50%, -50%) scale(1.4286); }
  .bx--slider__thumb:focus {
    background-color: #0f62fe;
    box-shadow: inset 0 0 0 2px #0f62fe, inset 0 0 0 3px #ffffff;
    transform: translate(-50%, -50%) scale(1.4286); }
  .bx--slider__thumb:active {
    box-shadow: inset 0 0 0 2px #0f62fe;
    transform: translate(-50%, -50%) scale(1.4286); }

.bx--slider__input {
  display: none; }

.bx--slider-text-input,
.bx-slider-text-input {
  width: 4rem;
  height: 2.5rem;
  text-align: center;
  -moz-appearance: textfield; }
  .bx--slider-text-input::-webkit-outer-spin-button, .bx--slider-text-input::-webkit-inner-spin-button,
  .bx-slider-text-input::-webkit-outer-spin-button,
  .bx-slider-text-input::-webkit-inner-spin-button {
    display: none; }

.bx--slider__thumb:focus ~ .bx--slider__filled-track {
  background-color: #0f62fe; }

.bx--label--disabled
~ .bx--slider-container
> .bx--slider__range-label {
  color: #c6c6c6; }

.bx--slider--disabled .bx--slider__thumb {
  background-color: #e0e0e0; }
  .bx--slider--disabled .bx--slider__thumb:hover {
    transform: translate(-50%, -50%);
    cursor: not-allowed; }
  .bx--slider--disabled .bx--slider__thumb:focus {
    background-color: #e0e0e0;
    outline: none;
    box-shadow: none;
    transform: translate(-50%, -50%); }
  .bx--slider--disabled .bx--slider__thumb:active {
    background: #e0e0e0;
    transform: translate(-50%, -50%); }

.bx--slider--disabled .bx--slider__track,
.bx--slider--disabled .bx--slider__filled-track,
.bx--slider--disabled
.bx--slider__thumb:focus
~ .bx--slider__filled-track {
  background-color: #e0e0e0;
  cursor: not-allowed; }

.bx--slider--disabled
~ .bx--form-item
.bx--slider-text-input,
.bx--slider--disabled ~ .bx--slider-text-input {
  color: #c6c6c6;
  background-color: #ffffff;
  border: none;
  cursor: not-allowed;
  transition: none; }
  .bx--slider--disabled
~ .bx--form-item
.bx--slider-text-input:active, .bx--slider--disabled
~ .bx--form-item
.bx--slider-text-input:focus, .bx--slider--disabled
~ .bx--form-item
.bx--slider-text-input:hover,
  .bx--slider--disabled ~ .bx--slider-text-input:active,
  .bx--slider--disabled ~ .bx--slider-text-input:focus,
  .bx--slider--disabled ~ .bx--slider-text-input:hover {
    color: #c6c6c6;
    outline: none; }

.bx--slider-container.bx--skeleton
.bx--slider__range-label {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 1.25rem;
  height: 0.75rem; }
  .bx--slider-container.bx--skeleton
.bx--slider__range-label:hover, .bx--slider-container.bx--skeleton
.bx--slider__range-label:focus, .bx--slider-container.bx--skeleton
.bx--slider__range-label:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--slider-container.bx--skeleton
.bx--slider__range-label::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--slider-container.bx--skeleton
.bx--slider__range-label::before {
        animation: none; } }
.bx--slider-container.bx--skeleton
.bx--slider__track {
  cursor: default;
  pointer-events: none; }

.bx--slider-container.bx--skeleton
.bx--slider__thumb {
  left: 50%;
  cursor: default;
  pointer-events: none; }

.bx--tile {
  position: relative;
  display: block;
  min-width: 8rem;
  min-height: 4rem;
  padding: 1rem;
  background-color: #ffffff;
  outline: 2px solid transparent;
  outline-offset: -2px; }
  .bx--tile:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.bx--tile--light {
  background-color: #f4f4f4; }

.bx--tile--clickable,
.bx--tile--selectable,
.bx--tile--expandable {
  cursor: pointer;
  transition: 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tile--clickable:hover,
  .bx--tile--selectable:hover,
  .bx--tile--expandable:hover {
    background: #e5e5e5; }

.bx--tile--clickable:focus,
.bx--tile--expandable:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--tile--clickable:hover .bx--tile__checkmark, .bx--tile--clickable:focus .bx--tile__checkmark,
.bx--tile--expandable:hover .bx--tile__checkmark,
.bx--tile--expandable:focus .bx--tile__checkmark {
  opacity: 1; }

.bx--tile--expandable::-moz-focus-inner {
  border: 0; }

.bx--tile--clickable {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  color: #161616;
  text-decoration: none; }

.bx--tile--selectable {
  padding-right: 3rem; }

.bx--tile__checkmark,
.bx--tile__chevron {
  position: absolute;
  background: transparent;
  border: none;
  transition: 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--tile__checkmark {
  top: 1rem;
  right: 1rem;
  height: 1rem;
  opacity: 0; }
  .bx--tile__checkmark svg {
    border-radius: 50%;
    fill: #525252; }
  .bx--tile__checkmark:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.bx--tile__chevron {
  position: absolute;
  right: 0.5rem;
  bottom: 0.5rem;
  height: 1rem; }
  .bx--tile__chevron svg {
    transform-origin: center;
    transition: 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
    fill: #161616; }
  .bx--tile__chevron:hover {
    cursor: pointer; }
  .bx--tile__chevron:focus {
    outline: none; }

.bx--tile--expandable {
  width: 100%;
  overflow: hidden;
  color: inherit;
  font-size: inherit;
  text-align: left;
  border: 0;
  transition: max-height 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--tile-content__above-the-fold {
  display: block; }

.bx--tile-content__below-the-fold {
  display: block;
  visibility: hidden;
  opacity: 0;
  transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9), visibility 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--tile--is-expanded {
  overflow: visible;
  transition: max-height 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .bx--tile--is-expanded .bx--tile__chevron svg {
    transform: rotate(-180deg); }
  .bx--tile--is-expanded .bx--tile-content__below-the-fold {
    visibility: inherit;
    opacity: 1;
    transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9), visibility 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.bx--tile--is-selected {
  outline: 1px solid #161616;
  outline-offset: -1px; }

.bx--tile--is-selected .bx--tile__checkmark {
  opacity: 1; }

.bx--tile-input:checked
+ .bx--tile
> .bx--tile__checkmark
svg {
  fill: #161616; }

.bx--tile-content {
  width: 100%;
  height: 100%; }

.bx--tile-input {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.bx--tile-input:focus + .bx--tile {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--skeleton__text {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%;
  height: 1rem;
  margin-bottom: 0.5rem; }
  .bx--skeleton__text:hover, .bx--skeleton__text:focus, .bx--skeleton__text:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--skeleton__text::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--skeleton__text::before {
        animation: none; } }
.bx--skeleton__heading {
  height: 1.5rem; }

.bx--icon--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  display: inline-block;
  width: 1rem;
  height: 1rem; }
  .bx--icon--skeleton:hover, .bx--icon--skeleton:focus, .bx--icon--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--icon--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--icon--skeleton::before {
        animation: none; } }
.bx--skeleton__placeholder {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 6.25rem;
  height: 6.25rem; }
  .bx--skeleton__placeholder:hover, .bx--skeleton__placeholder:focus, .bx--skeleton__placeholder:active {
    border: none;
    outline: none;
    cursor: default; }
  .bx--skeleton__placeholder::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .bx--skeleton__placeholder::before {
        animation: none; } }
@keyframes rotate {
  0% {
    transform: rotate(0deg); }
  100% {
    transform: rotate(360deg); } }

@keyframes rotate-end-p1 {
  100% {
    transform: rotate(360deg); } }

@keyframes rotate-end-p2 {
  100% {
    transform: rotate(-360deg); } }

/* Stroke animations */
@keyframes init-stroke {
  0% {
    stroke-dashoffset: 240; }
  100% {
    stroke-dashoffset: 40; } }

@keyframes stroke-end {
  0% {
    stroke-dashoffset: 40; }
  100% {
    stroke-dashoffset: 240; } }

@keyframes stroke {
  100% {
    stroke-dashoffset: 0; } }

.bx--inline-loading {
  display: flex;
  align-items: center;
  width: 100%;
  min-height: 2rem; }
  .bx--inline-loading .bx--loading__svg circle {
    stroke-width: 12; }
  .bx--inline-loading .bx--loading__stroke {
    stroke-dashoffset: 99; }

.bx--inline-loading__text {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  color: #525252; }

.bx--inline-loading__animation {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2rem;
  height: 2rem; }

.bx--inline-loading__checkmark-container {
  fill: #24a148; }
  .bx--inline-loading__checkmark-container.bx--inline-loading__svg {
    position: absolute;
    top: 0.75rem;
    width: 0.75rem; }
  .bx--inline-loading__checkmark-container[hidden] {
    display: none; }

.bx--inline-loading__checkmark {
  transform-origin: 50% 50%;
  animation-name: stroke;
  animation-duration: 250ms;
  animation-fill-mode: forwards;
  fill: none;
  stroke: #0f62fe;
  stroke-width: 1.8;
  stroke-dasharray: 12;
  stroke-dashoffset: 12; }

.bx--inline-loading--error {
  width: 1rem;
  height: 1rem;
  fill: #da1e28; }
  .bx--inline-loading--error[hidden] {
    display: none; }

.bx--loading--small .bx--inline-loading__svg {
  stroke: #0f62fe; }

/* If IE11 Don't show check animation */
@media screen and (-ms-high-contrast: active), screen and (-ms-high-contrast: none) {
  .bx--inline-loading__checkmark-container {
    top: 1px;
    right: 0.5rem; }
  .bx--inline-loading__checkmark {
    animation: none;
    stroke-dashoffset: 0;
    stroke-dasharray: 0; } }

.bx--pagination-nav {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  line-height: 0; }

.bx--pagination-nav__list {
  display: flex;
  align-items: center;
  list-style: none; }

.bx--pagination-nav__list-item {
  padding: 0; }
  .bx--pagination-nav__list-item:first-child {
    padding-left: 0; }
  .bx--pagination-nav__list-item:last-child {
    padding-right: 0; }

.bx--pagination-nav__page {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  position: relative;
  display: block;
  min-width: 3rem;
  padding: 1.0625rem 0.25rem;
  color: #525252;
  font-weight: 400;
  line-height: 1;
  text-align: center;
  text-decoration: none;
  border-radius: 0;
  outline: 0;
  transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9), color 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  user-select: none; }
  .bx--pagination-nav__page::-moz-focus-inner {
    border: 0; }
  .bx--pagination-nav__page:hover {
    color: #525252;
    background-color: #e5e5e5; }
  .bx--pagination-nav__page:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .bx--pagination-nav__page:disabled, .bx--pagination-nav__page.bx--pagination-nav__page--disabled {
    color: rgba(82, 82, 82, 0.5);
    background: none;
    outline: none;
    pointer-events: none; }
  .bx--pagination-nav__page:not(.bx--pagination-nav__page--direction)::after {
    position: absolute;
    bottom: 0;
    left: 50%;
    display: block;
    width: 0;
    height: 0.25rem;
    background-color: #0f62fe;
    opacity: 0;
    transition: width 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
    content: ''; }
  .bx--pagination-nav__page--active + .bx--pagination-nav__page::after, .bx--pagination-nav__page.bx--pagination-nav__page--active::after {
    left: calc(50% - 0.5rem);
    width: 1rem;
    opacity: 1; }
  .bx--pagination-nav__page.bx--pagination-nav__page--active {
    color: #525252;
    font-weight: 600;
    background-color: initial; }
  .bx--pagination-nav__page .bx--pagination-nav__icon {
    pointer-events: none;
    fill: currentColor; }

.bx--pagination-nav__page--direction {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 3rem;
  height: 3rem;
  line-height: 0; }

.bx--pagination-nav__select {
  position: relative; }

.bx--pagination-nav__page--select {
  max-height: 3rem;
  text-indent: calc(50% - 4.5px);
  appearance: none; }

@-moz-document url-prefix() {
  .bx--pagination-nav__page--select {
    text-indent: 0; } }

.bx--pagination-nav__select-icon-wrapper {
  position: absolute;
  top: 0;
  width: 100%;
  height: 100%;
  pointer-events: none; }
  .bx--pagination-nav__select-icon-wrapper:not(.bx--pagination-nav__page--direction)::after {
    position: absolute;
    bottom: 0;
    left: 50%;
    display: block;
    width: 0;
    height: 0.25rem;
    background-color: #0f62fe;
    opacity: 0;
    transition: width 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
    content: ''; }
  .bx--pagination-nav__page--active + .bx--pagination-nav__select-icon-wrapper::after, .bx--pagination-nav__select-icon-wrapper.bx--pagination-nav__page--active::after {
    left: calc(50% - 0.5rem);
    width: 1rem;
    opacity: 1; }
  .bx--pagination-nav__page--active + .bx--pagination-nav__select-icon-wrapper .bx--pagination-nav__select-icon {
    display: none; }

.bx--pagination-nav__select-icon {
  position: absolute;
  top: calc(50% - 0.5rem);
  left: calc(50% - 0.5rem);
  pointer-events: none; }

.bx--pagination-nav__accessibility-label {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.bx--unstable-pagination {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  height: 3rem;
  background-color: #ffffff;
  border-top: 1px solid #e0e0e0;
  border-bottom: 1px solid transparent; }

.bx--unstable-pagination__text {
  margin: 0 1rem;
  color: #525252; }
  @media (min-width: 42rem) {
    .bx--unstable-pagination__text {
      display: inline-block; } }
.bx--unstable-pagination__left,
.bx--unstable-pagination__right {
  display: flex;
  align-items: center;
  height: 100%; }

.bx--unstable-pagination__left {
  padding: 0 1rem 0 0; }

.bx--unstable-pagination__left > .bx--form-item,
.bx--unstable-pagination__right > .bx--form-item {
  height: 100%; }

.bx--unstable-pagination__left
.bx--unstable-pagination__text {
  margin-right: 0.0625rem; }

.bx--unstable-pagination__right
.bx--unstable-pagination__text {
  margin-right: 1rem;
  margin-left: 0.0625rem; }

.bx--unstable-pagination__button {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
  margin: 0;
  padding: 0 0.875rem;
  color: #161616;
  background: none;
  border: none;
  border-left: 1px solid #e0e0e0;
  cursor: pointer;
  transition: outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }

.bx--unstable-pagination__button .bx--btn__icon {
  width: initial;
  height: initial; }

.bx--unstable-pagination__button.bx--btn--icon-only.bx--tooltip__trigger:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--unstable-pagination__button:hover {
  color: #161616;
  background: #e5e5e5; }

.bx--unstable-pagination__button--no-index {
  cursor: not-allowed;
  fill: #c6c6c6; }

.bx--unstable-pagination__button.bx--btn:disabled {
  background: transparent;
  border-color: #e0e0e0; }

.bx--unstable-pagination__button:disabled:hover,
.bx--unstable-pagination__button--no-index:hover {
  background: transparent;
  cursor: not-allowed;
  fill: #c6c6c6; }

.bx--unstable-pagination__page-selector,
.bx--unstable-pagination__page-sizer {
  align-items: center;
  height: 100%; }

.bx--unstable-pagination__page-selector
.bx--select-input--inline__wrapper,
.bx--unstable-pagination__page-sizer
.bx--select-input--inline__wrapper {
  display: flex;
  height: 100%; }

.bx--unstable-pagination__page-selector .bx--select-input,
.bx--unstable-pagination__page-sizer .bx--select-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  width: auto;
  min-width: auto;
  height: 100%;
  margin-right: -0.65rem;
  padding: 0 2.5rem 0 1rem; }
  @media (min-width: 42rem) {
    .bx--unstable-pagination__page-selector .bx--select-input,
    .bx--unstable-pagination__page-sizer .bx--select-input {
      margin-right: 0;
      padding-right: 2.25rem; } }
.bx--unstable-pagination__page-selector
.bx--select-input:hover,
.bx--unstable-pagination__page-sizer .bx--select-input:hover {
  background: #e5e5e5; }

.bx--unstable-pagination__page-selector .bx--select__arrow,
.bx--unstable-pagination__page-sizer .bx--select__arrow {
  top: 50%;
  transform: translateY(-50%); }
  @media (min-width: 42rem) {
    .bx--unstable-pagination__page-selector .bx--select__arrow,
    .bx--unstable-pagination__page-sizer .bx--select__arrow {
      right: 1rem; } }
.bx--unstable-pagination__page-selector {
  border-left: 1px solid #e0e0e0; }

.bx--unstable-pagination__page-sizer {
  border-right: 1px solid #e0e0e0; }

.bx--header {
  position: fixed;
  top: 0;
  right: 0;
  left: 0;
  z-index: 8000;
  display: flex;
  align-items: center;
  height: 3rem;
  background-color: #161616;
  border-bottom: 1px solid #393939; }

.bx--header__action {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  width: 3rem;
  height: 3rem;
  border: 0.125rem solid transparent;
  transition: background-color 110ms, border-color 110ms; }
  .bx--header__action::-moz-focus-inner {
    border: 0; }

.bx--header__action
> svg.bx--navigation-menu-panel-collapse-icon,
.bx--header__action--active
> svg.bx--navigation-menu-panel-expand-icon {
  display: none; }

.bx--header__action--active
> svg.bx--navigation-menu-panel-collapse-icon {
  display: inline; }

.bx--header__action:hover {
  background-color: #353535; }

.bx--header__action--active {
  border-right: 1px solid #393939;
  border-bottom: 1px solid #161616;
  border-left: 1px solid #393939; }

.bx--header__action:focus {
  border-color: #ffffff;
  outline: none; }

.bx--header__action:active {
  background-color: #393939; }

.bx--header__action > svg {
  fill: #ffffff; }

.bx--header__menu-trigger > svg {
  fill: #f4f4f4; }

.bx--header__menu-trigger:hover {
  fill: #2c2c2c; }

.bx--header__menu-toggle {
  display: block; }

@media (min-width: 66rem) {
  .bx--header__menu-toggle__hidden {
    display: none; } }

a.bx--header__name {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  align-items: center;
  height: 100%;
  padding: 0 2rem 0 1rem;
  font-weight: 600;
  line-height: 1.25rem;
  letter-spacing: 0.1px;
  text-decoration: none;
  border: 0.125rem solid transparent;
  outline: none;
  transition: border-color 110ms;
  user-select: none; }

a.bx--header__name:focus {
  border-color: #ffffff; }

.bx--header__name--prefix {
  font-weight: 400; }

a.bx--header__name,
a.bx--header__name:hover {
  color: #f4f4f4; }

.bx--header__nav {
  position: relative;
  display: none;
  height: 100%;
  padding-left: 1rem; }
  @media (min-width: 66rem) {
    .bx--header__nav {
      display: block; } }
  .bx--header__nav::before {
    position: absolute;
    top: 50%;
    left: 0;
    display: block;
    width: 0.0625rem;
    height: 1.5rem;
    background-color: #393939;
    transform: translateY(-50%);
    content: ''; }

.bx--header__menu-bar {
  display: flex;
  height: 100%;
  margin: 0;
  padding: 0;
  list-style: none; }

a.bx--header__menu-item {
  position: relative;
  display: flex;
  align-items: center;
  height: 100%;
  padding: 0 1rem;
  color: #c6c6c6;
  font-weight: 400;
  font-size: 0.875rem;
  line-height: 1.125rem;
  letter-spacing: 0;
  text-decoration: none;
  border: 2px solid transparent;
  transition: background-color 110ms, border-color 110ms, color 110ms;
  user-select: none; }

a.bx--header__menu-item:hover {
  color: #f4f4f4;
  background-color: #2c2c2c; }

.bx--header__action:active,
a.bx--header__menu-item:active {
  color: #f4f4f4;
  background-color: #393939; }

a.bx--header__menu-item:focus {
  color: #f4f4f4;
  border-color: #ffffff;
  outline: none; }

a.bx--header__menu-item:hover > svg,
a.bx--header__menu-item:active > svg,
a.bx--header__menu-item:focus > svg {
  fill: #f4f4f4; }

a.bx--header__menu-item[aria-current='page']::after,
.bx--header__menu-item--current::after {
  position: absolute;
  top: 0;
  right: 0;
  bottom: -2px;
  left: 0;
  width: 100%;
  border-bottom: 3px solid #4589ff;
  content: ''; }

a.bx--header__menu-item[aria-current='page']:focus::after,
.bx--header__menu-item--current:focus::after {
  border: 0; }

a.bx--header__menu-item[aria-current='page']:focus,
a.bx--header__menu-item.bx--header__menu-item--current:focus {
  border: 2px solid #ffffff; }

.bx--header__submenu {
  position: relative; }

.bx--header__menu-title[aria-haspopup='true'] {
  position: relative; }

.bx--header__menu-title[aria-expanded='true'] {
  z-index: 8001;
  color: #ffffff;
  background-color: #262626; }

.bx--header__menu-title[aria-expanded='true']
> .bx--header__menu-arrow {
  transform: rotate(180deg); }

.bx--header__menu {
  display: none;
  margin: 0;
  padding: 0;
  list-style: none; }

.bx--header__menu-title[aria-expanded='true']
+ .bx--header__menu {
  position: absolute;
  bottom: 0;
  left: 0;
  z-index: 8000;
  display: flex;
  flex-direction: column;
  width: 12.5rem;
  background-color: #262626;
  box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.5);
  transform: translateY(100%); }

.bx--header__menu-title[aria-expanded='true']
+ .bx--header__menu
.bx--header__menu-item:hover {
  background-color: #353535; }

.bx--header__menu-title[aria-expanded='true']
+ .bx--header__menu
.bx--header__menu-item:active {
  background-color: #393939; }

.bx--header__menu .bx--header__menu-item {
  height: 3rem; }

.bx--header__menu .bx--header__menu-item:hover {
  color: #f4f4f4;
  background-color: #262626; }

.bx--header__menu-arrow {
  margin-left: 0.5rem;
  transition: transform 110ms, fill 110ms;
  fill: #c6c6c6; }

.bx--header__global {
  display: flex;
  flex: 1 1 0%;
  justify-content: flex-end;
  height: 100%; }

.bx--skip-to-content {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.bx--skip-to-content:focus {
  top: 0;
  left: 0;
  z-index: 9999;
  display: flex;
  align-items: center;
  width: auto;
  height: 3rem;
  padding: 0 1rem;
  color: #f4f4f4;
  background-color: #161616;
  border: 4px solid #0f62fe;
  outline: none;
  clip: auto; }

.bx--header-panel {
  transition-timing-function: cubic-bezier(0.2, 0, 1, 0.9);
  position: fixed;
  top: 3rem;
  right: 0;
  bottom: 0;
  z-index: 8000;
  width: 0;
  overflow: hidden;
  color: #c6c6c6;
  background-color: #161616;
  border: none;
  transition: width 0.11s;
  will-change: width; }

.bx--header-panel--expanded {
  width: 16rem;
  border-right: 1px solid #393939;
  border-left: 1px solid #393939; }

.bx--panel--overlay {
  position: fixed;
  top: 3rem;
  right: 0;
  bottom: 0;
  z-index: 1000;
  width: 16rem;
  height: 100%;
  padding: 1rem 0;
  overflow-x: hidden;
  overflow-y: auto;
  background-color: #161616;
  transform: translate3d(100%, 0, 0);
  transition: transform 0.11s cubic-bezier(0.2, 0, 0.38, 0.9);
  will-change: transform; }

.bx--panel--expanded {
  box-shadow: 0 8px 16px 0 rgba(0, 0, 0, 0.25);
  transform: translate3d(0, 0, 0); }

.bx--product-switcher__search {
  margin-bottom: 1.5rem;
  padding: 0 1rem; }

.bx--search--shell input {
  background-color: #e0e0e0; }

.bx--product-switcher__subheader,
.bx--product-switcher__all-btn {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  padding: 0.5rem;
  color: #c6c6c6; }

.bx--product-switcher__subheader {
  padding-left: 3.5rem; }

.bx--product-switcher__all-btn {
  padding-left: 3.5rem; }

.bx--product-switcher__all-btn,
.bx--product-switcher__back-btn {
  display: inline-block;
  width: 100%;
  color: #0f62fe;
  text-align: left;
  background: transparent;
  border: none;
  cursor: pointer; }

.bx--product-switcher__all-btn:hover,
.bx--product-switcher__back-btn:hover {
  text-decoration: underline; }

.bx--product-switcher__all-btn:focus,
.bx--product-switcher__back-btn:focus {
  outline: none;
  box-shadow: inset 0 0 0 3px #0f62fe; }

.bx--product-switcher__back-btn {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  align-items: center;
  padding: 0.5rem 1rem; }

.bx--product-switcher__back-arrow {
  margin-right: 1rem;
  fill: #0f62fe; }

.bx--product-list__item {
  display: flex;
  align-items: center;
  justify-content: space-between;
  cursor: pointer; }

.bx--product-list__item:hover {
  background: #e0e0e0; }

.bx--product-link {
  display: flex;
  flex-direction: row;
  align-items: center;
  width: 100%;
  padding: 0.5rem 1rem;
  text-decoration: none; }

.bx--product-link:focus {
  outline: none;
  box-shadow: inset 0 0 0 3px #0f62fe; }

.bx--product-switcher__icon {
  margin-right: 1rem; }

.bx--product-link__name {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  margin-left: 0.25rem;
  color: #c6c6c6;
  font-weight: 400; }

.bx--product-switcher__product-list .bx--overflow-menu {
  display: none;
  align-items: center;
  justify-content: center;
  width: 2.5rem; }
  .bx--product-switcher__product-list .bx--overflow-menu.bx--overflow-menu--open {
    display: flex; }

.bx--product-switcher__product-list .bx--overflow-menu > svg {
  fill: #c6c6c6; }

.bx--product-switcher__product-list .bx--overflow-menu:hover {
  background: #c6c6c6; }

.bx--product-switcher__product-list
.bx--overflow-menu:hover
> svg {
  fill: #c6c6c6; }

.bx--product-switcher__product-list .bx--overflow-menu:focus {
  display: flex;
  outline: none;
  box-shadow: inset 0 0 0 3px #0f62fe; }

.bx--product-switcher__product-list
.bx--overflow-menu-options__option:hover {
  background: #ffffff; }

.bx--product-list__item:hover .bx--overflow-menu {
  display: flex; }

.bx--switcher {
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  color: #c6c6c6; }

.bx--switcher__item {
  width: 100%;
  height: 2rem; }

.bx--switcher__item:nth-child(1) {
  margin-top: 1rem; }

.bx--switcher__item--divider {
  display: block;
  width: 14rem;
  height: 1px;
  margin: 0.5rem 1rem;
  background: #393939;
  border: none; }

.bx--switcher__item-link {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: block;
  height: 2rem;
  padding: 0.375rem 1rem;
  color: #c6c6c6;
  text-decoration: none; }
  .bx--switcher__item-link:hover:not(.bx--switcher__item-link--selected) {
    color: #f4f4f4;
    background: #2c2c2c;
    cursor: pointer; }
  .bx--switcher__item-link:focus {
    outline: 2px solid #ffffff;
    outline-offset: -2px; }
  .bx--switcher__item-link:active {
    color: #f4f4f4;
    background: #393939; }

.bx--switcher__item-link--selected {
  color: #f4f4f4;
  background: #262626; }

.bx--side-nav {
  position: fixed;
  top: 0;
  bottom: 0;
  left: 0;
  z-index: 8000;
  width: 3rem;
  max-width: 16rem;
  overflow: hidden;
  color: #525252;
  background-color: #ffffff;
  transition: width 0.11s cubic-bezier(0.2, 0, 1, 0.9);
  will-change: width; }

.bx--side-nav--ux {
  top: 3rem;
  width: 16rem; }
  @media (max-width: 65.98rem) {
    .bx--side-nav--ux {
      width: 0; } }
.bx--side-nav--rail {
  width: 3rem; }

.bx--side-nav--hidden {
  width: 0; }

.bx--side-nav.bx--side-nav--rail:not(.bx--side-nav--fixed):hover,
.bx--side-nav--expanded {
  width: 16rem; }

.bx--side-nav__overlay {
  position: absolute;
  top: 3rem;
  width: 0;
  height: 0;
  background-color: transparent;
  opacity: 0;
  transition: opacity 240ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 240ms cubic-bezier(0.2, 0, 0.38, 0.9); }

@media (max-width: 65.98rem) {
  .bx--side-nav__overlay-active {
    width: 100%;
    height: 100vh;
    background-color: rgba(22, 22, 22, 0.5);
    opacity: 1;
    transition: opacity 240ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 240ms cubic-bezier(0.2, 0, 0.38, 0.9); } }

.bx--header ~ .bx--side-nav {
  top: 3rem;
  height: calc(100% - 48px); }

.bx--side-nav--fixed {
  width: 16rem; }

.bx--side-nav--collapsed {
  width: 16rem;
  transform: translateX(-16rem); }

.bx--side-nav__navigation {
  display: flex;
  flex-direction: column;
  height: 100%; }

.bx--side-nav__header {
  display: flex;
  width: 100%;
  max-width: 100%;
  height: 3rem;
  border-bottom: 1px solid #393939; }
  .bx--side-nav:hover .bx--side-nav__header, .bx--side-nav--fixed .bx--side-nav__header, .bx--side-nav--expanded .bx--side-nav__header {
    height: auto; }

.bx--side-nav--ux .bx--side-nav__header {
  height: auto; }

.bx--side-nav__details {
  display: flex;
  flex: 1;
  flex-direction: column;
  min-width: 0;
  padding-right: 1rem;
  opacity: 0;
  visibility: hidden; }
  .bx--side-nav:hover .bx--side-nav__details, .bx--side-nav--fixed .bx--side-nav__details, .bx--side-nav--expanded .bx--side-nav__details {
    visibility: inherit;
    opacity: 1; }

.bx--side-nav--ux .bx--side-nav__details {
  visibility: inherit;
  opacity: 1; }

.bx--side-nav__title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  margin-top: 1rem;
  font-weight: 600;
  font-size: 0.875rem;
  letter-spacing: 0.1px;
  user-select: none; }

.bx--side-nav__title,
.bx--side-nav__select {
  padding-left: 0.5rem; }

.bx--side-nav__switcher {
  position: relative;
  display: flex;
  align-items: center;
  justify-content: space-between; }

.bx--side-nav__switcher-chevron {
  position: absolute;
  top: 0;
  right: 0.5rem;
  bottom: 0;
  display: flex;
  align-items: center;
  fill: #525252; }

.bx--side-nav__select {
  outline: 2px solid transparent;
  outline-offset: -2px;
  flex: 1 1 0%;
  min-width: 0;
  height: 2rem;
  padding-right: 2rem;
  color: #f4f4f4;
  font-size: 0.75rem;
  background-color: #161616;
  border: none;
  border-radius: 0;
  cursor: pointer;
  transition: outline 110ms;
  appearance: none; }

.bx--side-nav__select:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--side-nav__footer {
  flex: 0 0 3rem;
  width: 100%;
  background-color: #ffffff; }

.bx--side-nav__toggle {
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  height: 100%;
  padding-left: 1rem;
  text-align: left;
  transition: outline 110ms; }
  .bx--side-nav__toggle::-moz-focus-inner {
    border: 0; }

.bx--side-nav__toggle:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--side-nav__items {
  flex: 1 1 0%;
  padding: 1rem 0 0;
  overflow: hidden; }
  .bx--side-nav:hover .bx--side-nav__items, .bx--side-nav--fixed .bx--side-nav__items, .bx--side-nav--expanded .bx--side-nav__items {
    overflow-y: auto; }

.bx--side-nav--ux .bx--side-nav__items {
  overflow-y: auto; }

.bx--side-nav__item {
  width: 3rem;
  height: 3rem;
  overflow: hidden; }
  .bx--side-nav:hover .bx--side-nav__item, .bx--side-nav--fixed .bx--side-nav__item, .bx--side-nav--expanded .bx--side-nav__item {
    width: auto;
    height: auto; }

.bx--side-nav--ux .bx--side-nav__item {
  width: auto;
  height: auto; }

.bx--side-nav__item:not(.bx--side-nav__item--active):hover
.bx--side-nav__item:not(.bx--side-nav__item--active)
> .bx--side-nav__submenu:hover,
.bx--side-nav__item:not(.bx--side-nav__item--active)
> .bx--side-nav__link:hover,
.bx--side-nav__menu
a.bx--side-nav__link:not(.bx--side-nav__link--current):not([aria-current='page']):hover,
.bx--side-nav a.bx--header__menu-item:hover,
.bx--side-nav
.bx--header__menu-title[aria-expanded='true']:hover {
  color: #161616;
  background-color: #e5e5e5; }

.bx--side-nav__item:not(.bx--side-nav__item--active)
> .bx--side-nav__link:hover
> span,
.bx--side-nav__item:not(.bx--side-nav__item--active)
.bx--side-nav__menu-item
> .bx--side-nav__link:hover
> span {
  color: #161616; }

.bx--side-nav__item--large {
  height: 3rem; }

.bx--side-nav__submenu {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: flex;
  align-items: center;
  height: 2rem;
  padding: 0 1rem;
  color: #525252;
  transition: color 110ms, background-color 110ms, outline 110ms;
  user-select: none; }
  .bx--side-nav__submenu::-moz-focus-inner {
    border: 0; }

.bx--side-nav__submenu:hover {
  color: #161616;
  background-color: #e5e5e5; }

.bx--side-nav__submenu:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.bx--side-nav__submenu-title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  text-align: left; }

.bx--side-nav__icon.bx--side-nav__submenu-chevron {
  display: flex;
  flex: 1;
  justify-content: flex-end; }

.bx--side-nav__submenu-chevron > svg {
  width: 1rem;
  height: 1rem;
  transition: transform 110ms; }

.bx--side-nav__submenu[aria-expanded='true']
.bx--side-nav__submenu-chevron
> svg {
  transform: rotate(180deg); }

.bx--side-nav__item--large .bx--side-nav__submenu {
  height: 3rem; }

.bx--side-nav__item--active .bx--side-nav__submenu:hover {
  color: #161616;
  background-color: #e5e5e5; }

.bx--side-nav__item--active
.bx--side-nav__submenu[aria-expanded='false'] {
  position: relative;
  color: #161616;
  background-color: #e5e5e5; }
  .bx--side-nav__item--active
.bx--side-nav__submenu[aria-expanded='false']::before {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    width: 4px;
    background-color: #0f62fe;
    content: ''; }

.bx--side-nav__item--active .bx--side-nav__submenu-title {
  color: #161616;
  font-weight: 600; }

.bx--side-nav__menu {
  display: block;
  max-height: 0;
  visibility: hidden; }

.bx--side-nav__submenu[aria-expanded='true']
+ .bx--side-nav__menu {
  max-height: 93.75rem;
  visibility: inherit; }

.bx--side-nav__menu a.bx--side-nav__link {
  height: 2rem;
  min-height: 2rem;
  padding-left: 2rem;
  font-weight: 400; }

.bx--side-nav__item.bx--side-nav__item--icon
a.bx--side-nav__link {
  padding-left: 4.5rem; }

.bx--side-nav__menu a.bx--side-nav__link--current,
.bx--side-nav__menu a.bx--side-nav__link[aria-current='page'],
a.bx--side-nav__link--current {
  background-color: #e0e0e0; }
  .bx--side-nav__menu a.bx--side-nav__link--current > span,
  .bx--side-nav__menu a.bx--side-nav__link[aria-current='page'] > span,
  a.bx--side-nav__link--current > span {
    color: #161616;
    font-weight: 600; }

a.bx--side-nav__link,
.bx--side-nav a.bx--header__menu-item,
.bx--side-nav
.bx--header__menu-title[aria-expanded='true']
+ .bx--header__menu {
  outline: 2px solid transparent;
  outline-offset: -2px;
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  position: relative;
  display: flex;
  align-items: center;
  min-height: 2rem;
  padding: 0 1rem;
  text-decoration: none;
  transition: color 110ms, background-color 110ms, outline 110ms; }

.bx--side-nav__item--large a.bx--side-nav__link {
  height: 3rem; }

a.bx--side-nav__link > .bx--side-nav__link-text,
.bx--side-nav
a.bx--header__menu-item
.bx--text-truncate-end {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  color: #525252;
  font-size: 0.875rem;
  line-height: 1.25rem;
  letter-spacing: 0.1px;
  user-select: none; }

a.bx--side-nav__link:focus,
.bx--side-nav a.bx--header__menu-item:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

a.bx--side-nav__link[aria-current='page'],
a.bx--side-nav__link--current {
  font-weight: 600;
  background-color: #e5e5e5; }

a.bx--side-nav__link[aria-current='page']
.bx--side-nav__link-text,
a.bx--side-nav__link--current .bx--side-nav__link-text {
  color: #161616; }

a.bx--side-nav__link[aria-current='page']::before,
a.bx--side-nav__link--current::before {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 4px;
  background-color: #0f62fe;
  content: ''; }

.bx--side-nav__icon {
  display: flex;
  flex: 0 0 1rem;
  align-items: center;
  justify-content: center; }

.bx--side-nav__icon:not(.bx--side-nav__submenu-chevron) {
  margin-right: 1.5rem; }

.bx--side-nav__icon > svg {
  width: 1rem;
  height: 1rem;
  fill: #525252; }

.bx--side-nav__icon > svg.bx--side-nav-collapse-icon {
  display: none; }

.bx--side-nav--expanded
.bx--side-nav__icon
> svg.bx--side-nav-expand-icon {
  display: none; }

.bx--side-nav--expanded
.bx--side-nav__icon
> svg.bx--side-nav-collapse-icon {
  display: block; }

.bx--side-nav--fixed a.bx--side-nav__link,
.bx--side-nav--fixed .bx--side-nav__submenu {
  padding-left: 1rem; }

.bx--side-nav--fixed
.bx--side-nav__item:not(.bx--side-nav__item--icon)
.bx--side-nav__menu
a.bx--side-nav__link {
  padding-left: 2rem; }

@media (max-width: 65.98rem) {
  .bx--side-nav .bx--header__nav {
    display: block; } }

.bx--side-nav__header-navigation {
  display: none; }
  @media (max-width: 65.98rem) {
    .bx--side-nav__header-navigation {
      position: relative;
      display: block;
      margin-bottom: 2rem; } }
.bx--side-nav__header-divider::after {
  position: absolute;
  bottom: -1rem;
  left: 1rem;
  width: calc(100% - 32px);
  height: 0.0625rem;
  background: #e0e0e0;
  content: ''; }

.bx--side-nav a.bx--header__menu-item {
  justify-content: space-between;
  color: #525252;
  white-space: nowrap; }
  .bx--side-nav a.bx--header__menu-item[aria-expanded='true'] {
    background-color: transparent; }

.bx--side-nav
.bx--header__menu-title[aria-expanded='true']
+ .bx--header__menu {
  bottom: inherit;
  width: 100%;
  padding: 0;
  background-color: transparent;
  box-shadow: none;
  transform: none; }
  .bx--side-nav
.bx--header__menu-title[aria-expanded='true']
+ .bx--header__menu li {
    width: 100%; }
  .bx--side-nav
.bx--header__menu-title[aria-expanded='true']
+ .bx--header__menu a.bx--header__menu-item {
    padding-left: 4.25rem;
    font-weight: 400; }
  .bx--side-nav
.bx--header__menu-title[aria-expanded='true']
+ .bx--header__menu a.bx--header__menu-item:hover {
    color: #161616;
    background-color: #e5e5e5; }

.bx--side-nav
.bx--header__menu
a.bx--header__menu-item {
  height: inherit; }

.bx--side-nav
a.bx--header__menu-item:hover
.bx--header__menu-arrow,
.bx--side-nav
a.bx--header__menu-item:focus
.bx--header__menu-arrow,
.bx--side-nav .bx--header__menu-arrow {
  fill: #525252; }

.bx--navigation {
  position: fixed;
  top: 3rem;
  bottom: 0;
  left: 0;
  z-index: 6000;
  width: 16rem;
  color: #f4f4f4;
  background-color: #262626;
  box-shadow: 0 0.5rem 1rem 0 rgba(0, 0, 0, 0.25); }

.bx--navigation--right {
  right: 0;
  left: auto; }

.bx--navigation svg {
  fill: #f4f4f4; }

.bx--navigation-section:not(:last-child)::after {
  display: block;
  height: 1px;
  margin: 0 1rem;
  background-color: #393939;
  content: ''; }

.bx--navigation-item {
  position: relative;
  display: flex;
  align-items: center; }

.bx--navigation-item--active > a.bx--navigation-link {
  color: #ffffff;
  font-weight: 600; }

.bx--navigation-item--active::after {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  display: block;
  width: 4px;
  background-color: #0f62fe;
  content: ''; }

a.bx--navigation-link {
  display: flex;
  align-items: center;
  width: 100%;
  min-height: 2.5rem;
  padding-left: 1rem;
  color: #f4f4f4;
  font-weight: 400;
  font-size: 0.875rem;
  text-decoration: none; }

a.bx--navigation-link:hover {
  color: #ffffff;
  background-color: #333333; }

a.bx--navigation-link:focus {
  outline: 0.1875rem solid #0f62fe;
  outline-offset: -0.1875rem; }

.bx--navigation-item--icon > a.bx--navigation-link {
  padding-left: 0; }

.bx--navigation__category {
  width: 100%; }

.bx--navigation__category-toggle {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: flex;
  align-items: center; }
  .bx--navigation__category-toggle::-moz-focus-inner {
    border: 0; }

.bx--navigation__category-toggle:hover {
  background-color: #333333; }

.bx--navigation__category-toggle:focus {
  outline: 0.1875rem solid #0f62fe;
  outline-offset: -0.1875rem; }

.bx--navigation__category-title {
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  min-height: 2.5rem;
  padding-right: 1rem;
  padding-left: 1rem;
  color: #f4f4f4;
  font-weight: 400;
  font-size: 0.875rem; }

.bx--navigation-item--icon .bx--navigation__category-title {
  padding-left: 0; }

.bx--navigation__category-items {
  display: none;
  visibility: hidden; }

.bx--navigation__category-item > a.bx--navigation-link {
  display: flex;
  align-items: center;
  min-height: 2rem;
  padding-left: 2rem; }

.bx--navigation__category-item {
  position: relative; }

.bx--navigation-item--icon
.bx--navigation__category-item
> a.bx--navigation-link {
  padding-left: 3.5rem; }

.bx--navigation__category-item--active::after {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  display: block;
  width: 4px;
  background-color: #0f62fe;
  content: ''; }

.bx--navigation__category-item--active
> a.bx--navigation-link {
  color: #ffffff;
  font-weight: 600; }

.bx--navigation__category--expanded
.bx--navigation__category-title {
  font-weight: 600; }

.bx--navigation__category--expanded
.bx--navigation__category-title
> svg {
  transform: rotate(180deg); }

.bx--navigation__category--expanded
.bx--navigation__category-items {
  display: block;
  visibility: inherit; }

.bx--navigation-icon {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 3rem;
  min-width: 3rem;
  height: 2.5rem;
  margin-right: 0.5rem; }

.bx--content {
  padding: 2rem;
  background: #f4f4f4;
  transform: translate3d(0, 0, 0);
  will-change: margin-left; }

.bx--header ~ .bx--content {
  margin-top: 3rem; }

.bx--side-nav ~ .bx--content {
  margin-left: 3rem; }

.bx--side-nav.bx--side-nav--expanded ~ .bx--content {
  margin-left: 16rem; }

.choices {
  position: relative;
  margin-bottom: 24px; }

.choices:focus {
  outline: none; }

.choices:last-child {
  margin-bottom: 0; }

.choices.is-disabled .choices__inner,
.choices.is-disabled .choices__input {
  cursor: not-allowed;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.choices.is-disabled .choices__item {
  cursor: not-allowed; }

.choices [hidden] {
  display: none !important; }

.choices[data-type*='select-one'] {
  cursor: pointer; }

.choices[data-type*='select-one'] .choices__inner {
  padding-bottom: 7.5px; }

.choices[data-type*='select-one'] .choices__input {
  display: block;
  width: 100%;
  padding: 10px;
  border-bottom: 1px solid #dddddd;
  background-color: #ffffff;
  margin: 0; }

.choices[data-type*='select-one'] .choices__button {
  stroke: currentColor;
  fill: currentColor;
  background-image: url(data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMjEiIGhlaWdodD0iMjEiIHZpZXdCb3g9IjAgMCAyMSAyMSIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48ZyBmaWxsPSIjMDAwIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPjxwYXRoIGQ9Ik0yLjU5Mi4wNDRsMTguMzY0IDE4LjM2NC0yLjU0OCAyLjU0OEwuMDQ0IDIuNTkyeiIvPjxwYXRoIGQ9Ik0wIDE4LjM2NEwxOC4zNjQgMGwyLjU0OCAyLjU0OEwyLjU0OCAyMC45MTJ6Ii8+PC9nPjwvc3ZnPg==);
  padding: 0;
  background-size: 8px;
  position: absolute;
  top: 50%;
  right: 0;
  margin-top: -10px;
  margin-right: 25px;
  height: 20px;
  width: 20px;
  border-radius: 10em;
  opacity: 0.5; }

.choices[data-type*='select-one'] .choices__button:hover, .choices[data-type*='select-one'] .choices__button:focus {
  opacity: 1; }

.choices[data-type*='select-one'] .choices__button:focus {
  box-shadow: 0px 0px 0px 2px #00bcd4; }

.choices[data-type*='select-one'] .choices__item[data-value=''] .choices__button {
  display: none; }

.choices[data-type*='select-one']:after {
  content: '';
  height: 0;
  width: 0;
  border-style: solid;
  border-color: #333333 transparent transparent transparent;
  border-width: 5px;
  position: absolute;
  right: 11.5px;
  top: 50%;
  margin-top: -2.5px;
  pointer-events: none; }

.choices[data-type*='select-one'].is-open:after {
  border-color: transparent transparent #333333 transparent;
  margin-top: -7.5px; }

.choices[data-type*='select-multiple'] .choices__inner,
.choices[data-type*='text'] .choices__inner {
  cursor: text; }

.choices[data-type*='select-multiple'] .choices__button,
.choices[data-type*='text'] .choices__button {
  position: relative;
  display: inline-block;
  margin-top: 0;
  margin-right: -4px;
  margin-bottom: 0;
  margin-left: 8px;
  padding-left: 16px;
  border-left: 1px solid #161616;
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 32 32' preserveAspectRatio='xMidYMid meet' focusable='false' style=' will-change: transform;' width='20' height='20'%3E%3Cpolygon points='24 9.4 22.6 8 16 14.6 9.4 8 8 9.4 14.6 16 8 22.6 9.4 24 16 17.4 22.6 24 24 22.6 17.4 16 24 9.4'%3E%3C/polygon%3E%3C/svg%3E");
  background-size: 16px;
  width: 8px;
  line-height: 1;
  opacity: 0.75;
  border-radius: 0; }

.choices[data-type*='select-multiple'] .choices__button:hover, .choices[data-type*='select-multiple'] .choices__button:focus,
.choices[data-type*='text'] .choices__button:hover,
.choices[data-type*='text'] .choices__button:focus {
  opacity: 1; }

.choices__inner {
  display: inline-block;
  vertical-align: top;
  width: 100%;
  /* background-color: #f9f9f9;*/
  padding: 7.5px 7.5px 3.75px;
  min-height: 44px;
  overflow: hidden; }

.is-focused .choices__inner,
.is-open .choices__inner {
  border-color: #b7b7b7; }

.is-open .choices__inner {
  border-radius: 2.5px 2.5px 0 0; }

.is-flipped.is-open .choices__inner {
  border-radius: 0 0 2.5px 2.5px; }

.choices__list {
  margin: 0;
  padding-left: 0;
  list-style: none; }

.choices__list--single {
  display: inline-block;
  padding: 4px 16px 4px 4px;
  width: 100%; }

.choices__list--single .choices__item {
  width: 100%; }

.choices__list--multiple {
  display: block; }

.choices__list--multiple .choices__item.is-highlighted {
  /*background-color: #00a5bb;
  border: 1px solid #008fa1;*/ }

.is-disabled .choices__list--multiple .choices__item {
  background-color: #aaaaaa;
  border: 1px solid #919191; }

.choices__list--dropdown {
  visibility: hidden;
  z-index: 1;
  position: absolute;
  width: 100%;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  top: 100%;
  margin-top: -1px;
  border-bottom-left-radius: 2.5px;
  border-bottom-right-radius: 2.5px;
  overflow: hidden;
  word-break: break-all;
  will-change: visibility; }

.choices__list--dropdown.is-active {
  visibility: visible; }

.is-open .choices__list--dropdown {
  border-color: #b7b7b7; }

.is-flipped .choices__list--dropdown {
  top: auto;
  bottom: 100%;
  margin-top: 0;
  margin-bottom: -1px;
  border-radius: 0.25rem 0.25rem 0 0; }

.choices__list--dropdown .choices__list {
  position: relative;
  max-height: 300px;
  overflow: auto;
  -webkit-overflow-scrolling: touch;
  will-change: scroll-position; }

@media (min-width: 640px) {
  .choices__list--dropdown .choices__item--selectable:after {
    content: attr(data-select-text);
    opacity: 0;
    position: absolute;
    right: 10px;
    top: 50%;
    transform: translateY(-50%); } }

.choices__list--dropdown .choices__item--selectable.is-highlighted {
  background-color: #f2f2f2; }

.choices__list--dropdown .choices__item--selectable.is-highlighted:after {
  opacity: 0.5; }

.choices__item {
  cursor: default; }

.choices__item--selectable {
  cursor: pointer; }

.choices__item--choice.choices__item--selectable {
  display: block; }

.choices__item--disabled {
  cursor: not-allowed;
  -webkit-user-select: none;
  -ms-user-select: none;
  user-select: none;
  opacity: 0.5; }

.choices__heading {
  font-weight: 600;
  padding: 10px;
  border-bottom: 1px solid #f7f7f7;
  color: gray; }

.choices__button {
  text-indent: -9999px;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  border: 0;
  background-color: transparent;
  background-repeat: no-repeat;
  background-position: center;
  cursor: pointer; }

.choices__button:focus {
  outline: none; }

.choices__input {
  display: inline-block;
  vertical-align: baseline;
  margin-bottom: 5px;
  max-width: 100%;
  padding: 4px 0 4px 2px;
  width: 100% !important; }

.choices__input:focus {
  outline: 0; }

.choices__placeholder {
  opacity: 0.5; }

.ui-background {
  color: #f4f4f4; }

.ui-background-background {
  background-color: #f4f4f4; }

.interactive-01 {
  color: #0f62fe; }

.interactive-01-background {
  background-color: #0f62fe; }

.interactive-02 {
  color: #393939; }

.interactive-02-background {
  background-color: #393939; }

.interactive-03 {
  color: #0f62fe; }

.interactive-03-background {
  background-color: #0f62fe; }

.interactive-04 {
  color: #0f62fe; }

.interactive-04-background {
  background-color: #0f62fe; }

.danger {
  color: #da1e28; }

.danger-background {
  background-color: #da1e28; }

.ui-01 {
  color: #ffffff; }

.ui-01-background {
  background-color: #ffffff; }

.ui-02 {
  color: #f4f4f4; }

.ui-02-background {
  background-color: #f4f4f4; }

.ui-03 {
  color: #e0e0e0; }

.ui-03-background {
  background-color: #e0e0e0; }

.ui-04 {
  color: #8d8d8d; }

.ui-04-background {
  background-color: #8d8d8d; }

.ui-05 {
  color: #161616; }

.ui-05-background {
  background-color: #161616; }

.button-separator {
  color: #e0e0e0; }

.button-separator-background {
  background-color: #e0e0e0; }

.decorative-01 {
  color: #e0e0e0; }

.decorative-01-background {
  background-color: #e0e0e0; }

.text-01 {
  color: #161616; }

.text-01-background {
  background-color: #161616; }

.text-02 {
  color: #525252; }

.text-02-background {
  background-color: #525252; }

.text-03 {
  color: #a8a8a8; }

.text-03-background {
  background-color: #a8a8a8; }

.text-04 {
  color: #ffffff; }

.text-04-background {
  background-color: #ffffff; }

.text-05 {
  color: #6f6f6f; }

.text-05-background {
  background-color: #6f6f6f; }

.text-error {
  color: #da1e28; }

.text-error-background {
  background-color: #da1e28; }

.link-01 {
  color: #0f62fe; }

.link-01-background {
  background-color: #0f62fe; }

.inverse-link {
  color: #78a9ff; }

.inverse-link-background {
  background-color: #78a9ff; }

.icon-01 {
  color: #161616; }

.icon-01-background {
  background-color: #161616; }

.icon-02 {
  color: #525252; }

.icon-02-background {
  background-color: #525252; }

.icon-03 {
  color: #ffffff; }

.icon-03-background {
  background-color: #ffffff; }

.field-01 {
  color: #ffffff; }

.field-01-background {
  background-color: #ffffff; }

.field-02 {
  color: #f4f4f4; }

.field-02-background {
  background-color: #f4f4f4; }

.inverse-01 {
  color: #ffffff; }

.inverse-01-background {
  background-color: #ffffff; }

.inverse-02 {
  color: #393939; }

.inverse-02-background {
  background-color: #393939; }

.support-01 {
  color: #da1e28; }

.support-01-background {
  background-color: #da1e28; }

.support-02 {
  color: #24a148; }

.support-02-background {
  background-color: #24a148; }

.support-03 {
  color: #f1c21b; }

.support-03-background {
  background-color: #f1c21b; }

.support-04 {
  color: #0043ce; }

.support-04-background {
  background-color: #0043ce; }

.inverse-support-01 {
  color: #fa4d56; }

.inverse-support-01-background {
  background-color: #fa4d56; }

.inverse-support-02 {
  color: #42be65; }

.inverse-support-02-background {
  background-color: #42be65; }

.inverse-support-03 {
  color: #f1c21b; }

.inverse-support-03-background {
  background-color: #f1c21b; }

.inverse-support-04 {
  color: #4589ff; }

.inverse-support-04-background {
  background-color: #4589ff; }

.overlay-01 {
  color: rgba(22, 22, 22, 0.5); }

.overlay-01-background {
  background-color: rgba(22, 22, 22, 0.5); }

.focus {
  color: #0f62fe; }

.focus-background {
  background-color: #0f62fe; }

.inverse-focus-ui {
  color: #ffffff; }

.inverse-focus-ui-background {
  background-color: #ffffff; }

.hover-primary {
  color: #0353e9; }

.hover-primary-background {
  background-color: #0353e9; }

.hover-primary-text {
  color: #0043ce; }

.hover-primary-text-background {
  background-color: #0043ce; }

.hover-secondary {
  color: #4c4c4c; }

.hover-secondary-background {
  background-color: #4c4c4c; }

.hover-tertiary {
  color: #0353e9; }

.hover-tertiary-background {
  background-color: #0353e9; }

.hover-ui {
  color: #e5e5e5; }

.hover-ui-background {
  background-color: #e5e5e5; }

.hover-light-ui {
  color: #e5e5e5; }

.hover-light-ui-background {
  background-color: #e5e5e5; }

.hover-selected-ui {
  color: #cacaca; }

.hover-selected-ui-background {
  background-color: #cacaca; }

.hover-danger {
  color: #b81921; }

.hover-danger-background {
  background-color: #b81921; }

.hover-row {
  color: #e5e5e5; }

.hover-row-background {
  background-color: #e5e5e5; }

.inverse-hover-ui {
  color: #4c4c4c; }

.inverse-hover-ui-background {
  background-color: #4c4c4c; }

.active-primary {
  color: #002d9c; }

.active-primary-background {
  background-color: #002d9c; }

.active-secondary {
  color: #6f6f6f; }

.active-secondary-background {
  background-color: #6f6f6f; }

.active-tertiary {
  color: #002d9c; }

.active-tertiary-background {
  background-color: #002d9c; }

.active-ui {
  color: #c6c6c6; }

.active-ui-background {
  background-color: #c6c6c6; }

.active-danger {
  color: #750e13; }

.active-danger-background {
  background-color: #750e13; }

.selected-ui {
  color: #e0e0e0; }

.selected-ui-background {
  background-color: #e0e0e0; }

.selected-light-ui {
  color: #e0e0e0; }

.selected-light-ui-background {
  background-color: #e0e0e0; }

.highlight {
  color: #d0e2ff; }

.highlight-background {
  background-color: #d0e2ff; }

.skeleton-01 {
  color: #e5e5e5; }

.skeleton-01-background {
  background-color: #e5e5e5; }

.skeleton-02 {
  color: #c6c6c6; }

.skeleton-02-background {
  background-color: #c6c6c6; }

.visited-link {
  color: #8a3ffc; }

.visited-link-background {
  background-color: #8a3ffc; }

.disabled-01 {
  color: #ffffff; }

.disabled-01-background {
  background-color: #ffffff; }

.disabled-02 {
  color: #c6c6c6; }

.disabled-02-background {
  background-color: #c6c6c6; }

.disabled-03 {
  color: #8d8d8d; }

.disabled-03-background {
  background-color: #8d8d8d; }

.caption-01 {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.label-01 {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.helper-text-01 {
  font-size: 0.75rem;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.body-short-01 {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px; }

.body-long-01 {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px; }

.body-short-02 {
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.375;
  letter-spacing: 0; }

.body-long-02 {
  font-size: 1rem;
  font-weight: 400;
  line-height: 1.5;
  letter-spacing: 0; }

.code-01 {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.code-02 {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.32px; }

.productive-heading-01 {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px; }

.productive-heading-02 {
  font-size: 1rem;
  font-weight: 600;
  line-height: 1.375;
  letter-spacing: 0; }

.productive-heading-03 {
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.4;
  letter-spacing: 0; }

.productive-heading-04 {
  font-size: 1.75rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0; }

.productive-heading-05 {
  font-size: 2rem;
  font-weight: 400;
  line-height: 1.25;
  letter-spacing: 0; }

.productive-heading-06 {
  font-size: 2.625rem;
  font-weight: 300;
  line-height: 1.199;
  letter-spacing: 0; }

.productive-heading-07 {
  font-size: 3.375rem;
  font-weight: 300;
  line-height: 1.19;
  letter-spacing: 0; }

/* thai font face */
@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Light Italic"), local("IBMPlexSans-LightItalic"), url("/static/fonts/IBM-Plex-Sans-Thai-Looped/fonts/complete/woff2/IBMPlexSansThaiLooped-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0E00-0E7F; }

@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans Italic"), local("IBMPlexSans-Italic"), url("/static/fonts/IBM-Plex-Sans-Thai-Looped/fonts/complete/woff2/IBMPlexSansThaiLooped-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0E00-0E7F; }

@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: italic;
  src: local("IBM Plex Sans SemiBold Italic"), local("IBMPlexSans-SemiBoldItalic"), url("/static/fonts/IBM-Plex-Sans-Thai-Looped/fonts/complete/woff2/IBMPlexSansThaiLooped-Bold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0E00-0E7F; }

@font-face {
  font-weight: 300;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans Light"), local("IBMPlexSans-Light"), url("/static/fonts/IBM-Plex-Sans-Thai-Looped/fonts/complete/woff2/IBMPlexSansThaiLooped-Light.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0E00-0E7F; }

@font-face {
  font-weight: 400;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans"), local("IBMPlexSans"), url("/static/fonts/IBM-Plex-Sans-Thai-Looped/fonts/complete/woff2/IBMPlexSansThaiLooped-Regular.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0E00-0E7F; }

@font-face {
  font-weight: 600;
  font-family: 'IBM Plex Sans';
  font-style: normal;
  src: local("IBM Plex Sans SemiBold"), local("IBMPlexSans-SemiBold"), url("/static/fonts/IBM-Plex-Sans-Thai-Looped/fonts/complete/woff2/IBMPlexSansThaiLooped-Bold.woff2") format("woff2");
  font-display: auto;
  unicode-range: U+0E00-0E7F; }

.bx--content {
  transform: none; }

a[disabled], a.bx--btn--disabled {
  pointer-events: none; }

@media print {
  html, body {
    background-color: white !important; }
  aside, header, button, .no-print {
    display: none !important; }
  .bx--content {
    margin: 0 !important;
    padding: 0 !important; } }

h3 {
  margin-bottom: 3rem; }

h4 {
  margin-bottom: 1.5rem;
  margin-top: 0.75rem; }

h5 {
  margin-bottom: 1rem; }

.bx--form-item {
  margin-bottom: 2rem; }

td .bx--form-item {
  margin-bottom: 0; }

td .bx--modal .bx--form-item {
  margin-bottom: 2rem; }

.bx--data-table .bx--table-column-menu,
.bx--data-table .bx--table-column-menu:last-of-type {
  width: 3.25rem;
  min-width: 3.25rem;
  padding-top: 0.5rem;
  padding-right: 0.5rem; }

.bx--col .bx--form-item .bx--select {
  width: 100%;
  max-width: 100%; }
  .bx--col .bx--form-item .bx--select .bx--select-input__wrapper {
    width: 100%;
    max-width: 100%; }
    .bx--col .bx--form-item .bx--select .bx--select-input__wrapper select {
      width: 100%;
      max-width: 100%; }

.bx--col .bx--form-item .bx--date-picker-container {
  width: 100%; }

.bx--col .bx--form-item [data-date-picker] {
  width: 100%;
  max-width: 100%; }
  .bx--col .bx--form-item [data-date-picker] input {
    width: 100%;
    max-width: 100%; }

.bx--col .bx--form-item > * {
  width: 100%; }

.bx--action-list .bx--btn.bx--btn--icon-only .bx--btn__icon {
  margin-left: 0; }

.bx--form-item.bx--checkbox-wrapper.standalone {
  height: 5rem;
  justify-content: center; }

fieldset[readonly] {
  color: initial !important;
  cursor: auto !important; }
  fieldset[readonly] .bx--label--disabled {
    color: initial !important; }

@keyframes notification {
  0% {
    opacity: 0; }
  10% {
    opacity: 1; }
  90% {
    opacity: 1; }
  100% {
    opacity: 0; } }

.raised {
  box-shadow: 0 2px 6px 0 rgba(0, 0, 0, 0.2); }

.highlighted {
  font-weight: 600; }

.text-input-icon {
  position: absolute;
  right: 1rem; }

.bx--text-input:disabled
+ .text-input-icon {
  fill: #c6c6c6; }

.text-input-with-icon[data-invalid] .text-input-icon {
  fill: #da1e28; }

.text-input-with-icon .bx--text-input__invalid-icon {
  display: none; }

.theme-white .bx--btn-set {
  display: flex; }

.theme-white .bx--btn-set--stacked {
  flex-direction: column; }

.theme-white .bx--btn-set .bx--btn {
  width: 100%;
  max-width: 12.25rem; }
  .theme-white .bx--btn-set .bx--btn:not(:focus) {
    box-shadow: -0.0625rem 0 0 0 #e0e0e0; }
  .theme-white .bx--btn-set .bx--btn:first-of-type:not(:focus) {
    box-shadow: inherit; }

.theme-white .bx--btn-set .bx--btn:focus + .bx--btn {
  box-shadow: inherit; }

.theme-white .bx--btn-set--stacked .bx--btn:not(:focus) {
  box-shadow: 0 -0.0625rem 0 0 #e0e0e0; }

.theme-white .bx--btn-set--stacked .bx--btn:first-of-type:not(:focus) {
  box-shadow: inherit; }

.theme-white .bx--btn-set .bx--btn.bx--btn--disabled {
  box-shadow: -0.0625rem 0 0 0 #8d8d8d; }
  .theme-white .bx--btn-set .bx--btn.bx--btn--disabled:first-of-type {
    box-shadow: none; }

.theme-white .bx--btn-set--stacked .bx--btn.bx--btn--disabled {
  box-shadow: 0 -0.0625rem 0 0 #8d8d8d; }
  .theme-white .bx--btn-set--stacked .bx--btn.bx--btn--disabled:first-of-type {
    box-shadow: none; }

.theme-white .bx--btn {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  position: relative;
  display: inline-flex;
  flex-shrink: 0;
  align-items: center;
  justify-content: space-between;
  max-width: 20rem;
  min-height: 3rem;
  margin: 0;
  padding: calc(0.875rem - 3px) 63px calc(0.875rem - 3px) 15px;
  text-align: left;
  text-decoration: none;
  vertical-align: top;
  border-radius: 0;
  outline: none;
  cursor: pointer;
  transition: all 70ms cubic-bezier(0, 0, 0.38, 0.9); }
  .theme-white .bx--btn:disabled, .theme-white .bx--btn:hover:disabled, .theme-white .bx--btn:focus:disabled, .theme-white .bx--btn.bx--btn--disabled, .theme-white .bx--btn.bx--btn--disabled:hover, .theme-white .bx--btn.bx--btn--disabled:focus {
    color: #8d8d8d;
    background: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none;
    cursor: not-allowed; }
  .theme-white .bx--btn .bx--btn__icon {
    position: absolute;
    right: 1rem;
    flex-shrink: 0;
    width: 1rem;
    height: 1rem; }

.theme-white .bx--btn::-moz-focus-inner {
  padding: 0;
  border: 0; }

.theme-white .bx--btn--primary {
  color: #ffffff;
  background-color: #0f62fe;
  border-color: transparent;
  border-style: solid;
  border-width: 1px; }
  .theme-white .bx--btn--primary:hover {
    background-color: #0353e9; }
  .theme-white .bx--btn--primary:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #ffffff; }
  .theme-white .bx--btn--primary:disabled:hover, .theme-white .bx--btn--primary:disabled:focus, .theme-white .bx--btn--primary:hover.bx--btn--disabled, .theme-white .bx--btn--primary:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .theme-white .bx--btn--primary:active {
    background-color: #002d9c; }
  .theme-white .bx--btn--primary .bx--btn__icon,
  .theme-white .bx--btn--primary .bx--btn__icon path {
    fill: currentColor; }
  .theme-white .bx--btn--primary:hover {
    color: #ffffff; }

.theme-white .bx--btn--secondary {
  color: #ffffff;
  background-color: #393939;
  border-color: transparent;
  border-style: solid;
  border-width: 1px; }
  .theme-white .bx--btn--secondary:hover {
    background-color: #4c4c4c; }
  .theme-white .bx--btn--secondary:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #ffffff; }
  .theme-white .bx--btn--secondary:disabled:hover, .theme-white .bx--btn--secondary:disabled:focus, .theme-white .bx--btn--secondary:hover.bx--btn--disabled, .theme-white .bx--btn--secondary:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .theme-white .bx--btn--secondary:active {
    background-color: #6f6f6f; }
  .theme-white .bx--btn--secondary .bx--btn__icon,
  .theme-white .bx--btn--secondary .bx--btn__icon path {
    fill: currentColor; }
  .theme-white .bx--btn--secondary:hover, .theme-white .bx--btn--secondary:focus {
    color: #ffffff; }

.theme-white .bx--btn--tertiary {
  color: #0f62fe;
  background-color: transparent;
  border-color: #0f62fe;
  border-style: solid;
  border-width: 1px; }
  .theme-white .bx--btn--tertiary:hover {
    background-color: #0353e9; }
  .theme-white .bx--btn--tertiary:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #ffffff; }
  .theme-white .bx--btn--tertiary:disabled:hover, .theme-white .bx--btn--tertiary:disabled:focus, .theme-white .bx--btn--tertiary:hover.bx--btn--disabled, .theme-white .bx--btn--tertiary:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .theme-white .bx--btn--tertiary:active {
    background-color: #002d9c; }
  .theme-white .bx--btn--tertiary .bx--btn__icon,
  .theme-white .bx--btn--tertiary .bx--btn__icon path {
    fill: currentColor; }
  .theme-white .bx--btn--tertiary:hover {
    color: #ffffff; }
  .theme-white .bx--btn--tertiary:focus {
    color: #ffffff;
    background-color: #0f62fe; }
  .theme-white .bx--btn--tertiary:active {
    border-color: transparent; }
  .theme-white .bx--btn--tertiary:disabled, .theme-white .bx--btn--tertiary:hover:disabled, .theme-white .bx--btn--tertiary:focus:disabled, .theme-white .bx--btn--tertiary.bx--btn--disabled, .theme-white .bx--btn--tertiary.bx--btn--disabled:hover, .theme-white .bx--btn--tertiary.bx--btn--disabled:focus {
    color: #c6c6c6;
    background: transparent;
    outline: none; }

.theme-white .bx--btn--ghost {
  color: #0f62fe;
  background-color: transparent;
  border-color: transparent;
  border-style: solid;
  border-width: 1px;
  padding: calc(0.875rem - 3px) 12px; }
  .theme-white .bx--btn--ghost:hover {
    background-color: #e5e5e5; }
  .theme-white .bx--btn--ghost:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #ffffff; }
  .theme-white .bx--btn--ghost:disabled:hover, .theme-white .bx--btn--ghost:disabled:focus, .theme-white .bx--btn--ghost:hover.bx--btn--disabled, .theme-white .bx--btn--ghost:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .theme-white .bx--btn--ghost:active {
    background-color: #c6c6c6; }
  .theme-white .bx--btn--ghost .bx--btn__icon,
  .theme-white .bx--btn--ghost .bx--btn__icon path {
    fill: currentColor; }
  .theme-white .bx--btn--ghost .bx--btn__icon {
    position: static;
    margin-left: 0.5rem; }
  .theme-white .bx--btn--ghost:hover, .theme-white .bx--btn--ghost:active {
    color: #0043ce; }
  .theme-white .bx--btn--ghost:active {
    background-color: #c6c6c6; }
  .theme-white .bx--btn--ghost:disabled, .theme-white .bx--btn--ghost:hover:disabled, .theme-white .bx--btn--ghost:focus:disabled, .theme-white .bx--btn--ghost.bx--btn--disabled, .theme-white .bx--btn--ghost.bx--btn--disabled:hover, .theme-white .bx--btn--ghost.bx--btn--disabled:focus {
    color: #c6c6c6;
    background: transparent;
    border-color: transparent;
    outline: none; }
  .theme-white .bx--btn--ghost.bx--btn--sm {
    padding: calc(0.375rem - 3px) 12px; }
  .theme-white .bx--btn--ghost.bx--btn--field {
    padding: calc(0.675rem - 3px) 12px; }

.theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus {
    outline: 1px solid #0f62fe; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus {
    outline: 1px solid transparent; }
    .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus svg {
      outline: 1px solid #0f62fe; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
        display: inline-block; } }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--a11y::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--a11y::after {
    transition: none; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after,
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger .bx--assistive-text,
      .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger + .bx--assistive-text {
        width: 13rem; } }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger::after {
    content: attr(aria-label); }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--a11y::after {
    content: none; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible::after, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover::after, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible + .bx--assistive-text, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover + .bx--assistive-text, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible + .bx--assistive-text, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--visible.bx--tooltip--a11y::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover + .bx--assistive-text, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover.bx--tooltip--a11y::before, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus .bx--assistive-text,
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus + .bx--assistive-text, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--hidden .bx--assistive-text, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger svg, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:hover svg, .theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus svg {
    fill: currentColor; }

.theme-white .bx--btn.bx--btn--icon-only.bx--btn--ghost:focus svg {
  fill: #161616; }

.theme-white .bx--btn.bx--btn--icon-only.bx--btn--ghost:hover svg {
  fill: #161616; }

.theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus {
  border-color: #0f62fe; }

.theme-white .bx--btn.bx--btn--icon-only.bx--tooltip__trigger:focus
svg {
  outline-color: transparent; }

.theme-white .bx--btn--icon-only--top {
  position: relative;
  display: inline-flex;
  align-items: center;
  overflow: visible;
  cursor: pointer; }
  .theme-white .bx--btn--icon-only--top:focus {
    outline: 1px solid #0f62fe; }
  .theme-white .bx--btn--icon-only--top:focus {
    outline: 1px solid transparent; }
    .theme-white .bx--btn--icon-only--top:focus svg {
      outline: 1px solid #0f62fe; }
  .theme-white .bx--btn--icon-only--top::before, .theme-white .bx--btn--icon-only--top::after,
  .theme-white .bx--btn--icon-only--top .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
    position: absolute;
    z-index: 6000;
    display: flex;
    align-items: center;
    opacity: 0;
    pointer-events: none; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .theme-white .bx--btn--icon-only--top::before, .theme-white .bx--btn--icon-only--top::after,
      .theme-white .bx--btn--icon-only--top .bx--assistive-text,
      .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
        display: inline-block; } }
  .theme-white .bx--btn--icon-only--top::before, .theme-white .bx--btn--icon-only--top::after {
    transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .theme-white .bx--btn--icon-only--top.bx--tooltip--a11y::before, .theme-white .bx--btn--icon-only--top.bx--tooltip--a11y::after {
    transition: none; }
  .theme-white .bx--btn--icon-only--top::before {
    width: 0;
    height: 0;
    border-style: solid;
    content: ''; }
  .theme-white .bx--btn--icon-only--top .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
    box-sizing: content-box;
    color: inherit;
    white-space: normal;
    opacity: 1; }
  .theme-white .bx--btn--icon-only--top::after,
  .theme-white .bx--btn--icon-only--top .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
    box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
    width: max-content;
    min-width: 1.5rem;
    max-width: 13rem;
    height: auto;
    padding: 0.1875rem 1rem;
    color: #ffffff;
    font-weight: 400;
    text-align: left;
    background-color: #393939;
    border-radius: 0.125rem;
    transform: translateX(-50%);
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.29;
    letter-spacing: 0.16px; }
    @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
      .theme-white .bx--btn--icon-only--top::after,
      .theme-white .bx--btn--icon-only--top .bx--assistive-text,
      .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-accelerator: true) {
      .theme-white .bx--btn--icon-only--top::after,
      .theme-white .bx--btn--icon-only--top .bx--assistive-text,
      .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
        width: 13rem; } }
    @supports (-ms-ime-align: auto) {
      .theme-white .bx--btn--icon-only--top::after,
      .theme-white .bx--btn--icon-only--top .bx--assistive-text,
      .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
        width: 13rem; } }
  .theme-white .bx--btn--icon-only--top::after {
    content: attr(aria-label); }
  .theme-white .bx--btn--icon-only--top.bx--tooltip--a11y::after {
    content: none; }
  .theme-white .bx--btn--icon-only--top.bx--tooltip--visible::before, .theme-white .bx--btn--icon-only--top.bx--tooltip--visible::after, .theme-white .bx--btn--icon-only--top:hover::before, .theme-white .bx--btn--icon-only--top:hover::after, .theme-white .bx--btn--icon-only--top:focus::before, .theme-white .bx--btn--icon-only--top:focus::after {
    opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
  .theme-white .bx--btn--icon-only--top.bx--tooltip--visible .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top.bx--tooltip--visible + .bx--assistive-text, .theme-white .bx--btn--icon-only--top:hover .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top:hover + .bx--assistive-text, .theme-white .bx--btn--icon-only--top:focus .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top:focus + .bx--assistive-text {
    margin: auto;
    overflow: visible;
    clip: auto; }
  .theme-white .bx--btn--icon-only--top.bx--tooltip--visible .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top.bx--tooltip--visible + .bx--assistive-text, .theme-white .bx--btn--icon-only--top.bx--tooltip--visible.bx--tooltip--a11y::before, .theme-white .bx--btn--icon-only--top:hover .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top:hover + .bx--assistive-text, .theme-white .bx--btn--icon-only--top:hover.bx--tooltip--a11y::before, .theme-white .bx--btn--icon-only--top:focus .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top:focus + .bx--assistive-text, .theme-white .bx--btn--icon-only--top:focus.bx--tooltip--a11y::before {
    animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .theme-white .bx--btn--icon-only--top.bx--tooltip--hidden .bx--assistive-text, .theme-white .bx--btn--icon-only--top.bx--tooltip--hidden + .bx--assistive-text {
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0); }
  .theme-white .bx--btn--icon-only--top.bx--tooltip--hidden.bx--tooltip--a11y::before {
    opacity: 0;
    animation: none; }
  .theme-white .bx--btn--icon-only--top::before, .theme-white .bx--btn--icon-only--top::after,
  .theme-white .bx--btn--icon-only--top .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
    top: 0;
    left: 50%; }
  .theme-white .bx--btn--icon-only--top::before {
    top: -0.5rem;
    border-color: #393939 transparent transparent transparent;
    border-width: 0.3125rem 0.25rem 0 0.25rem;
    transform: translate(-50%, -100%); }
  .theme-white .bx--btn--icon-only--top::after,
  .theme-white .bx--btn--icon-only--top .bx--assistive-text,
  .theme-white .bx--btn--icon-only--top + .bx--assistive-text {
    top: -0.8125rem;
    left: 50%;
    transform: translate(-50%, -100%); }

.theme-white .bx--btn--icon-only--bottom::before, .theme-white .bx--btn--icon-only--bottom::after,
.theme-white .bx--btn--icon-only--bottom .bx--assistive-text,
.theme-white .bx--btn--icon-only--bottom + .bx--assistive-text {
  bottom: 0;
  left: 50%; }

.theme-white .bx--btn--icon-only--bottom::before {
  bottom: -0.5rem;
  border-color: transparent transparent #393939 transparent;
  border-width: 0 0.25rem 0.3125rem 0.25rem;
  transform: translate(-50%, 100%); }

.theme-white .bx--btn--icon-only--bottom::after,
.theme-white .bx--btn--icon-only--bottom .bx--assistive-text,
.theme-white .bx--btn--icon-only--bottom + .bx--assistive-text {
  bottom: -0.8125rem;
  transform: translate(-50%, 100%); }

.theme-white .bx--btn--icon-only {
  padding-right: 0.9375rem;
  padding-left: 0.9375rem; }
  .theme-white .bx--btn--icon-only .bx--btn__icon {
    position: static; }
  .theme-white .bx--btn--icon-only.bx--btn--ghost .bx--btn__icon {
    margin: 0; }

.theme-white .bx--btn path[data-icon-path='inner-path'] {
  fill: none; }

.theme-white .bx--btn.bx--btn--icon-only.bx--btn--ghost
.bx--btn__icon,
.theme-white .bx--btn.bx--btn--icon-only.bx--btn--ghost:hover
.bx--btn__icon {
  fill: #161616; }

.theme-white .bx--btn--ghost.bx--btn--icon-only
.bx--btn__icon
path,
.theme-white .bx--btn--ghost.bx--btn--icon-only .bx--btn__icon {
  fill: #161616; }

.theme-white .bx--btn--ghost.bx--btn--icon-only[disabled]
.bx--btn__icon
path,
.theme-white .bx--btn--ghost.bx--btn--icon-only[disabled]
.bx--btn__icon,
.theme-white .bx--btn.bx--btn--icon-only.bx--btn--ghost[disabled]:hover
.bx--btn__icon {
  fill: #c6c6c6; }

.theme-white .bx--btn--ghost.bx--btn--icon-only[disabled] {
  cursor: not-allowed; }

.theme-white .bx--btn--field.bx--btn--icon-only {
  padding-right: 0.6875rem;
  padding-left: 0.6875rem; }

.theme-white .bx--btn--sm.bx--btn--icon-only {
  padding-right: 0.4375rem;
  padding-left: 0.4375rem; }

.theme-white .bx--btn--danger {
  color: #ffffff;
  background-color: #da1e28;
  border-color: transparent;
  border-style: solid;
  border-width: 1px; }
  .theme-white .bx--btn--danger:hover {
    background-color: #b81921; }
  .theme-white .bx--btn--danger:focus {
    border-color: #0f62fe;
    box-shadow: inset 0 0 0 1px #0f62fe, inset 0 0 0 2px #ffffff; }
  .theme-white .bx--btn--danger:disabled:hover, .theme-white .bx--btn--danger:disabled:focus, .theme-white .bx--btn--danger:hover.bx--btn--disabled, .theme-white .bx--btn--danger:focus.bx--btn--disabled {
    color: #8d8d8d;
    text-decoration: none;
    background-color: #c6c6c6;
    border-color: #c6c6c6;
    box-shadow: none; }
  .theme-white .bx--btn--danger:active {
    background-color: #750e13; }
  .theme-white .bx--btn--danger .bx--btn__icon,
  .theme-white .bx--btn--danger .bx--btn__icon path {
    fill: currentColor; }
  .theme-white .bx--btn--danger:hover {
    color: #ffffff; }

.theme-white .bx--btn--sm {
  min-height: 2rem;
  padding: calc(0.375rem - 3px) 60px calc(0.375rem - 3px) 12px; }

.theme-white .bx--btn--field {
  min-height: 2.5rem;
  padding: calc(0.675rem - 3px) 60px calc(0.675rem - 3px) 12px; }

.theme-white .bx--btn.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 9.375rem; }
  .theme-white .bx--btn.bx--skeleton:hover, .theme-white .bx--btn.bx--skeleton:focus, .theme-white .bx--btn.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white .bx--btn.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white .bx--btn.bx--skeleton::before {
        animation: none; } }
.theme-white .bx--search {
  position: relative;
  display: flex;
  align-items: center;
  width: 100%; }

.theme-white .bx--search .bx--label {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.theme-white .bx--search-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  order: 1;
  width: 100%;
  padding: 0 2.5rem;
  color: #161616;
  text-overflow: ellipsis;
  background-color: #f4f4f4;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  appearance: none; }
  .theme-white .bx--search-input:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .theme-white .bx--search-input::placeholder {
    color: #6f6f6f;
    font-weight: 400; }
  .theme-white .bx--search-input::-ms-clear {
    display: none; }

.theme-white .bx--search-input[disabled] {
  color: #c6c6c6;
  background-color: #ffffff;
  border-bottom: 1px solid transparent;
  cursor: not-allowed; }
  .theme-white .bx--search-input[disabled]::placeholder {
    color: #c6c6c6;
    font-weight: 400; }

.theme-white .bx--search-input[disabled] ~ .bx--search-magnifier {
  fill: #c6c6c6; }

.theme-white .bx--search--light .bx--search-input {
  background: #ffffff; }

.theme-white .bx--search--sm .bx--search-input {
  height: 2rem;
  padding: 0 2rem; }

.theme-white .bx--search--sm .bx--search-magnifier {
  left: 0.5rem; }

.theme-white .bx--search--lg .bx--search-input {
  height: 2.5rem;
  padding: 0 2.5rem; }

.theme-white .bx--search--lg .bx--search-magnifier {
  left: 0.75rem; }

.theme-white .bx--search--xl .bx--search-input {
  height: 3rem;
  padding: 0 3rem; }

.theme-white .bx--search-magnifier {
  position: absolute;
  top: 50%;
  left: 1rem;
  z-index: 2;
  width: 1rem;
  height: 1rem;
  transform: translateY(-50%);
  pointer-events: none;
  fill: #525252; }

.theme-white .bx--search-close {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: absolute;
  top: 0;
  right: 0; }
  .theme-white .bx--search-close::-moz-focus-inner {
    border: 0; }
  .theme-white .bx--search-close::before {
    position: absolute;
    top: 0.0625rem;
    left: 0;
    display: block;
    width: 2px;
    height: calc(100% - 2px);
    background-color: #f4f4f4;
    transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
    content: ''; }
  .theme-white .bx--search-close:hover {
    border-bottom: 1px solid #8d8d8d; }
    .theme-white .bx--search-close:hover::before {
      background-color: #e5e5e5; }

.theme-white .bx--search-button {
  flex-shrink: 0;
  margin-left: 0.125rem;
  background-color: #f4f4f4; }
  .theme-white .bx--search-button svg {
    vertical-align: middle;
    fill: currentColor; }

.theme-white .bx--search-close svg {
  fill: inherit; }

.theme-white .bx--search-close,
.theme-white .bx--search-button {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2.5rem;
  height: 2.5rem;
  border-color: transparent;
  border-style: solid;
  border-width: 1px 0;
  visibility: inherit;
  cursor: pointer;
  opacity: 1;
  transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9), border 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #161616; }
  .theme-white .bx--search-close:hover,
  .theme-white .bx--search-button:hover {
    background-color: #e5e5e5; }
  .theme-white .bx--search-close:focus,
  .theme-white .bx--search-button:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .theme-white .bx--search-close:active,
  .theme-white .bx--search-button:active {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    background-color: #e0e0e0; }

.theme-white .bx--search-close:focus::before,
.theme-white .bx--search-close:active::before {
  background-color: #0f62fe; }

.theme-white .bx--search-input:focus ~ .bx--search-close:hover {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.theme-white .bx--search--sm .bx--search-close,
.theme-white .bx--search--sm ~ .bx--search-button {
  width: 2rem;
  height: 2rem; }

.theme-white .bx--search--lg .bx--search-close,
.theme-white .bx--search--lg ~ .bx--search-button {
  width: 2.5rem;
  height: 2.5rem; }

.theme-white .bx--search--xl .bx--search-close,
.theme-white .bx--search--xl ~ .bx--search-button {
  width: 3rem;
  height: 3rem; }

.theme-white .bx--search-close--hidden {
  visibility: hidden;
  opacity: 0; }

.theme-white .bx--search--xl.bx--skeleton .bx--search-input,
.theme-white .bx--search--lg.bx--skeleton .bx--search-input,
.theme-white .bx--search--sm.bx--skeleton .bx--search-input {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%; }
  .theme-white .bx--search--xl.bx--skeleton .bx--search-input:hover, .theme-white .bx--search--xl.bx--skeleton .bx--search-input:focus, .theme-white .bx--search--xl.bx--skeleton .bx--search-input:active,
  .theme-white .bx--search--lg.bx--skeleton .bx--search-input:hover,
  .theme-white .bx--search--lg.bx--skeleton .bx--search-input:focus,
  .theme-white .bx--search--lg.bx--skeleton .bx--search-input:active,
  .theme-white .bx--search--sm.bx--skeleton .bx--search-input:hover,
  .theme-white .bx--search--sm.bx--skeleton .bx--search-input:focus,
  .theme-white .bx--search--sm.bx--skeleton .bx--search-input:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white .bx--search--xl.bx--skeleton .bx--search-input::before,
  .theme-white .bx--search--lg.bx--skeleton .bx--search-input::before,
  .theme-white .bx--search--sm.bx--skeleton .bx--search-input::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white .bx--search--xl.bx--skeleton .bx--search-input::before,
      .theme-white .bx--search--lg.bx--skeleton .bx--search-input::before,
      .theme-white .bx--search--sm.bx--skeleton .bx--search-input::before {
        animation: none; } }
  .theme-white .bx--search--xl.bx--skeleton .bx--search-input::placeholder,
  .theme-white .bx--search--lg.bx--skeleton .bx--search-input::placeholder,
  .theme-white .bx--search--sm.bx--skeleton .bx--search-input::placeholder {
    color: transparent; }

.theme-white .bx--select {
  position: relative;
  display: flex;
  flex-direction: column;
  align-items: flex-start; }

.theme-white .bx--select-input__wrapper {
  position: relative;
  display: flex;
  align-items: center; }

.theme-white .bx--select-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  display: block;
  width: 14rem;
  min-width: 8rem;
  max-width: 28rem;
  height: 2.5rem;
  padding: 0 3rem 0 1rem;
  color: #161616;
  background-color: #f4f4f4;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  border-radius: 0;
  cursor: pointer;
  transition: outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  appearance: none;
  -moz-appearance: none;
  -webkit-appearance: none; }
  .theme-white .bx--select-input:hover {
    background-color: #e5e5e5; }
  .theme-white .bx--select-input::-ms-expand {
    display: none; }

@-moz-document url-prefix() {
  .theme-white .bx--select-input:-moz-focusring, .theme-white .bx--select-input::-moz-focus-inner {
    color: transparent;
    text-shadow: 0 0 0 #000000;
    background-image: none; } }
  .theme-white .bx--select-input:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    color: #161616; }
  .theme-white .bx--select-input:disabled, .theme-white .bx--select-input:hover:disabled {
    color: #c6c6c6;
    background-color: #ffffff;
    border-bottom-color: #ffffff;
    cursor: not-allowed; }

.theme-white .bx--select-input--sm {
  height: 2rem;
  max-height: 2rem; }

.theme-white .bx--select-input--xl {
  height: 3rem;
  max-height: 3rem; }

.theme-white .bx--select--disabled .bx--label,
.theme-white .bx--select--disabled .bx--form__helper-text {
  color: #c6c6c6; }

.theme-white .bx--select-input__wrapper[data-invalid] .bx--select-input {
  padding-right: 5rem; }

.theme-white .bx--select-input:disabled ~ .bx--select__arrow {
  fill: #c6c6c6; }

.theme-white .bx--select--light .bx--select-input {
  background-color: #ffffff; }
  .theme-white .bx--select--light .bx--select-input:hover {
    background-color: #e5e5e5; }
  .theme-white .bx--select--light .bx--select-input:disabled, .theme-white .bx--select--light .bx--select-input:hover:disabled {
    color: #c6c6c6;
    background-color: #ffffff;
    cursor: not-allowed; }

.theme-white .bx--select__arrow {
  position: absolute;
  top: 0;
  right: 1rem;
  height: 100%;
  pointer-events: none;
  fill: #161616; }

.theme-white .bx--select-input__wrapper[data-invalid]
.bx--select-input
~ .bx--select__invalid-icon {
  position: absolute;
  right: 3rem;
  fill: #da1e28; }

.theme-white .bx--select-optgroup,
.theme-white .bx--select-option {
  color: #161616; }

.theme-white .bx--select-option[disabled] {
  cursor: not-allowed;
  opacity: 0.5; }

@-moz-document url-prefix() {
  .theme-white .bx--select-option {
    color: #161616;
    background-color: #f4f4f4; }
  .theme-white .bx--select-optgroup {
    color: #161616; } }

.theme-white .bx--select--inline {
  display: flex;
  flex-direction: row;
  align-items: center; }

.theme-white .bx--select--inline.bx--select--invalid .bx--label,
.theme-white .bx--select--inline.bx--select--invalid
.bx--form__helper-text {
  align-self: flex-start;
  margin-top: 0.8125rem; }

.theme-white .bx--select--inline .bx--form__helper-text {
  margin-bottom: 0;
  margin-left: 0.5rem; }

.theme-white .bx--select--inline .bx--label {
  margin: 0 0.5rem 0 0;
  white-space: nowrap; }

.theme-white .bx--select--inline .bx--select-input {
  padding-right: 2rem;
  padding-left: 0.5rem;
  color: #161616;
  background-color: transparent;
  border-bottom: none; }

.theme-white .bx--select--inline .bx--select-input[disabled],
.theme-white .bx--select--inline .bx--select-input[disabled]:hover {
  background-color: #ffffff; }

.theme-white .bx--select--inline .bx--select__arrow {
  right: 0.5rem; }

.theme-white .bx--select--inline.bx--select--invalid
.bx--select-input {
  padding-right: 3.5rem; }

.theme-white .bx--select--inline.bx--select--invalid
.bx--select-input
~ .bx--select__invalid-icon {
  right: 2rem; }

.theme-white .bx--select--inline .bx--select-input:disabled {
  color: #c6c6c6;
  cursor: not-allowed; }
  .theme-white .bx--select--inline .bx--select-input:disabled ~ * {
    cursor: not-allowed; }

.theme-white .bx--select.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%;
  height: 2.5rem; }
  .theme-white .bx--select.bx--skeleton:hover, .theme-white .bx--select.bx--skeleton:focus, .theme-white .bx--select.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white .bx--select.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white .bx--select.bx--skeleton::before {
        animation: none; } }
.theme-white .bx--select.bx--skeleton .bx--select-input {
  display: none; }

.theme-white .bx--text-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  width: 100%;
  height: 2.5rem;
  padding: 0 1rem;
  color: #161616;
  background-color: #f4f4f4;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .theme-white .bx--text-input:focus, .theme-white .bx--text-input:active {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .theme-white .bx--text-input-wrapper svg[hidden] {
    display: none; }

.theme-white .bx--text-input--xl {
  height: 3rem; }

.theme-white .bx--text-input--sm {
  height: 2rem; }

.theme-white .bx--password-input {
  padding-right: 2.5rem; }

.theme-white .bx--text-input::placeholder {
  color: #a8a8a8;
  opacity: 1; }

.theme-white .bx--text-input--light {
  background-color: #ffffff; }

.theme-white .bx--text-input__field-wrapper {
  position: relative;
  display: flex;
  align-items: center;
  width: 100%; }
  .theme-white .bx--text-input__field-wrapper .bx--text-input__invalid-icon {
    position: absolute;
    top: 50%;
    right: 1rem;
    transform: translateY(-50%);
    fill: #da1e28; }
  .theme-white .bx--text-input__field-wrapper .bx--text-input__invalid-icon--warning {
    fill: #f1c21b; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input__invalid-icon--warning path[data-icon-path='inner-path'] {
      opacity: 1;
      fill: #000000; }
  .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility {
    position: relative;
    display: inline-flex;
    align-items: center;
    overflow: visible;
    cursor: pointer; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus {
      outline: 1px solid #0f62fe; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus {
      outline: 1px solid transparent; }
      .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus svg {
        outline: 1px solid #0f62fe; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      position: absolute;
      z-index: 6000;
      display: flex;
      align-items: center;
      opacity: 0;
      pointer-events: none; }
      @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
          display: inline-block; } }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after {
      transition: opacity 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--a11y::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--a11y::after {
      transition: none; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::before {
      width: 0;
      height: 0;
      border-style: solid;
      content: ''; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      box-sizing: content-box;
      color: inherit;
      white-space: normal;
      opacity: 1; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      box-shadow: 0 2px 6px rgba(0, 0, 0, 0.2);
      width: max-content;
      min-width: 1.5rem;
      max-width: 13rem;
      height: auto;
      padding: 0.1875rem 1rem;
      color: #ffffff;
      font-weight: 400;
      text-align: left;
      background-color: #393939;
      border-radius: 0.125rem;
      transform: translateX(-50%);
      font-size: 0.875rem;
      font-weight: 400;
      line-height: 1.29;
      letter-spacing: 0.16px; }
      @media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
          width: 13rem; } }
      @supports (-ms-accelerator: true) {
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
          width: 13rem; } }
      @supports (-ms-ime-align: auto) {
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
        .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
          width: 13rem; } }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after {
      content: attr(aria-label); }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--a11y::after {
      content: none; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible::after, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover::after, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus::after {
      opacity: 1; }

@keyframes tooltip-fade {
  from {
    opacity: 0; }
  to {
    opacity: 1; } }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible + .bx--assistive-text, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover + .bx--assistive-text, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus + .bx--assistive-text {
      margin: auto;
      overflow: visible;
      clip: auto; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible + .bx--assistive-text, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--visible.bx--tooltip--a11y::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover + .bx--assistive-text, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:hover.bx--tooltip--a11y::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus + .bx--assistive-text, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility:focus.bx--tooltip--a11y::before {
      animation: tooltip-fade 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--hidden .bx--assistive-text, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--hidden + .bx--assistive-text {
      margin: -1px;
      overflow: hidden;
      clip: rect(0, 0, 0, 0); }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility.bx--tooltip--hidden.bx--tooltip--a11y::before {
      opacity: 0;
      animation: none; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::before, .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      bottom: 0;
      left: 50%; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::before {
      bottom: -0.5rem;
      border-color: transparent transparent #393939 transparent;
      border-width: 0 0.25rem 0.3125rem 0.25rem;
      transform: translate(-50%, 100%); }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility::after,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility .bx--assistive-text,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility + .bx--assistive-text {
      bottom: -0.8125rem;
      transform: translate(-50%, 100%); }
  .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility,
  .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility__toggle.bx--tooltip__trigger {
    position: absolute;
    right: 1rem;
    width: 1rem;
    height: 1rem;
    padding: 0;
    background: none;
    border: 0;
    cursor: pointer; }
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility svg,
    .theme-white .bx--text-input__field-wrapper .bx--text-input--password__visibility__toggle.bx--tooltip__trigger svg {
      fill: #525252; }
  .theme-white .bx--text-input__field-wrapper .bx--text-input--invalid {
    padding-right: 2.5rem; }
  .theme-white .bx--text-input__field-wrapper .bx--text-input--invalid.bx--password-input {
    padding-right: 4rem; }
  .theme-white .bx--text-input__field-wrapper .bx--text-input--invalid
+ .bx--text-input--password__visibility,
  .theme-white .bx--text-input__field-wrapper .bx--text-input--invalid
+ .bx--text-input--password__visibility__toggle {
    right: 1rem; }

.theme-white .bx--password-input-wrapper .bx--text-input__invalid-icon {
  right: 2.5rem; }

.theme-white .bx--text-input:disabled
+ .bx--text-input--password__visibility
svg,
.theme-white .bx--text-input:disabled
+ .bx--text-input--password__visibility__toggle
svg {
  cursor: not-allowed;
  opacity: 0.5; }

.theme-white .bx--text-input:disabled {
  outline: 2px solid transparent;
  outline-offset: -2px;
  color: #c6c6c6;
  background-color: #f4f4f4;
  border-bottom: 1px solid transparent;
  -webkit-text-fill-color: currentColor;
  cursor: not-allowed; }

.theme-white .bx--text-input--light:disabled {
  background-color: #ffffff; }

.theme-white .bx--text-input:disabled::placeholder {
  color: #c6c6c6;
  opacity: 1; }

.theme-white .bx--text-input--invalid {
  outline: 2px solid #da1e28;
  outline-offset: -2px;
  box-shadow: none; }
  .theme-white .bx--text-input--invalid .bx--text-input--password__visibility,
  .theme-white .bx--text-input--invalid .bx--text-input--password__visibility__toggle {
    right: 2.5rem; }

.theme-white .bx--form--fluid .bx--text-input-wrapper {
  position: relative;
  background: #f4f4f4;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.theme-white .bx--form--fluid .bx--label {
  position: absolute;
  top: 0.8125rem;
  left: 1rem;
  z-index: 1;
  margin: 0; }

.theme-white .bx--form--fluid .bx--form__helper-text {
  display: none; }

.theme-white .bx--form--fluid .bx--text-input {
  min-height: 4rem;
  padding: 2rem 1rem 0.8125rem; }

.theme-white .bx--text-input__divider,
.theme-white .bx--form--fluid .bx--text-input__divider {
  display: none; }

.theme-white .bx--form--fluid .bx--text-input--invalid,
.theme-white .bx--form--fluid .bx--text-input--warn {
  border-bottom: none; }

.theme-white .bx--form--fluid
.bx--text-input--invalid
+ .bx--text-input__divider,
.theme-white .bx--form--fluid
.bx--text-input--warn
+ .bx--text-input__divider {
  display: block;
  margin: 0 1rem;
  border-color: #e0e0e0;
  border-style: solid;
  border-bottom: none; }

.theme-white .bx--form--fluid .bx--text-input__invalid-icon {
  top: 5rem; }

.theme-white .bx--form--fluid .bx--text-input-wrapper--light {
  background: #ffffff; }

.theme-white .bx--form--fluid
.bx--text-input__field-wrapper[data-invalid]
> .bx--text-input--invalid {
  outline: 2px solid transparent;
  outline-offset: -2px; }

.theme-white .bx--form--fluid
.bx--text-input__field-wrapper[data-invalid]:not(:focus) {
  outline: 2px solid #da1e28;
  outline-offset: -2px; }

.theme-white .bx--form--fluid
.bx--text-input__field-wrapper[data-invalid]
> .bx--text-input--invalid:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.theme-white .bx--text-input-wrapper--inline {
  flex-flow: row wrap; }

.theme-white .bx--label--inline {
  flex: 1;
  margin: 0.8125rem 0 0 0;
  word-break: break-word;
  overflow-wrap: break-word; }

.theme-white .bx--label--inline--sm {
  margin-top: 0.5625rem; }

.theme-white .bx--label--inline--xl {
  margin-top: 1.0625rem; }

.theme-white .bx--text-input__label-helper-wrapper {
  flex: 2;
  flex-direction: column;
  max-width: 8rem;
  margin-right: 1.5rem;
  overflow-wrap: break-word; }

.theme-white .bx--form__helper-text--inline {
  margin-top: 0.125rem; }

.theme-white .bx--text-input__field-outer-wrapper {
  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
  align-items: flex-start;
  width: 100%; }

.theme-white .bx--text-input__field-outer-wrapper--inline {
  flex: 8;
  flex-direction: column; }

.theme-white .bx--multi-select .bx--list-box__menu {
  min-width: auto; }

.theme-white .bx--multi-select
.bx--list-box__menu-item__option
.bx--checkbox-wrapper {
  display: flex;
  align-items: center;
  width: 100%;
  height: 100%; }

.theme-white .bx--multi-select
.bx--list-box__menu-item__option
.bx--checkbox-label {
  display: inline-block;
  width: 100%;
  padding-left: 1.75rem;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.theme-white .bx--multi-select
.bx--list-box__menu-item__option
> .bx--form-item {
  flex-direction: row;
  margin: 0; }

.theme-white .bx--multi-select
.bx--list-box__menu-item
.bx--checkbox:checked
~ .bx--checkbox-label-text {
  color: #161616; }

.theme-white .bx--multi-select--filterable .bx--list-box__selection--multi {
  position: absolute;
  right: auto;
  left: 0.5rem; }

.theme-white .bx--multi-select--selected .bx--text-input {
  padding-left: 3.5rem; }

.theme-white .bx--tabs {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  width: 100%;
  height: auto;
  min-height: 2.5rem;
  color: #161616; }

.theme-white .bx--tabs--container {
  min-height: 3rem; }

.theme-white .bx--tabs__nav {
  display: flex;
  flex-direction: row;
  width: auto;
  max-width: 100%;
  margin: 0;
  padding: 0;
  overflow: auto hidden;
  list-style: none;
  transition: max-height 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  scrollbar-width: none; }
  .theme-white .bx--tabs__nav::-webkit-scrollbar {
    display: none; }

.theme-white .bx--tabs__overflow-indicator--left,
.theme-white .bx--tabs__overflow-indicator--right {
  z-index: 1;
  flex: 1 0 auto;
  width: 0.5rem; }

.theme-white .bx--tabs__overflow-indicator--left {
  margin-right: -0.5rem;
  background-image: linear-gradient(to left, transparent, #ffffff); }

.theme-white .bx--tabs__overflow-indicator--right {
  margin-left: -0.5rem;
  background-image: linear-gradient(to right, transparent, #ffffff); }

.theme-white .bx--tabs--light .bx--tabs__overflow-indicator--left {
  background-image: linear-gradient(to left, transparent, #f4f4f4); }

.theme-white .bx--tabs--light .bx--tabs__overflow-indicator--right {
  background-image: linear-gradient(to right, transparent, #f4f4f4); }

.theme-white .bx--tabs--container .bx--tabs__overflow-indicator--left {
  background-image: linear-gradient(to left, transparent, #e0e0e0); }

.theme-white .bx--tabs--container .bx--tabs__overflow-indicator--right {
  background-image: linear-gradient(to right, transparent, #e0e0e0); }

@media not all and (min-resolution: 0.001dpcm) {
  @supports (-webkit-appearance: none) and (stroke-color: transparent) {
    .theme-white .bx--tabs__overflow-indicator--left {
      margin-right: -1rem;
      background-image: linear-gradient(to left, rgba(255, 255, 255, 0), #ffffff); }
    .theme-white .bx--tabs__overflow-indicator--right {
      margin-left: -1rem;
      background-image: linear-gradient(to right, rgba(255, 255, 255, 0), #ffffff); }
    .theme-white .bx--tabs--container .bx--tabs__overflow-indicator--left {
      background-image: linear-gradient(to left, rgba(224, 224, 224, 0), #e0e0e0); }
    .theme-white .bx--tabs--container
.bx--tabs__overflow-indicator--right {
      background-image: linear-gradient(to right, rgba(224, 224, 224, 0), #e0e0e0); } } }

.theme-white .bx--tab--overflow-nav-button {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: flex;
  flex-shrink: 0;
  align-items: center;
  justify-content: center;
  width: 2.5rem; }
  .theme-white .bx--tab--overflow-nav-button::-moz-focus-inner {
    border: 0; }
  .theme-white .bx--tab--overflow-nav-button:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.theme-white .bx--tab--overflow-nav-button--hidden {
  display: none; }

.theme-white .bx--tabs--container .bx--tab--overflow-nav-button {
  width: 3rem;
  margin: 0;
  background-color: #e0e0e0; }

.theme-white .bx--tab--overflow-nav-button svg {
  fill: #161616; }

.theme-white .bx--tabs__nav-item {
  display: flex;
  padding: 0;
  cursor: pointer;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.theme-white .bx--tabs__nav-item + .bx--tabs__nav-item {
  margin-left: 0.0625rem; }

.theme-white .bx--tabs--container .bx--tabs__nav-item {
  background-color: #e0e0e0; }

.theme-white .bx--tabs--container
.bx--tabs__nav-item
+ .bx--tabs__nav-item {
  margin-left: 0;
  box-shadow: -0.0625rem 0 0 0 #8d8d8d; }

.theme-white .bx--tabs--container
.bx--tabs__nav-item
+ .bx--tabs__nav-item.bx--tabs__nav-item--selected,
.theme-white .bx--tabs--container
.bx--tabs__nav-item.bx--tabs__nav-item--selected
+ .bx--tabs__nav-item {
  box-shadow: none; }

.theme-white .bx--tabs__nav-item .bx--tabs__nav-link {
  transition: color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), border-bottom-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.theme-white .bx--tabs--container .bx--tabs__nav-item:hover {
  background-color: #cacaca; }

.theme-white .bx--tabs__nav-item--disabled,
.theme-white .bx--tabs__nav-item--disabled:hover {
  background-color: transparent;
  outline: none;
  cursor: not-allowed; }

.theme-white .bx--tabs--container
.bx--tabs__nav-item.bx--tabs__nav-item--disabled,
.theme-white .bx--tabs--container
.bx--tabs__nav-item.bx--tabs__nav-item--disabled:hover {
  background-color: #c6c6c6; }

.theme-white .bx--tabs__nav-item--selected {
  transition: color 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.theme-white .bx--tabs__nav-item--selected .bx--tabs__nav-link,
.theme-white .bx--tabs__nav-item--selected .bx--tabs__nav-link:focus,
.theme-white .bx--tabs__nav-item--selected .bx--tabs__nav-link:active {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  color: #161616;
  border-bottom: 2px solid #0f62fe; }

.theme-white .bx--tabs--container .bx--tabs__nav-item--selected,
.theme-white .bx--tabs--container .bx--tabs__nav-item--selected:hover {
  background-color: #f4f4f4; }
  .theme-white .bx--tabs--container .bx--tabs__nav-item--selected .bx--tabs__nav-link:focus,
  .theme-white .bx--tabs--container .bx--tabs__nav-item--selected .bx--tabs__nav-link:active,
  .theme-white .bx--tabs--container .bx--tabs__nav-item--selected:hover .bx--tabs__nav-link:focus,
  .theme-white .bx--tabs--container .bx--tabs__nav-item--selected:hover .bx--tabs__nav-link:active {
    box-shadow: none; }

.theme-white .bx--tabs--container
.bx--tabs__nav-item--selected
.bx--tabs__nav-link {
  line-height: calc(3rem - (0.5rem * 2));
  box-shadow: inset 0 2px 0 0 #0f62fe; }

.theme-white .bx--tabs--light.bx--tabs--container
.bx--tabs__nav-item--selected,
.theme-white .bx--tabs--light.bx--tabs--container
.bx--tabs__nav-item--selected:hover {
  background-color: #ffffff; }

.theme-white .bx--tabs__nav-link {
  outline: 2px solid transparent;
  outline-offset: -2px;
  width: 10rem;
  padding: 0.75rem 1rem 0.5rem;
  overflow: hidden;
  color: #525252;
  white-space: nowrap;
  text-decoration: none;
  text-overflow: ellipsis;
  border-bottom: 2px solid #e0e0e0;
  transition: border 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .theme-white .bx--tabs__nav-link:focus, .theme-white .bx--tabs__nav-link:active {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }

.theme-white .bx--tabs--container .bx--tabs__nav-link {
  height: 3rem;
  padding: 0.5rem 1rem;
  line-height: calc(3rem - (0.5rem * 2));
  border-bottom: 0; }

.theme-white .bx--tabs__nav-item:hover .bx--tabs__nav-link {
  color: #161616;
  border-bottom: 2px solid #8d8d8d; }

.theme-white .bx--tabs--container
.bx--tabs__nav-item
.bx--tabs__nav-link {
  border-bottom: none; }

.theme-white .bx--tabs__nav-item--disabled .bx--tabs__nav-link {
  color: #c6c6c6;
  border-bottom: 2px solid #ffffff; }

.theme-white .bx--tabs__nav-item--disabled:hover .bx--tabs__nav-link {
  color: #c6c6c6;
  border-bottom: 2px solid #ffffff;
  cursor: not-allowed;
  pointer-events: none; }

.theme-white .bx--tabs__nav-item--disabled .bx--tabs__nav-link:focus,
.theme-white .bx--tabs__nav-item--disabled .bx--tabs__nav-link:active {
  border-bottom: 2px solid #ffffff;
  outline: none; }

.theme-white .bx--tabs--light
.bx--tabs__nav-item--disabled
.bx--tabs__nav-link {
  border-bottom-color: #e0e0e0; }

.theme-white .bx--tabs--light
.bx--tabs__nav-item--disabled:hover
.bx--tabs__nav-link {
  border-bottom-color: #e0e0e0; }

.theme-white .bx--tabs--light
.bx--tabs__nav-item--disabled
.bx--tabs__nav-link:focus,
.theme-white .bx--tabs--light
.bx--tabs__nav-item--disabled
.bx--tabs__nav-link:active {
  border-bottom-color: #e0e0e0; }

.theme-white .bx--tabs--container
.bx--tabs__nav-item--disabled
.bx--tabs__nav-link {
  color: #8d8d8d;
  border-bottom: none; }

.theme-white .bx--tab-content {
  padding: 1rem; }

.theme-white .bx--tabs.bx--skeleton {
  cursor: default;
  pointer-events: none; }

.theme-white .bx--tabs.bx--skeleton .bx--tabs__nav-link {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 4.6875rem; }
  .theme-white .bx--tabs.bx--skeleton .bx--tabs__nav-link:hover, .theme-white .bx--tabs.bx--skeleton .bx--tabs__nav-link:focus, .theme-white .bx--tabs.bx--skeleton .bx--tabs__nav-link:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white .bx--tabs.bx--skeleton .bx--tabs__nav-link::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white .bx--tabs.bx--skeleton .bx--tabs__nav-link::before {
        animation: none; } }
.theme-white .bx--tabs.bx--skeleton .bx--tabs-trigger {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 4.6875rem;
  margin-right: 0.0625rem; }
  .theme-white .bx--tabs.bx--skeleton .bx--tabs-trigger:hover, .theme-white .bx--tabs.bx--skeleton .bx--tabs-trigger:focus, .theme-white .bx--tabs.bx--skeleton .bx--tabs-trigger:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white .bx--tabs.bx--skeleton .bx--tabs-trigger::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white .bx--tabs.bx--skeleton .bx--tabs-trigger::before {
        animation: none; } }
.theme-white .bx--tabs.bx--skeleton .bx--tabs-trigger svg {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.theme-white .bx--text-area {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  width: 100%;
  min-width: 10rem;
  height: 100%;
  min-height: 2.5rem;
  padding: 0.6875rem 1rem;
  color: #161616;
  background-color: #f4f4f4;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  transition: background-color 70ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  resize: vertical; }

.theme-white .bx--text-area:focus,
.theme-white .bx--text-area:active {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.theme-white .bx--text-area::placeholder {
  color: #a8a8a8;
  opacity: 1;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.16px; }

.theme-white .bx--text-area--light {
  background-color: #ffffff; }

.theme-white .bx--text-area--invalid {
  padding-right: 2.5rem; }

.theme-white .bx--text-area__wrapper {
  position: relative;
  display: flex;
  width: 100%; }

.theme-white .bx--text-area__invalid-icon {
  position: absolute;
  top: 0.75rem;
  right: 1rem;
  fill: #da1e28; }

.theme-white .bx--text-area:disabled {
  color: #c6c6c6;
  background-color: #ffffff;
  border-bottom: 1px solid transparent;
  outline: none;
  cursor: not-allowed; }

.theme-white .bx--text-area:disabled::placeholder {
  color: #c6c6c6; }

.theme-white .bx--text-area.bx--text-area--light:disabled {
  background-color: #ffffff; }

.theme-white bx--text-area.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  height: 6.25rem; }
  .theme-white bx--text-area.bx--skeleton:hover, .theme-white bx--text-area.bx--skeleton:focus, .theme-white bx--text-area.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white bx--text-area.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white bx--text-area.bx--skeleton::before {
        animation: none; } }
  .theme-white bx--text-area.bx--skeleton::placeholder {
    color: transparent; }

.theme-white .bx--content-switcher {
  display: flex;
  justify-content: space-evenly;
  width: 100%;
  height: 2.5rem; }

.theme-white .bx--content-switcher--disabled {
  cursor: not-allowed; }

.theme-white .bx--content-switcher-btn {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: relative;
  display: inline-flex;
  align-items: center;
  width: 100%;
  margin: 0;
  padding: 0.5rem 1rem;
  overflow: hidden;
  color: #525252;
  white-space: nowrap;
  text-align: left;
  text-decoration: none;
  background-color: #f4f4f4;
  border: none;
  transition: all 70ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .theme-white .bx--content-switcher-btn:focus {
    z-index: 3;
    box-shadow: inset 0 0 0 2px #0f62fe; }
  .theme-white .bx--content-switcher-btn:hover {
    cursor: pointer; }
  .theme-white .bx--content-switcher-btn:hover, .theme-white .bx--content-switcher-btn:active {
    z-index: 3;
    color: #161616;
    background-color: #e5e5e5; }
  .theme-white .bx--content-switcher-btn:disabled {
    color: #c6c6c6;
    background-color: #f4f4f4;
    pointer-events: none; }
    .theme-white .bx--content-switcher-btn:disabled:hover {
      cursor: not-allowed; }

.theme-white .bx--content-switcher--light .bx--content-switcher-btn {
  background-color: #ffffff; }
  .theme-white .bx--content-switcher--light .bx--content-switcher-btn:hover {
    background-color: #e5e5e5; }

.theme-white .bx--content-switcher-btn:first-child {
  border-top-left-radius: 0.25rem;
  border-bottom-left-radius: 0.25rem; }

.theme-white .bx--content-switcher-btn:last-child {
  border-top-right-radius: 0.25rem;
  border-bottom-right-radius: 0.25rem; }

.theme-white .bx--content-switcher-btn::before {
  position: absolute;
  left: 0;
  z-index: 2;
  display: block;
  width: 0.0625rem;
  height: 1rem;
  background-color: #e0e0e0;
  content: ''; }

.theme-white .bx--content-switcher-btn:first-of-type::before {
  display: none; }

.theme-white .bx--content-switcher--light
.bx--content-switcher-btn::before {
  background-color: #e0e0e0; }

.theme-white .bx--content-switcher--light
.bx--content-switcher-btn:focus::before,
.theme-white .bx--content-switcher--light
.bx--content-switcher-btn:focus
+ .bx--content-switcher-btn::before,
.theme-white .bx--content-switcher--light
.bx--content-switcher-btn:hover::before,
.theme-white .bx--content-switcher--light
.bx--content-switcher-btn:hover
+ .bx--content-switcher-btn::before,
.theme-white .bx--content-switcher--light
.bx--content-switcher--selected::before,
.theme-white .bx--content-switcher--light
.bx--content-switcher--selected
+ .bx--content-switcher-btn::before,
.theme-white .bx--content-switcher-btn:focus::before,
.theme-white .bx--content-switcher-btn:focus
+ .bx--content-switcher-btn::before,
.theme-white .bx--content-switcher-btn:hover::before,
.theme-white .bx--content-switcher-btn:hover
+ .bx--content-switcher-btn::before,
.theme-white .bx--content-switcher--selected::before,
.theme-white .bx--content-switcher--selected
+ .bx--content-switcher-btn::before {
  background-color: transparent; }

.theme-white .bx--content-switcher__icon {
  transition: fill 70ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #525252; }

.theme-white .bx--content-switcher__icon + span {
  margin-left: 0.5rem; }

.theme-white .bx--content-switcher__label {
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis; }

.theme-white .bx--content-switcher-btn:hover .bx--content-switcher__icon,
.theme-white .bx--content-switcher-btn:focus .bx--content-switcher__icon {
  fill: #161616; }

.theme-white .bx--content-switcher--light
.bx--content-switcher-btn.bx--content-switcher--selected,
.theme-white .bx--content-switcher-btn.bx--content-switcher--selected {
  z-index: 3;
  color: #ffffff;
  background-color: #161616; }
  .theme-white .bx--content-switcher--light
.bx--content-switcher-btn.bx--content-switcher--selected:disabled,
  .theme-white .bx--content-switcher-btn.bx--content-switcher--selected:disabled {
    color: #c6c6c6;
    background-color: #8d8d8d; }

.theme-white .bx--content-switcher-btn.bx--content-switcher--selected
.bx--content-switcher__icon {
  fill: #ffffff; }

.theme-white .bx--fieldset {
  margin-bottom: 2rem; }

.theme-white .bx--form-item {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
  align-items: flex-start; }

.theme-white .bx--label {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  display: inline-block;
  margin-bottom: 0.5rem;
  color: #525252;
  font-weight: 400;
  line-height: 1rem;
  vertical-align: baseline; }

.theme-white .bx--label .bx--tooltip__trigger {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.theme-white .bx--label.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 4.6875rem;
  height: 0.875rem; }
  .theme-white .bx--label.bx--skeleton:hover, .theme-white .bx--label.bx--skeleton:focus, .theme-white .bx--label.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white .bx--label.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white .bx--label.bx--skeleton::before {
        animation: none; } }
.theme-white input[type='number'] {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace; }

.theme-white input[data-invalid]:not(:focus),
.theme-white .bx--number[data-invalid] input[type='number']:not(:focus),
.theme-white .bx--text-input__field-wrapper[data-invalid]
> .bx--text-input--invalid:not(:focus),
.theme-white .bx--text-area__wrapper[data-invalid]
> .bx--text-area--invalid:not(:focus),
.theme-white .bx--select-input__wrapper[data-invalid]
.bx--select-input:not(:focus),
.theme-white .bx--list-box[data-invalid]:not(:focus),
.theme-white .bx--combo-box[data-invalid] .bx--text-input:not(:focus) {
  outline: 2px solid #da1e28;
  outline-offset: -2px; }

.theme-white input[data-invalid] ~ .bx--form-requirement,
.theme-white [data-invalid] ~ .bx--form-requirement,
.theme-white .bx--number[data-invalid] .bx--number__input-wrapper ~ .bx--form-requirement,
.theme-white .bx--date-picker-input__wrapper ~ .bx--form-requirement,
.theme-white .bx--time-picker--invalid ~ .bx--form-requirement,
.theme-white .bx--text-input__field-wrapper[data-invalid] ~ .bx--form-requirement,
.theme-white .bx--text-input--warn ~ .bx--form-requirement,
.theme-white .bx--text-area__wrapper[data-invalid] ~ .bx--form-requirement,
.theme-white .bx--select-input__wrapper[data-invalid] ~ .bx--form-requirement,
.theme-white .bx--time-picker[data-invalid] ~ .bx--form-requirement,
.theme-white .bx--list-box[data-invalid] ~ .bx--form-requirement {
  display: block;
  max-height: 12.5rem;
  overflow: visible;
  font-weight: 400; }

.theme-white input[data-invalid] ~ .bx--form-requirement,
.theme-white [data-invalid] ~ .bx--form-requirement,
.theme-white .bx--number[data-invalid] .bx--number__input-wrapper ~ .bx--form-requirement,
.theme-white .bx--date-picker-input__wrapper ~ .bx--form-requirement,
.theme-white .bx--time-picker--invalid ~ .bx--form-requirement,
.theme-white .bx--text-input__field-wrapper[data-invalid] ~ .bx--form-requirement,
.theme-white .bx--text-area__wrapper[data-invalid] ~ .bx--form-requirement,
.theme-white .bx--select-input__wrapper[data-invalid] ~ .bx--form-requirement,
.theme-white .bx--time-picker[data-invalid] ~ .bx--form-requirement,
.theme-white .bx--list-box[data-invalid] ~ .bx--form-requirement {
  color: #da1e28; }

.theme-white .bx--form--fluid .bx--text-input__field-wrapper[data-invalid],
.theme-white .bx--form--fluid .bx--text-input__field-wrapper[data-warn] {
  display: block; }

.theme-white .bx--form--fluid .bx--fieldset {
  margin: 0; }

.theme-white .bx--form--fluid input[data-invalid] {
  outline: none; }

.theme-white .bx--form--fluid .bx--form-requirement {
  margin: 0;
  padding: 0.5rem 2.5rem 0.5rem 1rem; }

.theme-white input:not(output):not([data-invalid]):-moz-ui-invalid {
  box-shadow: none; }

.theme-white .bx--form-requirement {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px;
  display: none;
  max-height: 0;
  margin: 0.25rem 0 0;
  overflow: hidden; }

.theme-white .bx--select--inline .bx--form__helper-text {
  margin-top: 0; }

.theme-white .bx--form__helper-text {
  font-size: 0.75rem;
  line-height: 1.34;
  letter-spacing: 0.32px;
  z-index: 0;
  width: 100%;
  margin-top: 0.25rem;
  color: #525252;
  opacity: 1; }

.theme-white .bx--label--disabled,
.theme-white .bx--form__helper-text--disabled {
  color: #c6c6c6; }

.theme-white .bx--date-picker {
  display: flex; }

.theme-white .bx--date-picker--light .bx--date-picker__input {
  background: #ffffff; }

.theme-white .bx--date-picker ~ .bx--label {
  order: 1; }

.theme-white .bx--date-picker-container {
  position: relative;
  display: flex;
  flex-direction: column;
  justify-content: space-between; }

.theme-white .bx--date-picker-input__wrapper {
  position: relative;
  display: flex;
  align-items: center; }

.theme-white .bx--date-picker.bx--date-picker--simple .bx--date-picker__input {
  width: 7.5rem; }

.theme-white .bx--date-picker.bx--date-picker--simple.bx--date-picker--short .bx--date-picker__input {
  width: 5.7rem; }

.theme-white .bx--date-picker.bx--date-picker--single
.bx--date-picker__input {
  width: 18rem; }

.theme-white .bx--date-picker__input {
  font-family: 'IBM Plex Mono', 'Menlo', 'DejaVu Sans Mono', 'Bitstream Vera Sans Mono', Courier, monospace;
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.43;
  letter-spacing: 0.32px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: relative;
  display: block;
  min-width: 9rem;
  height: 2.5rem;
  padding: 0 1rem;
  color: #161616;
  background-color: #f4f4f4;
  border: none;
  border-bottom: 1px solid #8d8d8d;
  transition: 70ms cubic-bezier(0.2, 0, 0.38, 0.9) all; }
  .theme-white .bx--date-picker__input:focus, .theme-white .bx--date-picker__input.bx--focused {
    outline: 2px solid #0f62fe;
    outline-offset: -2px; }
  .theme-white .bx--date-picker__input:disabled {
    color: #c6c6c6;
    background-color: #ffffff;
    border-bottom: 1px solid transparent;
    cursor: not-allowed; }
  .theme-white .bx--date-picker__input:disabled::placeholder {
    color: #c6c6c6; }
  .theme-white .bx--date-picker__input:disabled:hover {
    border-bottom: 1px solid transparent; }
  .theme-white .bx--date-picker__input::placeholder {
    color: #6f6f6f;
    opacity: 1; }

.theme-white .bx--date-picker__input--xl {
  height: 3rem; }

.theme-white .bx--date-picker__input--sm {
  height: 2rem; }

.theme-white .bx--date-picker__icon {
  position: absolute;
  top: 50%;
  right: 1rem;
  z-index: 1;
  transform: translateY(-50%);
  cursor: pointer;
  fill: #161616; }

.theme-white .bx--date-picker__icon ~ .bx--date-picker__input {
  padding-right: 3rem; }

.theme-white .bx--date-picker__input:disabled ~ .bx--date-picker__icon {
  cursor: not-allowed;
  fill: #c6c6c6; }

.theme-white .bx--date-picker--range
> .bx--date-picker-container:first-child {
  margin-right: 0.125rem; }

.theme-white .bx--date-picker--range .bx--date-picker-container,
.theme-white .bx--date-picker--range .bx--date-picker__input {
  width: 8.96875rem; }

.theme-white .bx--date-picker.bx--skeleton input,
.theme-white .bx--date-picker__input.bx--skeleton {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%; }
  .theme-white .bx--date-picker.bx--skeleton input:hover, .theme-white .bx--date-picker.bx--skeleton input:focus, .theme-white .bx--date-picker.bx--skeleton input:active,
  .theme-white .bx--date-picker__input.bx--skeleton:hover,
  .theme-white .bx--date-picker__input.bx--skeleton:focus,
  .theme-white .bx--date-picker__input.bx--skeleton:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white .bx--date-picker.bx--skeleton input::before,
  .theme-white .bx--date-picker__input.bx--skeleton::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white .bx--date-picker.bx--skeleton input::before,
      .theme-white .bx--date-picker__input.bx--skeleton::before {
        animation: none; } }
  .theme-white .bx--date-picker.bx--skeleton input::placeholder,
  .theme-white .bx--date-picker__input.bx--skeleton::placeholder {
    color: transparent; }

.theme-white .bx--date-picker.bx--skeleton .bx--label {
  position: relative;
  padding: 0;
  background: #e5e5e5;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 4.6875rem;
  height: 0.875rem; }
  .theme-white .bx--date-picker.bx--skeleton .bx--label:hover, .theme-white .bx--date-picker.bx--skeleton .bx--label:focus, .theme-white .bx--date-picker.bx--skeleton .bx--label:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-white .bx--date-picker.bx--skeleton .bx--label::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #c6c6c6;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-white .bx--date-picker.bx--skeleton .bx--label::before {
        animation: none; } }
.theme-white .bx--data-table-container {
  padding-top: 0.125rem; }

.theme-white .bx--data-table-content {
  overflow-x: auto; }

.theme-white .bx--data-table-header {
  padding: 1rem 0 1.5rem 1rem;
  background: #f4f4f4; }

.theme-white .bx--data-table-header__title {
  font-size: 1.25rem;
  font-weight: 400;
  line-height: 1.4;
  letter-spacing: 0;
  color: #161616; }

.theme-white .bx--data-table-header__description {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  color: #525252; }

.theme-white .bx--data-table {
  width: 100%;
  border-collapse: collapse;
  border-spacing: 0; }

.theme-white .bx--data-table thead {
  font-size: 0.875rem;
  font-weight: 600;
  line-height: 1.29;
  letter-spacing: 0.16px;
  background-color: #e0e0e0; }

.theme-white .bx--data-table tbody {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  width: 100%;
  background-color: #f4f4f4; }

.theme-white .bx--data-table tr {
  width: 100%;
  height: 3rem;
  border: none; }

.theme-white .bx--data-table tbody tr,
.theme-white .bx--data-table tbody tr td,
.theme-white .bx--data-table tbody tr th {
  transition: background-color 70ms cubic-bezier(0, 0, 0.38, 0.9); }

.theme-white .bx--data-table tbody tr:hover {
  background: #e5e5e5; }

.theme-white .bx--data-table tbody tr:hover td,
.theme-white .bx--data-table tbody tr:hover th {
  color: #161616;
  background: #e5e5e5;
  border-top: 1px solid #e5e5e5;
  border-bottom: 1px solid #e5e5e5; }

.theme-white .bx--data-table th,
.theme-white .bx--data-table td {
  text-align: left;
  vertical-align: middle; }

.theme-white .bx--data-table td {
  padding-right: 1rem;
  padding-left: 1rem; }

.theme-white .bx--data-table th {
  color: #161616;
  background-color: #e0e0e0; }

.theme-white .bx--data-table th:last-of-type {
  position: static;
  width: auto; }

.theme-white .bx--data-table .bx--table-header-label {
  padding-right: 1rem;
  padding-left: 1rem;
  text-align: left; }

.theme-white .bx--data-table td,
.theme-white .bx--data-table tbody th {
  padding-right: 1rem;
  padding-left: 1rem;
  color: #525252;
  background: #f4f4f4;
  border-top: 1px solid #f4f4f4;
  border-bottom: 1px solid #e0e0e0; }
  .theme-white .bx--data-table td + td:first-of-type,
  .theme-white .bx--data-table tbody th + td:first-of-type {
    padding-left: 0.75rem; }

@supports (-moz-appearance: none) {
  .theme-white .bx--data-table td {
    background-clip: padding-box; } }

.theme-white .bx--data-table
td.bx--table-column-menu
.bx--overflow-menu[aria-expanded='false']:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.theme-white .bx--data-table
td.bx--table-column-menu
.bx--overflow-menu[aria-expanded='true']:focus {
  outline: none; }

@media screen and (hover: hover), (-ms-high-contrast: active), (-ms-high-contrast: none) {
  .theme-white .bx--data-table
td.bx--table-column-menu
.bx--overflow-menu
.bx--overflow-menu__icon {
    opacity: 0; } }

.theme-white .bx--data-table
td.bx--table-column-menu
.bx--overflow-menu.bx--overflow-menu--open
.bx--overflow-menu__icon {
  opacity: 1; }

.theme-white .bx--data-table.bx--data-table--visible-overflow-menu
td.bx--table-column-menu
.bx--overflow-menu
.bx--overflow-menu__icon,
.theme-white .bx--data-table
td.bx--table-column-menu
.bx--overflow-menu:hover
.bx--overflow-menu__icon,
.theme-white .bx--data-table
td.bx--table-column-menu
.bx--overflow-menu:focus
.bx--overflow-menu__icon,
.theme-white .bx--data-table
tr:hover
td.bx--table-column-menu
.bx--overflow-menu
.bx--overflow-menu__icon {
  opacity: 1; }

.theme-white .bx--overflow-menu-options__btn
.bx--overflow-menu-options__option-content
svg {
  position: relative;
  top: 0.1875rem;
  margin-right: 0.5rem; }

.theme-white .bx--data-table .bx--overflow-menu:hover,
.theme-white .bx--data-table .bx--overflow-menu__trigger:hover {
  background-color: #cacaca; }

.theme-white .bx--data-table--selected .bx--overflow-menu:hover,
.theme-white .bx--data-table--selected .bx--overflow-menu__trigger:hover {
  background-color: #e5e5e5; }

.theme-white .bx--data-table--compact td.bx--table-column-menu,
.theme-white .bx--data-table--short td.bx--table-column-menu {
  height: 1.5rem;
  padding-top: 0;
  padding-bottom: 0; }

.theme-white .bx--data-table--short td.bx--table-column-menu {
  height: 2rem; }

.theme-white .bx--data-table--tall .bx--table-column-menu {
  padding-top: 0.5rem; }

.theme-white .bx--data-table--zebra
tbody
tr:not(.bx--parent-row):nth-child(even)
td {
  border-bottom: 1px solid #f4f4f4; }

.theme-white .bx--data-table--zebra
tbody
tr:not(.bx--parent-row):nth-child(odd)
td {
  background-color: #f4f4f4;
  border-top: 1px solid #f4f4f4;
  border-bottom: 1px solid #f4f4f4; }

.theme-white .bx--data-table--zebra
tbody
tr:not(.bx--parent-row):hover
td {
  background-color: #e5e5e5;
  border-top: 1px solid #e5e5e5;
  border-bottom: 1px solid #e5e5e5; }

.theme-white .bx--table-column-checkbox .bx--checkbox-label {
  padding-left: 1rem; }

.theme-white .bx--data-table th.bx--table-column-checkbox {
  position: static;
  width: 2.75rem;
  padding-right: 1rem;
  padding-left: 1rem;
  background: #e0e0e0;
  transition: background-color 70ms cubic-bezier(0, 0, 0.38, 0.9); }

.theme-white .bx--data-table thead th.bx--table-column-checkbox,
.theme-white .bx--data-table tbody td.bx--table-column-checkbox,
.theme-white .bx--data-table thead th.bx--table-expand,
.theme-white .bx--data-table tbody td.bx--table-expand {
  min-width: 0;
  padding-right: 0;
  padding-left: 1rem; }

.theme-white .bx--data-table thead th.bx--table-column-checkbox,
.theme-white .bx--data-table tbody td.bx--table-column-checkbox {
  width: 2.25rem; }

.theme-white .bx--data-table thead th.bx--table-expand,
.theme-white .bx--data-table tbody td.bx--table-expand {
  width: 2rem; }

.theme-white .bx--data-table--tall .bx--table-column-checkbox {
  padding-top: 0.8125rem; }

.theme-white .bx--data-table--tall .bx--table-column-radio {
  padding-top: 1rem; }

.theme-white .bx--date-table tbody th.bx--table-column-checkbox:hover {
  background: #cacaca; }

.theme-white .bx--table-column-radio {
  width: 48px; }

.theme-white .bx--table-column-radio .bx--radio-button__appearance {
  margin-right: -0.125rem; }

.theme-white .bx--data-table--zebra
tbody
tr:nth-child(odd).bx--data-table--selected
td,
.theme-white tr.bx--data-table--selected td {
  color: #161616;
  background-color: #e0e0e0;
  border-top: 1px solid #e0e0e0;
  border-bottom: 1px solid #c6c6c6; }

.theme-white .bx--data-table--zebra
tbody
tr:first-of-type:nth-child(odd).bx--data-table--selected
td,
.theme-white tr.bx--data-table--selected:first-of-type td {
  border-top: 1px solid #c6c6c6; }

.theme-white .bx--data-table--zebra
tbody
tr:last-of-type:nth-child(odd).bx--data-table--selected
td,
.theme-white .bx--data-table--zebra
tbody
tr:last-of-type:nth-child(even).bx--data-table--selected
td,
.theme-white tr.bx--data-table--selected:last-of-type td {
  border-top: 1px solid #e0e0e0;
  border-bottom: 1px solid #e0e0e0; }

.theme-white .bx--data-table--zebra
tbody
tr:nth-child(even).bx--data-table--selected
td {
  border-bottom: 1px solid #c6c6c6; }

.theme-white .bx--data-table--zebra
tbody
tr:nth-child(even).bx--data-table--selected:hover
td {
  border-bottom: 1px solid #cacaca; }

.theme-white .bx--data-table--zebra
tbody
tr:nth-child(odd).bx--data-table--selected:hover
td,
.theme-white .bx--data-table tbody .bx--data-table--selected:hover td {
  color: #161616;
  background: #cacaca;
  border-top: 1px solid #cacaca;
  border-bottom: 1px solid #cacaca; }

.theme-white .bx--data-table--selected
.bx--overflow-menu
.bx--overflow-menu__icon {
  opacity: 1; }

.theme-white .bx--data-table--compact thead tr,
.theme-white .bx--data-table--compact tbody tr,
.theme-white .bx--data-table--compact tbody tr th {
  height: 1.5rem; }

.theme-white .bx--data-table--compact .bx--table-header-label {
  padding-top: 0.125rem;
  padding-bottom: 0.125rem; }

.theme-white .bx--data-table--compact td,
.theme-white .bx--data-table--compact tbody tr th {
  padding-top: 0.125rem;
  padding-bottom: 0.125rem; }

.theme-white .bx--data-table--compact .bx--overflow-menu {
  width: 2rem;
  height: 100%; }

.theme-white .bx--data-table.bx--data-table--compact
.bx--table-column-checkbox {
  padding-top: 0;
  padding-bottom: 0; }

.theme-white .bx--data-table.bx--data-table--compact
.bx--table-column-checkbox
.bx--checkbox-label {
  height: 1.4375rem;
  min-height: 1.4375rem; }

.theme-white .bx--data-table--short thead tr,
.theme-white .bx--data-table--short tbody tr,
.theme-white .bx--data-table--short tbody tr th {
  height: 2rem; }

.theme-white .bx--data-table--short .bx--table-header-label {
  padding-top: 0.4375rem;
  padding-bottom: 0.4375rem; }

.theme-white .bx--data-table--short td,
.theme-white .bx--data-table--short tbody tr th {
  padding-top: 0.4375rem;
  padding-bottom: 0.375rem; }

.theme-white .bx--data-table.bx--data-table--short
.bx--table-column-checkbox {
  padding-top: 0.1875rem;
  padding-bottom: 0.1875rem; }

.theme-white .bx--data-table--short .bx--overflow-menu {
  height: 100%; }

.theme-white .bx--data-table--tall thead tr,
.theme-white .bx--data-table--tall tbody tr,
.theme-white .bx--data-table--tall tbody tr th {
  height: 4rem; }

.theme-white .bx--data-table--tall .bx--table-header-label {
  padding-top: 1rem;
  padding-bottom: 1rem; }

.theme-white .bx--data-table--tall td,
.theme-white .bx--data-table--tall tbody tr th {
  padding-top: 1rem; }

.theme-white .bx--data-table--tall th,
.theme-white .bx--data-table--tall td {
  vertical-align: top; }

.theme-white .bx--data-table--cell-secondary-text {
  font-size: 0.75rem;
  font-weight: 400;
  line-height: 1.34;
  letter-spacing: 0.32px; }

.theme-white .bx--data-table--static {
  width: auto; }

.theme-white .bx--data-table_inner-container {
  background-color: #e0e0e0;
  transform: translateZ(0); }

.theme-white .bx--data-table--sticky-header {
  display: block;
  overflow-y: scroll;
  /* When using sticky header, with a selection element in the first column, we need to set the last item to a fixed width to match the table body. We only want this to happen when the last table header does not have any text */ }
  .theme-white .bx--data-table--sticky-header thead,
  .theme-white .bx--data-table--sticky-header tbody,
  .theme-white .bx--data-table--sticky-header tr,
  .theme-white .bx--data-table--sticky-header th,
  .theme-white .bx--data-table--sticky-header td {
    display: flex; }
  .theme-white .bx--data-table--sticky-header thead {
    position: sticky;
    top: 0;
    z-index: 1;
    width: 100%;
    overflow: scroll;
    will-change: transform;
    -ms-overflow-style: none; }
  .theme-white .bx--data-table--sticky-header thead tr th {
    border-bottom: 1px solid #c6c6c6; }
  .theme-white .bx--data-table--sticky-header tbody {
    flex-direction: column;
    overflow-x: scroll;
    -ms-overflow-style: none;
    will-change: transform; }
  .theme-white .bx--data-table--sticky-header tr.bx--parent-row.bx--expandable-row {
    height: auto;
    min-height: 3rem; }
  .theme-white .bx--data-table--sticky-header tr.bx--expandable-row:not(.bx--parent-row) {
    height: auto; }
  .theme-white .bx--data-table--sticky-header .bx--table-expand {
    max-width: 3rem; }
  .theme-white .bx--data-table--sticky-header thead .bx--table-expand {
    align-items: center; }
  .theme-white .bx--data-table--sticky-header .bx--parent-row {
    min-height: 3rem; }
  .theme-white .bx--data-table--sticky-header:not(.bx--data-table--compact):not(.bx--data-table--tall):not(.bx--data-table--short) td:not(.bx--table-column-menu):not(.bx--table-column-checkbox) {
    padding-top: 0.875rem; }
  .theme-white .bx--data-table--sticky-header tr.bx--parent-row.bx--expandable-row:hover
+ tr[data-child-row]
td {
    border-top: 1px solid #e5e5e5; }
  .theme-white .bx--data-table--sticky-header tr.bx--expandable-row:last-of-type {
    overflow: hidden; }
  .theme-white .bx--data-table--sticky-header tr.bx--data-table--selected:first-of-type td {
    border-top: none; }
  .theme-white .bx--data-table--sticky-header thead th.bx--table-column-checkbox,
  .theme-white .bx--data-table--sticky-header tbody tr td.bx--table-column-checkbox {
    align-items: center;
    width: 2.25rem;
    min-width: 2.25rem; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--tall thead th.bx--table-column-checkbox, .theme-white .bx--data-table--sticky-header.bx--data-table--tall td.bx--table-column-checkbox {
    align-items: flex-start; }
  .theme-white .bx--data-table--sticky-header th.bx--table-column-checkbox ~ th:last-of-type:empty {
    max-width: 4rem; }
  .theme-white .bx--data-table--sticky-header th:empty:not(.bx--table-expand) {
    max-width: 2.25rem; }
  .theme-white .bx--data-table--sticky-header td.bx--table-column-menu {
    align-items: center;
    height: auto;
    padding-top: 0; }
  .theme-white .bx--data-table--sticky-header thead::-webkit-scrollbar,
  .theme-white .bx--data-table--sticky-header tbody::-webkit-scrollbar {
    display: none; }

@-moz-document url-prefix() {
  .theme-white .bx--data-table--sticky-header thead,
  .theme-white .bx--data-table--sticky-header tbody {
    scrollbar-width: none; } }
  .theme-white .bx--data-table--sticky-header tbody tr:last-of-type {
    border-bottom: 0; }
  .theme-white .bx--data-table--sticky-header th:not(.bx--table-column-checkbox):not(.bx--table-column-menu):not(.bx--table-expand-v2):not(.bx--table-column-icon),
  .theme-white .bx--data-table--sticky-header td:not(.bx--table-column-checkbox):not(.bx--table-column-menu):not(.bx--table-expand-v2):not(.bx--table-column-icon) {
    width: 100%;
    min-width: 0; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--compact tr:not(.bx--expandable-row), .theme-white .bx--data-table--sticky-header.bx--data-table--short tr:not(.bx--expandable-row), .theme-white .bx--data-table--sticky-header.bx--data-table--tall tr:not(.bx--expandable-row) {
    height: auto; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--compact tr:not(.bx--expandable-row) {
    min-height: 1.5rem; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--short tr:not(.bx--expandable-row) {
    min-height: 2rem; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--tall tr:not(.bx--expandable-row) {
    min-height: 4rem; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--compact tr td.bx--table-expand {
    padding-top: 0.25rem; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--short tr td.bx--table-expand {
    padding-top: 0.5rem; }
  .theme-white .bx--data-table--sticky-header .bx--table-header-label {
    display: block;
    overflow-x: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    max-width: calc(100% - 10px);
    padding-top: 0.9375rem;
    padding-bottom: 1rem;
    overflow-y: hidden; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--compact th .bx--table-header-label {
    padding-top: 0.1875rem;
    padding-bottom: 0; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--short th .bx--table-header-label {
    padding-top: 0.5rem;
    padding-bottom: 0; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--tall th .bx--table-header-label {
    padding-top: 1rem; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--tall th.bx--table-expand {
    display: flex;
    align-items: flex-start; }
  .theme-white .bx--data-table--sticky-header.bx--data-table--compact tr.bx--parent-row
.bx--table-column-checkbox, .theme-white .bx--data-table--sticky-header.bx--data-table--short tr.bx--parent-row
.bx--table-column-checkbox {
    align-items: flex-start; }

.theme-white .bx--data-table--max-width {
  max-width: 100%; }

.theme-white .bx--data-table--sticky-header {
  max-height: 18.75rem; }

.theme-white .bx--data-table .bx--form-item.bx--checkbox-wrapper:last-of-type {
  margin: 0; }

.theme-white .bx--data-table--short
.bx--form-item.bx--checkbox-wrapper:last-of-type,
.theme-white .bx--data-table--compact
.bx--form-item.bx--checkbox-wrapper:last-of-type {
  margin: -0.1875rem 0; }

.theme-white .bx--table-toolbar {
  position: relative;
  display: flex;
  width: 100%;
  height: 3rem;
  overflow: hidden;
  background: #f4f4f4; }

.theme-white .bx--toolbar-content {
  display: flex;
  justify-content: flex-end;
  width: 100%;
  height: 3rem;
  transform: translate3d(0, 0, 0);
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9), clip-path 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.theme-white .bx--batch-actions ~ .bx--toolbar-content {
  clip-path: polygon(0 0, 100% 0, 100% 100%, 0 100%); }

.theme-white .bx--toolbar-content .bx--search .bx--search-input {
  background-color: transparent; }

.theme-white .bx--batch-actions ~ .bx--toolbar-search-container {
  display: flex;
  align-items: center;
  opacity: 1;
  transition: opacity 110ms; }

.theme-white .bx--toolbar-search-container-expandable {
  position: relative;
  width: 3rem;
  height: 3rem;
  box-shadow: none;
  transition: flex 240ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.theme-white .bx--toolbar-search-container-expandable .bx--search {
  position: initial;
  width: 3rem;
  height: 100%; }

.theme-white .bx--toolbar-search-container-expandable
.bx--search
.bx--search-magnifier {
  left: 0;
  width: 3rem;
  height: 3rem;
  padding: 1rem;
  cursor: pointer;
  transition: background 110ms cubic-bezier(0, 0, 0.38, 0.9);
  pointer-events: all; }

.theme-white .bx--toolbar-search-container-expandable
.bx--search
.bx--search-magnifier:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.theme-white .bx--toolbar-search-container-expandable
.bx--search
.bx--search-magnifier:hover {
  background: #e5e5e5; }

.theme-white .bx--toolbar-search-container-expandable
.bx--search
.bx--label {
  visibility: hidden; }

.theme-white .bx--toolbar-search-container-expandable
.bx--search
.bx--search-input {
  height: 100%;
  padding: 0;
  background-color: transparent;
  border: none;
  visibility: hidden; }

.theme-white .bx--toolbar-search-container-expandable
.bx--search
.bx--search-close {
  width: 3rem;
  height: 3rem; }
  .theme-white .bx--toolbar-search-container-expandable
.bx--search
.bx--search-close::before {
    top: 2px;
    height: calc(100% - 4px);
    background-color: #e5e5e5; }

.theme-white .bx--toolbar-search-container-expandable
.bx--search
.bx--search-close:focus::before {
  background-color: #0f62fe; }

.theme-white .bx--toolbar-search-container-active {
  flex: auto;
  transition: flex 150ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.theme-white .bx--toolbar-search-container-active .bx--search {
  width: 100%; }

.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--label,
.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-input {
  padding: 0 3rem;
  visibility: inherit; }

.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-input:focus {
  outline: 2px solid #0f62fe;
  outline-offset: -2px;
  box-shadow: inset 0 0 0 2px #0f62fe; }

.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-input:focus
+ .bx--search-close {
  border: none;
  outline: none;
  box-shadow: none; }

.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-input:not(:placeholder-shown) {
  background: #e5e5e5;
  border: none; }

.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:focus,
.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:active,
.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:hover {
  background: transparent;
  border: none;
  outline: none; }

.theme-white .bx--toolbar-search-container-persistent .bx--search-close,
.theme-white .bx--toolbar-search-container-persistent
.bx--search-close:hover,
.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-close,
.theme-white .bx--toolbar-search-container-active
.bx--search
.bx--search-close:hover {
  background-color: transparent;
  border: none; }

.theme-white .bx--toolbar-search-container-persistent
.bx--search-close::before {
  display: none; }

.theme-white .bx--overflow-menu.bx--toolbar-action {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: flex;
  width: 3rem;
  height: 3rem;
  padding: 1rem;
  cursor: pointer;
  transition: background 110ms cubic-bezier(0, 0, 0.38, 0.9); }
  .theme-white .bx--overflow-menu.bx--toolbar-action::-moz-focus-inner {
    border: 0; }

.theme-white .bx--toolbar-action {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  width: 100%;
  display: flex;
  width: 3rem;
  height: 3rem;
  cursor: pointer;
  transition: background 110ms cubic-bezier(0, 0, 0.38, 0.9); }
  .theme-white .bx--toolbar-action::-moz-focus-inner {
    border: 0; }

.theme-white .bx--toolbar-action:hover:not([disabled]) {
  background: #e5e5e5; }

.theme-white .bx--toolbar-action:hover[aria-expanded='true'] {
  background: #f4f4f4; }

.theme-white .bx--toolbar-action[disabled] {
  cursor: not-allowed; }

.theme-white .bx--toolbar-action[disabled] .bx--toolbar-action__icon {
  cursor: not-allowed;
  fill: #c6c6c6; }

.theme-white .bx--toolbar-action:focus:not([disabled]),
.theme-white .bx--toolbar-action:active:not([disabled]) {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }
  .theme-white .bx--toolbar-action:focus:not([disabled]).bx--toolbar-search-container-expandable,
  .theme-white .bx--toolbar-action:active:not([disabled]).bx--toolbar-search-container-expandable {
    outline: none; }

.theme-white .bx--toolbar-action ~ .bx--btn {
  max-width: none;
  margin: 0;
  white-space: nowrap; }

.theme-white .bx--overflow-menu--data-table {
  height: 3rem; }

.theme-white .bx--toolbar-action__icon {
  width: auto;
  max-width: 1rem;
  height: 1rem;
  fill: #161616; }

.theme-white .bx--toolbar-search-container-persistent {
  position: relative;
  width: 100%;
  height: 3rem;
  opacity: 1; }

.theme-white .bx--toolbar-search-container-persistent
+ .bx--toolbar-content {
  position: relative;
  width: auto; }

.theme-white .bx--toolbar-search-container-persistent .bx--search {
  position: initial; }

.theme-white .bx--toolbar-search-container-persistent
.bx--search
.bx--search-magnifier {
  left: 1rem; }

.theme-white .bx--toolbar-search-container-persistent
.bx--search
.bx--search-input {
  height: 3rem;
  padding: 0 3rem;
  border: none; }

.theme-white .bx--toolbar-search-container-persistent
.bx--search
.bx--search-input:focus:not([disabled]) {
  outline: 2px solid #0f62fe;
  outline-offset: -2px; }

.theme-white .bx--toolbar-search-container-persistent
.bx--search
.bx--search-input:hover:not([disabled]) {
  background: #e5e5e5; }

.theme-white .bx--toolbar-search-container-persistent
.bx--search
.bx--search-input:active:not([disabled]),
.theme-white .bx--toolbar-search-container-persistent
.bx--search
.bx--search-input:not(:placeholder-shown) {
  background: #e5e5e5; }

.theme-white .bx--toolbar-search-container-persistent
.bx--search
.bx--search-close {
  width: 3rem;
  height: 3rem; }

.theme-white .bx--batch-actions--active ~ .bx--toolbar-search-container,
.theme-white .bx--batch-actions--active ~ .bx--toolbar-content {
  transform: translate3d(0, 48px, 0);
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9), clip-path 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  clip-path: polygon(0 0, 100% 0, 100% 0, 0 0); }

.theme-white .bx--batch-actions {
  position: absolute;
  top: 0;
  left: 0;
  display: flex;
  align-items: center;
  width: 100%;
  height: 100%;
  padding-right: 1.5rem;
  padding-left: 1.5rem;
  overflow-x: auto;
  background-color: #0f62fe;
  transform: translate3d(0, 48px, 0);
  transition: transform 110ms cubic-bezier(0.2, 0, 0.38, 0.9), clip-path 110ms cubic-bezier(0.2, 0, 0.38, 0.9), opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  clip-path: polygon(0 0, 100% 0, 100% 0, 0 0);
  pointer-events: none;
  will-change: transform; }

.theme-white .bx--batch-actions:focus {
  outline: 1px solid #0f62fe; }

.theme-white .bx--batch-actions--active {
  transform: translate3d(0, 0, 0);
  clip-path: polygon(0 0, 100% 0, 100% 100%, 0 100%);
  pointer-events: all; }

.theme-white .bx--action-list {
  position: absolute;
  right: 0;
  display: flex; }

.theme-white .bx--action-list .bx--btn {
  min-width: 0;
  padding: calc(0.875rem - 3px) 12px;
  color: #ffffff; }

.theme-white .bx--action-list .bx--btn:disabled {
  color: #8d8d8d; }

.theme-white .bx--action-list .bx--btn .bx--btn__icon {
  position: static;
  margin-left: 0.5rem;
  fill: #ffffff; }

.theme-white .bx--action-list .bx--btn .bx--btn__icon .st0 {
  fill: none; }

.theme-white .bx--batch-download {
  padding: 0.0625rem; }

.theme-white .bx--action-list .bx--btn--primary:focus::before,
.theme-white .bx--action-list .bx--btn--primary::before,
.theme-white .bx--action-list .bx--btn--primary:focus::after,
.theme-white .bx--action-list .bx--btn--primary::after {
  display: none; }

.theme-white .bx--action-list .bx--btn--primary:focus {
  outline: 2px solid #f4f4f4;
  outline-offset: -0.125rem; }

.theme-white .bx--action-list
.bx--btn--primary:nth-child(3):hover
+ .bx--btn--primary.bx--batch-summary__cancel::before,
.theme-white .bx--action-list
.bx--btn--primary:nth-child(3):focus
+ .bx--btn--primary.bx--batch-summary__cancel::before {
  opacity: 0; }

.theme-white .bx--btn--primary.bx--batch-summary__cancel::before {
  position: absolute;
  top: 0.9375rem;
  left: 0;
  display: block;
  width: 0.0625rem;
  height: 1rem;
  background-color: #ffffff;
  border: none;
  opacity: 1;
  transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  content: ''; }

.theme-white .bx--btn--primary.bx--batch-summary__cancel:hover::before {
  opacity: 0;
  transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9); }

.theme-white .bx--batch-summary__cancel {
  position: relative;
  padding-right: 1rem; }

.theme-white .bx--batch-summary {
  position: absolute;
  left: 0;
  display: flex;
  align-items: center;
  margin-left: 1rem;
  color: #ffffff; }

.theme-white .bx--batch-summary__para {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px; }

.theme-white .bx--table-toolbar--small {
  height: 2rem; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-expandable,
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-persistent {
    height: 2rem; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-expandable
.bx--search
.bx--search-input,
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-persistent
.bx--search
.bx--search-input {
    height: 2rem; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-expandable
.bx--search
.bx--search-close,
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-persistent
.bx--search
.bx--search-close {
    width: 2rem;
    height: 2rem; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-expandable
.bx--search
.bx--search-magnifier,
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-persistent
.bx--search
.bx--search-magnifier {
    width: 2rem;
    height: 2rem;
    padding: 0.5rem; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-expandable {
    width: 2rem; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-expandable
.bx--search
.bx--search-input {
    padding: 0 3rem; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-active {
    flex: auto;
    transition: flex 175ms cubic-bezier(0.2, 0, 0.38, 0.9); }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-input {
    visibility: inherit; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-input:focus {
    outline: 2px solid #0f62fe;
    outline-offset: -2px;
    background: #e5e5e5; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-input:active,
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-input:not(:placeholder-shown) {
    background: #e5e5e5; }
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:focus,
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:active,
  .theme-white .bx--table-toolbar--small .bx--toolbar-search-container-active
.bx--search
.bx--search-magnifier:hover {
    outline: 2px solid transparent;
    outline-offset: -2px;
    background: transparent; }

.theme-white .bx--table-toolbar--small
.bx--batch-actions
.bx--action-list {
  height: 2rem; }

.theme-white .bx--table-toolbar--small .bx--toolbar-action {
  width: 2rem;
  height: 2rem;
  padding: 0.5rem 0; }

.theme-white .bx--table-toolbar--small .bx--btn--primary {
  height: 2rem;
  min-height: auto;
  padding-top: calc(0.375rem - 3px);
  padding-bottom: calc(0.375rem - 3px); }

.theme-white .bx--table-toolbar--small
.bx--btn--primary.bx--batch-summary__cancel::before {
  top: 0.5rem; }

.theme-white .bx--table-toolbar--small
.bx--toolbar-action
~ .bx--btn {
  height: 2rem;
  overflow: hidden; }

.theme-white .bx--text-area:disabled, .theme-white .bx--text-area:hover:disabled {
  background-color: #f4f4f4; }

.theme-white .bx--select-input:disabled, .theme-white .bx--select-input:hover:disabled {
  background-color: #f4f4f4; }

.theme-white .bx--date-picker__input:disabled, .theme-white .bx--date-picker__input:hover:disabled {
  background-color: #f4f4f4; }

.theme-gray-100 .bx--search {
  position: relative;
  display: flex;
  align-items: center;
  width: 100%; }

.theme-gray-100 .bx--search .bx--label {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  visibility: inherit;
  clip: rect(0, 0, 0, 0); }

.theme-gray-100 .bx--search-input {
  font-size: 0.875rem;
  font-weight: 400;
  line-height: 1.29;
  letter-spacing: 0.16px;
  outline: 2px solid transparent;
  outline-offset: -2px;
  order: 1;
  width: 100%;
  padding: 0 2.5rem;
  color: #f4f4f4;
  text-overflow: ellipsis;
  background-color: #262626;
  border: none;
  border-bottom: 1px solid #6f6f6f;
  transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  appearance: none; }
  .theme-gray-100 .bx--search-input:focus {
    outline: 2px solid #ffffff;
    outline-offset: -2px; }
  .theme-gray-100 .bx--search-input::placeholder {
    color: #8d8d8d;
    font-weight: 400; }
  .theme-gray-100 .bx--search-input::-ms-clear {
    display: none; }

.theme-gray-100 .bx--search-input[disabled] {
  color: #c6c6c6;
  background-color: #ffffff;
  border-bottom: 1px solid transparent;
  cursor: not-allowed; }
  .theme-gray-100 .bx--search-input[disabled]::placeholder {
    color: #c6c6c6;
    font-weight: 400; }

.theme-gray-100 .bx--search-input[disabled] ~ .bx--search-magnifier {
  fill: #c6c6c6; }

.theme-gray-100 .bx--search--light .bx--search-input {
  background: #393939; }

.theme-gray-100 .bx--search--sm .bx--search-input {
  height: 2rem;
  padding: 0 2rem; }

.theme-gray-100 .bx--search--sm .bx--search-magnifier {
  left: 0.5rem; }

.theme-gray-100 .bx--search--lg .bx--search-input {
  height: 2.5rem;
  padding: 0 2.5rem; }

.theme-gray-100 .bx--search--lg .bx--search-magnifier {
  left: 0.75rem; }

.theme-gray-100 .bx--search--xl .bx--search-input {
  height: 3rem;
  padding: 0 3rem; }

.theme-gray-100 .bx--search-magnifier {
  position: absolute;
  top: 50%;
  left: 1rem;
  z-index: 2;
  width: 1rem;
  height: 1rem;
  transform: translateY(-50%);
  pointer-events: none;
  fill: #c6c6c6; }

.theme-gray-100 .bx--search-close {
  display: inline-block;
  padding: 0;
  background: none;
  border: 0;
  cursor: pointer;
  appearance: none;
  outline: 2px solid transparent;
  outline-offset: -2px;
  position: absolute;
  top: 0;
  right: 0; }
  .theme-gray-100 .bx--search-close::-moz-focus-inner {
    border: 0; }
  .theme-gray-100 .bx--search-close::before {
    position: absolute;
    top: 0.0625rem;
    left: 0;
    display: block;
    width: 2px;
    height: calc(100% - 2px);
    background-color: #262626;
    transition: background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
    content: ''; }
  .theme-gray-100 .bx--search-close:hover {
    border-bottom: 1px solid #6f6f6f; }
    .theme-gray-100 .bx--search-close:hover::before {
      background-color: #353535; }

.theme-gray-100 .bx--search-button {
  flex-shrink: 0;
  margin-left: 0.125rem;
  background-color: #262626; }
  .theme-gray-100 .bx--search-button svg {
    vertical-align: middle;
    fill: currentColor; }

.theme-gray-100 .bx--search-close svg {
  fill: inherit; }

.theme-gray-100 .bx--search-close,
.theme-gray-100 .bx--search-button {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2.5rem;
  height: 2.5rem;
  border-color: transparent;
  border-style: solid;
  border-width: 1px 0;
  visibility: inherit;
  cursor: pointer;
  opacity: 1;
  transition: opacity 110ms cubic-bezier(0.2, 0, 0.38, 0.9), background-color 110ms cubic-bezier(0.2, 0, 0.38, 0.9), outline 110ms cubic-bezier(0.2, 0, 0.38, 0.9), border 110ms cubic-bezier(0.2, 0, 0.38, 0.9);
  fill: #f4f4f4; }
  .theme-gray-100 .bx--search-close:hover,
  .theme-gray-100 .bx--search-button:hover {
    background-color: #353535; }
  .theme-gray-100 .bx--search-close:focus,
  .theme-gray-100 .bx--search-button:focus {
    outline: 2px solid #ffffff;
    outline-offset: -2px; }
  .theme-gray-100 .bx--search-close:active,
  .theme-gray-100 .bx--search-button:active {
    outline: 2px solid #ffffff;
    outline-offset: -2px;
    background-color: #393939; }

.theme-gray-100 .bx--search-close:focus::before,
.theme-gray-100 .bx--search-close:active::before {
  background-color: #ffffff; }

.theme-gray-100 .bx--search-input:focus ~ .bx--search-close:hover {
  outline: 2px solid #ffffff;
  outline-offset: -2px; }

.theme-gray-100 .bx--search--sm .bx--search-close,
.theme-gray-100 .bx--search--sm ~ .bx--search-button {
  width: 2rem;
  height: 2rem; }

.theme-gray-100 .bx--search--lg .bx--search-close,
.theme-gray-100 .bx--search--lg ~ .bx--search-button {
  width: 2.5rem;
  height: 2.5rem; }

.theme-gray-100 .bx--search--xl .bx--search-close,
.theme-gray-100 .bx--search--xl ~ .bx--search-button {
  width: 3rem;
  height: 3rem; }

.theme-gray-100 .bx--search-close--hidden {
  visibility: hidden;
  opacity: 0; }

.theme-gray-100 .bx--search--xl.bx--skeleton .bx--search-input,
.theme-gray-100 .bx--search--lg.bx--skeleton .bx--search-input,
.theme-gray-100 .bx--search--sm.bx--skeleton .bx--search-input {
  position: relative;
  padding: 0;
  background: #353535;
  border: none;
  box-shadow: none;
  pointer-events: none;
  width: 100%; }
  .theme-gray-100 .bx--search--xl.bx--skeleton .bx--search-input:hover, .theme-gray-100 .bx--search--xl.bx--skeleton .bx--search-input:focus, .theme-gray-100 .bx--search--xl.bx--skeleton .bx--search-input:active,
  .theme-gray-100 .bx--search--lg.bx--skeleton .bx--search-input:hover,
  .theme-gray-100 .bx--search--lg.bx--skeleton .bx--search-input:focus,
  .theme-gray-100 .bx--search--lg.bx--skeleton .bx--search-input:active,
  .theme-gray-100 .bx--search--sm.bx--skeleton .bx--search-input:hover,
  .theme-gray-100 .bx--search--sm.bx--skeleton .bx--search-input:focus,
  .theme-gray-100 .bx--search--sm.bx--skeleton .bx--search-input:active {
    border: none;
    outline: none;
    cursor: default; }
  .theme-gray-100 .bx--search--xl.bx--skeleton .bx--search-input::before,
  .theme-gray-100 .bx--search--lg.bx--skeleton .bx--search-input::before,
  .theme-gray-100 .bx--search--sm.bx--skeleton .bx--search-input::before {
    position: absolute;
    top: 0;
    left: 0;
    width: 0%;
    height: 100%;
    background: #393939;
    animation: 3000ms ease-in-out skeleton infinite;
    content: ''; }
    @media (prefers-reduced-motion: reduce) {
      .theme-gray-100 .bx--search--xl.bx--skeleton .bx--search-input::before,
      .theme-gray-100 .bx--search--lg.bx--skeleton .bx--search-input::before,
      .theme-gray-100 .bx--search--sm.bx--skeleton .bx--search-input::before {
        animation: none; } }
  .theme-gray-100 .bx--search--xl.bx--skeleton .bx--search-input::placeholder,
  .theme-gray-100 .bx--search--lg.bx--skeleton .bx--search-input::placeholder,
  .theme-gray-100 .bx--search--sm.bx--skeleton .bx--search-input::placeholder {
    color: transparent; }

.bx--data-table .bx--text-area:disabled, .bx--data-table .bx--text-area:hover:disabled {
  border-bottom: none; }

.bx--data-table .bx--select-input:disabled, .bx--data-table .bx--select-input:hover:disabled {
  border-bottom: none; }

.bx--data-table .bx--date-picker__input {
  border-bottom: none; }

.bx--data-table .bx--select-input {
  border-bottom: none; }

.bx--data-table .bx--search-input {
  border-bottom: none; }

.tile-container .tile-col:nth-of-type(2n) {
  border-left: 1px solid #e0e0e0; }

.tile-container .tile {
  border-top: 1px solid #e0e0e0;
  padding: 4rem;
  background-color: white; }
  .tile-container .tile h4 {
    margin-top: 0; }

.tile-container .bx--data-table-container {
  padding-top: 0; }

a.bx--header__name {
  padding: 0 .5rem 0 .5rem; }

.bx--modal-container {
  min-height: 20rem; }
  .bx--modal-container .bx--modal-content--overflow-indicator {
    z-index: 9999; }

.bx--data-table-container .bx--file-container {
  display: inline-block;
  margin-top: 0; }

.bx--modal-content {
  padding-bottom: 2rem; }

